﻿(function () {
'using strict';
WinJS.Namespace.define("SportsJS.Controls.Components", {
StickyHeaderAnimator: WinJS.Class.define(function (listContainerWrapper, listContainer, headerElements) {
var that = this;
if (!listContainerWrapper || !listContainer || !headerElements) {
SportsJS.Controls.Utilities.interfaceException(this._name, "invalid StickyHeaderAnimator configuration");
return null;
}
that._listContainerWrapper = listContainerWrapper;
that._listContainer = listContainer;
that._stickyHeaderContainer = SportsJS.Controls.Utilities.createDivWithClassName("stickyHeaderContainer");
that._listContainerWrapper.insertBefore(that._stickyHeaderContainer, that._listContainer);
that._headerElements = headerElements;
that._setupStickyZones();
//// setup event listener manager
that._evtListenerManager = new SportsJS.Controls.Utilities.EventListenerManager();
that._evtListenerManager.addEventListener(that._listContainer, "scroll", that._animate, that);
//// For all the listContainer items, listen to onfocus. When in focus but hidden behind sticky header, we need to scroll down
that._attachOnFocus();
that._animate();
}, {
//// Private variables            
_name: "SportsJS.Controls.Components.StickyHeaderAnimator",
_listContainer: null,
_listContainerWrapper: null,
_stickyHeaderContainer: null,
_headerElements: null,
_headerBinding: null,
_stickyZones: null,
_scrollPos: 0,
_dir: null,
_animating: false,
_curStickyZone: null,
_curHeaderEl: null,
_curStickyHeaderEl: null,
_isObjectValid: true,
_evtListenerManager: null,
//// Public properties
//// Private Properties
//// Private functions          
_animate: function _animate() {
var that = this;
var scrollPos = that._listContainer.scrollTop;
if (scrollPos === 0) {
WinJS.Utilities.addClass(that._stickyHeaderContainer, "hidden");
} else {
WinJS.Utilities.removeClass(that._stickyHeaderContainer, "hidden");
}
if (scrollPos === that._scrollPos) {
return;
}
that._dir = scrollPos > that._scrollPos ? "up" : "down";
that._scrollPos = scrollPos;
that._curStickyZone = that._getCurStickyZone();
if (!that._curStickyZone) {
return;
}
if (that._dir === "up") {
that._pushUp();
} else {
that._pushDown();
}
},
//// Original header is animated-out to insert final header
_pushUp: function _pushUp() {
var that = this;
if (!that._curStickyZone.finalHeader) {
return;
}
//// If final header is already inserted, do nothing
if (that._curHeaderEl === that._curStickyZone.finalHeader.element) {
return;
}
//// Check if we should animate, else push final header
var animating = that._shouldAnimate() && !!that._curStickyZone.origHeader;
if (animating) {
//// Make sure the current sticky header element is current sticky zone's original header element which will be pushed up
if (that._curHeaderEl !== that._curStickyZone.origHeader.element) {
that._insertStickyHeader(that._curStickyZone.origHeader);
}
//// How much is scrolled out of container
that._curStickyHeaderEl.style.top = that._curStickyZone.animZone.start - that._scrollPos + "px";
} else {
that._insertStickyHeader(that._curStickyZone.finalHeader);
}
},
//// Final header is inserted and animated-in
_pushDown: function _pushDown() {
var that = this;
if (!that._curStickyZone.finalHeader) {
return;
}
//// Insert final header if not already there
if (that._curHeaderEl !== that._curStickyZone.finalHeader.element) {
that._insertStickyHeader(that._curStickyZone.finalHeader);
}
//// Check if we should animate, else end animation
var animating = that._shouldAnimate();
if (animating) {
that._curStickyHeaderEl.style.top = that._curStickyZone.animZone.start - that._scrollPos + "px";
} else {
that._curStickyHeaderEl.style.top = "0px";
}
},
_insertStickyHeader: function _insertStickyHeader(header) {
var that = this;
if (!header) {
return;
}
that._stickyHeaderContainer.innerHTML = "";
that._stickyHeaderContainer.style.height = header.height + "px";
that._stickyHeaderContainer.style.width = header.width + "px";
var stickyHeader = header.element.cloneNode(true);
////Prevent the sticky Header from becoming navigable through tab & prevent id clash
stickyHeader.tabIndex = -2;
stickyHeader.id += "_sh";
WinJS.Utilities.addClass(stickyHeader, "stickyHeader");
that._stickyHeaderContainer.appendChild(stickyHeader);
that._curHeaderEl = header.element;
that._curStickyHeaderEl = stickyHeader;
that._evtListenerManager.addEventListener(that._curStickyHeaderEl, "click", that._curStickyHeaderOnClick, that);
},
_curStickyHeaderOnClick: function _curStickyHeaderOnClick(event) {
var that = this;
SportsJS.Controls.Utilities.dispatchCustomEvent(that._curHeaderEl, "click", event.detail);
},
_setupStickyZones: function _setupStickyZones() {
var that = this;
var i;
var headerElements = that._headerElements;
that._stickyZones = {};
that._stickyZones['up'] = [];
that._stickyZones['down'] = [];
for (i = 0; i < headerElements.length; i++) {
var headerEl = headerElements[i];
var prevHeaderEl = headerElements[i - 1];
var nextHeaderEl = headerElements[i + 1];
var header = { element: headerEl, height: headerEl.clientHeight, width: headerEl.clientWidth, offsetTop: headerEl.offsetTop };
var prevHeader = prevHeaderEl ? { element: prevHeaderEl, height: prevHeaderEl.clientHeight, width: prevHeaderEl.clientWidth, offsetTop: headerEl.offsetTop } : null;
var nextHeader = nextHeaderEl ? { element: nextHeaderEl, height: nextHeaderEl.clientHeight, width: nextHeaderEl.clientWidth, offsetTop: nextHeaderEl.offsetTop } : null;
//// During pushUp, header pushes the prev header up.
that._stickyZones['up'][i] = {
animZone: {
start: prevHeader ? header.offsetTop - prevHeader.height : header.offsetTop,
end: header.offsetTop - 1,
},
origHeader: prevHeader,
finalHeader: header,
};
//// During pushDown, header pushes the next header down.
that._stickyZones['down'][i] = {
animZone: {
start: nextHeader ? nextHeader.offsetTop - header.height + 1 : Number.POSITIVE_INFINITY,
end: nextHeader ? nextHeader.offsetTop : Number.POSITIVE_INFINITY,
},
origHeader: nextHeader,
finalHeader: header,
};
}
var curStickyZone = null;
var nextStickyZone = null;
var prevStickyZone = null;
for (i = 0; i < headerElements.length; i++) {
//// For up
curStickyZone = that._stickyZones['up'][i];
nextStickyZone = that._stickyZones['up'][i + 1];
curStickyZone.zone = {
start: curStickyZone.animZone.start,
end: nextStickyZone ? nextStickyZone.animZone.start - 1 : Number.POSITIVE_INFINITY,
};
//// For down
prevStickyZone = that._stickyZones['down'][i - 1];
curStickyZone = that._stickyZones['down'][i];
curStickyZone.zone = {
start: prevStickyZone ? prevStickyZone.animZone.end + 1 : 0,
end: curStickyZone.animZone.end,
};
}
},
_getCurStickyZone: function _getCurStickyZone() {
var that = this;
var stickyZones = that._stickyZones[that._dir];
var curStickyZone = null;
for (var i = 0; i < stickyZones.length; i++) {
curStickyZone = stickyZones[i];
if (curStickyZone.zone.start <= that._scrollPos && that._scrollPos <= curStickyZone.zone.end) {
return curStickyZone;
}
}
return null;
},
_shouldAnimate: function _shouldAnimate() {
var that = this;
if (that._curStickyZone.animZone.start <= that._scrollPos && that._scrollPos <= that._curStickyZone.animZone.end) {
return true;
}
return false;
},
_attachOnFocus: function _attachOnFocus() {
var that = this;
for (var i = 0; i < that._listContainer.children.length; i++) {
var item = that._listContainer.children[i];
that._evtListenerManager.addEventListener(item, "focus", that._onListItemFocus, that);
}
},
//// Make sure the list item in focus is not hidden behind sticky header
_onListItemFocus: function _onListItemFocus(evt) {
var that = this;
if (!evt || !evt.srcElement || !that._curStickyHeaderEl) {
return;
}
var scrollPos = that._listContainer.scrollTop;
var offsetTop = evt.srcElement.offsetTop;
var curStickyHeaderHeight = that._curStickyHeaderEl.clientHeight;
if (scrollPos !== 0 && offsetTop - curStickyHeaderHeight < scrollPos && scrollPos <= offsetTop) {
that._listContainer.scrollTop = offsetTop - curStickyHeaderHeight;
}
},
//// Public functions
cleanUp: function cleanUp() {
var that = this;
//// Remove event listeners
that._evtListenerManager.purgeEventListeners();
//// remove stickyHeaderContainer
that._listContainerWrapper.removeChild(that._stickyHeaderContainer);
SportsJS.Controls.Utilities.setObjectPropertiesToNull(that);
that._isObjectValid = false;
},
}, {
})
});
})();