﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.Controls.ViewControls",
{
/// <summary>
/// ListControl - view control to render list of items + chrome (optional). 
/// </summary>
ListControl: WinJS.Class.derive(SportsJS.Controls.ViewControls.ViewControlBase, function ListControl_constructor(element, config) {
SportsJS.Controls.ViewControls.ViewControlBase.call(this, element, config);
WinJS.Utilities.addClass(this._element, "listControl");
this._scrollHandler = this._onScroll.bind(this);
this._tabClickHandler = this._onTabClick.bind(this);
}, {
type: "ListControl",
_name: "SportsJS.Controls.ViewControls.ListControl",
// controls used inside the control
_tabControl: null,
_bannerControl: null,
_headerControl: null,
_listControl: null,
_viewPortElement: null,
_tabClickHandler: null,
_scrollHandler: null,
_scrollableElement: null,
// view blocks inside the control
_titleElement: null,
_tabElement: null,
_bannerElement: null,
_headerElement: null,
_listElement: null,
_footerElement: null,
// variables to track tab status and its data
_currentTabId: null,
_currentTabItemElement: null,
_renderBlockingPromise: null,
_tabDataMap: null,
_isValidResponse: function _isValidResponse(response) {
if (!response || !response.itemsList || response.itemsList.length < 1) {
return false;
}
// id is must for tabs
if (response.tabsList) {
for(var i = 0, iLength = response.tabsList.length; i < iLength; i++) {
if(!response.tabsList[i].id) {
return false;
}
}
}
return true;
},
_adaptResponse: function _adaptResponse(response) {
response.tabDataMap = null;
// no adaption when there is no tabs 
if (!response.tabsList || response.tabsList.length < 1) {
return response;
}
// update the response for tab behaviour
// - group items from itemsList for tabs and keep them in tab data map.
// - update tab click handler
var tabDataMap = {};
// extract items per tab from itemsList. 
// Note: TODO: arengak - Ideally we should have separate control with tab support 
var currentGroup = null;
for (var j = 0, jLength = response.itemsList.length; j < jLength; j++) {
var item = response.itemsList[j];
if (item.isGroupHeader && item.id) {
if (!tabDataMap[item.id]) {
tabDataMap[item.id] = [];
}
currentGroup = tabDataMap[item.id];
}
if (!currentGroup) {
return false;
}
currentGroup.push(item);
}
for (var i = 0, iLength = response.tabsList.length; i < iLength; i++) {
var tabItem = response.tabsList[i];
// check we have data for the tab item. 
if (!tabDataMap[tabItem.id]) {
return false;
}
tabItem.clickHandler = this._tabClickHandler;
}
// Refresh: We already have valid current tab-id and its data. 
// Use the current tab data for the list 
if (this._currentTabId && tabDataMap[this._currentTabId]) {
response.itemsList = tabDataMap[this._currentTabId];
} else {
// first time render or new response does not have the current tab.
// use the first tab data                        
this._currentTabId = response.tabsList[0].id;
response.itemsList = tabDataMap[this._currentTabId];
}
response.tabDataMap = tabDataMap;
return response;
},
// function to highlight the tab.
// - hightlight the currently-selected tab element if the tab exists.
_hightlightTab: function _hightlightTab(control) {
// if the control is not tab control... dont do anything
if(!control || !control.element || 
!this._tabControl || !this._tabControl.element || !this._tabControl._viewPortElement ||
control.element !== this._tabControl.element) {
return;
}
// remove highlighting on previous tab
if (this._currentTabItemElement && this._currentTabItemElement.children && this._currentTabItemElement.children.length > 0) {
WinJS.Utilities.removeClass(this._currentTabItemElement.children[0], "listControlTabTapped");
}
this._currentTabItemElement = null;
// get element for the current tab id
var tabItems = this._tabControl._viewPortElement.querySelectorAll(".itemsContainerViewItem");
var iLength = tabItems ? tabItems.length : 0;
for (var i = 0; i < iLength; i++) {
if (tabItems[i] && tabItems[i].children && tabItems[i].children.length > 0 && tabItems[i].children[0]) {
var tabId = tabItems[i].children[0].getAttribute("data-controls-id");
if (tabId && this._currentTabId && this._currentTabId === tabId) {
this._currentTabItemElement = tabItems[i];
break;
}
}
}
if (this._currentTabItemElement && this._currentTabItemElement.children && this._currentTabItemElement.children.length > 0) {
WinJS.Utilities.addClass(this._currentTabItemElement.children[0], "listControlTabTapped");
} else {
SportsJS.Controls.Utilities.interfaceException(this._name, "issue: could not find a tab to highlight");
}
},
_onEveryControlRenderComplete: function _onEveryControlRenderComplete(control) {
this._hightlightTab(control);
},
_onSelfCanceling: function _onSelfCanceling(controls) {
// remove list of controls from controls list which can do self rendering
if (controls) {
var listControlIndex = controls.indexOf(this._listControl);
listControlIndex !== -1 ? controls.splice(listControlIndex, 1) : "";
}
this._isSelfCanceling = false;
},
_onTabClick: function _onTabClick(item, eventElement, tabItemElement) {
// check we really need to update the list for the tab click.
if (this._listControl && item && item.id && tabItemElement
&& this._currentTabItemElement !== tabItemElement
&& this._currentTabId !== item.id
&& this._tabDataMap && this._tabDataMap[item.id] && this._tabDataMap[item.id].length > 0) {
// remove highlighting on previous tab
if (this._currentTabItemElement && this._currentTabItemElement.children && this._currentTabItemElement.children.length > 0) {
WinJS.Utilities.removeClass(this._currentTabItemElement.children[0], "listControlTabTapped");
}
// highlight the current tab
if (tabItemElement.children && tabItemElement.children.length > 0) {
WinJS.Utilities.addClass(tabItemElement.children[0], "listControlTabTapped");
}
// disable the tab to avoid multiple clicks on the same tab.
//TODO: arengak - disabling does not work here.. investigate
tabItemElement.disabled = true;
this._currentTabId = item.id;
this._currentTabItemElement = tabItemElement;
this._isSelfCanceling = true;   
SportsJS.Controls.Utilities.cancelPromise(this._renderBlockingPromise);
SportsJS.Controls.Services.uiThreadTimer.reset();
this._renderBlockingPromise = this._listControl.render(this._tabDataMap[item.id]);
}
},
_onScroll: function _onScroll(event) {
if (event) {
if (event && event.currentTarget === this._scrollableElement) {
event.stopPropagation();
} else {
event.preventDefault();
}
}
},
_removeScrollHandler: function _removeScrollHandler() {
if (this._scrollableElement) {
this._scrollableElement.removeEventListener("wheel", this._scrollHandler, false);
this._scrollableElement.removeEventListener("scroll", this._scrollHandler, false);
}
},
_addScrollHandler: function _addScrollHandler(element) {
this._removeScrollHandler();
if (element) {
element.addEventListener("wheel", this._scrollHandler, false);
element.addEventListener("scroll", this._scrollHandler, false);
this._scrollableElement = element;
}
},
_getControls: function _getControls() {
var controls = [];
if (this._tabControl) {
controls.push(this._tabControl);
}
if (this._bannerControl) {
controls.push(this._bannerControl);
}
if (this._headerControl) {
controls.push(this._headerControl);
}
if (this._listControl) {
controls.push(this._listControl);
}
return controls;
},
_createTabControl: function _createTabControl(element, dataId) {
var options = {
innerListContainerClass: "inlinedList",
};
// TODO: arengak - itemsContainer for tabs seems to be an expensive control. We can have a separate control to handle tabs.
var control = new SportsJS.Controls.ViewBlocks.ItemsContainerView(element, options);
if (control) {
SportsJS.Controls.Utilities.setDataId(element, dataId);
return control;
}
return null;
},
_createChromeControl: function _createChromeControl(element, dataId) {
var control = new SportsJS.Controls.ViewBlocks.ChromeView(element);
if (control) {
SportsJS.Controls.Utilities.setDataId(element, dataId);
return control;
}
return null;
},
_createListControl: function _createListControl(element, dataId) {
var listOptions = {
innerListContainerClass: this._config.listLayout ? this._config.listLayout : "verticalList"
};
var listControl = new SportsJS.Controls.ViewBlocks.ItemsContainerView(element, listOptions);
if (listControl) {
if (listOptions.innerListContainerClass === "verticalList") {
this._addScrollHandler(listControl.viewPortElement);
// Note: dont change the order of decoration
listControl = SportsJS.Controls.Utilities.addStickyHeader(listControl);
listControl = SportsJS.Controls.Utilities.addVirtualizer(listControl);
}
SportsJS.Controls.Utilities.setDataId(element, dataId);
return listControl;
}
return null;
},
// removes the element contents and also remove its corresponding attribute from view port element
_resetElement: function _resetElement(element, attribute, defaultClassName) {
if (element) {
element.innerHTML = "";
if (this._viewPortElement && attribute) {
this._viewPortElement.removeAttribute(attribute);
}
if (defaultClassName) {
element.style.className = defaultClassName;
}
}
},
_disposeTabControl: function _disposeTabControl() {
this._tabDataMap = null;
this._currentTabId = null;
this._currentTabItemElement = null;
if (this._tabControl) {
this._cleanupControl(this._tabControl);
this._resetElement(this._tabElement, "data-controls-tabs", "tabsListContainerBlock");
this._tabControl = null;
}
},
_disposeBannerControl: function _disposeBannerControl() {
if (this._bannerControl) {
this._cleanupControl(this._bannerControl);
this._resetElement(this._bannerElement, "data-controls-banner", "bannerBlock");
this._bannerControl = null;
}
},
_disposeHeaderControl: function _disposeHeaderControl() {
if (this._headerControl) {
this._cleanupControl(this._headerControl);
this._resetElement(this._headerElement, "data-controls-header", "headerBlock");
this._headerControl = null;
}
},
_initializeTitleElement: function _initializeTitleElement(title) {
if (title && this._viewPortElement && this._titleElement) {
WinJS.Utilities.addClass(this._titleElement, "controlTitleText");
this._viewPortElement.setAttribute("data-controls-title", "true");
this._titleElement.innerText = title;
}
},
_initializeFooterElement: function _initializeFooterElement(footer) {
if (footer && this._viewPortElement && this._footerElement) {
WinJS.Utilities.addClass(this._footerElement, "controlFooterText");
this._viewPortElement.setAttribute("data-controls-footer", "true");
this._footerElement.innerText = footer;
}
},
_initializeTabControl: function _initializeTabControl(response) {
if (this._viewPortElement && this._tabElement && !this._tabControl) {
this._tabControl = this._createTabControl(this._tabElement, "tabsList");
if (this._tabControl) {
this._viewPortElement.setAttribute("data-controls-tabs", "true");
}
}
this._tabDataMap = response.tabDataMap;
},
_initializeBannerControl: function _initializeBannerControl(response) {
if (this._viewPortElement && this._bannerElement && !this._bannerControl) {
this._bannerControl = this._createChromeControl(this._bannerElement, "banner");
if (this._bannerControl) {
this._viewPortElement.setAttribute("data-controls-banner", "true");
}
}
},
_initializeHeaderControl: function _initializeHeaderControl(response) {
if (this._viewPortElement && this._headerElement && !this._headerControl) {
this._headerControl = this._createChromeControl(this._headerElement, "header");
if (this._headerControl) {
this._viewPortElement.setAttribute("data-controls-header", "true");
}
}
},
_initializeListControl: function _initializeListControl(response) {
if (this._listElement && !this._listControl) {
this._listControl = this._createListControl(this._listElement, "itemsList");
}
},
_createView: function _createView(response, parentElement) {
this._viewPortElement = SportsJS.Controls.Utilities.createDivWithClassName("listControlLayout");
this._titleElement = SportsJS.Controls.Utilities.createDivWithClassName("titleText");
this._tabElement = SportsJS.Controls.Utilities.createDivWithClassName("tabsListContainerBlock");
this._bannerElement = SportsJS.Controls.Utilities.createDivWithClassName("bannerBlock");
this._headerElement = SportsJS.Controls.Utilities.createDivWithClassName("headerBlock");
this._listElement = SportsJS.Controls.Utilities.createDivWithClassName("itemsListContainerBlock");
this._footerElement = SportsJS.Controls.Utilities.createDivWithClassName("footerText");
this._viewPortElement.appendChild(this._titleElement);
this._viewPortElement.appendChild(this._tabElement);
this._viewPortElement.appendChild(this._bannerElement);
this._viewPortElement.appendChild(this._headerElement);
this._viewPortElement.appendChild(this._listElement);
this._viewPortElement.appendChild(this._footerElement);
parentElement.appendChild(this._viewPortElement);
return this._refreshView(response);
},
_refreshView: function _refreshView(response) {
if (response.titleText) {
this._initializeTitleElement(response.titleText);
} else {
this._resetElement(this._titleElement, "data-controls-title", "titleText");
}
if (response.tabsList && response.tabsList.length > 0) {
this._initializeTabControl(response);
} else {
this._disposeTabControl();
}
if (response.banner) {
this._initializeBannerControl(response);
} else {
this._disposeBannerControl();
}
if (response.header) {
this._initializeHeaderControl(response);
} else {
this._disposeHeaderControl();
}
this._initializeListControl(response);
if (response.footerText) {
this._initializeFooterElement(response.footerText);
} else {
this._resetElement(this._footerElement, "data-controls-footer", "footerText");
}
this._controls = this._getControls();
if (!this._listControl) {
return WinJS.Promise.wrapError({ message: "list control is not initialized" });
}
var that = this;
return new WinJS.Promise(function ListControl_refreshPromiseConstructor(complete, error) {
that._renderBlockingPromise = that._renderBlockingPromise ? that._renderBlockingPromise : WinJS.Promise.wrap(true);
that._renderBlockingPromise = that._renderBlockingPromise.then(function ListControl_refreshOnRenderBlockingCompleteHandler () {
complete(that._controls);
return WinJS.Promise.wrap(true);
}, function ListControl_refreshPromisePromiseError(errorMessage) {
if (SportsJS.Controls.Utilities.isCancellationError(errorMessage) !== true) {
error(errorMessage);
return;
}
// TODO: arengak - try to extract the selfCancelation info from the message.
if (that._isSelfCanceling === true) {
that._onSelfCanceling(that._controls);
// control itself has canceld the promise (example: tab click)
// complete the render promise of the caller promise to unblock the caller.
// Note: This can lead to rendering two controls in parallel. 
// TODO: arengak - we can chain the complete handler
complete(that._controls);
return;
}                        
}); 
}, function ListControl_refreshPromiseCancelHandler() {
// the control using the list control wants to cancel it.
SportsJS.Controls.Utilities.cancelPromise(that._renderBlockingPromise);
that._renderBlockingPromise = null;
});
},
cleanUp: function cleanUp() {
this._removeScrollHandler();
SportsJS.Controls.Utilities.cancelPromise(this._renderBlockingPromise);
SportsJS.Controls.ViewControls.ViewControlBase.prototype.cleanUp.call(this);
}
})
});
})();