﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.Controls.ViewControls",
{
/// <summary>
/// MixedListControl - to render list of any view controls
/// </summary>
// TODO: arengak - find better name for the control name
MixedListControl: WinJS.Class.derive(SportsJS.Controls.ViewControls.ViewControlBase, function MixedListControl_constructor(element, config) {
SportsJS.Controls.ViewControls.ViewControlBase.call(this, element, config);
WinJS.Utilities.addClass(this._element, "mixedListControl");
}, {
type: "MixedListControl",
_name: "SportsJS.Controls.ViewControls.MixedListControl",
_viewPortElement: null,
// OVERRIDDEN: we get data for each control in an array but we can't directly bind the array data
// so converting the array data into object properties.
_adaptResponse: function _adaptResponse(response) {
for (var i = 0, iLength = response.itemsList.length; i < iLength; i++) {
response["control" + i + "Data"] = response.itemsList[i];
}
return response;
},
/// OVERRIDDEN: validate the response
_isValidResponse: function _isValidResponse(response) {
if (response && response.itemsList && response.itemsList.length > 0) {
return true;
}
return false;
},
_createControl: function _createControl(dataId, controlData, previousCreateControlPromise) {
var that = this;
var viewControlElement = SportsJS.Controls.Utilities.createDivWithClassName("mixedListControlItem");
SportsJS.Controls.Utilities.setDataId(viewControlElement, dataId);
that._viewPortElement.appendChild(viewControlElement);
return SportsJS.Controls.Utilities.createViewControlAsync(controlData.type, viewControlElement, controlData.uiOptions, previousCreateControlPromise).then(function (control) {
that._controls.push(control);
return WinJS.Promise.wrap(control);
});
},
// creates a new control and replaces existing control at the specified index 
_updateControl: function _updateControl(index, data, controlElement, previousUpdateControlPromise) {
var that = this;
return SportsJS.Controls.Utilities.createViewControlAsync(data.type, controlElement, data.uiOptions, previousUpdateControlPromise).then(function (control) {
that._controls[index] = control;
return WinJS.Promise.wrap(true);
});
},
/// IMPLEMENTATION: create view function
_createView: function _createView(response, parentElement) {
var that = this;
that._controls = [];
that._viewPortElement = SportsJS.Controls.Utilities.createDivWithClassName("mixedListControlLayout");
var previousCreateControlPromise = WinJS.Promise.wrap(true);
for (var i = 0, iLength = response.itemsList.length; i < iLength; i++) {
previousCreateControlPromise = this._createControl("control" + i + "Data", response.itemsList[i], previousCreateControlPromise);
}
return previousCreateControlPromise.then(function () {
parentElement.appendChild(that._viewPortElement);
return WinJS.Promise.wrap(that._controls);
});
},
// TODO: arengak - more DOM operations are done here... revisit here for optimizations
_refreshView: function _refreshView(response, viewPortElement) {
var that = this;
var requiredControlsCount = response.itemsList ? response.itemsList.length : 0;
var exisitingControlsCount = that._controls.length;
var previousUpdateControlPromise = WinJS.Promise.wrap(true);
var minCount = Math.min(requiredControlsCount, exisitingControlsCount);
for (var i = 0; i < minCount; i++) {
if (response.itemsList[i].type !== that._controls[i].type) {
var controlElement = that._controls[i].element;
that._controls[i].cleanUp();
// TODO: arengak - animate
controlElement.innerHTML = "";
controlElement.style.className = "mixedListControlItem";
previousUpdateControlPromise = that._updateControl(i, response.itemsList[i], controlElement, previousUpdateControlPromise);
}
}
return previousUpdateControlPromise.then(function () {
var previousCreateControlPromise = WinJS.Promise.wrap(true);
if (requiredControlsCount < exisitingControlsCount) {
for (var j = requiredControlsCount; j < exisitingControlsCount; j++) {
var ctrlElement = that._controls[j].element;
that._controls[j].cleanUp();
// TODO: arengak - animate
that._viewPortElement.removeChild(ctrlElement);
}
that._controls.splice(requiredControlsCount, exisitingControlsCount - requiredControlsCount);
} else {
for (var k = exisitingControlsCount; k < requiredControlsCount; k++) {
previousCreateControlPromise = that._createControl("control" + k + "Data", response.itemsList[k], previousCreateControlPromise);
}
}
return previousCreateControlPromise.then(function () {
return WinJS.Promise.wrap(that._controls);
});
});
}
}),
});
})();
