﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.Controls.Templates",
{
// renderer function for "InlinedItemsHeaderTileSchema" data. Render list of items in-line
createInlinedItemsHeaderTile: function createInlinedItemsHeaderTile(data) {
return SportsJS.Controls.Templates.createInlinedItemsTile(data, true);
},
createInlinedItemsTileV2: function createInlinedItemsTileV2(data) {
var tile = SportsJS.Controls.Templates.createInlinedItemsTile(data);
WinJS.Utilities.addClass(tile, "multiLineItemsTile");
return tile;
},
createInlinedItemsTileV3: function createInlinedItemsTileV3(data) {
var tile = SportsJS.Controls.Templates.createInlinedItemsTile(data);
WinJS.Utilities.addClass(tile, "compactInlinedItemsTile");
return tile;
},
// renderer function for "InlinedItemsTileSchema" data. Render list of items in-line
createInlinedItemsTile: function createInlinedItemsTile(inputData, isHeader) {
// validate the input data before creting fragment for the data
if (!inputData || !inputData.data || !inputData.data.entries || inputData.data.entries.length < 1) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Templates.createInlinedItemsTile", "invalid data received");
return document.createElement("div");
}
var data = inputData.data;
var langClass = data.ignoreMarket ? "" : "nonEnglish ";
// covering node/root element of inlined items
var rowElement = SportsJS.Controls.Utilities.createDivWithClassName(langClass + "inlinedItemsTile");
rowElement.style.msGridColumns = data.entries.length + 1;
// apply header/row specific css classes
if (isHeader) {
WinJS.Utilities.addClass(rowElement, "viewHeaderTile inlinedItemsHeaderTile");
} else {
WinJS.Utilities.addClass(rowElement, "inlinedItemsRowTile");
}
var getStyleList = function (typeStr) {
typeStr = typeStr ? typeStr : "Unknown";
return typeStr.split("|");
};
var setTextStyle = function (inputTextElement, textDataType, formatList) {
formatList = formatList ? formatList : [];
if (isHeader) {
WinJS.Utilities.addClass(inputTextElement, "viewColumnTitle");
} else if (SportsJS.Controls.Templates.Configs.recognizedDataType.indexOf(textDataType) !== -1 || formatList.indexOf("R") !== -1) {
WinJS.Utilities.addClass(inputTextElement, "viewRecognizedText");
} else if (SportsJS.Controls.Templates.Configs.prominentDataType.indexOf(textDataType) !== -1 || formatList.indexOf("P") !== -1) {
WinJS.Utilities.addClass(inputTextElement, "viewProminentText");
} else if (SportsJS.Controls.Utilities.isAppexSymbolType(type)) {
return; // TODO: arengak - handle appex symbol styles
} else {
WinJS.Utilities.addClass(inputTextElement, "viewGenericText");
}
};
for (var i = 0, iLength = data.entries.length; i < iLength; i++) {
var columnName = "inlinedItemsCell" + (i + 1);
var element = SportsJS.Controls.Utilities.createDivWithClassName(columnName);
element.style.msGridColumn = i + 1;
var styleList = getStyleList(data.entries[i].type);
var type = styleList[0];
var text = SportsJS.Controls.Utilities.isAppexSymbolType(type) ? "" : data.entries[i].text;
var image = data.entries[i].image;
if (!isHeader && SportsJS.Controls.Templates.Configs.imageDataType.indexOf(type) !== -1) {
WinJS.Utilities.addClass(element, "inlinedItemsCellWithImage");
var textElement = SportsJS.Controls.Utilities.createDivWithClassName("text");
setTextStyle(textElement, type, styleList);
textElement.innerText = text ? text : "";
element.appendChild(textElement);
// we want to insert the image card only when there is image data.. helps reducing dom size
if (image) {
var imgElement = SportsJS.Controls.Utilities.createDivWithClassName("image");
// TODO: chthakur - horizontal - need sports non-specific image control
var imgControl = new SportsJS.Utilities.ImgControl(imgElement);
if (imgControl) {
imgControl.imgData = image;
}
element.appendChild(imgElement);
}
} else {
WinJS.Utilities.addClass(element, "inlinedItemsCell");
setTextStyle(element, type, styleList);
element.innerText = text ? text : "";
}
// set corresponding CSS class and attribute for the type
var cssClass = SportsJS.Controls.Templates.Configs.entityClassByDataType[type];
if (cssClass) {
WinJS.Utilities.addClass(element, cssClass);
element.setAttribute("data-controls-type", type);
}
// set icon attribute for AppexSymbol type
if (SportsJS.Controls.Utilities.isAppexSymbolType(type)) {
element.setAttribute("data-controls-icon", data.entries[i].text);
}
// if width is specified explictly, use it
if (data.entries[i].width) {
element.style.width = data.entries[i].width;
}
rowElement.appendChild(element);
}
var columnNumber = (data.entries.length + 1);
var scrollPlaceHolderElement = SportsJS.Controls.Utilities.createDivWithClassName("scrollBarPlaceHolder inlinedItemsCell" + columnNumber);
scrollPlaceHolderElement.style.msGridColumn = columnNumber;
rowElement.appendChild(scrollPlaceHolderElement);
return rowElement;
},
// renderer function for "CombinedScheduleGameItemsSchema" data. Render list of items in-line
createCombinedScheduleGameHeaderTile: function createCombinedScheduleGameHeaderTile(inputData) {
// validate the input data before creating fragment for the data
if (!inputData) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Templates.createCombinedScheduleGameTile", "invalid data received");
return document.createElement("div");
}
var isGameResult = (inputData.data.gameIsResult === "true");
var hasLiveGames = (inputData.data.hasLiveGames === "true");
var gameShowOpponentTeamIcon = (inputData.data.gameShowOpponentTeamIcon === "true");
// covering node/root element of inlined items
var rowElement = SportsJS.Controls.Utilities.createDivWithClassName("csTileGrid viewHeaderTile");
if (isGameResult) {
WinJS.Utilities.addClass(rowElement, "csResultTileHeaderGrid");
WinJS.Utilities.addClass(rowElement, gameShowOpponentTeamIcon ? "csResultTileHeaderGridWidth" : "csResultTileNoLogoHeaderGridWidth");
}
else {
WinJS.Utilities.addClass(rowElement, "csFixtureTileHeaderGrid");
WinJS.Utilities.addClass(rowElement, "csFixtureTile" + (hasLiveGames ? "LiveScore" : "") + (gameShowOpponentTeamIcon ? "" : "NoLogo") + "HeaderGridWidth");
}
var gameDateTimeStr = inputData.data.gameDateTime;
var gameAtOrVsStr = inputData.data.gameAtOrVs;
var gameOutcomeStr = inputData.data.gameOutcome;
var columnNumber = 1;
var gameDate = SportsJS.Controls.Utilities.createDivWithClassName("csDate viewColumnTitle csDateHeader");
gameDate.innerText = gameDateTimeStr;
gameDate.style.msGridColumn = columnNumber++;
rowElement.appendChild(gameDate);
if (hasLiveGames) {
var gameLiveScore = SportsJS.Controls.Utilities.createDivWithClassName("viewColumnTitle csLiveScoreHeader");
gameLiveScore.innerText = "";
gameLiveScore.style.msGridColumn = columnNumber++;
rowElement.appendChild(gameLiveScore);
}
var gameAtOrVs = SportsJS.Controls.Utilities.createDivWithClassName("csAtOrVs viewColumnTitle");
WinJS.Utilities.addClass(gameAtOrVs, gameShowOpponentTeamIcon || !isGameResult ? "csAtOrVsHeaderWidth" : "csAtOrVsNoLogoHeaderWidth");
//WinJS.Utilities.addClass(gameAtOrVs, "csAtOrVs" + (hasLiveGames ? "LiveScore" : "") + (gameShowOpponentTeamIcon ? "" : "NoLogo") + "HeaderWidth");
gameAtOrVs.innerText = gameAtOrVsStr;
gameAtOrVs.style.msGridColumn = columnNumber;
rowElement.appendChild(gameAtOrVs);
//Increment for icon, team name, final result info and outcome
columnNumber += gameShowOpponentTeamIcon ? 3 : 2;
if (isGameResult) {
var gameFinalStateInfo = SportsJS.Controls.Utilities.createDivWithClassName("csFinalStateInfo viewColumnTitle csFinalStateInfoHeader");
gameFinalStateInfo.innerText = gameOutcomeStr;
gameFinalStateInfo.style.msGridColumn = columnNumber;
rowElement.appendChild(gameFinalStateInfo);
}
return rowElement;
},
// renderer function for "CombinedScheduleSchema" data. Render list of items in-line
createCombinedScheduleGameTile: function createCombinedScheduleGameTile(inputData) {
// validate the input data before creating fragment for the data
if (!inputData) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Templates.createCombinedScheduleGameTile", "invalid data received");
return document.createElement("div");
}
var isGameResult = (inputData.data.gameIsResult === "true");
var hasLiveGames = (inputData.data.hasLiveGames === "true");
var gameShowOpponentTeamIcon = (inputData.data.gameShowOpponentTeamIcon === "true");
// covering node/root element of inlined items
var rowElement = SportsJS.Controls.Utilities.createDivWithClassName("csTileGrid");
if (isGameResult) {
WinJS.Utilities.addClass(rowElement, "csResultTileGrid");
WinJS.Utilities.addClass(rowElement, gameShowOpponentTeamIcon ? "csResultTileGridWidth" : "csResultTileNoLogoGridWidth");
}
else {
WinJS.Utilities.addClass(rowElement, "csFixtureTileGrid");
WinJS.Utilities.addClass(rowElement, "csFixtureTile" + (hasLiveGames ? "LiveScore" : "") + (gameShowOpponentTeamIcon ? "" : "NoLogo") + "GridWidth");
}
var gameDateTimeStr = inputData.data.gameDateTime;
var gameLeagueStr = inputData.data.gameLeague;
var gameAtOrVsStr = inputData.data.gameAtOrVs;
var gameOpponentTeamNameStr = inputData.data.gameOpponentTeamName;
var gameOpponentTeamIconStr = inputData.data.gameOpponentTeamIcon;
var gameFinalStateInfoStr = inputData.data.gameFinalStateInfo;
var gameOutcomeStr = inputData.data.gameOutcome;
var gameDateAndLeagueGrid = SportsJS.Controls.Utilities.createDivWithClassName("csDateAndLeagueGrid");
var columnNumber = 1;
var gameDate = SportsJS.Controls.Utilities.createDivWithClassName("csDate csDateItem");
gameDate.innerText = gameDateTimeStr;
if (hasLiveGames && gameOutcomeStr !== "") {
WinJS.Utilities.addClass(gameDate, "fontSmallRegular sportsProminentStatValue");
}
else {
WinJS.Utilities.addClass(gameDate, "sportsContentTiny");
}
gameDateAndLeagueGrid.appendChild(gameDate);
var gameLeague = SportsJS.Controls.Utilities.createDivWithClassName("csLeague sportsContentTiny");
gameLeague.innerText = gameLeagueStr;
gameDateAndLeagueGrid.appendChild(gameLeague);
gameDateAndLeagueGrid.style.msGridColumn = columnNumber++;
rowElement.appendChild(gameDateAndLeagueGrid);
if (!isGameResult && hasLiveGames) {
//Insert Live Score
var gameLiveScore = SportsJS.Controls.Utilities.createDivWithClassName("csLiveScore sportsProminentStatValueMedium");
gameLiveScore.style.msGridColumn = columnNumber++;
gameLiveScore.innerText = gameOutcomeStr;
rowElement.appendChild(gameLiveScore);
}
var gameAtOrVs = SportsJS.Controls.Utilities.createDivWithClassName("csAtOrVs csAtOrVsItem sportsContentTiny");
gameAtOrVs.style.msGridColumn = columnNumber++;
gameAtOrVs.innerText = gameAtOrVsStr;
rowElement.appendChild(gameAtOrVs);
//Create image control only if we have an image to show!
if (gameShowOpponentTeamIcon && gameOpponentTeamIconStr !== "") {
var imgElement = SportsJS.Controls.Utilities.createDivWithClassName("image csOpponentTeamIcon");
var imgControl = new SportsJS.Utilities.ImgControl(imgElement);
if (imgControl) {
imgControl.imgData = gameOpponentTeamIconStr;
}
imgElement.style.msGridColumn = columnNumber++;
rowElement.appendChild(imgElement);
}
var gameOpponentTeamName = SportsJS.Controls.Utilities.createDivWithClassName("csOpponentTeamName sportsEntityTitleSmall");
gameOpponentTeamName.innerText = gameOpponentTeamNameStr;
gameOpponentTeamName.style.msGridColumn = columnNumber++;
rowElement.appendChild(gameOpponentTeamName);
if (isGameResult) {
var gameFinalStateInfo = SportsJS.Controls.Utilities.createDivWithClassName("showStatusBadge sportsSubtitleTextTiny csFinalStateInfo");
gameFinalStateInfo.innerText = gameFinalStateInfoStr;
gameFinalStateInfo.style.msGridColumn = columnNumber++;
rowElement.appendChild(gameFinalStateInfo);
var gameOutcome = SportsJS.Controls.Utilities.createDivWithClassName("csOutcome csOutcomeWidth sportsStatMedium");
gameOutcome.innerText = gameOutcomeStr;
gameOutcome.style.msGridColumn = columnNumber++;
rowElement.appendChild(gameOutcome);
}
return rowElement;
},
createMoreSportsTile: function createMoreSportsTile(inputData) {
var moduleInfo = {
fragmentPath: "/leagues/common/modules/AllSportsModule/AllSportsModule.html",
templateId: "MoreSportsTileTemplate"
};
inputData.data.isUserLeague = SportsJS.mainProcessManager.isValidUserLeague(inputData.data.leagueType);
var isFreOffline = SportsJS.Utilities.isFirstRunOfflineExperience();
if (isFreOffline) {
inputData.data.title = SportsJS.Utilities.getLocLeagueDisplayTextOfflineFre(inputData.data.leagueType);
var sport = AppEx.Sports.Services.Utils.getSportsFromLeague(inputData.data.leagueType);
inputData.data.tileHeader = SportsJS.Utilities.getLocSportsDisplayTextOfflineFre(sport);
}
var loadModulePromise = CommonJS.loadModule(moduleInfo, inputData, null, null, null).then(function (renderedItem) {
var logoTitleBox = renderedItem.querySelector(".leagueLogoTitleBox");
var logoCheckBox = renderedItem.querySelector(".leagueCheckBox");
// make interactive only if not fre offline
if (!isFreOffline) {
logoCheckBox.style.display = "block";
WinJS.Utilities.addClass(logoTitleBox, "sportsInteractiveItem");
PlatformJS.Utilities.enablePointerUpDownAnimations(logoTitleBox);
PlatformJS.Utilities.registerItemClickProxy(logoTitleBox,
function (domElement) {
return WinJS.Utilities.hasClass(domElement, "leagueTile");
}, function (domElement) {
SportsJS.Common.Modules.AllSportsModuleControl.navigateToLeaguePage(domElement, inputData.data.leagueType);
});
} else {
logoCheckBox.style.display = "none";
}
var sportsTile = renderedItem.querySelector(".moreSportsTile");
var sports = AppEx.Sports.Services.Utils.getSportsFromLeague(inputData.data.leagueType);
WinJS.Utilities.addClass(sportsTile, "leagueTile " + sports);
renderedItem.setAttribute("data-league-type", inputData.data.leagueType);
return renderedItem;
});
return loadModulePromise;
},
createMatchLeadersSingleStatTile: function createMatchLeadersSingleStatTile(inputData) {
var moduleInfo = {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
templateId: "matchLeadersSingleStatTileTemplate",
};
return CommonJS.loadModule(moduleInfo, inputData, null, null, null).then(function (renderedItem) {
var makeLeaderClickable = function (leaderType) {
var className = leaderType + "TeamLeader";
var destination = leaderType === "home" ? inputData.data.homeTeamLeaderUrl : inputData.data.visitingTeamLeaderUrl;
var leaderTile = renderedItem.querySelector("." + className);
PlatformJS.Utilities.enablePointerUpDownAnimations(leaderTile);
PlatformJS.Utilities.registerItemClickProxy(leaderTile,
function (domElement) {
return WinJS.Utilities.hasClass(domElement, className);
}, function (domElement) {
PlatformJS.Navigation.navigateTo(destination);
});
};
if (inputData && inputData.data && inputData.data.homeTeamLeaderUrl && inputData.data.visitingTeamLeaderUrl) {
makeLeaderClickable("home");
makeLeaderClickable("visiting");
}
////highlight leader who is ahead
var visitingTeamLeaderStat = parseFloat(inputData.data.visitingTeamLeaderStatValue);
var homeTeamLeaderStat = parseFloat(inputData.data.homeTeamLeaderStatValue);
var leaderStatEl;
if (visitingTeamLeaderStat > homeTeamLeaderStat) {
leaderStatEl = renderedItem.querySelector(".visitingTeamLeader .leaderStat");
}
else if (homeTeamLeaderStat > visitingTeamLeaderStat) {
leaderStatEl = renderedItem.querySelector(".homeTeamLeader .leaderStat");
}
if (leaderStatEl) {
WinJS.Utilities.addClass(leaderStatEl, "sportsProminentText");
}
return renderedItem;
});
},
createBannerTile: function createBannerTile(inputData, isHeader)
{
if (!inputData || !inputData.data || !inputData.data.topLeft || !inputData.data.topRight || inputData.data.secondRow.length < 1) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Templates.createInlinedItemsTile", "invalid data received");
return document.createElement("div");
}
var data = inputData.data;
// covering node/root element of inlined items
var rowElement = SportsJS.Controls.Utilities.createDivWithClassName("bannerTile");
var row1 = SportsJS.Controls.Utilities.createDivWithClassName("bannerRow1");
rowElement.appendChild(row1);
var cellName = "bannerCell1";
var element = SportsJS.Controls.Utilities.createDivWithClassName(cellName);
WinJS.Utilities.addClass(element, "bannerCellCommon");  
var text = data.topLeft;
var textElement = SportsJS.Controls.Utilities.createDivWithClassName("text");
textElement.innerText = text ? text : "";
element.appendChild(textElement);
row1.appendChild(element);
cellName = "bannerCell2";
element = SportsJS.Controls.Utilities.createDivWithClassName(cellName);
WinJS.Utilities.addClass(element, "bannerCellCommon");
text = data.topRight;
textElement = SportsJS.Controls.Utilities.createDivWithClassName("text");
textElement.innerText = text ? text : "";
element.appendChild(textElement);
row1.appendChild(element);
var row2 = SportsJS.Controls.Utilities.createDivWithClassName("bannerRow2");
rowElement.appendChild(row2);
for (var i = 0; i < inputData.data.secondRow.length; i++) {
cellName = "bannerCell" + (i + 3);
element = SportsJS.Controls.Utilities.createDivWithClassName(cellName);
WinJS.Utilities.addClass(element, "bannerCellCommon");
text = data.secondRow[i];
textElement = SportsJS.Controls.Utilities.createDivWithClassName("text");
textElement.innerText = text ? text : "";
element.appendChild(textElement);
row2.appendChild(element);
}
return rowElement;
},
createMatchOverviewHeaderTile: function createMatchOverviewHeaderTile(responseData) {
if (!responseData || !responseData.data) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Templates.createMatchOverviewHeaderTile", "invalid data received");
return document.createElement("div");
}
var data = responseData.data;
var rootEl = SportsJS.Controls.Utilities.createDivWithClassName("matchOverviewHeader");
var section1El = SportsJS.Controls.Utilities.createDivWithClassName("section1");
var section2El = SportsJS.Controls.Utilities.createDivWithClassName("section2");
var section3El = SportsJS.Controls.Utilities.createDivWithClassName("section3");
rootEl.appendChild(section1El);
rootEl.appendChild(section2El);
rootEl.appendChild(section3El);
var insertTeamData = function (teamType) {
// team name
var teamNameEl = SportsJS.Controls.Utilities.createDivWithClassName(teamType + "TeamName sportsEntityTitleSmall");
teamNameEl.innerText = data[teamType + "TeamName"];
section1El.appendChild(teamNameEl);
//  team logo
var TeamLogoEl = SportsJS.Controls.Utilities.createDivWithClassName(teamType + "TeamLogo");
var TeamLogoImgControl = new SportsJS.Utilities.ImgControl(TeamLogoEl);
if (TeamLogoImgControl) {
TeamLogoImgControl.imgData = data[teamType + "TeamLogoUrl"];
}
section2El.appendChild(TeamLogoEl);
// team score
var teamScoreEl = SportsJS.Controls.Utilities.createDivWithClassName(teamType + "TeamScore sportsStatExtraLarge");
teamScoreEl.innerText = data[teamType + "TeamScore"];
section2El.appendChild(teamScoreEl);
// team info
var teamInfoEl = SportsJS.Controls.Utilities.createDivWithClassName(teamType + "TeamInfo");
var timeouts = parseInt(data[teamType + "TeamInfo"]);
for (var i = 0; i < timeouts; i++) {
var timeoutEl = SportsJS.Controls.Utilities.createDivWithClassName("timeout");
teamInfoEl.appendChild(timeoutEl);
}
section3El.appendChild(teamInfoEl);
};
insertTeamData("visiting");
insertTeamData("home");
// highlight leading team's score
var visitingTeamScore = parseInt(data.visitingTeamScore);
var homeTeamScore = parseInt(data.homeTeamScore);
var leaderScoreEl;
if (visitingTeamScore > homeTeamScore) {
leaderScoreEl = rootEl.querySelector(".visitingTeamScore");
}
else if (visitingTeamScore < homeTeamScore) {
leaderScoreEl = rootEl.querySelector(".homeTeamScore");
}
if (leaderScoreEl) {
WinJS.Utilities.addClass(leaderScoreEl, "sportsProminentText");
}
// separator
var separatorEl = SportsJS.Controls.Utilities.createDivWithClassName("separator");
section2El.appendChild(separatorEl);
// game Info
var gameInfoEl = SportsJS.Controls.Utilities.createDivWithClassName("gameInfo sportsProminentContentTiny");
gameInfoEl.innerText = data.gameInfo;
section3El.appendChild(gameInfoEl);
return rootEl;
},
createMatchSessionScoresTile: function createMatchSessionScoresTile(responseData) {
if (!responseData || !responseData.data || !responseData.data.sessionScores || responseData.data.sessionScores.length === 0) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Templates.createMatchOverviewHeaderTile", "invalid data received");
return document.createElement("div");
}
var data = responseData.data;
var rootEl = SportsJS.Controls.Utilities.createDivWithClassName("matchSessionScores");
var titleRowEl = SportsJS.Controls.Utilities.createDivWithClassName("titleRow");
var visitingTeamRowEl = SportsJS.Controls.Utilities.createDivWithClassName("visitingTeamRow");
var homeTeamRowEl = SportsJS.Controls.Utilities.createDivWithClassName("homeTeamRow");
rootEl.appendChild(titleRowEl);
rootEl.appendChild(visitingTeamRowEl);
rootEl.appendChild(homeTeamRowEl);
//// TODO(saarya): AFAIK, we want to shown minimum of 4 quarters with 0's or -'s if not present in data [which implies 5 session, including the final column]
var numScoreCols = data.sessionScores.length; // 4 + 1 for final scores
var scoreColWidth = 550 / numScoreCols;
var scoreColStyle = "";
for(var i = 0; i < numScoreCols; i++) {
scoreColStyle += scoreColWidth + "px ";
}
var style = "20px 60px " + scoreColStyle + "20px";
titleRowEl.style.msGridColumns = visitingTeamRowEl.style.msGridColumns = homeTeamRowEl.style.msGridColumns = style;
var homeTeamAliasEl = SportsJS.Controls.Utilities.createDivWithClassName("homeTeamAlias sportsTileTitleSmall");
homeTeamAliasEl.innerText = data.homeTeamAlias;
homeTeamRowEl.appendChild(homeTeamAliasEl);
var visitingTeamAliasEl = SportsJS.Controls.Utilities.createDivWithClassName("visitingTeamAlias sportsTileTitleSmall");
visitingTeamAliasEl.innerText = data.visitingTeamAlias;
visitingTeamRowEl.appendChild(visitingTeamAliasEl);
var sessionScoresStartingCol = 3;
for (var ii = 0; ii < numScoreCols; ii++) {
var titleFontClass = "", scoreFontClass = "";
if (ii === numScoreCols - 1) {
titleFontClass = "sportsStatTitleHeavy";
scoreFontClass = "sportsStatTextHeavy";
}
else {
titleFontClass = "sportsStatTitle";
scoreFontClass = "sportsStatText";
}
var sessionLabelEl = SportsJS.Controls.Utilities.createDivWithClassName("sessionLabel " + titleFontClass);
sessionLabelEl.innerText = data.sessionScores[ii].sessionLabel;
sessionLabelEl.style.msGridColumn = ii + sessionScoresStartingCol;
titleRowEl.appendChild(sessionLabelEl);
var visitingTeamScoreEl = SportsJS.Controls.Utilities.createDivWithClassName("visitingTeamScore " + scoreFontClass);
visitingTeamScoreEl.innerText = data.sessionScores[ii].visitingTeamScore;
visitingTeamScoreEl.style.msGridColumn = ii + sessionScoresStartingCol;
visitingTeamRowEl.appendChild(visitingTeamScoreEl);
var homeTeamScoreEl = SportsJS.Controls.Utilities.createDivWithClassName("homeTeamScore " + scoreFontClass);
homeTeamScoreEl.innerText = data.sessionScores[ii].homeTeamScore;
homeTeamScoreEl.style.msGridColumn = ii + sessionScoresStartingCol;
homeTeamRowEl.appendChild(homeTeamScoreEl);
}
return rootEl;
},
createEntityLinkTile: function createEntityLinkTile(inputData)
{
if (!inputData || !inputData.data) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Templates.createEntityLinkTile", "invalid data received");
return document.createElement("div");
}
var data = inputData.data;
var tileElement = SportsJS.Controls.Utilities.createDivWithClassName("linkTile");
var mainContent = SportsJS.Controls.Utilities.createDivWithClassName("mainContent");
var isTileTransparent = false;
var imgElement;
if (data.image) {
var imgContent = SportsJS.Controls.Utilities.createDivWithClassName("imgContent");
if (SportsJS.Utilities.isGlyphUri(data.image)) {
WinJS.Utilities.addClass(imgContent, "sportsGlyph");
imgElement = SportsJS.Controls.Utilities.createSpanWithClassName(SportsJS.Utilities.getGlyphFromUri(data.image));
}
else {
if (data.imageType && data.imageType === "Player") {
imgElement = SportsJS.Controls.Utilities.createDivWithClassName("playerLogo");
}
else {
imgElement = SportsJS.Controls.Utilities.createDivWithClassName("logo");
}
var imgControl = new SportsJS.Utilities.ImgControl(imgElement);
if (imgControl) {
imgControl.imgData = data.image;
}
}
if (data.isTransparent) {
isTileTransparent = true;
}
else {
WinJS.Utilities.addClass(imgContent, "tileAlternate");
}
imgContent.appendChild(imgElement);
mainContent.appendChild(imgContent);
}
if (!isTileTransparent) {
WinJS.Utilities.addClass(tileElement, "tile");
}
var textContent = SportsJS.Controls.Utilities.createDivWithClassName("textContent");
if (data.size) {
WinJS.Utilities.addClass(textContent, "width" + data.size);
}
else {
WinJS.Utilities.addClass(textContent, "widthDefault");
}
var titleElement = SportsJS.Controls.Utilities.createDivWithClassName("title sportsTitleMedium");
titleElement.innerText = data.title;
textContent.appendChild(titleElement);
if (data.subTitle) {
var subTitleElement = SportsJS.Controls.Utilities.createDivWithClassName("subtitle sportsSnippetText");
subTitleElement.innerText = data.subTitle;
textContent.appendChild(subTitleElement);
}
mainContent.appendChild(textContent);
tileElement.appendChild(mainContent);
if (data.footer || data.date) {
var footerContent = SportsJS.Controls.Utilities.createDivWithClassName("footerContent");
var footerElement = SportsJS.Controls.Utilities.createDivWithClassName("footer sportsContentTiny");
footerElement.innerText = data.footer;
var dateElement = SportsJS.Controls.Utilities.createDivWithClassName("date sportsContentTiny");
dateElement.innerText = data.date;
footerContent.appendChild(footerElement);
footerContent.appendChild(dateElement);
tileElement.appendChild(footerContent);
}
return tileElement;
},
createSingleTextWrapTile: function createSingleTextWrapTile(inputData) {
if (!inputData || !inputData.data) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Templates.SingleTextWrapTile", "invalid data received");
return document.createElement("div");
}
var data = inputData.data;
var tileElement = SportsJS.Controls.Utilities.createDivWithClassName("singleTextWrapTile");
var setSize = function (size) {
switch (size) {
case "Large":
WinJS.Utilities.addClass(tileElement, "singleTextWrapLong");
break;
case "Medium":
WinJS.Utilities.addClass(tileElement, "singleTextWrapMedium");
break;
case "Small":
WinJS.Utilities.addClass(tileElement, "singleTextWrapSmall");
break;
default:
WinJS.Utilities.addClass(tileElement, "Unknown");
break;
}
};
if (data.text) {
tileElement.innerText = data.text;
WinJS.Utilities.addClass(tileElement, "viewTextTiny");
}
setSize(data.size);
return tileElement;
},
});
WinJS.Namespace.define("SportsJS.Controls.Templates.Configs",
{
// List of data types that support images
imageDataType: ["TeamNameWithImage", "TeamFullNameWithImage", "MovementWithImage", "PlayerNameWithImage"],
// List of data types that needs highlighting
recognizedDataType: ["PlayerNameWithImage", "TeamNameWithImage", "TeamFullNameWithImage", "TeamName", "TeamFullName",
"PlayerName", "StatName", "TournamentName", "TournamentFullName" ],
// List of data types that needs prominent color
prominentDataType: ["PlayerNameWinner"],
// mapping of entity data type to corresponding css class
entityClassByDataType: {
MovementWithImage: "movementWithImage",
PlayerNameWithImage: "playerNameWithImage",
TeamNameWithImage: "teamNameWithImage",
TeamFullNameWithImage: "teamFullNameWithImage",            
AppexSymbolSmall: "appexSymbolSmall",
TeamName: "teamName",
TeamFullName: "teamFullName",
PlayerName: "playerName",
PlayerNameWinner: "playerNameWinner",
TournamentName: "tournamentName",
TournamentFullName: "tournamentFullName",
StatName: "statName",
DateRange: "dateRange",
Message: "message",
// stat types
StatSmall: "statSmall",
StatMedium: "statMedium",
StatLong: "statLong",
StatLong2: "statLong2",
// generic types
Text0X: "text0x",
Text1X: "text1x",
Text2X: "text2x",
Text3X: "text3x",
Text4X: "text4x",
Text5X: "text5x",
Text6X: "text6x",
Text7X: "text7x",
Text8X: "text8x",
Text9X: "text9x",            
Num1X: "num1x",
Num2X: "num2x",
Num3X: "num3x",
Num4X: "num4x",  
Num5X: "num5x",  
Unknown: "unknown",
// DEPRECATED types
TeamPoints: "teamPoints",
Position: "position",
TeamRecord: "teamRecord"            
}
});
})();
