﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.Controls.Cluster",
{
/// <summary>
/// Cluster Controller - Controls data fetching and rendering tasks of a cluster. 
/// </summary>
ClusterController: WinJS.Class.define(function ClusterController_constructor(element, config) {
if (!this._validateConfig(config)) {
SportsJS.Controls.Utilities.interfaceException(this._name, "invalid cluster configuration");
return;
}
SportsJS.Controls.Utilities.writeProfilerMark(this._name, "constructor", "StartTM");
// root element of the whole cluster fragment
this._element = element ? element : document.createElement("div");
this._element.winControl = this;
WinJS.Utilities.addClass(this._element, "controlsClusterController");
this._config = config;
this._initializeModel(config.model);
this._initializeView(config);
this._id = this._config.id ? this._config.id : "";
this._telemetryId = config.telemetryId;
this._telemetryName = config.telemetryName;
this._config.clusterType = this._config.clusterType ? this._config.clusterType : "generic";
this._element.setAttribute("data-controls-type", this._config.clusterType);
// TODO: arengak - pending new implementation to control the cluster rendering order
// TODO: arengak - Remove
this._isValidObject = true;
this._onClusterRenderInitCallback = this._config.onClusterRenderInit;
this._onClusterRenderCompleteCallback = this._config.onRenderComplete;
this._viewBlockClickEventHanlder = this._handleViewBlockClickEvent.bind(this);
this._element.addEventListener("viewblockitemclicked", this._viewBlockClickEventHanlder);
SportsJS.Controls.Utilities.writeProfilerMark(this._name, "constructor", "StopTM");
}, {
_name: "SportsJS.Controls.Cluster.ClusterController",
_id: null,
_telemetryId: null,
_config: null,
_element: null,
element: {
get: function get() {
return this._element;
},
set: function set(value) {
this._element = value;
}
},
id: {
get: function get() {
return this._id;
},
set: function set(value) {
this._id = value;
}
},
// TODO: arengak - Remove
_isValidObject: false,
// instance of data model
_modelInstance: null,
// instance of cluster controller view helper class
_viewHelper: null,
// timer id used for scheduling in-line refresh task
_refreshTimer: null,
_renderClusterPromise: null,
_clusterResponse: null,
// flag to track, we have refreshed the cluster atleast once.
_isFirstRefresh: true,
// page control needs lastUpdateTime & isStaleResponse attributes in order to handle pano watermark
lastUpdateTime: null,
isStaleResponse: null,
_fetchProxyPromise: null,
_viewBlockClickEventHanlder: null,
_handleViewBlockClickEvent: function _handleViewBlockClickEvent(event) {
SportsJS.Controls.Utilities.logClusterClick(this._telemetryId, this._telemetryName);
},
// make sure all mandatory configurations are specified
// INPUT: configuration object
// OUTPUT: returns true if the input config is valid
_validateConfig: function _validateConfig(config) {
if (!config || !config.model || !config.model.modelControl) {
return false;
}
return true;
},
// creates instance of data model
// INPUT: configuration object for the model
_initializeModel: function _initializeModel(modelConfig) {
this._modelInstance = PlatformJS.Utilities.createObject(modelConfig.modelControl, modelConfig.modelControlConfig);
if (!this._modelInstance) {
SportsJS.Controls.Utilities.interfaceException(this._name, "unable to create model instance");
}
},
_cleanUpModel: function _cleanUpModel() {
if (this._modelInstance && typeof this._modelInstance.cleanUp === "function") {
return this._modelInstance.cleanUp();
}
},
// creates instance of view helper that would take care of view initialization 
// INPUT: configuration object for the view helper
_initializeView: function _initializeView(config) {
// TODO: arengak - check we can use new element instead of this._element. 
// It might help reducing count of document reflow while rendering.
var options = {
retryCallback: this._retryCallback.bind(this)
};
this._viewHelper = PlatformJS.Utilities.createObject("SportsJS.Controls.Cluster.ClusterControllerViewHelper", this._element, options);
if (!this._viewHelper) {
SportsJS.Controls.Utilities.interfaceException(this._name, "unable to create view instance");
}
},
_cleanUpView: function _cleanUpView() {
if (this._viewHelper && typeof this._viewHelper.cleanUp === "function") {
return this._viewHelper.cleanUp();
}
},
// raise view refreshed event on successful render
_raiseViewRefreshedEvent: function _raiseViewRefreshedEvent(renderStatus) {
if (renderStatus && renderStatus === true && this._clusterResponse && this._clusterResponse.lastUpdateTime
&& this._clusterResponse.lastUpdateTime instanceof Date && typeof this._clusterResponse.maxAge !== "undefined") {
this.lastUpdateTime = this._clusterResponse.lastUpdateTime;
this.isStaleResponse = this._clusterResponse.maxAge < 1;
var eventObject = document.createEvent("CustomEvent");
eventObject.initCustomEvent("datarefreshed", true, true, null);
this._element.dispatchEvent(eventObject);
}
// TODO: arengak - pending new implementation for pano watermark update
// Cluster will raise only renderBegin and renderComplete event. Page should be able to update its watermark from renderComplete event
},
// validator to decide whether we can refresh (inline refresh) the cluster 
// INPUT: current response object
// OUTPUT: returns true if we can do inline refresh
_canDoRefresh: function _canDoRefresh(response) {
// TRUE -> when we have not done any refresh OR auto refresh is enabled
// TODO: arengak - we can also consider network availability
// TODO: arengak - horizontal: needs to handle auto refresh setting across all apps
return (this._isFirstRefresh || SportsJS.SettingsManager.isAutoRefreshEnabled());
},
// computes interval (in seconds) after which cluster needs to be refreshed based on the response
// INPUT: current response object
// OUTPUT: returns interval in seconds
_computeRefreshInterval: function _computeRefreshInterval(response) {
var interval = SportsJS.Controls.Configs.refreshIntervals.onInvalid;
// when the response is not valid
if (!response || !response.isValid) {
return interval;
}
var maxAge = response.maxAge > 0 ? response.maxAge : -1;
if (maxAge < 0) {
if (this._isFirstRefresh === true) {
// we have not done any refresh and response is stale...
interval = SportsJS.Controls.Configs.refreshIntervals.minimum;
} else {
// we have already done one refresh and response is still stale.. could be some issues...
interval = SportsJS.Controls.Configs.refreshIntervals.onError;
}
} else {
// we already have valid response... choose the interval based on AutoRefreshIntervalSetting and maxAge
// TODO: arengak - horizontal: needs to handle auto refresh interval setting across all apps or assume 30 secs.
interval = Math.max(maxAge, AppEx.Sports.Services.Storage.SettingsManager.fastRefreshInterval);
}
return interval;
},
// schedules the refresh task (inline refresh) based on response
// NOTE: when auto refresh setting is disabled, we still schedule a task but we dont make data request
// INPUT: current response object
_registerForClusterRefresh: function _registerForClusterRefresh(response) {
var that = this;
var interval = that._computeRefreshInterval(response);
var canDoRefresh = that._canDoRefresh(response);
if (canDoRefresh) {
// schedule a task to refresh the cluster after the specified interval 
that._refreshTimer = SportsJS.Controls.Utilities.setTimer(that._refreshTimer, that._refreshCluster, that, interval);
} else {
// it means auto refresh is disabled... or error 
// so just schedule a task to try registering for refresh after the specified interval  
var retryRegisteringClusterRefresh = function () {
that._isFirstRefresh = false;
that._registerForClusterRefresh(response);
};
that._refreshTimer = SportsJS.Controls.Utilities.setTimer(that._refreshTimer, retryRegisteringClusterRefresh, that, interval);
}
},
// function to be used to recover from errors Eg: refresh button click in error module)
_retryCallback: function _retryCallback() {
// cancel existing refresh task before doing the refresh
SportsJS.Controls.Utilities.clearTimer(this._refreshTimer);
this._refreshCluster();
},
// abstract base class method to support render complete call back. To be implemented in derived class to be used.
renderCompleteCallback: function renderCompleteCallback() {
return;
},
// list of tasks to be done post render
_onClusterRenderComplete: function _onClusterRenderComplete(renderStatus) {
this.renderCompleteCallback();
// schedule cluster refresh task
this._registerForClusterRefresh(this._clusterResponse);
this._raiseViewRefreshedEvent(renderStatus);
},
// function to get data from the model
// INPUT: parameters object to be passed to data model while making the data fetch call
// OUTPUT: returns promise for the data fetch task
_fetchData: function _fetchData(params) {
if (this._isFirstRefresh === true && this._fetchProxyPromise) {
return this._fetchProxyPromise;
}
if (this._modelInstance && typeof this._modelInstance.getData === "function") {
return this._modelInstance.getData(params);
}
SportsJS.Controls.Utilities.interfaceException(this._name, "data model interface violation");
return WinJS.Promise.wrapError(null);
},
// INPUT: current response object
// OUTPUT: returns promise for the render task
_renderView: function _renderView(response) {
// TODO: arengak - remove dataAdapter option and its dataAdapter code.
// Note: This is just for temp use (to get the cluster working without server changes).
// will remove it once the server changes are done to send the adapted response
response = typeof this._config.dataAdapter === "function" ? this._config.dataAdapter(response) : response;
if (this._viewHelper && typeof this._viewHelper.render === "function") {
this._clusterResponse = response;
return this._viewHelper.render(response);
}
SportsJS.Controls.Utilities.interfaceException(this._name, "view helper interface violation");
return WinJS.Promise.wrapError({ message: "invalid view helper" });
},
_renderCluster: function _renderCluster(params) {
var that = this;
SportsJS.Controls.Utilities.writeProfilerMark(that._name, "_renderCluster", "StartTM");
var p = new WinJS.Promise(function ClusterController_renderClusterInit(complete, error) {
SportsJS.Controls.Utilities.writeProfilerMark(that._name, "_fetchData", "StartTM");
that._renderClusterPromise = that._fetchData(params).then(function ClusterController_fetchDataCompleteHandler(response) {
SportsJS.Controls.Utilities.writeProfilerMark(that._name, "_fetchData", "StopTM");
SportsJS.Controls.Utilities.writeProfilerMark(that._name, "_renderView", "StartTM");
return that._renderView(response);
}, function ClusterController_fetchDataErrorHandler(errorResponse) {
if (SportsJS.Controls.Utilities.isCancellationError(errorResponse)) {
// dont break the promise chain here when the render is cancled. Propagate the cancellation error here.
// We catch it at the end (renderViewErrorHandler)
return WinJS.Promise.wrapError(errorResponse);
}
// send the error response to view control to decide on rendering error.
return that._renderView(errorResponse);
}).then(function ClusterController_renderViewCompleteHandler(renderStatus) {
SportsJS.Controls.Utilities.writeProfilerMark(that._name, "_renderView", "StopTM");
that._onClusterRenderComplete(renderStatus);
SportsJS.Controls.Utilities.writeProfilerMark(that._name, "_renderCluster", "StopTM");
complete(renderStatus);
}, function ClusterController_renderViewErrorHandler(errorMessage) {
if (SportsJS.Controls.Utilities.isCancellationError(errorMessage)) {
return;
}
complete(false); // just for completeness sake... this will never happen... 
SportsJS.Controls.Utilities.interfaceException(that._name, "something has gone wrong while rendering");
});
});
return p;
},
_refreshCluster: function _refreshCluster() {
var params = { canConsumeStaleResponse: false };
this._isFirstRefresh = false;
return this._renderCluster(params);
},
// TODO: arengak - Remove
fetchProxy: function fetchProxy() {
var that = this;
return new WinJS.Promise(function (complete, error) {
var params = { canConsumeStaleResponse: true };
that._fetchProxyPromise = that._fetchData(params);
that._fetchProxyPromise.then(complete, error);
});
},
// TODO: arengak - Remove
renderProxy: function renderProxy() {
var that = this;
// this is required as renderProxy is public API, We can't assume caller to cancel this after cleanup
if (!this._isValidObject) {
return WinJS.Promise.wrap(true);
}
// we always render using cached data though it is stale then we refresh the cluster.
var params = { canConsumeStaleResponse: true };
return that._renderCluster(params).then(function (renderStatus) {
if (that._onClusterRenderCompleteCallback && typeof that._onClusterRenderCompleteCallback === "function") {
that._onClusterRenderCompleteCallback(renderStatus);
that._onClusterRenderCompleteCallback = null;
}
return WinJS.Promise.wrap(renderStatus);
});
},
// TODO: arengak - pending new implementation to control the cluster rendering order
render: function render() {
var that = this;
// TODO: arengak - Remove
if (!this._isValidObject) {
return WinJS.Promise.wrap(true);
}
if (!that._onClusterRenderInitCallback || typeof that._onClusterRenderInitCallback !== "function") {
return this.renderProxy();
}
var p = new WinJS.Promise(function (complete, error) {
// TODO: arengak - Remove
that._onClusterRenderInitCallback(that, complete);
});
return p;
},
cleanUp: function cleanUp() {
var clusterName = this._name;
SportsJS.Controls.Utilities.writeProfilerMark(clusterName, "cleanUp", "StartTM");
this._element.removeEventListener("viewblockitemclicked", this._viewBlockClickEventHanlder);
SportsJS.Controls.Utilities.clearTimer(this._refreshTimer);
SportsJS.Controls.Utilities.cancelPromise(this._fetchProxyPromise);
SportsJS.Controls.Utilities.cancelPromise(this._renderClusterPromise);
this._cleanUpModel();
this._cleanUpView();
SportsJS.Controls.Utilities.setObjectPropertiesToNull(this);
SportsJS.Controls.Utilities.writeProfilerMark(clusterName, "cleanUp", "StopTM");
}
}),
/// <summary>
/// Cluster View Helper - Helps cluster controller to control views (css/html work). 
/// </summary>
ClusterControllerViewHelper: WinJS.Class.define(function ClusterControllerViewHelper_constructor(element, config) {
if (!this._validateConfig(config) || !element) {
SportsJS.Controls.Utilities.interfaceException(this._name, "invalid cluster view helper configuration");
}
this._element = element ? element : document.createElement("div");
this._config = config ? config : {};
}, {
_name: "SportsJS.Controls.Cluster.ClusterControllerViewHelper",
_element: null,
_config: null,
_viewPortElement: null,
// flag to track, we have rendered the view atleast once.
_isFirstRendering: true,
// instance of view control used for the cluster
_viewControl: null,
_loadViewPromise: null,
// data used for the view control
_viewData: null,
// message to throw when response is rejected (ex: new response is same as previous response)
_rejectMessage: "response is rejected",
// make sure all mandatory configurations are specified
// INPUT: configuration object
// OUTPUT: returns true if the input config is valid
_validateConfig: function _validateConfig(config) {
// Note: retry can be done by event handling.
// but it is fine as view helper is also part of the cluster control
if (!config || !config.retryCallback) {
return false;
}
return true;
},
// Checks whether the new response can be rejected.
// Response is rejected if it is invalid OR violates the response interface OR not changed
// INPUT: new response object
// OUTPUT: returns true if the response can be rejected
_canRejectResponse: function _canRejectResponse(response) {
return (this._viewData && this._viewData.etag === response.etag);
},
// validates the new response
// INPUT: new response object
// OUTPUT: returns true if the response is valid
_validateResponse: function _validateResponse(response) {
if (!response || response.isValid === false) {
SportsJS.Controls.Utilities.interfaceException(this._name, "response is invalid");
return false;
}
if (!response.etag || !response.type) {
SportsJS.Controls.Utilities.interfaceException(this._name, "response interface violation");
return false;
}
return true;
},
// checks whether the given response can be consumed
// INPUT: new response object
// OUTPUT: returns wrapper promise with true if the response can be consumed
_validateResponseAsync: function _validateResponseAsync(response) {
if (!this._validateResponse(response)) {
return WinJS.Promise.wrapError({ message: "response is invalid" });
}
if (this._canRejectResponse(response)) {
return WinJS.Promise.wrapError({ message: "response is rejected" });
}
return WinJS.Promise.wrap(response);
},
// clean up the given view control
// INPUT: view control object which needs to be destoryed
_cleanupViewControl: function _cleanupViewControl(control) {
if (control && typeof control.cleanUp === "function") {
control.cleanUp();
}
},
// start the rendering task using the given given view control and data
// INPUT: view control object and data object
// OUTPUT: returns promise for the rendering task
_renderViewControl: function _renderViewControl(control, data) {
if (control && typeof control.render === "function") {
return control.render(data);
}
return WinJS.Promise.wrapError({ message: "invalid view control" });
},
// checks whether we need to repaint the view
// INPUT: old and new response objects
// OUTPUT: returns true when the new response type is differnet from previous response
_isRepaintRequired: function _isRepaintRequired(oldResponse, newResponse) {
// we repaint the cluster when the response schema is changed otherwsie let the view control to decide on.
return (!oldResponse || oldResponse.type !== newResponse.type);
},
_updateViewData: function _updateViewData(response) {
var requiresRepaint = this._isRepaintRequired(this._viewData, response);
this._viewData = response;
this._viewData.requiresRepaint = requiresRepaint;
},
// Creats a view control object
// INPUT: type => to identify the required view control, element => control element, options => options for the view control
// OUTPUT: returns promise for the creating view control task
_createViewControlAsync: function _createViewControlAsync(type, element, options) {
return SportsJS.Controls.Utilities.createViewControlAsync(type, element, options);
},
// Loads the view fragment
// Note: when the new response requires deifferent view control to render, 
//       it destorys the current view and loads a new view
// INPUT: new response object
// OUTPUT: returns promise for the loading view task
_loadView: function _loadView(response) {
if (this._isFirstRendering || response.requiresRepaint) {
// could be: new response type if different so make sure we destroy the previous control if we have
this._cleanupViewControl(this._viewControl);
//TODO: arengak - animate - smooth transition
this._element.innerHTML = "";
this._viewPortElement = SportsJS.Controls.Utilities.createDivWithClassName("controlsClusterViewBlock");
this._element.appendChild(this._viewPortElement);
this._loadViewPromise = this._createViewControlAsync(response.type, this._viewPortElement, response.uiOptions);
}
return this._loadViewPromise;
},
// sets visibility of the view to hidden when rendering the first time
_hideViewPort: function _hideViewPort() {
if (this._isFirstRendering && this._viewPortElement) {
WinJS.Utilities.addClass(this._viewPortElement, "controlsHideViewPort");
}
},
// sets visibility of the view to visible
_showViewPort: function _showViewPort() {
if (this._viewPortElement) {
WinJS.Utilities.removeClass(this._viewPortElement, "controlsHideViewPort");
}
},
// list of tasks to be done before rendering
_onRenderViewControlBegin: function _onRenderViewControlBegin() {
this._hideViewPort();
},
// list of tasks to be done after rendering
_onRenderViewControlComplete: function _onRenderViewControlComplete() {
this._showViewPort();
},
// List of tasks to be done when cluster render task is failed
// INPUT: error message/error response
_onRenderViewControlsError: function _onRenderViewControlsError(errorResponse) {
this._element.innerHTML = "";
this._viewData = null;
},
// creates error module to show when cluster render failed.
// INPUT: error message/error response
// OUTPUT: promise for the loading error module task
_loadErrorModule: function _loadErrorModule(errorResponse) {
var errorModule = CommonJS.Error.getErrorModuleItem(WinJS.Utilities.markSupportedForProcessing(this._config.retryCallback));
if (errorModule) {
errorModule.errorContainerClassName += " " + "controlsClusterErrorItem";
// hide the refresh button in case of offline.
if (!SportsJS.Controls.Utilities.isInternetAvailable) {
errorModule.errorContainerClassName += " " + "controlsClusterErrorItemOffline";
// TODO: arengak - horizontal - error message on offline
errorModule.message = PlatformJS.Services.resourceLoader.getString("NoDataInOfflineText");
}
// update the view port with the error module
this._viewPortElement = SportsJS.Controls.Utilities.createDivWithClassName("controlsClusterErrorViewBlock");
this._element.appendChild(this._viewPortElement);
return SportsJS.Controls.Utilities.loadModule(errorModule.moduleInfo, errorModule, this._viewPortElement, null, null).then(function ClusterViewHelper_loadErrorModuleComplete(fragment) {
return WinJS.Resources.processAll(fragment);
}).then(function ClusterViewHelper_loadErrorModuleProcessResourcesComplete() {
return WinJS.Promise.wrap(false);
});
}
return WinJS.Promise.wrapError(errorResponse);
},
render: function render(response) {
var that = this;
SportsJS.Controls.Services.uiThreadTimer.reset();
return that._validateResponseAsync(response).then(function ClusterControllerViewHelper_validateResponseComplete() {
that._updateViewData(response);
return that._loadView(response);
}).then(function ClusterControllerViewHelper_loadViewCompleteHandler(viewControl) {
that._viewControl = viewControl;
that._onRenderViewControlBegin();
return that._renderViewControl(viewControl, response);
}).then(function ClusterControllerViewHelper_renderViewControlsCompleteHandler() {
that._isFirstRendering = false;
that._onRenderViewControlComplete();
return WinJS.Promise.wrap(true);
}, function ClusterControllerViewHelper_renderErrorHandler(errorMessage) {
// do nothing when the promise is cancelled
if (SportsJS.Controls.Utilities.isCancellationError(errorMessage)) {
return WinJS.Promise.wrapError(errorMessage);
}
// if it is the 1st rendering and rendering failed due to any reason, show error module
if (that._isFirstRendering) {
that._onRenderViewControlsError(errorMessage);
return that._loadErrorModule(errorMessage);
}
// if the response is rejected (new response and previous response are same), just complete the render 
if (errorMessage && errorMessage.message === that._rejectMessage) {
return WinJS.Promise.wrap(true);
}
return WinJS.Promise.wrap(false);
});
},
cleanUp: function cleanUp() {
this._cleanupViewControl(this._viewControl);
SportsJS.Controls.Utilities.setObjectPropertiesToNull(this);
}
})
});
})();
