﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.Controls.Views.Decorators",
{
/// <summary>
/// View Block Decorator Base - Base class of decorators used with view block (ItemsContainerView)
/// </summary>
ViewDecoratorBase: WinJS.Class.define(function ViewDecoratorBase(viewObject, options) {
if (!viewObject || !viewObject.render || !viewObject.cleanUp ||
typeof viewObject.render !== "function" || typeof viewObject.cleanUp !== "function" ||
!viewObject.element || !viewObject.viewPortElement) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Views.Decorators.ViewDecoratorBase", "source view object is invalid");
}
this._name = viewObject && viewObject._name ? viewObject._name + this._name : "unknownViewControl" + this._name;
this._viewObject = viewObject;
this._config = options ? options : {};
this.element.winControl = this;
}, {
_name: "_ViewDecoratorBase",
_viewObject: null,
_config: null,
// mock view block's element
element: {
set: function set(value) {
this._viewObject.element = value;
},
get: function get() {
return this._viewObject.element;
}
},
// mock view block's view port element
viewPortElement: {
set: function set(value) {
this._viewObject.viewPortElement = value;
},
get: function get() {
return this._viewObject.viewPortElement;
}
},
// derived class has to implement
render: function render(response) {
SportsJS.Controls.Utilities.interfaceException(this._name, "render is undefined");
return WinJS.Promise.wrapError({ message: "render is undefined" });
},
// Default cleanup function for decorator cleanup
cleanUp: function cleanUp() {
// not doing setObjectProperties to null as it causes the source view object element to become null.
// TODO: arengak - modify the setObjectPropertiesToNull function to ignore list of properties.
this._viewObject.cleanUp();
this._viewObject = null;
this._config = null;
this._name = null;
}
}),
});
WinJS.Namespace.define("SportsJS.Controls.Views.Decorators",
{
/// <summary>
/// StickyHeaderDecorator - adds stickyheader feature to a view object
/// </summary>
StickyHeaderDecorator: WinJS.Class.derive(SportsJS.Controls.Views.Decorators.ViewDecoratorBase, function StickyHeaderDecorator_constructor(viewObject, options) {
SportsJS.Controls.Views.Decorators.ViewDecoratorBase.call(this, viewObject, options);
// TODO: arengak - how to force that it can be used only with itemsContainer/decorated itemsContainer
}, {
_name: "_StickyHeaderDecorator",
_stickyHeaderAnimator: null,
_stickyHeaderInitPromise: null,
_cleanUpStickyHeader: function _cleanUpStickyHeader() {
if (this._stickyHeaderAnimator) {
this._stickyHeaderAnimator.cleanUp();
this._stickyHeaderAnimator = null;
}
},
// initializes the sticky header for all header items in the list of items
_setupStickyHeaderAnimator: function _setupStickyHeaderAnimator() {
var viewPort = this._viewObject.viewPortElement;
var view = this._viewObject.element;
var headerElements = viewPort ? viewPort.querySelectorAll(".controlsViewStickyHeader") : null;
if (!view || !headerElements || headerElements.length < 1) {
return;
}
var headers = [];
for (var i = 0, iLength = headerElements.length; i < iLength; i++) {
// Note: controlsViewStickyHeader class needs to be applied to first child (we should have only one child) of controlsViewItem (not to the controlsViewItem)
headers.push(headerElements[i].parentNode);
}
this._stickyHeaderAnimator = new SportsJS.Controls.Components.StickyHeaderAnimator(view, viewPort, headers);
},
// mock view block's render function
// renders using the actual view block object and then initializes the sticky header
render: function render(response) {
var that = this;
return that._viewObject.render.apply(that._viewObject, [response]).then(function StickyHeaderDecorator_viewRenderComplete(result) {
// initilalizing the sticky header immediately after render complete has some issues.
// querySelector for header items, does not return header elements.. so scheduling it to setup after 100ms
SportsJS.Controls.Utilities.cancelPromise(that._stickyHeaderInitPromise);
that._stickyHeaderInitPromise = WinJS.Promise.timeout(100).then(function StickyHeaderDecorator_initAnimatorTimeoutComplete() {
that._cleanUpStickyHeader();
that._setupStickyHeaderAnimator();
});
return WinJS.Promise.wrap(result);
});
},
// mock view block's cleanup function
// destroys sticky header specific object and then destorys the actual view object
cleanUp: function cleanUp() {
SportsJS.Controls.Utilities.cancelPromise(this._stickyHeaderInitPromise);
this._cleanUpStickyHeader();
this._stickyHeaderInitPromise = null;
SportsJS.Controls.Views.Decorators.ViewDecoratorBase.prototype.cleanUp.call(this);
}
}),
/// <summary>
/// VirtualizerDecorator - simple virtualizer, renders items which are visible on screen
/// Note: - it renders only the items that are visible on the screen 
/// and remaining items will be rendered on the first scroll event/significant change in the screen size).
///       - ItemHeight needs to be specified as part of options (default is 1)
///       - The screen hight is used as view port height.
///       - Does not remove the items from the view port once it is rendered.
/// </summary>
/// TODO: chthakur - we need a very good virtualizer. 
VirtualizerDecorator: WinJS.Class.derive(SportsJS.Controls.Views.Decorators.ViewDecoratorBase, function VirtualizerDecorator_constructor(viewObject, options) {
SportsJS.Controls.Views.Decorators.ViewDecoratorBase.call(this, viewObject, options);
// TODO: arengak - how to force that it can be used only with itemsContainer/decorated itemsContainer
this._onScrollEventHandler = this._onScroll.bind(this);
this._onResizeEventHandler = this._onResize.bind(this);
this._canRenderOnScrollAndResize = true;
this._maxItemsCountToRender = 0;            
this._registerEventHandlers();
this._addVerticalScrollPatch();
}, {
_name: "_VerticalScrollDecorator",
// flag to enable/disable rendering on scroll and resize events
_canRenderOnScrollAndResize: false,
// save the origanal response that will be used to render on scroll/resize events
_completeList: null,
// tells how items to be rendered. It is set based on screen height and some other options.
_maxItemsCountToRender: null,
_onScrollEventHandler: null,
_onResizeEventHandler: null,
_renderBlockingPromise: null,
_registerEventHandlers: function _registerEventHandlers() {
if (this.viewPortElement) {
this.viewPortElement.addEventListener("scroll", this._onScrollEventHandler, false);
}
window.addEventListener("resize", this._onResizeEventHandler, false);
},
_removeEventHandlers: function _removeEventHandlers() {
if (this.viewPortElement) {
this.viewPortElement.removeEventListener("scroll", this._onScrollEventHandler, false);
}
window.removeEventListener("resize", this._onResizeEventHandler, false);
},
_addVerticalScrollPatch: function _addVerticalScrollPatch() {
if (this.viewPortElement) {
this.viewPortElement.addEventListener("mousewheel", CommonJS.Immersive.PanoramaPanel.verticalScrollHandler, false);
}
},
_removeVerticalScrollPatch: function _removeVerticalScrollPatch() {
if (this.viewPortElement) {
this.viewPortElement.removeEventListener("mousewheel", CommonJS.Immersive.PanoramaPanel.verticalScrollHandler, false);
}
},
_computeMaxItemsCountToRender: function _computeMaxItemsCountToRender(response) {
// Note: we can add some threshold to container height to improve smoothness of scroll if needed
var containerHeight = document.body.clientHeight;                
var heightSum = 0;
var maxItemsCountToRender = response.length;
for (var i = 0; i < maxItemsCountToRender; i++) {
var moduleInfo = SportsJS.Controls.Utilities.getViewItemInfoByType(response[i].type);
var itemHeight = moduleInfo && moduleInfo.itemHeight ? parseInt(moduleInfo.itemHeight) : 0;
itemHeight = itemHeight > 0 ? itemHeight : 1; // item height is 1px by default
heightSum = heightSum + itemHeight;
if (heightSum > containerHeight) {
maxItemsCountToRender = i + 1;
break;
}
}
return maxItemsCountToRender;
},
// removes items from response that are not needed for rendering
_filterResponse: function _filterResponse(response) {
this._completeList = [];
if (!this._canRenderOnScrollAndResize || !response) {
return response;
}
var maxItemsCountToRender = this._computeMaxItemsCountToRender(response);
// no filtering - when we already have rendered more items
if (this._maxItemsCountToRender > maxItemsCountToRender) {
return response;
}
this._maxItemsCountToRender = maxItemsCountToRender;
if (this._maxItemsCountToRender < response.length) {
var destObj = {};
SportsJS.Controls.Utilities.observableObjectAwareDeepCopy({ data: response }, destObj, false);
this._completeList = destObj.data;
var newResponse = [];
for (var i = 0; i < maxItemsCountToRender; i++) {
newResponse.push(response[i]);
}
response = newResponse;
}
return response;
},
_updateViewObject: function _updateViewObject(response) {
var that = this;
this._renderBlockingPromise = this._renderBlockingPromise ? this._renderBlockingPromise : WinJS.Promise.wrap(true);
this._renderBlockingPromise = this._renderBlockingPromise.then(function VirtualizerDecorator_renderOnEventBlockingCompleteHandler() {
return that._viewObject.render.apply(that._viewObject, [response]);
});
return this._renderBlockingPromise;
},
_onScroll: function _onScroll(event) {
if (!event) {
return;
}
if (event.currentTarget === this.viewPortElement) {
this._removeEventHandlers();
this._canRenderOnScrollAndResize = false;
if (this._completeList && this._completeList.length > 0) {
this._updateViewObject(this._completeList);
}
} else {
event.preventDefault();
}
},
_onResize: function _onResize(event) {
var viewState = Windows.UI.ViewManagement.ApplicationView.value;
var snappedState = Windows.UI.ViewManagement.ApplicationViewState.snapped;
if (this._completeList && this._completeList.length > 0 && viewState !== snappedState) {
var maxItemsCountToRender = this._computeMaxItemsCountToRender(this._completeList);
if (maxItemsCountToRender > this._maxItemsCountToRender) {
var response = this._filterResponse(this._completeList);
this._updateViewObject(response);
}
}
},
render: function render(response) {
var that = this;
response = response ? this._filterResponse(response) : response;
return new WinJS.Promise(function VirtualizerDecorator_renderConstructor(complete, error) {
that._updateViewObject(response).then(function VirtualizerDecorator_renderCompleteHandler() {
complete();
}, function VirtualizerDecorator_renderPromiseError(errorMessage) {
if (SportsJS.Controls.Utilities.isCancellationError(errorMessage)) {
return;
}
error(errorMessage);
});
}, function VirtualizerDecorator_renderCancelHandler() {
SportsJS.Controls.Utilities.cancelPromise(that._renderBlockingPromise);
that._renderBlockingPromise = null;
});
},
cleanUp: function cleanUp() {
SportsJS.Controls.Utilities.cancelPromise(this._renderBlockingPromise);
this._removeEventHandlers();
this._removeVerticalScrollPatch();
this._renderBlockingPromise = null;
this._completeList = null;
this._onScrollEventHandler = null;
this._onResizeEventHandler = null;
SportsJS.Controls.Views.Decorators.ViewDecoratorBase.prototype.cleanUp.call(this);
}
}),
});
})();