﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.Controls.Models",
{
/// <summary>
/// Data Model Base - interface
/// </summary>
ClusterDataModelBase: WinJS.Class.define(function ClusterDataModelBase_constructor(config) {
this._config = config;
if (!this._validateConfig(config)) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Models.ClusterDataModelBase", "invalid cluster data model configuration");
this._config = {};
}
}, {
_config: null,
// Derived class to implement if needed.
_validateConfig: function _validateConfig(config) {
return true;
},
// Derived class must implement
getData: function getData(params) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Models.ClusterDataModelBase", "missing getData definition");
return WinJS.Promise.wrapError(false);
},
// Derived class must implement
cleanUp: function cleanUp() {
SportsJS.Utilities.interfaceException("SportsJS.Controls.Models.ClusterDataModelBase", "missing cleanUp definition");
}
})
});
WinJS.Namespace.define("SportsJS.Controls.Models",
{
/// <summary>
/// Cluster Data Model - Responsible to serve data to a cluster 
/// Note: implementation is sports app specific
/// </summary>
ClusterDataModel: WinJS.Class.derive(SportsJS.Controls.Models.ClusterDataModelBase, function ClusterDataModel_constructor(config) {
SportsJS.Controls.Models.ClusterDataModelBase.call(this, config);
}, {
_queryOptionsDictionary: null,
_queryOptions: {
get: function get() {
// TODO: arengak - we need to change the query class to use only standard and fixed parameters 
// eg: (sportsType, leagueName, entitytype and entity id)
// create dictionary with all the query options specified
if (!this._queryOptionsDictionary) {
this._queryOptionsDictionary = PlatformJS.Collections.createStringDictionary();
var options = this._config.queryOptions;
if (options) {
for (var key in options) {
this._queryOptionsDictionary.insert(key, options[key]);
}
}
}
return this._queryOptionsDictionary;
}
},
// make sure all mandatory configurations are specified
_validateConfig: function _validateConfig(config) {
if (!config || !config.query) {
return false;
}
return true;
},
// create instance of query  (uiQuery in C# SportsService)
constructQuery: function constructQuery(params) {
// TODO: arengak - we may not require to construct the query every time...can be cached?
var query = new this._config.query(this._queryOptions);
if (!query || !query.isValid) {
return null;
}
query.canConsumeStaleResponse = (params && params.canConsumeStaleResponse);
query.bypassCache = (params && params.canConsumeStaleResponse === false);
return query;
},
transformer: function transformer(data) {
return data;
},
getData: function getData(params) {
var query = this.constructQuery(params);
return $SpMgr.sportsJsController.requestV2(query, this.transformer.bind(this));
},
cleanUp: function cleanUp() {
SportsJS.Controls.Utilities.setObjectPropertiesToNull(this);
}
})
});
})();
