﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.Controls.Services",
{
_uiThreadTimer: null,
uiThreadTimer: {
get: function get() {
if (!this._uiThreadTimer) {
this._uiThreadTimer = new SportsJS.Controls.Utilities.UiThreadTimer();
}
return this._uiThreadTimer;
}
}
});
WinJS.Namespace.define("SportsJS.Controls.Utilities",
{
// UI thread timer (minimalistic version)
// To track time spent in UI thread and control UI thread yielding.
// TODO: arengak/chthakur: extend the approach/find better approach to control UI thread at app wide.
UiThreadTimer: WinJS.Class.define(function uiThreadTimer_constructor(id, options) {
}, {
// max duration (in ms), a task can block UI thread.
_maxDuration: 200,
// time, at which the task acquired (started blocking) UI thread
_lastUiThreadAcquireTime: null,
// reset the timer
reset: function reset() {
this._lastUiThreadAcquireTime = null;
},
// yields UI thread when the task has spent more than the maxDuration of time in UI thread.
getUiThreadReleasePromise: function getUiThreadReleasePromise() {
var that = this;
var p = WinJS.Promise.wrap(true);
that._lastUiThreadAcquireTime = that._lastUiThreadAcquireTime ? that._lastUiThreadAcquireTime : (new Date()).getTime();
var currentTime = (new Date()).getTime();
var duration = currentTime - that._lastUiThreadAcquireTime;
if (duration > that._maxDuration) {
SportsJS.Controls.Utilities.writeProfilerMark("UiThreadTimer", "timeout", "StartTM");
p = WinJS.Promise.timeout();
p.then(function uiThreadTimer_timeoutComplete() {
SportsJS.Controls.Utilities.writeProfilerMark("UiThreadTimer", "timeout", "StopTM");
that._lastUiThreadAcquireTime = (new Date()).getTime();
}, function uiThreadTimer_timeoutError() {
that.reset();
});
}
return p;
}
}),
//// EventListener manager
EventListenerManager: WinJS.Class.define(function (options) {
var that = this;
that._listenerQueue = [];
}, {
_listenerQueue: null,
addEventListener: function addEventListener(element, event, listener, ctx, useCapture) {
var that = this;
if (!element || !event || !listener || !ctx || typeof element.addEventListener !== 'function' || typeof listener.bind !== 'function') {
return false;
}
var listenerBinding = listener.bind(ctx);
element.addEventListener(event, listenerBinding, useCapture ? useCapture : false);
that._listenerQueue.push({
element: element,
event: event,
listener: listener,
listenerBinding: listenerBinding,
});
return true;
},
removeEventListener: function removeEventListener(element, event, listener) {
var that = this;
if (!element || !event || !listener || typeof element.removeEventListener !== 'function') {
return false;
}
for (var i = 0; i < that._listenerQueue.length; i++) {
var evtListener = that._listenerQueue[i];
if (evtListener.element === element && evtListener.event === event && evtListener.listener === listener) {
var listenerBinding = evtListener.listenerBinding;
element.removeEventListener(event, listenerBinding);
that._listenerQueue.splice(i, 1);
}
}
return true;
},
purgeEventListeners: function purgeEventListeners() {
var that = this;
for (var i = 0; i < that._listenerQueue.length; i++) {
var evtListener = that._listenerQueue[i];
evtListener.element.removeEventListener(evtListener.event, evtListener.listenerBinding);
}
},
}),
// wrappers to help ease measurements
jsonParse: function jsonParse(resString) {
var resObject;
if (resString === null) {
return resObject;
}
SportsJS.Controls.Utilities.writeProfilerMark("Utilities", "jsonParse", "StartTM");
try {
resObject = JSON.parse(resString);
} catch (e) {
resObject = null;
}
SportsJS.Controls.Utilities.writeProfilerMark("Utilities", "jsonParse", "StopTM");
return resObject;
},
// wrappers to help ease measurements
jsonStringify: function jsonStringify(resObject) {
var result;
if (result === null) {
return null;
}
SportsJS.Controls.Utilities.writeProfilerMark("Utilities", "jsonStringify", "StartTM");
try {
result = JSON.stringify(resObject);
} catch (e) {
result = null;
}
SportsJS.Controls.Utilities.writeProfilerMark("Utilities", "jsonStringify", "StopTM");
return result;
},
/// <summary>
/// executeFunctionByName - calls the function given its name string
/// <param name="context">context in which the function string is valid</param>
/// </summary>
executeFunctionByName: function executeFunctionByName(context, functionName) {
context = context || window;
var args = Array.prototype.slice.call(arguments, 2);
var namespaces = functionName.split(".");
var funcName = namespaces.pop();
for (var i = 0; i < namespaces.length; i++) {
if (!context[namespaces[i]]) { return null; }
context = context[namespaces[i]];
}
var retVal;
var functionObject = context[funcName];
if (typeof functionObject === "function") {
retVal = functionObject.apply(context, args);
}
return retVal;
},
writeProfilerMark: function writeProfilerMark(controlName, functionName, type) {
msWriteProfilerMark("Sports:" + controlName + ":" + functionName + "," + type);
},
getDataId: function getDataId(element) {
if (!element) { return null; }
return element.getAttribute("data-controls-dataid");
},
setDataId: function setDataId(element, dataId) {
if (!element || !dataId) { return; }
element.setAttribute("data-controls-dataid", dataId);
},
createDivWithClassName: function createDivWithClassName(className) {
var element = document.createElement('div');
WinJS.Utilities.addClass(element, className);
return element;
},
createSpanWithClassName: function createSpanWithClassName(className) {
var element = document.createElement('span');
WinJS.Utilities.addClass(element, className);
return element;
},
interfaceException: function interfaceException(callerName, msg) {
if (!PlatformJS.isDebug) {
return;
}
try {
// throwing Error. as this would happen mostly when required fields are not found
throw new Error(callerName + msg);
} catch (e) {
}
},
dispatchCustomEvent: function dispatchCustomEvent(element, eventName, detail) {
if (!element || !eventName) {
return null;
}
var that = this;
var eventObject = document.createEvent("CustomEvent");
eventObject.initCustomEvent(eventName, true, true, detail ? detail : null);
element.dispatchEvent(eventObject);
},
setObjectPropertiesToNull: function setObjectPropertiesToNull(obj) {
if (!obj) {
return;
}
var keys = Object.keys(obj);
//// Below code nullifies element as well. This causes issues if control has eventProperties defined.
//// setting eventProperties to null tries to remove any corresponding event handlers from element
//// The code crashes if element is null
//// Hence, we would set element to null at end
for (var kk = 0; kk < keys.length; kk++) {
var key = keys[kk];
if (key === 'element' || key === '_domElement') {
continue;
}
obj[keys[kk]] = null;
}
obj.element = null;
obj._domElement = null;
},
setTimer: function setTimer(timerId, fn, ctx, timeout) {
if (!fn || !timeout || typeof fn.bind !== 'function') {
return;
}
SportsJS.Controls.Utilities.clearTimer(timerId);
timerId = setTimeout(fn.bind(ctx), timeout * 1000);
return timerId;
},
clearTimer: function clearTimer(timerId) {
if (timerId) {
clearTimeout(timerId);
timerId = null;
}
return timerId;
},
isCancellationError: function isCancellationError(error) {
if (!error) {
return false;
}
if (Array.isArray(error)) {
for (var kk = 0; kk < error.length; kk++) {
if (error[kk] && error[kk].message === "Canceled") {
return true;
}
}
}
else {
return (error && error.message === "Canceled");
}
},
cancelPromise: function cancelPromise(promise) {
if (promise && promise.cancel && typeof promise.cancel === 'function') {
promise.cancel();
}
},
isInternetAvailable: {
get: function get() {
return Platform.Networking.NetworkManager.instance.isNetworkAvailable;
}
},
resetObjectProperties: function resetObjectProperties(obj) {
if (!obj) {
return;
}
try {
for (var p in obj) {
// TODO: arengak - setting to null as of now. Can do delete on the property if really needed. 
obj[p] = null;
}
} catch (e) {
// nothing to do here.
}
},
observableObjectAwareDeepCopy: function observableObjectAwareDeepCopy(src, dest, resetDestinationObject) {
if (resetDestinationObject) {
SportsJS.Controls.Utilities.resetObjectProperties(dest);
}
SportsJS.Controls.Utilities.deepCopyJsObject(src, dest);
return true;
},
nativeObjectToJsObject: function nativeObjectToJsObject(nativeObject, convertArrayElementsToProperties, isRecurse) {
var jsObject = {};
if (!isRecurse) {
SportsJS.Controls.Utilities.writeProfilerMark("Utilities", "nativeObjectToJsObject", "StartTM");
}
SportsJS.Controls.Utilities.deepCopyJsObject(nativeObject, jsObject, convertArrayElementsToProperties, isRecurse);
if (!isRecurse) {
SportsJS.Controls.Utilities.writeProfilerMark("Utilities", "nativeObjectToJsObject", "StopTM");
}
return jsObject;
},
nativeArrayToJsArray: function nativeArrayToJsArray(nativeArray, convertArrayElementsToProperties) {
var jsArray = [];
if (nativeArray) {
for (var kk = 0, max = nativeArray.length; kk < max; kk++) {
var nativeObject = nativeArray[kk];
if (typeof nativeObject === "number" || typeof nativeObject === "string") {
jsArray.push(nativeObject);
}
else {
jsArray.push(SportsJS.Controls.Utilities.nativeObjectToJsObject(nativeObject, convertArrayElementsToProperties, true));
}
}
}
return jsArray;
},
// This function is not aware of winRT. This is normal JS deepcopy
deepCopyJsObject: function deepCopyJsObject(src, dest, convertArrayElementsToProperties, isRecurse) {
var jsObject = dest ? dest : {};
var nativeObject = src;
try {
for (var p in nativeObject) {
var curProp = nativeObject[p];
// property is object
if (curProp && typeof curProp === "object") {
//property is array
if (typeof curProp.length === 'number' && !(curProp.propertyIsEnumerable('length'))) {
var jsArray = SportsJS.Controls.Utilities.nativeArrayToJsArray(curProp, convertArrayElementsToProperties);
// In order to be able to bind array elements, they need to be converted to direct properties of the object.
// for js cache perf reasons keep only either direct properties on array. 
if (convertArrayElementsToProperties) {
var len = jsArray.length;
for (var i = 0; i < len; i++) {
jsObject[p + i.toString()] = jsArray[i];
}
} else {
jsObject[p] = jsArray;
}
}
//// For DateTimeOffset type, properties get converted into get/set methods which are getting dropped by this converter
else if (curProp instanceof Date) {
jsObject[p] = curProp;
}
else {
jsObject[p] = SportsJS.Controls.Utilities.nativeObjectToJsObject(curProp, convertArrayElementsToProperties, true);
}
}
else {
var val = null;
try {
if (p === "hashCode" && typeof curProp === "number") {
val = curProp.toString();
}
else {
val = curProp;
}
}
catch (e) { }
jsObject[p] = val;
}
}
}
catch (e) {
// Conversion from WinRT to jsObject failed. Some properties might be null. 
}
},
getItemsFromIListDataSource: function getItemsFromIListDataSource(listDataSource) {
if (!listDataSource) {
return;
}
var getItemPromises = [];
return listDataSource.getCount().then(function (c) {
for (var i = 0; i < c; i++) {
getItemPromises.push(listDataSource.itemFromIndex(i));
}
return WinJS.Promise.join(getItemPromises);
});
},
// funcution to get all view controls used in a fragment
// - a view control should have set "viewControl" class to its element
// - a view control should have render and cleanUp functions
getViewControls: function getViewControls(viewFragment) {
var controls = [];
if (!viewFragment) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Utilities.getViewControls", "invalid view fragment");
return controls;
}
// TODO: arengak - do we need query on the element only at first level? -- confirm
var viewControlElements = viewFragment.querySelectorAll(".viewControl");
for (var i = 0, iLength = viewControlElements.length; i < iLength; i++) {
var viewElement = viewControlElements[i];
var viewControl = viewElement.winControl;
if (viewControl) {
if (typeof viewControl.render === "function" && typeof viewControl.cleanUp === "function") {
// Note: order of pushing of viewControls = order of rendering of viewControls
controls.push(viewControl);
} else {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Utilities.getViewControls", "invalid viewControl");
}
}
}
return controls;
},
// loads the appropriate fragment of the view control then creates instance of the view control 
// type -> actually type of a response
createViewControlAsync: function createViewControlAsync(type, element, options, blockingPromise) {
blockingPromise = blockingPromise ? blockingPromise : WinJS.Promise.wrap(true);
return blockingPromise.then(function (param) {
if (!SportsJS.Controls.Configs.viewControlInfoByDataType[type]) {
return WinJS.Promise.wrapError({ message: "unable to find view control for the type" });
}
var viewFragmentPath = SportsJS.Controls.Configs.viewControlInfoByDataType[type].fragmentPath;
var controlName = SportsJS.Controls.Configs.viewControlInfoByDataType[type].name;
return SportsJS.Controls.Utilities.createObjectAsync(controlName, viewFragmentPath, element, options);
});
},
// loads the given fragment then creates instance of a decorator
createDecoratedObjectAsync: function createDecoratedObjectAsync(srcObj, decorator, fragmentPath, options) {
if (!srcObj || !decorator) {
return WinJS.Promise.wrapError({ message: "invalid decorator name" });
}
return SportsJS.Controls.Utilities.createObjectAsync(decorator, fragmentPath, srcObj, options);
},
// loads the given fragment then creates instance of the class
// if the fragment path is not specified, it will be ignored. 
createObjectAsync: function createObjectAsync(className, fragmentPath, arg1, arg2) {
if (!className) {
return WinJS.Promise.wrapError({ message: "invalid class name" });
}
var fragmentLoadPromise = WinJS.Promise.wrap(true);
if (fragmentPath) {
fragmentLoadPromise = WinJS.UI.Fragments.cache(fragmentPath);
}
return fragmentLoadPromise.then(function ControlsUtilities_createObjectAsyncFragmentCacheComplete() {
var obj = PlatformJS.Utilities.createObject.apply(this, [className, arg1, arg2]);
if (obj) {
return WinJS.Promise.wrap(obj);
}
return WinJS.Promise.wrapError({ message: "unable to create object" });
});
},
// function to update standard (controls standard) CSS class based on module item data
updateModuleItemClass: function updateModuleItemClass(moduleInfo, itemData, itemNode) {
if (!itemNode || !itemNode.children || itemNode.children.length < 1 || !itemData) {
return;
}
// template should have a covering node.
if (itemNode.children.length > 1) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Utilities.updateModuleItemClass", "template does not have covering node");
return;
}
var element = itemNode.children[0];
WinJS.Utilities.addClass(element, "controlsViewTemplate");
// apply header classes
if (itemData.isGroupHeader) {
if (itemData.id) {
WinJS.Utilities.addClass(element, "controlsViewGroupHeader" + itemData.id);
} else {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Utilities.updateModuleItemClass", "missing header id");
}
}
if (itemData.isStickyHeader) {
WinJS.Utilities.addClass(element, "controlsViewStickyHeader");
}
if (itemData.id) {
element.setAttribute("data-controls-id", itemData.id);
}
},
// function to disable click animation and remove respective CSS classes
resetClickAnimation: function resetClickAnimation(element) {
if (element) {
PlatformJS.Utilities.disablePointerUpDownAnimations(element);
WinJS.Utilities.removeClass(element, "viewItemClickable");
}
},
// enable click animation on the given element
setClickAnimation: function setClickAnimation(element, isEnable) {
if (element && isEnable) {
PlatformJS.Utilities.enablePointerUpDownAnimations(element);
WinJS.Utilities.addClass(element, "viewItemClickable");
}
},
// if moduleInfo has renderer then the render function will be used to load the module
// otherwise CommonJS.loadmodule will be used
loadModule: function loadModule(moduleInfo, data, parentElement) {
SportsJS.Controls.Utilities.resetClickAnimation(parentElement);
if (moduleInfo && moduleInfo.renderer && moduleInfo.fragmentPath) {
parentElement = parentElement ? parentElement : document.createElement("div");
return WinJS.UI.Fragments.cache(moduleInfo.fragmentPath).then(function ControlsUtilities_loadModuleFragmentCacheComeplte() {
var addToParentNode = function (moduleFragment) {
if (moduleFragment) {
parentElement.appendChild(moduleFragment);
SportsJS.Controls.Utilities.updateModuleItemClass(moduleInfo, data, parentElement);
} else {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Utilities.loadModule", "unable to render the module");
}
SportsJS.Controls.Utilities.setClickAnimation(parentElement, (data && (data.clickTarget || data.clickHandler)));                        
return WinJS.Promise.wrap(parentElement);
};
var renderedModule = SportsJS.Controls.Utilities.executeFunctionByName(window, moduleInfo.renderer, data);
if (WinJS.Promise.is(renderedModule)) {
return renderedModule.then(addToParentNode);
} else {
return addToParentNode(renderedModule);
}
});
}
return CommonJS.loadModule(moduleInfo, data, parentElement, null, null).then(function ControlsUtilities_commonJSLoadModuleComeplte() {
SportsJS.Controls.Utilities.setClickAnimation(parentElement, (data && (data.clickTarget || data.clickHandler)));
SportsJS.Controls.Utilities.updateModuleItemClass(moduleInfo, data, parentElement);
return WinJS.Promise.wrap(parentElement);
});
},
//function to clone the input options recevied for any controls/views
cloneOptions: function cloneOptions(inputOptions) {
if (!inputOptions) {
return {};
}
var clone = SportsJS.Controls.Utilities.jsonParse(SportsJS.Controls.Utilities.jsonStringify(inputOptions));
return clone ? clone : {};
},
// function to decorate a control (view block) with sticky header feature
addStickyHeader: function addStickyHeader(control) {
if (!control) {
return control;
}
var decoratedControl = new SportsJS.Controls.Views.Decorators.StickyHeaderDecorator(control);
if (!decoratedControl) {
decoratedControl = control;
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Utilities.addStickyHeader", "unable to use sticky header");
}
return decoratedControl;
},
// function to decorate a control (view block) with virtualizer feature
addVirtualizer: function addVirtualizer(control, options) {
if (!control) {
return control;
}
var decoratedControl = new SportsJS.Controls.Views.Decorators.VirtualizerDecorator(control, options);
if (!decoratedControl) {
decoratedControl = control;
SportsJS.Controls.Utilities.interfaceException(this._name, "unable to use virtualizer");
}
return decoratedControl;
},
// callback for keydown events on navigable items in cluster
navigationKeydownListener: function navigationKeydownListener(e) {
var that = this;
if (!e || !e.keyCode || !e.srcElement) {
return;
}
// move the focus to appropriate neighbor cluster
if (e.keyCode === WinJS.Utilities.Key.rightArrow) {
CommonJS.NavigableView.dispatchBoundaryEvent(e.srcElement, CommonJS.NavigableView.Direction.RIGHT);
e.stopPropagation();
}
else if (e.keyCode === WinJS.Utilities.Key.leftArrow) {
CommonJS.NavigableView.dispatchBoundaryEvent(e.srcElement, CommonJS.NavigableView.Direction.LEFT);
e.stopPropagation();
}
},
isAppexSymbolType: function isAppexSymbolType(type) {
if (!type) {
SportsJS.Controls.Utilities.interfaceException("SportsJS.Controls.Utilities.isAppexSymbolType", "type is undefined");
return false;
}
return type.match("^AppexSymbol") !== null;
},
getViewItemInfoByType: function getViewItemInfoByType(type) {
return SportsJS.Controls.Configs.viewItemInfoByType[type];
},
logClusterClick: function logClusterClick(telemetryId, telemetryName) {
//Telemetry function is called directly to keep common controls code
//independent of SportsJS.Telemetry
var config = {};
config.ClusterID = telemetryId;
if (telemetryName) {
config.ClusterName = telemetryName;
}
var jsonString = SportsJS.Controls.Utilities.jsonStringify(config);
Platform.Telemetry.FlightRecorder.logUserActionWithJsonAttributes(
Platform.Telemetry.LogLevel.normal,
"Cluster",
"Cluster Tile",
"click",
0,
0,
jsonString);
}
});
WinJS.Namespace.define("SportsJS.Controls.Configs",
{
// refresh intervals used by cluster controller to schedule inline refresh task
refreshIntervals: {
minimum: 5,     // 5 secs
onInvalid: 60,  // 1 minute
onError: 300,   // 5 minutes
},
// mapping of view item type to its module/tempalte information
viewItemInfoByType: {
// for table row, header, etc
CombinedScheduleGameHeaderTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createCombinedScheduleGameHeaderTile",
itemHeight: "30px"
},
CombinedScheduleGameTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createCombinedScheduleGameTile",
itemHeight: "50px"
},
// for table row, header, etc
InlinedItemsTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createInlinedItemsTile",
itemHeight: "50px"
},
// for table header
InlinedItemsHeaderTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createInlinedItemsHeaderTile",
itemHeight: "30px"
},
// for multi line tile
InlinedItemsTileV2: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createInlinedItemsTileV2",
itemHeight: "60px"
},
InlinedItemsTileV3: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createInlinedItemsTileV3",
itemHeight: "38px"
},
// tab with a text
TextTabTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
templateId: "textTabTileTemplate"
},
//title & result
GameHeaderTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
templateId: "gameHeaderTileTemplate",
itemHeight: "30px"
},
//2 teams with status
GameTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
templateId: "gameTileTemplate",
itemHeight: "80px"
},
MessageControl: {
fragmentPath: "/SportsCommonControls/core/ClusterController.html",
templateId: "messageTileTemplate"
},
//Banner items
BannerTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createBannerTile",
itemHeight: "80px"
},
// Match overview header tile
MatchOverviewHeaderTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createMatchOverviewHeaderTile",
},
// Match session scores tile
MatchSessionScoresTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createMatchSessionScoresTile",
},
// Match leaders tile, shows single stat for a leader
MatchLeadersSingleStatTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createMatchLeadersSingleStatTile"
},
//entity link tile
EntityLinkTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createEntityLinkTile"
},
//Match Summary Tile
GameEntityRecordTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
templateId: "gameEntityRecordTileTemplate",
},
//Match Summary Tile
SummaryDetailTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
templateId: "summaryDetailTileTemplate",
},
//Match Summary Tile
MetadataTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
templateId: "metadataTileTemplate",
},
// SingleTextWrapTile tile
SingleTextWrapTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createSingleTextWrapTile"
},
//More Sports Tile
MoreSportsTile: {
fragmentPath: "/SportsCommonControls/TileTemplates/TileTemplates.html",
renderer: "SportsJS.Controls.Templates.createMoreSportsTile"
}
},
// mapping of response type to corresponding control and its fragment path
viewControlInfoByDataType: {
MessageControl: {
name: "SportsJS.Controls.ViewControls.MessageControl",
},
ListControl: {
fragmentPath: "/SportsCommonControls/ListControl/ListControl.html",
name: "SportsJS.Controls.ViewControls.ListControl",
},
MixedListControl: {
fragmentPath: "/SportsCommonControls/MixedListControl/MixedListControl.html",
name: "SportsJS.Controls.ViewControls.MixedListControl",
},
TempClusterViewControl: {
fragmentPath: "/SportsCommonControls/TempClusterControl/TempClusterControl.html",
name: "SportsJS.Controls.ViewControls.TempClusterViewControl",
},
},
});
})();
