﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.Controls.ViewBlocks",
{
/// <summary>
/// View Block Base - interface of a view block. 
/// </summary>
ViewBlockBase: WinJS.Class.define(function ViewBlockBase_constructor(element, options) {
this._element = element || document.createElement("div");
WinJS.Utilities.addClass(this._element, "viewBlock");
this._element.winControl = this;
this._config = options ? options : {};
}, {
_name: "SportsJS.Controls.ViewBlocks.ViewBlockBase",
_element: null,
_viewPortElement: null,
_config: null,
element: {
set: function set(value) {
this._element = value;
},
get: function get() {
return this._element;
}
},
viewPortElement: {
set: function set(value) {
this._viewPortElement = value;
},
get: function get() {
if (!this._viewPortElement) {
SportsJS.Controls.Utilities.interfaceException(this._name, "_viewPortElement is undefined");
}
return this._viewPortElement;
}
},
render: function render(response) {
SportsJS.Controls.Utilities.interfaceException(this._name, "render function is undefined");
return WinJS.Promise.wrapError({ message: "cleanUp function is undefined" });
},
cleanUp: function cleanUp() {
SportsJS.Controls.Utilities.interfaceException(this._name, "cleanUp function is undefined");
}
})
});
WinJS.Namespace.define("SportsJS.Controls.ViewBlocks",
{
/// <summary>
/// ChromeView - View block to render an item.
/// </summary>
ChromeView: WinJS.Class.derive(SportsJS.Controls.ViewBlocks.ViewBlockBase, function ChromeView_constructor(element, options) {
SportsJS.Controls.ViewBlocks.ViewBlockBase.call(this, element, options);
WinJS.Utilities.addClass(this._element, "chormeViewBlock");
this._viewPortElement = SportsJS.Controls.Utilities.createDivWithClassName("chormeViewBlockContainer");
this._viewPortElement.tabIndex = 0;
this._viewPortElement.addEventListener("keydown", SportsJS.Controls.Utilities.navigationKeydownListener, true);
this._element.appendChild(this._viewPortElement);
}, {
_name: "SportsJS.Controls.ViewBlocks.ChromeView",
_chromeData: null,
// validates the response received for rendering.
_isValidResponse: function _isValidResponse(response) {
if (!response || !response.type || !SportsJS.Controls.Utilities.getViewItemInfoByType(response.type)) {
return false;
}
return true;
},
// creates a new data source using the response and render
_createView: function _createView(response) {
this._chromeData = response;
var moduleInfo = SportsJS.Controls.Utilities.getViewItemInfoByType(response.type);
return SportsJS.Controls.Utilities.loadModule(moduleInfo, this._chromeData, this._viewPortElement, null, null);
},
_refreshView: function _refreshView(response) {
// reload the module if response schema is not same
if (this._chromeData.type !== response.type || this._chromeData.hashCode !== response.hashCode) {
//TODO: arengak - animate?
this.viewPortElement.innerHTML = "";
return this._createView(response);
}
return WinJS.Promise.wrap(true);
},
render: function render(response) {
if (this._isValidResponse(response)) {
return this._chromeData ? this._refreshView(response) : this._createView(response);
}
return WinJS.Promise.wrapError({ message: "invalid response" });
},
cleanUp: function cleanUp() {
this._viewPortElement.removeEventListener("keydown", SportsJS.Controls.Utilities.navigationKeydownListener, true);
SportsJS.Controls.Utilities.setObjectPropertiesToNull(this);
}
}),
/// <summary>
/// Sports Container View - View block to render list of items.
/// Wrapper over CommonJS.ItemsContainer class. 
/// Supports itemClick, refresh using data binding, ordered rendering, template change. 
/// </summary>
ItemsContainerView: WinJS.Class.derive(SportsJS.Controls.ViewBlocks.ViewBlockBase, function ItemsContainerView_constructor(element, options) {
SportsJS.Controls.ViewBlocks.ViewBlockBase.call(this, element, options);
WinJS.Utilities.addClass(this._element, "itemsContainerViewBlock");
this._listControl = this._createListControl(this._config);
this._viewPortElement = this._listControl.element;
WinJS.Utilities.addClass(this._viewPortElement, "itemsContainerViewBlockContainer");
this._element.appendChild(this._listControl.element);
}, {
_name: "SportsJS.Controls.ViewBlocks.ItemsContainerView",
// instance of commonJS items container control
_listControl: null,
// binding list data source that is used to render the list control
_listDataSource: null,
// flag to track we have rendered atleast once
_isFirstRendering: true,
// to chain and track load module promises
_previousLoadModulePromise: null,
// to track render promise
_renderBlockingPromise: null,
// set CommonJS.ItemsContainer control options
_setListControlOptions: function _setListControlOptions(control, options) {
var that = this;
WinJS.UI.setOptions(control, {
className: options && options.innerListContainerClass ? options.innerListContainerClass : "",
onitemclick: function onitemclick(element) {
if (element && element.item) {
that._onItemClick.apply(that, [element, { data: element.item }]);
}
}
});
},
// creates instance of CommonJS.ItemsContainer control
_createListControl: function _createListControl(options) {
var control = new CommonJS.Immersive.ItemsContainer();
this._setListControlOptions(control, options);
return control;
},
// click event handler function for items in the list.
_onItemClick: function _onItemClick(element, item) {
if (!item || !item.data) {
return;
}
if (item.data.clickTarget) {
SportsJS.Controls.Utilities.dispatchCustomEvent(this._element, "viewblockitemclicked");
// platfrom itemsContainer already takes care of instrumentation-- confirm.
// $SpMgr.instrumentationManager.logClick(item.data);
SportsJS.Utilities.navigateTo(item.data.clickTarget);
}
else if (item.data.clickHandler && typeof item.data.clickHandler === "function") {
var parentElement = item.data._parentElementReference && typeof item.data._parentElementReference === "function" ? item.data._parentElementReference() : null;
// invoke the click handler with data, event element and root node of source element of the event (.i.e viewItem element)
item.data.clickHandler(item.data, element, parentElement);
}
// TODO: arengak - list control can fire item clicked event here
},
_createItem: function _createItem(itemConfig) {
return SportsJS.Controls.Services.uiThreadTimer.getUiThreadReleasePromise().then(function ItemsContainerView_timeoutComplete() {
return SportsJS.Controls.Utilities.loadModule(itemConfig.moduleInfo, itemConfig.data, itemConfig.parentElement, null, null);
}).then(function ItemsContainerView_createItem_loadModuleComplete(renderedItem) {
CommonJS.Immersive.ItemsContainer.reActivate(renderedItem);
return WinJS.Promise.wrap(renderedItem);
});
},
// custom renderer function of the list control (CommonJS.ItemsContainer)
_itemRenderer: function _itemRenderer(item) {
var that = this;
var parentElement = document.createElement("div");
parentElement.setAttribute("data-controls-viewitem", item.data.type);
WinJS.Utilities.addClass(parentElement, "itemsContainerViewItem");
if (!item || !item.data || !item.data.type) {
return parentElement;
}
var moduleInfo = SportsJS.Controls.Utilities.getViewItemInfoByType(item.data.type);
if (!moduleInfo) {
return parentElement;
}
var itemConfig = {
moduleInfo: moduleInfo,
data: item.data,
parentElement: parentElement,
};
// save the refrence of parent node in order to hanlde item type change in refresh
// NOTE: could be an issue when the parent element has been removed from DOM but could not find any such scenarios
// NOTE: there should not be any dependency between parent (itemsContainerViewItem) and the content (tile)
item.data._parentElementReference = function () { return parentElement; };
that._previousLoadModulePromise = that._previousLoadModulePromise ? that._previousLoadModulePromise : WinJS.Promise.wrap(true);
var loadModulePromise = that._previousLoadModulePromise.then(function ItemsContainerView_previousLoadModuleComplete() {
return that._createItem(itemConfig);
});
that._previousLoadModulePromise = loadModulePromise;
return parentElement;
},
// validates the response received for rendering.
// As of now, we consider only array as valid response
_isValidResponse: function _isValidResponse(response) {
if (!response || !Array.isArray(response) || response.length < 1) {
return false;
}
return true;
},
// function defines how to update an item while refreshing the list data source.
_updateItem: function _updateItem(oldItem, newItem) {
var bkpParentReference = oldItem._parentElementReference;
SportsJS.Controls.Utilities.observableObjectAwareDeepCopy(newItem, oldItem, true);
oldItem._parentElementReference = bkpParentReference;
var moduleInfo = SportsJS.Controls.Utilities.getViewItemInfoByType(newItem.type);
var parentElement = oldItem._parentElementReference && typeof oldItem._parentElementReference === "function" ? oldItem._parentElementReference() : null;
if (moduleInfo && parentElement) {
var itemConfig = {
moduleInfo: moduleInfo,
data: oldItem,
parentElement: parentElement
};
parentElement.setAttribute("data-controls-viewitem", newItem.type);
// TODO: arengak - animate
parentElement.innerHTML = "";
// TODO: arengak - PROBLEM: when parent element has dependency on the item. Eg: enable/disable click.
return this._createItem(itemConfig);
} else {
// we dont have enough info to repaint... just ignore it...
SportsJS.Controls.Utilities.interfaceException(this._name, "could not repaint");
}
return WinJS.Promise.wrap(true);
},
_itemComparator: function _itemComparator(item1, item2) {
// must review before checkin
if (item1.type === item2.type &&
typeof item1.hashCode !== 'undefined' &&
typeof item2.hashCode !== 'undefined' &&
item1.hashCode &&
item2.hashCode &&
item1.hashCode !== "0" && // 0 means not set
item2.hashCode !== "0" &&
item1.hashCode === item2.hashCode) {
return true;
}
// we return false when we are unable to compare/they are actually different.
return false;
},
// refresh the bindingList data source based on the new items. 
_refreshBindingListDataSource: function _refreshBindingListDataSource(dataSource, newItems) {
var that = this;
dataSource.beginEdits();
return SportsJS.Controls.Utilities.getItemsFromIListDataSource(dataSource).then(function ItemsContainerView_getListItemsComplete(listItems) {
var listItemsCount = listItems.length;
var newItemsCount = newItems.length;
var minCount = Math.min(listItems.length, newItems.length);
var promiseStack = [WinJS.Promise.wrap(true)];
for (var i = 0; i < minCount; i++) {
var oldItem = listItems[i].data;
var newItem = newItems[i];
if (!that._itemComparator(oldItem, newItem)) {
promiseStack.push(that._updateItem(oldItem, newItem));
}
}
if (listItemsCount < newItemsCount) {
for (var j = listItemsCount; j < newItemsCount; j++) {
var item = newItems[j];
dataSource.insertAtEnd(null, item);
}
} else if (listItemsCount > newItemsCount) {
for (var k = newItemsCount; k < listItemsCount; k++) {
dataSource.remove(listItems[k].key);
}
}
return WinJS.Promise.join(promiseStack);
}).then(function ItemsContainerView_refreshBindingListComplete() {
dataSource.endEdits();
return WinJS.Promise.wrap(true);
});
},
// adapts the response for CommonJS.ItemsContainer 
// moduleInfo should be avilable with every items
_adaptResponse: function _adaptResponse(response) {
var that = this;
for (var i = 0, iLength = response.length; i < iLength; i++) {
response[i].moduleInfo = {
renderer: that._itemRenderer.bind(that),
isInteractive: true
};
}
return response;
},
// creates a new data source using the response and render
_createView: function _createView(response) {
var observableResponse = response;
this._viewPortElement.innerHTML = "";
var bindingList = new WinJS.Binding.List(observableResponse);
this._listControl.itemDataSource = this._listDataSource = bindingList.dataSource;
return this._listControl.render();
},
// updates the existing data source with the response
_refreshView: function _refreshView(response) {
if (!this._listDataSource) {
return WinJS.Promise.wrapError({ message: "data source is not available for refresh" });
}
return this._refreshBindingListDataSource(this._listDataSource, response);
},
render: function render(response) {
var that = this;
if (!that._isValidResponse(response)) {
return WinJS.Promise.wrapError({ message: "invalid response" });
}
var destObj = {};
SportsJS.Controls.Utilities.observableObjectAwareDeepCopy({ data: response }, destObj, false);
response = that._adaptResponse(destObj.data);
var p = new WinJS.Promise(function ItemsContainerView_renderPromiseConstructor(complete, error) {
that._renderBlockingPromise = that._renderBlockingPromise ? that._renderBlockingPromise : WinJS.Promise.wrap(true);
that._renderBlockingPromise.then(function ItemsContainerView_renderViewComplete() {
return that._isFirstRendering ? that._createView(response) : that._refreshView(response);
}).then(function ItemsContainerView_renderViewComplete() {
// wait till all load module taks to be complete
that._previousLoadModulePromise = that._previousLoadModulePromise ? that._previousLoadModulePromise : WinJS.Promise.wrap(true);
return that._previousLoadModulePromise;
}).then(function ItemsContainerView_loadModulePromiseComplete() {
that._isFirstRendering = false;
complete(true);
}, function ItemsContainerView_renderPromiseError(errorMessage) {
if (SportsJS.Controls.Utilities.isCancellationError(errorMessage)) {
return;
}
error(errorMessage);
});
}, function ItemsContainerView_renderPromiseCancelHandler() {
// the caller wants to cancel the rendering... cancel all pending rendering works.
SportsJS.Controls.Utilities.cancelPromise(that._renderBlockingPromise);
SportsJS.Controls.Utilities.cancelPromise(that._previousLoadModulePromise);
// We dont track rendering state at each item level. So when the rendering is canceled,
// We dont know howmany items have been rendered and howmany are pending. 
// setting isFirstRendering = "true" so that next render call will re-create the list.
that._isFirstRendering = true;
that._renderBlockingPromise = null;
that._previousLoadModulePromise = null;
});
return p;
},
/// cleanup function - to free all used resources
cleanUp: function cleanUp() {
SportsJS.Controls.Utilities.cancelPromise(this._renderBlockingPromise);
SportsJS.Controls.Utilities.cancelPromise(this._previousLoadModulePromise);
this._listControl.dispose();
SportsJS.Controls.Utilities.setObjectPropertiesToNull(this);
}
})
});
})();
