﻿(function () {
"use strict";
WinJS.Namespace.define("SportsJS.UI", {
LegendFlyout: WinJS.Class.define(function (element, options) {
if (!options || !options.leagueType) {
throw new Error("SportsJS.UI.LegendFlyout: Missing mandatory option leagueType");
}
var that = this;
element = element || document.createElement("div");
this._options = options;
//// Init the flyout
this._flyout = new WinJS.UI.Flyout(element);
//// Add class to flyout so that css can be customized
WinJS.Utilities.addClass(this._flyout.element, "sportsLegendFlyout");
//// Needs to be done, otherwise the flyout doesnt show up
document.getElementById("platformPageArea").appendChild(this._flyout.element);
},
{
_options: null,
_flyout: null,
_legendEntries: null,
show: function show(anchor, placement) {
var that = this;
//// Get the itemTemplate for legend module listView
var legendFragmentPath = "/sportsLegend/sportsLegend.html";
var promises = [WinJS.UI.Fragments.cache(legendFragmentPath), SportsJS.UI.LegendFlyout._getLegendEntries(that._options.leagueType)];
return WinJS.Promise.join(promises).then(function (response) {
var moduleFragment = response[0];
that._legendEntries = response[1];
if (!that._legendEntries || that._legendEntries.length === 0) {
return;
}
//// Init the datasource for legend module listView
var legendDataSource = new WinJS.Binding.List(that._legendEntries);
if (!moduleFragment) {
return;
}
WinJS.UI.processAll(moduleFragment);
var legendEntryTemplate = moduleFragment.querySelector(".sportsLegendEntryTemplate");
if (!legendEntryTemplate) {
return;
}
//// Load the legend module inside the flyout
var legendModuleInfo = {
fragmentPath: legendFragmentPath,
templateId: "sportsLegendTemplate",
};
CommonJS.loadModule(
legendModuleInfo,
{
legendDataSource: legendDataSource.dataSource,
legendEntryTemplate: legendEntryTemplate,
},
that._flyout.element,
null,
null).then(function (legendContainer) {
that._flyout.show(anchor, placement);
});
}, function () {
console.log("");
// do nothing
});
},           
},
{
_getLegendEntries: function _getLegendEntries(league) {
var that = this;
return SportsJS.UI.LegendFlyout.legendAcronyms(league).then(
function (response) {
var leagueEntries = [];
if (response && response.response.isValid) {
var glossaryData = response.response.data.Response.Glossary;
for (var i = 0; i < glossaryData.length; i++) {
var singleEntry = SportsJS.UI.LegendFlyout._createLegendEntry(glossaryData[i]);
if (singleEntry) {
leagueEntries.push(singleEntry);
}
}
if (leagueEntries.length > 0) {
//// Sort the entries 
leagueEntries.sort(function (entry1, entry2) {
var abbreviation1 = entry1.abbreviation.toUpperCase();
var abbreviation2 = entry2.abbreviation.toUpperCase();
if (abbreviation1 > abbreviation2) {
return 1;
}
else if (abbreviation1 < abbreviation2) {
return -1;
}
return 0;
});
}
}
return leagueEntries;
});
},
//// Returns a promise whose response will provide array of legend acronyms per sport.
legendAcronyms: function legendAcronyms(league) {
var glossaryPromise = new WinJS.Promise(function (complete) {
var controller = AppEx.Sports.Services.SportsController();
var uiQuery = new AppEx.Sports.Services.TypeDefs.Request.LeagueGlossaryQuery(league);
uiQuery.bypassCache = false;
controller.requestV2(uiQuery).then(function (res) {
var isValidResponse = false;
var glossary = null;
if (res && res.dataString) {
glossary = SportsJS.Utilities.jsonParse(res.dataString);
}
if (glossary && glossary.Results && glossary.Results.length === 1 && glossary.Results[0]) {
complete({ response: { data: glossary.Results[0], isValid: true }, meta: res });
}
else {
complete({ response: { isValid: false }, meta: {} });
}
});
});
return glossaryPromise;
},
_createLegendEntry: function _createLegendEntry(legendData) {
var entry = {
abbreviation: legendData.Key,
description: legendData.Value,
};
return entry;
}
})
});
})();
