﻿(function () {
"use strict";
WinJS.Namespace.define("SportsJS", {
EntityBase: WinJS.Class.derive(SportsJS.Page,
/// <summary>
/// Constructor for entity base class
/// </summary>
/// <param name="state">
/// The state object passed to WinJS.Navigation.navigate or the state object
/// preserved when the page has been navigated away from
/// </param>
function (state) {
// support search
state = SportsJS.Utilities.entityStateAdapter(state);
if (!state || !state.entityType || !state.entityId) {
return;
}
var sports = SportsJS.Page.getSportsFromPageInfo(state);
if (!sports) {
this._isValid = false;
return false;
}
if (state.pageType) {
this._pageType = state.pageType;
}
this._leagueName = sports;
this._leagueType = sports;
this._entityId = state.entityId;
this._entityType = state.entityType;
this._basePageConstructor(state);
this._isValid = true;
},
{
_pinButtonControl: null,
_unpinButtonControl: null,
_isValid: false,
_pageType: null,
_entityType: null,
_entityData: null,
_entityId: null,
getPageImpressionContext: function getPageImpressionContext() {
if (this._pageType === SportsJS.UI.PageType.League || this._pageType === SportsJS.UI.PageType.Home) {
var telemetryName = SportsJS.Telemetry.getSportsTelemetryName(this.leagueType);
var context = SportsJS.Utilities.stringFormat("/{0}{1}", SportsJS.UI.PageType.League, telemetryName);
return context;
} else {
return "/" + this._pageType;
}
},
_logTelemetry: function _logTelemetry() {
if (this._entityType === SportsJS.UI.EntityType.Team) {
var teamUnivId = SportsJS.Utilities.stringFormat("{0}/{1}",this.leagueType, this._entityId);
SportsJS.Telemetry.logContent(this._entityType, teamUnivId, this.leagueType, this._entityData.entityDisplayName);
SportsJS.Telemetry.logContentAsSearch(SportsJS.Utilities.stringFormat("/{0}/{1}/{2}", SportsJS.UI.EntityType.Team, this.leagueType, this._entityId));
} else {
SportsJS.Telemetry.logContent(this._entityType, this._entityId, this.leagueType, this._entityData.entityDisplayName);
SportsJS.Telemetry.logContentAsSearch(this._entityData);
}
},
entityId: {
get: function get() {
if (!this._entityId) {
throw new Error("required _entityId is missing");
}
return this._entityId;
}
},
// league type is mandatory for entity pages
leagueType: {
get: function get() {
if (this._leagueType) {
return this._leagueType;
}
throw new Error("required _leagueType is missing");
}
},
pageUri: {
get: function get() {
if (!this.leagueName || !this.entityId) {
return null;
}
var uriBuilder = new Platform.Utilities.AppExUriBuilder();
//lame - chthakur - fix
if (this._entityType === SportsJS.UI.EntityType.League) {
uriBuilder.controllerId = SportsJS.NavControllers.league;
} else if (this._entityType === SportsJS.UI.EntityType.Team) {
uriBuilder.controllerId = SportsJS.NavControllers.team;
} else if (this._entityType === SportsJS.UI.EntityType.Player) {
uriBuilder.controllerId = SportsJS.NavControllers.player;
} else if (this._entityType === SportsJS.UI.EntityType.Match) {
uriBuilder.controllerId = SportsJS.NavControllers.match;
}
uriBuilder.queryParameters.insert("id", this.entityId);
uriBuilder.queryParameters.insert("league", this.leagueName);
return uriBuilder.toString();
}
},
_isDeeplinkSharable: true,
_pageData: function _pageData(clusterConfigs) {
var that = this;
if (!that._modelResponse || !that._modelResponse.pageData) {
return;
}
var data = new WinJS.Binding.List(clusterConfigs);
that._pageTitle = that._modelResponse.pageData.title;
var pageData = {
// provide the title for the header control
title: that._pageTitle,
clusters: data.dataSource,
semanticZoomRenderer: that.semanticZoomRenderer,
panoramaState: this._panoramaState,
maxAge: that._modelResponse.maxAge,
status: that._modelResponse.pageData.status,
};
//// The panorama state has been consumed once..we dont want to use this again.
this._data = data;
this._panoramaState = null;
return pageData;
},
_modelResponse: null,
_modelInstance: null,
model: {
get: function get() {
var that = this;
if(!this._modelInstance) {
this._modelInstance = new SportsJS.EntityModelBase({ league: that._leagueName, entityType: that._entityType, entityId: that._entityId}); 
}
return this._modelInstance;
}
},
_pageInitAsync: function _pageInitAsync(isRefresh, pageResponse) {
var that = this;
var modelDataAsync = null;
// if page has to be initialized with specific reponse, use the provided response
if (pageResponse) {
modelDataAsync = WinJS.Promise.wrap(pageResponse);
} else {
modelDataAsync = that.model.getData(isRefresh);
}
return modelDataAsync.then(function (response) {
if (response && response.isValid === true) {
that._entityData = response.pageData && response.pageData.entityData ? response.pageData.entityData : {};
that._modelResponse = response;                            
} else {
// invalid response.
if (isRefresh === true && that._modelResponse && that._modelResponse.isValid === true) {
// refresh scenario && last response was valid, use the older response
response = that._modelResponse;
that._entityData = response.pageData && response.pageData.entityData ? response.pageData.entityData : {};
} else {
// return null if response is invalid in first run
return WinJS.Promise.wrapError(null);
}
}
return that.getClusterConfigAsync(response.pageData).then(function (clusterConfigs) {
return that._pageData(clusterConfigs);
});
});
},
// Put all the code which is dependent on succussfull data initialization of the page
_pageDataInitialized: function _pageDataInitialized() {
if (!this._modelResponse || !this._modelResponse.pageData) {
return;
}
this._initBottomEdgy();
},
getClusterConfigAsync: function getClusterConfigAsync(response) {
var that = this;
that._clusterConfig = that.getClusterConfig(response);
that.injectRenderConfigInClusterConfigs();
return WinJS.Promise.wrap(that._clusterConfig);
},
/// <summary>
/// Gets the Cluster-Config for the page
/// </summary>
getClusterConfig: function getClusterConfig(response) {
var that = this;
if (that._clusterConfig && that._clusterConfig.length > 0) {
return that._clusterConfig;
}
var clusterConfigs = [];
var clusterConfigArray;
if (!response || !response.clusters || response.clusters.length === 0) {
return [];
}
var cfgs = SportsJS.Cluster.Configs.Common;
clusterConfigArray = response.clusters;
for (var kk = 0; kk < clusterConfigArray.length; kk++) {
var clusterConfig = clusterConfigArray[kk];
var configParams = {};
SportsJS.Utilities.deepCopyJsObject(clusterConfig, configParams);
var requestParams = clusterConfig.requestParams;
var kvPairs = SportsJS.Utilities.getQueryVariable(requestParams);
if (kvPairs) {
var keys = Object.keys(kvPairs);
keys.forEach(function (key) {
configParams[key] = kvPairs[key];
});
configParams.requestKvPairs = kvPairs;
}
var clusterType = SportsJS.UI.ClusterTypeToJsClass[clusterConfig.type];
if (!clusterType) {
SportsJS.Utilities.interfaceException("SportsPage:getClusterConfig", "invalid cluster configuration");
continue;
}
configParams.league = that.leagueType; // backward compat issue
configParams.leagueType = that.leagueType;
configParams.entityId = that._entityId;
configParams.entityType = that._entityType;
var cfg = SportsJS.Utilities.executeFunctionByName(window, clusterType, that.leagueType, {}, configParams);
if (cfg) {
clusterConfigs.push(cfg);
}
}
return clusterConfigs;
},
_initBottomEdgy: function _initBottomEdgy() {
var that = this;
that._addEntityButtonToBottomEdgy();
that._addPinButtonToBottomEdgy();
},
_addEntityButtonToBottomEdgy: function _addEntityButtonToBottomEdgy() {
var that = this;
var collectionName = AppEx.Sports.Services.SportsEntityManager.getSportsEntityCollectionNameFromEntityName(that._entityType);
var entityCollectionBottomEdgyButton = new SportsJS.Controls.EntityCollectionBottomEdgyButton(null, {
entityCollectionType: collectionName,
leagueName: that._leagueName,
entityId: that._entityId,
dataAsync: that._entityAddRemoveDataAsync.bind(that)
});
that.bottomEdgy.addButton(entityCollectionBottomEdgyButton);
},
//dataModel c#
_entityAddRemoveDataAsync: function _entityAddRemoveDataAsync() {
var that = this;
var entityDisplayName = that._entityData ? that._entityData.entityDisplayName : "";
var collectionName = AppEx.Sports.Services.SportsEntityManager.getSportsEntityCollectionNameFromEntityName(that._entityType);
var entityDisplayType = PlatformJS.Services.resourceLoader.getString(collectionName);
return WinJS.Promise.wrap({
entityDisplayName: entityDisplayName,
entityDisplayType: entityDisplayType,
});
},
_addPinButtonToBottomEdgy: function _addPinButtonToBottomEdgy() {
var that = this;
// tileId should be unique for each league page
var channelName = SportsJS.Utilities.stringProperCase(that._leagueName) + that.pageType;
var pageTileId = channelName + that.entityId;
var pinningButton = new SportsJS.Controls.PinBottomEdgyButton(null, {
tileId: pageTileId,
leagueType: that.leagueType,
tileDataAsync: that._tileDataAsync.bind(that)
});
that.bottomEdgy.addButton(pinningButton);
},
// create datamodel - c#
_tileDataAsync: function _tileDataAsync() {
var that = this;
if (!that._modelResponse || !that._modelResponse.pageData || !that._modelResponse.pageData.tileData) {
return WinJS.Promise.wrap(null);
}
var leagueType = that.leagueType;
var entityId = that.entityId;
var entityData = that._entityData;
var pageType = this._pageType === SportsJS.UI.PageType.League ? SportsJS.UI.PageType.Home : this._pageType;
var newsData = that._modelResponse.pageData.tileData;
var heroSetting = that._modelResponse.pageData.tileData.heroSetting;
var tileData = {
sportsType: leagueType,
entityData: entityData,
newsData: newsData,
entityType: that._entityType,
entityText: that._entityData.entityDisplayName,
entityId: entityId,
heroSetting: heroSetting,
page: SportsJS.Utilities.stringFormat("SportsJS.{0}Base", pageType)
};
// chthakur - tiles issue. Ideally we should remove this
// chthakur to revisit
if (that._entityType === SportsJS.UI.EntityType.Team) {
//secondaryTile needs teamId, fixable
tileData.teamId = that._entityId;
} else if (that._entityType === SportsJS.UI.EntityType.Player) {
tileData.playerId = that._entityId;
}
return WinJS.Promise.wrap(tileData);
},
},
{
areStateEqual: function areStateEqual(firstState, secondState) {
if (SportsJS.Page && SportsJS.Page.areStateEqual) {
return SportsJS.Page.areStateEqual(firstState, secondState);
}
return false;
}
}),
// EntityModelBase - Minimal implementation.
EntityModelBase: WinJS.Class.define(function (options) {
this._leagueName = options ? options.league : null;
this._entityType = options ? options.entityType : null;
this._entityId = options ? options.entityId : null;
}, {
getData: function getData(isRefresh) {
var that = this;
// create instance of query  (uiQuery in C# SportsService)
var constructQuery = function (params) {
var query = new AppEx.Sports.Services.TypeDefs.Request.EntityPageQuery(that._leagueName, that._entityType, that._entityId);
if (!query || !query.isValid) {
return null;
}
if (params && typeof params.canConsumeStaleResponse !== "undefined") {
query.canConsumeStaleResponse = params.canConsumeStaleResponse;
query.bypassCache = params.bypassCache;
}
return query;
};
var requestQuery = constructQuery({ canConsumeStaleResponse: !isRefresh, bypassCache: isRefresh });
return $SpMgr.sportsJsController.requestV2(requestQuery);
}
})
});
})();
