﻿(function () {
"use strict";
WinJS.Namespace.define("SportsJS", {
GenericPage: WinJS.Class.derive(SportsJS.Page,
/// <summary>
/// Constructor for Generic Page
/// </summary>
/// <param name="params">
/// The params object passed to WinJS.Navigation.navigate or the params object
/// preserved when the page has been navigated away from
/// </param>
function (params) {
// id here is pageId
if (!params || !params.pagetype || !params.id) {
return;
}
this._pageId = params.id;
this._pageType = params.pagetype;
this._pageArgs = params;
this._theme = params.theme;
this._basePageConstructor(params);
this._isValid = true;
},
{
_pinButtonControl: null,
_unpinButtonControl: null,
_isValid: false,
_pageType: null,
_pageId: null,
_pageArgs: null,
_theme: "default",
pageUri: {
get: function get() {
var that = this;
if (that._pageArgs && that._pageArgs.__uri) {
return that._pageArgs.__uri;
}
var uriBuilder = new Platform.Utilities.AppExUriBuilder();
uriBuilder.controllerId = SportsJS.NavControllers.page;
if (that._pageArgs) {
var keys = Object.keys(this._pageArgs);
keys.forEach(function (key) {
if (that._pageArgs[key] && typeof that._pageArgs[key] !== "function" && typeof that._pageArgs[key] !== "object") {
uriBuilder.queryParameters.insert(key, that._pageArgs[key]);
}
});
}
return uriBuilder.toString();
}
},
getPageImpressionContext: function getPageImpressionContext() {
var context = SportsJS.Utilities.stringFormat("/{0}/{1}", this._pageType, this._pageId);
return context;
},
_logTelemetry: function _logTelemetry() {
SportsJS.Telemetry.logContent(this._pageType, this._pageId, "", "");
},
_isDeeplinkSharable: true,
_pageData: function _pageData(clusterConfigs) {
var that = this;
if (!that._modelResponse || !that._modelResponse.pageData) {
return;
}
var data = new WinJS.Binding.List(clusterConfigs);
that._pageTitle = that._modelResponse.pageData.title;
var pageData = {
// provide the title for the header control
title: that._pageTitle,
clusters: data.dataSource,
semanticZoomRenderer: that.semanticZoomRenderer,
panoramaState: this._panoramaState,
maxAge: that._modelResponse.maxAge,
status: that._modelResponse.pageData.status,
};
//// The panorama state has been consumed once..we dont want to use this again.
this._data = data;
this._panoramaState = null;
return pageData;
},
_modelResponse: null,
_modelInstance: null,
model: {
get: function get() {
var that = this;
if(!this._modelInstance) {
this._modelInstance = new SportsJS.PageModel({ pageType: that._pageType, pageId: that._pageId, pageArgs: that._pageArgs });
}
return this._modelInstance;
}
},
_pageInitAsync: function _pageInitAsync(isRefresh, pageResponse) {
var that = this;
var modelDataAsync = null;
// if page has to be initialized with specific reponse, use the provided response
if (pageResponse) {
modelDataAsync = WinJS.Promise.wrap(pageResponse);
} else {
modelDataAsync = that.model.getData(isRefresh);
}
return modelDataAsync.then(function (response) {
if (response && response.isValid === true) {
that._modelResponse = response;
} else {
// invalid response.
if (isRefresh === true && that._modelResponse && that._modelResponse.isValid === true) {
// refresh scenario && last response was valid, use the older response
response = that._modelResponse;
} else {
// return null if response is invalid in first run
return WinJS.Promise.wrapError(null);
}
}
return that.getClusterConfigAsync(response.pageData).then(function (clusterConfigs) {
return that._pageData(clusterConfigs);
});
});
},
// Put all the code which is dependent on succussfull data initialization of the page
_pageDataInitialized: function _pageDataInitialized() {
if (!this._modelResponse || !this._modelResponse.pageData) {
return;
}
var dataPointId = this._modelResponse.pageData.instId;
this._initBottomEdgy();
},
getClusterConfigAsync: function getClusterConfigAsync(response) {
var that = this;
that._clusterConfig = that.getClusterConfig(response);
that.injectRenderConfigInClusterConfigs();
return WinJS.Promise.wrap(that._clusterConfig);
},
/// <summary>
/// Gets the Cluster-Config for the page
/// </summary>
getClusterConfig: function getClusterConfig(response) {
var that = this;
if (that._clusterConfig && that._clusterConfig.length > 0) {
return that._clusterConfig;
}
var clusterConfigs = [];
var clusterConfigArray;
if (!response || !response.clusters || response.clusters.length === 0) {
return [];
}
var cfgs = SportsJS.Cluster.Configs.Common;
clusterConfigArray = response.clusters;
for (var kk = 0; kk < clusterConfigArray.length; kk++) {
var clusterConfig = clusterConfigArray[kk];
var configParams = {};
SportsJS.Utilities.deepCopyJsObject(clusterConfig, configParams);
var requestParams = clusterConfig.requestParams;
var kvPairs = SportsJS.Utilities.getQueryVariable(requestParams);
if (kvPairs) {
var keys = Object.keys(kvPairs);
keys.forEach(function (key) {
configParams[key] = kvPairs[key];
});
}
var clusterType = SportsJS.UI.ClusterTypeToJsClass[clusterConfig.type];
if (!clusterType) {
SportsJS.Utilities.interfaceException("SportsPage:getClusterConfig", "invalid cluster configuration");
continue;
}
var notUsed = null;
var cfg = SportsJS.Utilities.executeFunctionByName(window, clusterType, notUsed, {}, configParams);
if (cfg) {
clusterConfigs.push(cfg);
}
}
return clusterConfigs;
},
_initBottomEdgy: function _initBottomEdgy() {
var that = this;
}
},
{
areStateEqual: function areStateEqual(firstState, secondState) {
if (SportsJS.Page && SportsJS.Page.areStateEqual) {
return SportsJS.Page.areStateEqual(firstState, secondState);
}
return false;
}
}),
PageModel: WinJS.Class.define(function (options) {
this._pageId = options.pageId;
this._pageType = options.pageType;
this._pageArgs = options.pageArgs;
}, {
getData: function getData(isRefresh) {
var that = this;
// create instance of query  (uiQuery in C# SportsService)
var constructQuery = function (queryOptions, queryArgs) {
var paramsDictionary = null;
if (queryOptions) {
var optionsToSkip = ["__uri", "isNavBarEvent", "panoramaState"];
paramsDictionary = PlatformJS.Collections.createStringDictionary();
for (var key in queryOptions) {
// we do not need __uri as request params. This is part of pageArgs when we navigate using protocol handlers
if (optionsToSkip.indexOf(key) !== -1) {
continue;
}
if(queryOptions[key] && typeof queryOptions[key] !== "function") {
paramsDictionary.insert(key, queryOptions[key]);
}
}
}
var query = new AppEx.Sports.Services.TypeDefs.Request.PageQuery(that._pageType, that._pageId, paramsDictionary);
if (!query || !query.isValid) {
return null;
}
if (queryArgs && typeof queryArgs.canConsumeStaleResponse !== "undefined") {
query.canConsumeStaleResponse = queryArgs.canConsumeStaleResponse;
query.bypassCache = queryArgs.bypassCache;
}
return query;
};
var requestQuery = constructQuery(that._pageArgs, { canConsumeStaleResponse: !isRefresh, bypassCache: isRefresh });
return $SpMgr.sportsJsController.requestV2(requestQuery);
}
})
});
})();
