﻿(function () {
"use strict";
WinJS.Namespace.define("SportsJS", {
/// <summary>
/// Sports Data Service - Responsible to manage all data requests of sports cluster. 
/// </summary>
JsController: WinJS.Class.define(function JsController_constructor() {
},
{
_jsCache: {
get: function get() {
return window.$AppMgr.jsCache;
}
},
_csController: {
get: function get() {
return AppEx.Sports.Services.SportsController();
}
},
_isStaleResponse: function _isStaleResponse(response) {
return response && response.maxAge && response.maxAge > 0 ? false : true;
},
_storeToJsCache: function _storeToJsCache(query, response) {
var jsCacheKey = this.getUrl(query);
// save only valid response in to cache. 
// any response which does not have isValid flag set true, will be treated as invalid response and wont be cached.
var cacheOptions = { storeToDisk: true };
if (query.storageType) {
cacheOptions.storageType = query.storageType;
}
if (jsCacheKey && response && response.isValid) {
this._jsCache.addObject(jsCacheKey, response, cacheOptions);
}
},
_getCsResponseObject: function _getCsResponseObject(csResponse, query) {
var responseObject = null;
if (csResponse && csResponse.dataObject && query) {
if (csResponse.dataObject.data && csResponse.dataObject.type === "DataModelWrapper") {
responseObject = csResponse.dataObject.data;
} else {
responseObject = query.passThroughResponse ? csResponse : csResponse.dataObject;
}
}
return responseObject;
},
/// function to transform C# object into Js object. Also does UX/JS data modeling if needed.
_jsTransformer: function _jsTransformer(csObject, transformer) {
var jsObject = null;
// isValid check is not required. csResponse was valid
if (csObject) {
jsObject = SportsJS.Utilities.nativeObjectToJsObject(csObject);
if (transformer && typeof transformer === "function") {
jsObject = transformer(jsObject);
}
}
return jsObject;
},
/// function to handle response recevied from c# controller.
_processCsControllerResponse: function _processCsControllerResponse(csResponse, query, transformer) {
if (!csResponse || csResponse.isValid === false) {
return { isValid: false };
}
var csObject = this._getCsResponseObject(csResponse, query);
var jsObject = this._jsTransformer(csObject, transformer);
if (jsObject) {
jsObject.etag = csResponse.etag;
jsObject.maxAge = csResponse.maxAge;
jsObject.lastUpdateTime = jsObject.lastUpdateTime ? jsObject.lastUpdateTime : csResponse.lastUpdateTime;
jsObject.isValid = true;
this._storeToJsCache(query, jsObject);
return jsObject;
} else {
return { isValid: false };
}
},
requestV2: function requestV2(query, transformer) {
var that = this;
if (!query) {
return WinJS.Promise.wrapError(null);
}
var dataFetchPromise = null;
var cacheOptions = query.storageType ? { storageType: query.storageType } : {};
var uniqueMarker = Math.random();
msWriteProfilerMark("Sports:jsController:requestV2:" + uniqueMarker + ",StartTM");
var p = new WinJS.Promise(function JsController_requestV2Init(complete, error) {
var key = that.getUrl(query);
dataFetchPromise = that._jsCache.getObjectAsync(key, cacheOptions).then(function JsController_requestV2JsCacheReadComplete(jsResponse) {
if (jsResponse && jsResponse.isValid && query.bypassCache !== true && (query.canConsumeStaleResponse || !that._isStaleResponse(jsResponse))) {
msWriteProfilerMark("Sports:jsController:requestV2:" + uniqueMarker + ",StopTM");
complete(jsResponse);
} else {
return that._csController.requestV2(query).then(function JsController_csControllerRequestV2CompleteHandler(completeResponse) {
msWriteProfilerMark("Sports:jsController:requestV2:" + uniqueMarker + ",StopTM");
complete(that._processCsControllerResponse(completeResponse, query, transformer));
}, function JsController_csControllerRequestV2ErrorHandler(errorResponse) {
error(errorResponse);
}, function JsController_csControllerRequestV2ProgressHandler(progressResponse) {
if (query.canConsumeStaleResponse && progressResponse && progressResponse.modelResponse && progressResponse.modelResponse.isValid) {
msWriteProfilerMark("Sports:jsController:requestV2:" + uniqueMarker + ",StopTM");
complete(that._processCsControllerResponse(progressResponse.modelResponse, query, transformer));
}
});
}
});
}, function JsController_requesV2Cancel() {
SportsJS.Controls.Utilities.cancelPromise(dataFetchPromise);
dataFetchPromise = null;
});
return p;
},
getUrl: function getUrl(query) {
var url = null;
if (query && query.isValid) {
url = AppEx.Sports.Services.SportsController.getUrl(query);
}
return url;
}
})
});
})();