﻿(function () {
"use strict";
WinJS.Namespace.define("SportsJS", {
Telemetry: WinJS.Class.define(function () { },
{},
{
LogLevel: Platform.Telemetry.LogLevel.normal,
ActionType: {
add: "add",
remove: "remove",
click: "click",
pin: "pin",
unpin: "unpin",
share: "share",
snap: "snap",
bottomEdgy: "App-Bar",
none: "none"
},
// Mapping to context
ItemType: {
schedule: "Schedule",
secondaryTile: "Secondary Tile",
shareItem: "Share",
favLeague: "Favorite League",
favTeam: "Favorite Team",
snap: "Snap",
slideshow: "Slideshow",
headlines: "Headlines",
hero: "Hero",
bottomEdgy: "App-Bar",
charm: "Charm",
cluster: "Cluster",
},
ElementType: {
Page: "Page",
ClusterTile: "Cluster Tile",
AppBar: "App-Bar",
Help: "Help Button",
Refresh: "Refresh Button",
Glossary: "Glossary Button",
SearchBox: "Search Box",
},
SportsTelemetryName: {
football: "/Football",
rugby: "/Rugby",
basketball: "/Basketball",
baseball: "/Baseball",
hockey: "/Hockey",
icehockey: "/Ice Hockey",
golf: "/Golf",
soccer: "/Soccer",
tennis: "/Tennis",
cricket: "/Cricket",
cycling: "/Cycling",
racing: "/Racing",
athletics: "/Athletics",
rugbyleague: "/Rugby League",
none: "/Others"
},
PagesExtra: {
slideshow: "/Slideshow",
articleReader: "/Article Reader",
searchNoResults: "/SportsNoResults",
videos: "/Videos",
},
SearchIndex: {
Bing: "Bing",
},
SearchCategory: {
SearchCharm: "SearchCharm",
Pin: "Pin",
Implicit: "Implicit",
},
getSportsTelemetryName: function getSportsTelemetryName(league) {
var sports = AppEx.Sports.Services.Utils.getSportsFromLeague(league);
var telemetryName = this.SportsTelemetryName[sports];
if (telemetryName) {
return telemetryName;
} else {
return this.SportsTelemetryName.none;
}
},
logContent: function logContent(type, id, league, localizedName) {
var impression = PlatformJS.Navigation.mainNavigator.getCurrentImpression();
if (!impression) {
return;
}
var config = {};
config.type = type;
config.id = id;
config.league = league;
config.localizedName = localizedName;
var dateTime = new Date();
var k = impression.addContent(
"", // sourceName
"", // partnerCode
id, // contentId
type, //type
dateTime, //date
"", //uri
"", //slug
false, //isSummary
Platform.Telemetry.ContentWorth.Normal, //worth
false, //isAdd
"" //addCampaign
);
var jsonString = SportsJS.Utilities.jsonStringify(config);
impression.logContentWithJsonAttributes(this.LogLevel, jsonString);
impression.logContentViewWithJsonAttributes(
this.LogLevel,
k, // k value from content event
Platform.Telemetry.ContentViewMechanism.static, // content view mechanism
false, //log only if not views
null, //content view progress not tracking
jsonString);
},
logContentAsSearch: function logContentAsSearch(entity) {
var searchText;
if (entity.entityType && entity.entityId) {
searchText = SportsJS.Utilities.stringFormat("/{0}/{1}", entity.entityType, entity.entityId);
} else if (typeof (entity) === "string") {
searchText = entity;
}
Platform.Telemetry.FlightRecorder.logSearch(
this.LogLevel,
searchText,
this.SearchIndex.Bing,
"",
false, //search was invoked by user
-1, //number of results not known
false, //explicit user search (implicit in this case)
true, //comscore countable
false, //is initiated by autorefresh
SportsJS.Telemetry.getFormCode(this.SearchCategory.Implicit), //category code
"" // details
);
},
logUserAction: function logUserAction(context, elementName, operation, k, jsonObject) {
if (jsonObject && jsonObject !== String.Empty) {
var jsonString = SportsJS.Utilities.jsonStringify(jsonObject);
Platform.Telemetry.FlightRecorder.logUserActionWithJsonAttributes(this.LogLevel, context, elementName, operation, 0, k, jsonString);
}
else {
Platform.Telemetry.FlightRecorder.logUserAction(this.LogLevel, context, elementName, operation, 0, k);
}
},
logClusterClick: function logClusterClick(elementId, elementName) {
var config = {};
config.ClusterID = elementId;
if (elementName) {
config.ClusterName = elementName;
}
this.logUserAction(this.ItemType.cluster, this.ElementType.ClusterTile, SportsJS.Telemetry.ActionType.click, 0, config);
},
logECVContentView: function logECVContentView(ecv, league) {
var impression = PlatformJS.Navigation.mainNavigator.getCurrentImpression();
if (!impression) {
return;
}
var dateTime = new Date();
impression.addContent(
"", // sourceName
"", // partnerCode
ecv, // contentId
league, //type
dateTime, //date
"", //uri
"", //slug
false, //isSummary
Platform.Telemetry.ContentWorth.Normal, //worth
false, //isAdd
"" //addCampaign
);
impression.logContent(this.LogLevel);
},
logSearchEntity: function logSearchEntity(res) {
//when search navigates to an entity page
if (res && res.entityMatches && res.entityMatches[0] && res.entityMatches[0].matchingEntity) {
var entity = res.entityMatches[0].matchingEntity;
var logText;
if (entity.type === SportsJS.UI.EntityType.League) {
logText = "/" + entity.type + "/" + entity.id;
} else {
logText = "/" + entity.type + "/" + entity.id + "/" + entity.name;
}
Platform.Telemetry.FlightRecorder.logSearch(
this.LogLevel,
logText,
this.SearchIndex.Bing,
Platform.Telemetry.SearchMethod.charm,
false, //search was invoked by user
-1, //number of results not known
true, //explicit user search
true, //comscore countable
false, //is initiated by autorefresh
SportsJS.Telemetry.getFormCode(this.SearchCategory.SearchCharm), //category code
"" //details
);
}
},
logSearchText: function logSearchText(text) {
//this will help us log unifinished or unsuccessful search queries
var config = {};
config.text = text;
this.logUserAction(this.ItemType.charm, this.ElementType.SearchBox, this.ActionType.click, 0, config);
},
logFavTeamAction: function logFavTeamAction(teamUnivId, action, element) {
if (teamUnivId) {
var config = {};
config.team = teamUnivId;
config.addremove = action;
this.logUserAction(SportsJS.Telemetry.ItemType.favTeam, element, action, 0, config);
}
},
logHeadlinesClick: function logHeadlinesClick(league, data) {
if (league) {
var config = {};
config.league = league;
if (data) {
config.articleId = data.articleid;
config.articleURL = data.articleUrl;
}
this.logUserAction(SportsJS.Telemetry.ItemType.headlines, SportsJS.Telemetry.ElementType.ClusterTile, SportsJS.Telemetry.ActionType.click, 0, config);
}
},
logAppBarClick: function logAppBarClick(elementName) {
this.logUserAction(SportsJS.Telemetry.ItemType.bottomEdgy, elementName, SportsJS.Telemetry.ActionType.click, 0, "");
},
logHeroClick: function logHeroClick(contentId) {
if (contentId) {
var config = {};
config.contentId = contentId;
this.logUserAction(SportsJS.Telemetry.ItemType.hero, SportsJS.Telemetry.ElementType.ClusterTile, SportsJS.Telemetry.ActionType.click, 0, config);
}
},
logSlideshowClick: function logSlideshowClick(contentId) {
if (contentId) {
var config = {};
config.contentId = contentId;
this.logUserAction(SportsJS.Telemetry.ItemType.slideshow, SportsJS.Telemetry.ElementType.ClusterTile, SportsJS.Telemetry.ActionType.click, 0, config);
}
},
logPreviewRecap: function logPreviewRecap(league, page) {
var impression = PlatformJS.Navigation.mainNavigator.getCurrentImpression();
if (!impression) {
return;
}
var dateTime = new Date();
impression.addContent(
"", // sourceName
"", // partnerCode
page, // contentId
league, //type
dateTime, //date
"", //uri
"", //slug
false, //isSummary
Platform.Telemetry.ContentWorth.Normal, //worth
false, //isAdd
"" //addCampaign
);
impression.logContent(this.LogLevel);
},
logSnapView: function logSnapView(league) {
if (league) {
var config = {};
config.league = league;
this.logUserAction(SportsJS.Telemetry.ItemType.snap, SportsJS.Telemetry.ElementType.Page, SportsJS.Telemetry.ActionType.snap, 0, config);
}
},
logFavLeagueAction: function logFavLeagueAction(league, action, element) {
if (league && action) {
var config = {};
config.league = league;
config.addremove = action;
this.logUserAction(SportsJS.Telemetry.ItemType.favLeague, element, action, 0, config);
}
},
logMyLeagues: function logMyLeagues(league, action) {
if (league && action) {
var config = {};
config.league = league;
config.addremove = SportsJS.Telemetry.ActionType.none;
this.logUserAction(SportsJS.Telemetry.ItemType.favLeague, SportsJS.Telemetry.ElementType.ClusterTile, action, 0, config);
}
},
logShare: function logShare(entity) {
if (entity) {
var config = {};
config.type = entity.entityType;
config.id = entity.entityId;
this.logUserAction(SportsJS.Telemetry.ItemType.shareItem, SportsJS.Telemetry.ElementType.Page, SportsJS.Telemetry.ActionType.share, 0, config);
}
},
logScheduleClick: function logScheduleClick(item, type) {
if (item && type) {
var config = {};
config.type = type;
config.gamecode = item.gameCode;
this.logUserAction(SportsJS.Telemetry.ItemType.schedule, SportsJS.Telemetry.ElementType.ClusterTile, SportsJS.Telemetry.ActionType.click, 0, config);
}
},
logTilePin: function logTilePin(args, action) {
if (args) {
var config = {};
config.league = args.leagueType;
config.team = args.teamId;
this.logUserAction(SportsJS.Telemetry.ItemType.secondaryTile, SportsJS.Telemetry.ElementType.AppBar, action, 0, config);
}
},
getFormCode: function getFormCode(type) {
if (!this.FormCodeConfig) {
this.FormCodeConfig = PlatformJS.Services.appConfig.getDictionary("TelemetryFormCodes");
}
var formCode = this.FormCodeConfig[type].value;
return formCode;
}
}),
});
})();