﻿(function () {
"use strict";
var Control = WinJS.Class.define(null, {
raiseEvent: function raiseEvent(type, details) {
/// <summary locid="170">
/// Raises an event of the specified type and with additional properties.
/// </summary>
/// <param name="type" locid="171">
/// The type (name) of the event.
/// </param>
/// <param name="details" locid="172">
/// The set of additional properties to be attached to the event object when the event is raised.
/// </param>
/// <returns type="Boolean" locid="173">
/// Boolean indicating whether preventDefault was called on the event.
/// </returns>
this.dispatchEvent(type, details);
}
});
WinJS.Class.mix(Control, WinJS.UI.DOMEventMixin);
WinJS.Namespace.define('SportsJS.UI', {
SportsModule: WinJS.Class.derive(Control, function (element, options) {
element = element || document.createElement("div");
this.title = options.Title !== undefined ? options.Title : 'Not Set';
//// Need either dataProvider or dataId
if (!(options.dataProvider || options.dataId)) {
this._trace(SportsJS.Msg.DataProviderConfigurationNotFound);
}
this.moduleId = this.getModuleId(options);
WinJS.Utilities.addClass(element, "sportsModuleContainer");
// app specific configurations
if (!$SpMgr.isPlaceholderFeatureEnabled) {
options.showPlaceholder = false;
}
if (options.showPlaceholder) {
WinJS.Utilities.addClass(element, "showSportsModulePlaceholder");
var placeholderElement = this.createModulePlaceHolder();
element.appendChild(placeholderElement);
}
if (options.showLogos === false) {
WinJS.Utilities.addClass(element, "sportsNoLogoModule");
}
this._hasChrome = typeof options.hasChrome !== 'undefined' ? options.hasChrome : false;
//// assume parent datasource if dataProvider is explicitly missing
this._dataProvider = typeof options.dataProvider !== "undefined" ? options.dataProvider : this._passthroughDataProvider;
this.element = element;
element.winControl = this;
var that = this;
if (options) {
this.options = options;
}
if (this.usesItemsContainer && this.usesItemsContainer === true) {
this._isInnerListAnItemsContainer = true;
}
this._dataPromiseStack = [];
this.loadModuleStack = [];
this._msSetImmediateIdentifierList = [];
this._imageLoadingTasks = [];
this.listViewKeydownCallback = this._listViewKeydownCallback.bind(this);
Object.defineProperties(this, WinJS.Utilities.createEventProperties("rendercomplete"));
////TODO: understand why the constructor is getting called twice. Seems like processAll related
this._trace('object constructed');
}, {
_isInnerListAnItemsContainer: false,
// IsInteractive true means the animation on tile is disabled, isInteractive is implied from event handler value in options
_isInteractive: true,
_hasChrome: false,
_bindableProviderResponse: null,
chromeData: null,
groupShortCutHandler: null,
// This will have reference to module fragment. This is done by cluster
// TODO: chthakur to remove, once migration is done. Instead of this we should use the module element itself
fragmentObject: null,
// scroll event handler
_moduleScrollEventHandler: null,
// Funtion pointer to handle keydown event over listview item
_handleKeydownOnListviewItem: null,
// Function pointer to handle resize event
_moduleResizeEventHandler: null,
_dataPromiseStack: null,
_fetchDataTimerId: null,
// list of all the msSetImmediate call references to dispose during clean-up
_msSetImmediateIdentifierList: null,
// list of references of image loading task
_imageLoadingTasks: null,
// Avoid UI Blocking: if we have more items to render than we timeout after rendering every 10 items.
// 10 => Assume average rendering time of an item is 10ms and we need to timeout at every 100ms. 
// Derived module control is expeted to override this based on approximate rendering time of an item.
// Note: it is used only for itemContainer items.
loadModulesCountToTimeout: 10,
loadModuleStack: null,
// Count of contiguous retries for transition from refresh to no refresh
_refreshToNoRefreshTries: 0,
// Tries before we make module to transition from refresh to No refresh
_maxRefreshToNoRefreshTries: 2,
// max entries to render (currently it is only takes care of itemscontainer)
_maxEntriesToRender: -1,
// reference to listview keydown callback
listViewKeydownCallback: null,
options: {
get: function get() {
return this._options;
},
set: function set(value) {
this._options = value;
WinJS.UI.setOptions(this, value);
//// TODO: provide custom renderer too
this._fragmentPath = value.fragmentPath;
this._templateId = value.templateId;
this._isInteractive = true; // no animation on click
if (typeof value.isInteractive !== "undefined") {
this._isInteractive = value.isInteractive;
}
else if (value.eventHandler && typeof value.eventHandler === "function") {
this._isInteractive = false; // enable animation + click
}
}
},
moduleId: null,
getModuleId: function getModuleId(options) {
// TODO: chthakur & arengak - need beter way to create unique id for module
var sportsModuleString = "SportsModule";
if (!options) {
return sportsModuleString;
}
var moduleControlName = options.moduleInfo && options.moduleInfo.control ? options.moduleInfo.control : "";
var tmpArr = moduleControlName.split(".");
var moduleName = tmpArr[tmpArr.length - 1];
var teamId = options.teamId ? options.teamId : "";
var league = options.league ? options.league : "";
var uiScenarioName = options.uiScenarioName ? options.uiScenarioName : "";
var conference = options.conference ? options.conference : "";
var entityType = options.entityType ? options.entityType : "";
var clusterId = options.clusterId ? options.clusterId : "";
var divisionTitle = options.divisionTitle ? options.divisionTitle : "";
var leadersType = options.leadersType ? options.leadersType : "";
var scheduleDate = options.scheduleDate ? SportsJS.DateTimeHelpers.formatDateAsPerBackend(options.scheduleDate) : "";
sportsModuleString = sportsModuleString + moduleName + league + teamId + uiScenarioName + conference + entityType + clusterId + divisionTitle + leadersType + scheduleDate;
return sportsModuleString;
},
getData: function getData(bypassCache, isInlineRefresh) {
var that = this;
var promise = new WinJS.Promise(function (complete, error) {
that._trace('getdata request received');
var fetchPromise = that._fetchdata(isInlineRefresh, bypassCache);
//// We need to initialize view only for the first time
//// TODO: scope of improvement here. ListView control should always be initialized when we hit this point
//// TODO: While the code below helps us bind the data outside the list container, we will have to revisit this to make it more generic.
fetchPromise.then(function () {
complete(true);
}, function (errRes) {
error(errRes);
});
});
return promise;
},
createModulePlaceHolder: function createModulePlaceHolder() {
var that = this;
var placeholderElement = document.createElement("div");
WinJS.Utilities.addClass(placeholderElement, "sportsModulePlaceholder");
if (that.moduleId && $SpMgr.moduleLayoutCache.hasKey(that.moduleId)) {
var layoutStr = $SpMgr.moduleLayoutCache.getItem(that.moduleId);
var layout = SportsJS.Utilities.jsonParse(layoutStr);
if (!layout) { return placeholderElement; }
// dont use the cache data if the layouts are different
var winAppViewState = Windows.UI.ViewManagement.ApplicationViewState;
var currentViewState = Windows.UI.ViewManagement.ApplicationView.value;
var lastViewState = layout.viewState;
// layout is same for fullScreenLandscape and filled states.
currentViewState = (currentViewState === winAppViewState.filled || currentViewState === winAppViewState.fullScreenLandscape) ? winAppViewState.fullScreenLandscape : currentViewState;
lastViewState = (lastViewState === winAppViewState.filled || lastViewState === winAppViewState.fullScreenLandscape) ? winAppViewState.fullScreenLandscape : lastViewState;
// if cached data is for different state then dont use the cache
if (layout.viewState !== currentViewState) { return placeholderElement; }
if (layout.height && layout.width) {
placeholderElement.style.height = layout.height;
placeholderElement.style.width = layout.width;
}
}
return placeholderElement;
},
updateModuleLayoutInfo: function updateModuleLayoutInfo() {
var that = this;
var currentViewState = Windows.UI.ViewManagement.ApplicationView.value;
var layout = { height: that.element.offsetHeight + "px", width: that.element.offsetWidth + "px", viewState: currentViewState };
var layoutStr = SportsJS.Utilities.jsonStringify(layout);
$SpMgr.moduleLayoutCache.addItem(that.moduleId, layoutStr);
},
render: function render() {
var that = this;
var promise = new WinJS.Promise(function (complete, error) {
that._trace('data binding starts now');
var viewPromise = that._isInnerListAnItemsContainer ? that._loadChildItemContainerControl() : that._loadChildListViewControl();
viewPromise.then(function () {
var refreshDataSourcePromise = that._promiseStack(that._refreshDataSource());
refreshDataSourcePromise.then(function () {
that._trace('data binding complete');
WinJS.Utilities.removeClass(that.element, "showSportsModulePlaceholder");
that._promiseStack(WinJS.Promise.timeout()).then(function () {
if (that._isModuleObjectValid === false || !that.element) { return; }
if (that.options && that.options.showPlaceholder && that.moduleId) {
that.updateModuleLayoutInfo();
}
}, function () {
});
that.dispatchEvent("rendercomplete");
complete(true);
}, function (errRes) {
if (SportsJS.Utilities.isCancellationError(errRes)) {
// simple return, no error if the promise has been cancelled
return;
}
that._trace('data binding failed');
WinJS.Utilities.removeClass(that.element, "showSportsModulePlaceholder");
error(errRes);
});
}, function (errRes) {
WinJS.Utilities.removeClass(that.element, "showSportsModulePlaceholder");
error(errRes);
});
});
return promise;
},
createItem: {
get: function get() {
return this._moduleItemRenderer.bind(this);
}
},
_cancelPendingImageLoadTasks: function _cancelPendingImageLoadTasks() {
var that = this;
if (!that._imageLoadingTasks) {
return;
}
for (var i = 0, iLength = that._imageLoadingTasks.length; i < iLength; i++) {
if (that._imageLoadingTasks[i]) {
clearTimeout(that._imageLoadingTasks[i]);
}
}
},
_defaultRenderItem: function _defaultRenderItem(moduleInfo, data, parentElement, renderCompleteCallBack) {
var that = this;
var loadModulePromise = CommonJS.loadModule(moduleInfo, data, parentElement, null, null).then(function (renderedItem) {
if (renderCompleteCallBack) {
renderCompleteCallBack(renderedItem);
}
}, function () {
// ignore the error
});
that._promiseStack(loadModulePromise);
that.loadModuleStack.push(loadModulePromise);
},
_moduleItemRenderer: function _moduleItemRenderer(item) {
var that = this;
var parentElement = document.createElement("div");
if (that._isModuleObjectValid === false || !item) {
return parentElement;
}
var customRendererInfo = null;
if (that.options.rendererInfo) {
customRendererInfo = that.options.rendererInfo(item);
} else {
customRendererInfo = { data: item.data, moduleInfo: item.data.moduleInfo };
}
if (customRendererInfo) {
var moduleInfo = customRendererInfo.moduleInfo;
var data = customRendererInfo.data;
if (data && data.moduleInfo && !data.moduleInfo.isInteractive) {
WinJS.Utilities.addClass(parentElement, "clickableSportsModuleItem");
}
if (customRendererInfo.className) {
WinJS.Utilities.addClass(parentElement, customRendererInfo.className);
}
if (customRendererInfo.ariaLabel) {
parentElement.setAttribute("aria-label", customRendererInfo.ariaLabel);
}
if (data && moduleInfo) {
var itemIndex = item.data.index;
if (itemIndex === 0) {
that.loadModuleStack = [];
that.loadModuleStack.push(WinJS.Promise.wrap(true));
}
var loadModulePromise;
if (that.options.useOrderedRendering && itemIndex >= 0) {
var p = new WinJS.Promise(function (c, e) {
that.loadModuleStack[itemIndex].then(function () {
loadModulePromise = CommonJS.loadModule(moduleInfo, data, parentElement, null, null);
that._promiseStack(loadModulePromise);
loadModulePromise.then(function (renderedItem) {
if (customRendererInfo.itemRendererCompleteCallBack) {
customRendererInfo.itemRendererCompleteCallBack(renderedItem);
}
CommonJS.Immersive.ItemsContainer.reActivate(renderedItem);
$SpMgr.uiThreadTimer.getUiThreadReleasePromise().then(function () {
c();
});
}, function () {
// ignore the error
});
}, function () {
// ignore the error
});
});
that.loadModuleStack.push(p);
} else {
that._defaultRenderItem(moduleInfo, data, parentElement, customRendererInfo.itemRendererCompleteCallBack);
}
} else if (customRendererInfo.itemRendererCompleteCallBack) {
customRendererInfo.itemRendererCompleteCallBack(parentElement);
}
}
return parentElement;
},
_refreshDataSource: function _refreshDataSource() {
var that = this;
var p = new WinJS.Promise(function (complete, error) {
if (!that._ListControl) {
error(false);
return;
}
var dataSource = new WinJS.Binding.List(that._dataSource);
var loadingStateCompleteCallback = function (eventObject) {
if (that._ListControl && that._ListControl.loadingState === "itemsLoaded") {
that._ListControl.removeEventListener("loadingstatechanged", loadingStateCompleteCallback, false);
that._makeListViewBoundaryNavigable();
complete(true);
}
};
if (that._ListControl.groupBy) {
var selectGroupKey = that._ListControl.groupBy;
var selectGroupData = function (item) {
return item;
};
var groupSorter = that._ListControl.groupSorter ? that._ListControl.groupSorter : null;
var groupedData = dataSource.createGrouped(selectGroupKey, selectGroupData, groupSorter);
that._ListControl.addEventListener("loadingstatechanged", loadingStateCompleteCallback, false);
WinJS.UI.setOptions(that._ListControl, { itemDataSource: groupedData.dataSource, groupDataSource: groupedData.groups.dataSource });
}
else {
WinJS.UI.setOptions(that._ListControl, { itemDataSource: dataSource.dataSource });
// need to render the itemcontainer, This is not required for listview as listview fires the rendering on setting up the datasource
if (that._isInnerListAnItemsContainer) {
that._cancelPendingImageLoadTasks();
that._ListControl.render().then(function () {
if (that.loadModuleStack && that.loadModuleStack.length > 0) {
WinJS.Promise.join(that.loadModuleStack).then(function () {
complete(true);
}, function () {
complete(true);
});
} else {
complete(true);
}
}, function (errRes) {
error(errRes);
});
}
else {
// Register for loading complete event
that._ListControl.addEventListener("loadingstatechanged", loadingStateCompleteCallback, false);
}
}
});
return p;
},
// make ListView navigable across clusters thru left-right arrow keys
_makeListViewBoundaryNavigable: function _makeListViewBoundaryNavigable() {
var that = this;
if (that._isInnerListAnItemsContainer) {
return;
}
var processListView = function () {
if (!that._isModuleObjectValid) {
return;
}
that._ListControl.addEventListener("keydown", that.listViewKeydownCallback, true);
};
that._msSetImmediateIdentifierList.push(msSetImmediate(processListView));
},
// callback for keydown events on listview items
// rare case: if keys are pressed fast, we might get same list view item as source again, as first promise might still not got over
_listViewKeydownCallback: function _listViewKeydownCallback(e) {
var that = this;
// some extra null checks are better here
if (!e || !e.keyCode || !e.srcElement || (e.keyCode !== WinJS.Utilities.Key.rightArrow && e.keyCode !== WinJS.Utilities.Key.leftArrow)
|| !that._isModuleObjectValid || !that._ListControl) {
return;
}
var oldFocus = that._ListControl.currentItem.index;
that._promiseStack(WinJS.Promise.join([that._ListControl.itemDataSource.getCount(), that._ListControl.layout.getKeyboardNavigatedItem(oldFocus, null, e.keyCode)])).then(function (params) {
if (!params || params.length !== 2) {
return;
}
var maxCount = params[0];
var newFocus = params[1];
if (newFocus === oldFocus || newFocus < 0 || newFocus >= maxCount) {
// move the focus to appropriate neighbor cluster
if (e.keyCode === WinJS.Utilities.Key.rightArrow) {
CommonJS.NavigableView.dispatchBoundaryEvent(e.srcElement, CommonJS.NavigableView.Direction.RIGHT);
}
else if (e.keyCode === WinJS.Utilities.Key.leftArrow) {
CommonJS.NavigableView.dispatchBoundaryEvent(e.srcElement, CommonJS.NavigableView.Direction.LEFT);
}
}
});
},
dataProvider: function dataProvider(bypassCache, bypassProgress) {
var that = this;
var uiQuery;
var processResponseWrapper = function (sportsResponseData) {
var modelResponse = null;
// there is no reason this will fail
if (sportsResponseData && sportsResponseData.dataObject) {
var responseObject = uiQuery.passThroughResponse ? sportsResponseData : sportsResponseData.dataObject;
modelResponse = that.processResponse(responseObject);
if (modelResponse) {
modelResponse.etag = sportsResponseData.etag;
modelResponse.maxAge = sportsResponseData.maxAge;
}
} else {
modelResponse = null;
}
return modelResponse;
};
var promise = new WinJS.Promise(function (complete, error, progress) {
var controller = AppEx.Sports.Services.SportsController();
uiQuery = that.constructUiQuery();
if (!uiQuery) {
return SportsJS.Utilities.fallbackResponsePromise();
}
uiQuery.bypassCache = bypassCache;
that._promiseStack(controller.requestV2(uiQuery)).then(
function (res) {
var modelResponse;
if (uiQuery.passThroughResponse) {
// in case of passthrough response, the SportsResponseData meta data should be used
modelResponse = res;
} else {
modelResponse = (res && res.dataObject) ? res.dataObject : null;
modelResponse.etag = res.etag;
}
if (that._canRejectCompleteResponse(res)) {
that._updateStalenessParameters(res);
promise.cancel();
return;
}
var response = processResponseWrapper(res);
if (response) {
complete({ response: response });
}
else {
complete({ response: { data: null, isValid: false } });
}
}, function () {
}, function (progressData) {
if (that.shouldHandleProgress === false || bypassCache || bypassProgress) {
return;
}
if (progressData) {
var response = processResponseWrapper(progressData.modelResponse);
//// Ignore inValid or noData progress response
//// TODO(ashondik): For daily league schedule, we set isValid false for noGamesToday response, which needs to be handled specially here
//// Remove this special handling once schedule call is moved to cluster level.
if (response && ((response.isValid && response.data && response.data.status !== "NoData") || (typeof that._isNoGamesResponse !== 'undefined' && that._isNoGamesResponse(response)))) {
progress({ response: response });
}
}
});
});
return promise;
},
_inlineRefresh: function _inlineRefresh() {
////call this function to refresh inline
var that = this;
that._trace('inlinerefresh request received');
that._doInlineRefresh().then(function () {
that._trace('inlinerefresh request processed');
});
},
////Exposed to cluster.
clusterResponse: {
get: function get() {
return this._clusterResponse;
},
set: function set(value) {
var that = this;
////parent cluster called for value set
var parentDataSource = value && value.data ? value.data : null;
if (parentDataSource !== null && typeof that.dataId !== "undefined" && parentDataSource[that.dataId]) {
that._clusterResponse = {};
that._clusterResponse.data = parentDataSource[that.dataId];
that._clusterResponse.isValid = value.isValid;
that._clusterResponse.hashCode = value.hashCode;
that._clusterResponse.isStaleResponse = value.isStaleResponse;
that._clusterResponse.lastUpdateTime = value.lastUpdateTime;
this._trace(SportsJS.Msg.DataServedByParent);
}
else {
this._trace(SportsJS.Msg.DataNotServedByParent);
}
}
},
dataSource: {
get: function get() {
return this._dataSource;
},
set: function set(value) {
this._dataSource = value;
}
},
// Data adapter to adapt the data source to itemsContainer datasource,
// This requires two adaptations:
// 1. Adding module info to every item
// 2. Using observable object for binding
_itemsContainerDataAdapter: function _itemsContainerDataAdapter(newDataSource, isInlineRefreshRequest) {
var that = this;
var outputDataSource = [];
var countToTimeout = that.loadModulesCountToTimeout && that.loadModulesCountToTimeout > 0 ? that.loadModulesCountToTimeout : 10;
var moduleInfo = {
fragmentPath: that._fragmentPath,
templateId: "InnerListItemTemplate",
// will only be used when we need custom renderer or else the templateId will be used
renderer: that.createItem,
isInteractive: that._isInteractive
};
var noDataModuelInfo = {
fragmentPath: "/html/templates.html",
templateId: "sportsNoDataTemplate",
isInteractive: true
};
var entriesToRender = (that._maxEntriesToRender !== -1) && (that._maxEntriesToRender < newDataSource.length) ? that._maxEntriesToRender : newDataSource.length;
if (that.isBindingBasedRefreshDisabled || !isInlineRefreshRequest) {
for (var dataIndex = 0; dataIndex < newDataSource.length; dataIndex++) {
newDataSource[dataIndex].index = dataIndex;
if (newDataSource[dataIndex].status === "NoData") {
newDataSource[dataIndex].moduleInfo = noDataModuelInfo;
} else {
newDataSource[dataIndex].moduleInfo = moduleInfo;
}
if (dataIndex > 0 && dataIndex % countToTimeout === 0) {
newDataSource[dataIndex].useTimeout = true;
}
if (dataIndex < entriesToRender) {
if (that.isBindingBasedRefreshDisabled) {
outputDataSource.push(newDataSource[dataIndex]);
} else {
outputDataSource.push(WinJS.Binding.as(newDataSource[dataIndex]));
}
}
}
}
// do not make the source observable if this is an inline request.
// We want to modify the datasource already set.
else {
// Couple of limitations/assumptions with inline refresh. This applies in whole module control
// 1. The items to be refreshed are always in order
// 2. The next refresh always has more than equal to items than the current refresh
// 3. The objects to be refreshed doesn't not contain arrays. There are limitations with binding in making
//    complex objects observable.
// we'll support above on need basis
var maxLength = Math.min(that._dataSource.length, entriesToRender);
for (var inlineIndex = 0; inlineIndex < maxLength; inlineIndex++) {
var existingData = that._dataSource[inlineIndex];
var newData = newDataSource[inlineIndex];
var requiresUpdate = false;
if (existingData.hashCode && newData.hashCode && existingData.hashCode !== newData.hashCode) {
requiresUpdate = true;
} else if (typeof existingData.hashCode === "undefined" && typeof newData.hashCode === "undefined") {
// incase the hashcode is not supported, we always update
requiresUpdate = true;
}
if (requiresUpdate) {
if (that.isBindingBasedRefreshDisabled) {
that._dataSource[inlineIndex] = newDataSource[inlineIndex];
}
else {
SportsJS.Utilities.observableObjectAwareDeepCopy(newData, existingData);
}
}
}
// We need to be carefull when we are appending the dataSource though. Handle this while
// doing inline refresh for items container.
// Append the remaining items so that modulecontrol dataSource is always representing the current dom state of module
for (; inlineIndex < entriesToRender; inlineIndex++) {
newDataSource[inlineIndex].moduleInfo = moduleInfo;
newDataSource[inlineIndex].index = inlineIndex;
if (inlineIndex > 0 && inlineIndex % countToTimeout === 0) {
newDataSource[inlineIndex].useTimeout = true;
}
if (that.isBindingBasedRefreshDisabled) {
that._dataSource.push(newDataSource[inlineIndex]);
} else {
that._dataSource.push(WinJS.Binding.as(newDataSource[inlineIndex]));
}
}
outputDataSource = that._dataSource;
}
return outputDataSource;
},
//TODO:chthakur, This function will go away, once we all move to using moduleconfig and clusterconfig
_loadModuleFragment: function _loadModuleFragment() {
var that = this;
var p = new WinJS.Promise(function (complete) {
if (that.fragmentObject) {
complete(that.fragmentObject);
}
else {
WinJS.UI.Fragments.cache(that._fragmentPath).then(function (moduleFragment) {
complete(moduleFragment);
});
}
});
return p;
},
_loadChildItemContainerControl: function _loadChildItemContainerControl() {
var that = this;
//// In case of Retry, the module's getData gets called again which calls _loadChildItemContainerControl.
//// We dont want to Load the child ListView again.
if (this._ListControl) {
return new WinJS.Promise(function (complete) {
complete(true);
});
}
var p = new WinJS.Promise(function (complete, error) {
that._loadModuleFragment().then(function (moduleFragment) {
WinJS.UI.processAll(moduleFragment);
WinJS.Resources.processAll(moduleFragment);
var moduleInfo = {
fragmentPath: that._fragmentPath,
templateId: that.templateId
};
// make the chromeData observable
if (that._hasChrome) {
that.chromeData = WinJS.Binding.as(that._providerResponse.chromeData);
that._options.chromeData = that.chromeData;
}
CommonJS.loadModule(moduleInfo, that._options, null, null, null).then(function (container) {
if (!container) {
that._trace('Mandatory list container not found');
error(false);
return;
}
var innerList = container.querySelector(".InnerListContainer");
WinJS.UI.processAll(innerList);
var lc = innerList ? innerList.winControl : null;
that._ListControl = lc;
if (lc) {
innerList.setAttribute("aria-label", "Sports Module");
WinJS.UI.setOptions(lc, {
className: "platformListLayout",
onitemclick: function onitemclick(element) {
if (element && that.options && that.options.eventHandler && typeof that.options.eventHandler === "function") {
that.options.eventHandler.apply(that, [element, { data: element.item }]);
}
}
});
if (that._isModuleScrollable && that._isModuleScrollable === true) {
that.handleModuleScroll(that._ListControl.element);
}
if (that._isModuleResizeable) {
that.handleModuleResize(that._ListControl.element);
}
that.element.appendChild(container);
that._trace('inner itemscontainer instantiated');
complete(true);
}
else {
error(false);
that._trace('Mandatory itemscontainer control not found');
}
});
});
});
return p;
},
_loadChildListViewControl: function _loadChildListViewControl() {
var that = this;
//// In case of Retry, the module's getData gets called again which calls loadChildListViewControl.
//// We dont want to Load the child ListView again.
if (this._ListControl) {
return new WinJS.Promise(function (complete) {
complete(true);
});
}
var p = new WinJS.Promise(function (complete) {
that._loadModuleFragment().then(function (moduleFragment) {
WinJS.UI.processAll(moduleFragment);
var moduleInfo = {
fragmentPath: that._fragmentPath,
templateId: that.templateId,
};
if (that._hasChrome) {
that._bindableProviderResponse = WinJS.Binding.as(that._providerResponse);
} else {
that._bindableProviderResponse = that._providerResponse;
}
CommonJS.loadModule(moduleInfo, that._bindableProviderResponse, null, null, null).then(function (container) {
if (!container) {
that._trace('Mandatory itemscontainer not found');
complete(false);
return;
}
var innerList = container.querySelector(".InnerListContainer");
WinJS.UI.processAll(innerList);
var lv = innerList ? innerList.winControl : null;
that._ListControl = lv;
if (lv) {
innerList.setAttribute("aria-label", "Sports Module");
if (that.innerListViewOptions) {
WinJS.UI.setOptions(lv, that.innerListViewOptions);
}
var listItemTemplate;
if (that.options.rendererInfo) {
listItemTemplate = WinJS.UI.simpleItemRenderer(that.createItem);
}
else {
listItemTemplate = moduleFragment.querySelector("." + lv.itemRendererSelector);
}
WinJS.UI.setOptions(lv, {
groupHeaderTemplate: that.innerListViewOptions && that.innerListViewOptions.groupRendererId ? moduleFragment.querySelector("." + that.innerListViewOptions.groupRendererId) : null,
itemTemplate: listItemTemplate,
selectionMode: that.innerListViewOptions && that.innerListViewOptions.selectionMode ? that.innerListViewOptions.selectionMode : 'none',
tapBehavior: that._isInteractive ? WinJS.UI.TapBehavior.none : ((that.innerListViewOptions && that.innerListViewOptions.tapBehavior) ? that.innerListViewOptions.tapBehavior : WinJS.UI.TapBehavior.invokeOnly),
oniteminvoked: function oniteminvoked(event) {
if (!event || !event.detail || typeof event.detail.itemIndex === 'undefined' || that._ListControl.isHandlePrevented()) {
return;
}
var itemIndex = event.detail.itemIndex;
var dataSource = that._ListControl.itemDataSource;
if (dataSource && that.options.eventHandler && typeof that.options.eventHandler === 'function') {
var listBinding = dataSource.createListBinding();
listBinding.fromIndex(itemIndex).then(function (item) {
if (item) {
that.options.eventHandler.apply(that, [event, item.data]);
}
});
}
}
});
that._handleKeydownOnListviewItem = function (e) {
if (e.ctrlKey && e.keyCode === WinJS.Utilities.Key.g && e.altKey) {
if (lv.itemDataSource && lv.itemDataSource.list && lv.currentItem) {
var itemData = lv.itemDataSource.list.getAt(lv.currentItem.index);
that.groupShortCutHandler(e, itemData);
e.preventDefault();
e.stopImmediatePropagation();
}
}
};
// for grouped grid views, we will listen for shortcut 'ctrl+alt+g' to invoke header corresponding to item
if (typeof that.groupShortCutHandler === "function") {
lv.addEventListener("keydown", that._handleKeydownOnListviewItem, true);
}
if (that._isModuleScrollable && that._isModuleScrollable === true) {
that.handleModuleScroll(that._ListControl.element);
}
if (that._isModuleResizeable) {
that.handleModuleResize(that._ListControl.element);
}
}
else {
that._trace('Mandatory listview not found');
}
that.element.appendChild(container);
that._trace('inner listview instantiated');
complete(true);
});
});
});
return p;
},
handleModuleScroll: function handleModuleScroll(controlElement) {
if (controlElement) {
controlElement.addEventListener("mousewheel", CommonJS.Immersive.PanoramaPanel.verticalScrollHandler, false);
}
},
handleModuleResize: function handleModuleResize(controlElement) {
var that = this;
// currently we dont have any common scenario. Derived class can override it if needed.
},
_ListControl: null,
listControl: {
get: function get() {
return this._ListControl;
}
},
_clusterResponse: null,
_dataSource: null,
_providerResponse: null,
providerResponse: {
get: function get() {
return this._providerResponse;
}
},
_readyForInlineRequest: false,
_dataProvider: null,
_timerId: null,
_isModuleObjectValid: true,
_lastResponseRejected: false,
_passthroughDataProvider: function _passthroughDataProvider() {
var that = this;
var clusterResponse = that._clusterResponse;
if (!clusterResponse) {
clusterResponse = { data: null, isValid: false, hashCode: -1 };
}
var promise = WinJS.Promise.wrap(
{
//response has already been validated to be valid
response: {
data: clusterResponse.data,
isValid: clusterResponse.isValid,
hashCode: clusterResponse.hashCode,
isStaleResponse: clusterResponse.isStaleResponse,
lastUpdateTime: clusterResponse.lastUpdateTime,
}
}
);
return promise;
},
_checkForNoData: function _checkForNoData(completeAdapter) {
if (completeAdapter && completeAdapter.response && completeAdapter.response.isNoData) {
completeAdapter.data = [];
var noDataModuelInfo = {
fragmentPath: "/html/templates.html",
templateId: "sportsNoDataTemplate",
isInteractive: true
};
/* TODO: arengak - using status for nodata does not look good. Need better way to handle it */
completeAdapter.data.push({ status: "NoData", isValid: true, moduleInfo: noDataModuelInfo });
completeAdapter.response.isValid = true;
}
},
_consumeData: function _consumeData(data, isInlineRefreshRequest) {
var that = this;
that._checkForNoData(data);
if (data.response && data.response.isValid && data.response.data) {
if (isInlineRefreshRequest) {
// verify the validity of new response for inline refresh
if (!that._isResponseValidForInlineRefresh(data.response)) {
// do not modify the state/data of module if the response is not valid. So return immediately                           
return true;
}
}
var oldProviderResponse = that._providerResponse;
var hasOldResponse = !!(oldProviderResponse);
if (hasOldResponse) {
that._updateStalenessParameters(data.response);
}
var shouldRefreshData = isInlineRefreshRequest || hasOldResponse;
that.dataSource = that._isInnerListAnItemsContainer ? that._itemsContainerDataAdapter(data.response.data, shouldRefreshData) : data.response.data;
that._providerResponse = data.response;
Object.defineProperty(that._providerResponse, "options", that._options);
// TODO: chthakur - Got a flaw in design. 
// that._ListControl is quite tricky. if the difference between progress & complete handler is minimal
// We end up refreshing the datasource without list instantiation.
// To fix this, we need to disable the refresh datasource if listcontrol is not available. This is not ideal but works.
// the order in which datasource updates saves us. Proper fix requires bigger change. Queuing is the way to go. 
if (shouldRefreshData && that.isBindingBasedRefreshDisabled && that._ListControl) {
// refresh the full datasource. 
that._refreshDataSource();
} else if (shouldRefreshData) {
that._refreshListInline();
}
return true;
}
//// In case of inline refresh, we dont want to show error control. 
//// So, we will return success.
else if (isInlineRefreshRequest === true) {
return true;
}
return false;
},
_fetchdata: function _fetchdata(isInlineRefreshRequest, bypassCache) {
var that = this;
var promise = new WinJS.Promise(function (complete, error) {
//// Support promise and non-promise data adapters here. check the type and then take action
if (that._dataProvider) {
var bypassProgress = false;
that._hasValidData = false;
var dataProviderCompleteHandler = function (completeHandlerResponse) {
// Note: Ideally the _isModuleObjectValid check is not required but we see that the function is being executed 
// after the module is cleaned-up. Workaround: preventing the function execution by doing check for isModuleObjectValid.
// TODO: arengak - find the root cause and revert the workaround
if (!that._isModuleObjectValid) {
return;
}
if (that._consumeData(completeHandlerResponse, isInlineRefreshRequest)) {
that._hasValidData = true;
if (that.dataProviderKey && completeHandlerResponse && completeHandlerResponse.response && completeHandlerResponse.response.isValid) {
$SpMgr.jsCache.addObject(that.dataProviderKey, completeHandlerResponse.response, { storeToDisk: true });
}
// register for inline refresh if required
that._registerForInlineRequest(that._providerResponse);
complete();
}
else {
error(completeHandlerResponse);
}
};
var dataProviderErrorHandler = function (errorResponse) {
if (SportsJS.Utilities.isCancellationError(errorResponse)) {
return;
}
else {
error(errorResponse);
}
};
var dataProviderProgressHandler = function (progressResponse) {
//// Purpose of progress is to render quickly using cache.
//// For inline refresh request, we have already rendered 
//// using cached data (exception is when response is rejected on going from Live->Non-Live)
//// hence we can safely reject progress.
if ((isInlineRefreshRequest && !that._lastResponseRejected) || bypassProgress) {
return;
}
//// If progress data can be consumed successfully, complete the promise, else let the complete handler take care.
if (that._consumeData(progressResponse, isInlineRefreshRequest)) {
if (that.dataProviderKey && progressResponse && progressResponse.response && progressResponse.response.isValid) {
$SpMgr.jsCache.addObject(that.dataProviderKey, progressResponse.response, { storeToDisk: true });
}
that._hasValidData = true;
// register for inline refresh if required
that._registerForInlineRequest(that._providerResponse);
complete();
}
//// TODO(ashondik): For daily league schedule, we set isValid false for noGamesToday response, which needs to be handled specially here
//// Remove this special handling once schedule call is moved to cluster level.
else if (progressResponse && (typeof that._isNoGamesResponse !== 'undefined' && that._isNoGamesResponse(progressResponse.response))) {
error(progressResponse);
}
};
var getDataFromDataProvider = function () {
var dataPromise = that._promiseStack(that._dataProvider(bypassCache, bypassProgress));
dataPromise.then(dataProviderCompleteHandler, dataProviderErrorHandler, dataProviderProgressHandler);
};
var memoryCacheResponseHandler = function (inMemoryResponse, requiresFetch) {
if (that._consumeData(inMemoryResponse, isInlineRefreshRequest)) {
that._hasValidData = true;
bypassProgress = true;
// register for inline refresh if required
that._registerForInlineRequest(that._providerResponse);
if (requiresFetch) {
// make actual data provider call after 100ms.
that._fetchDataTimerId = setTimeout(function () {
that._fetchDataTimerId = null;
getDataFromDataProvider();
}, 2000);
}
complete();
}
};
var dataProviderKey = that.dataProviderKey;
if (bypassCache || isInlineRefreshRequest || !dataProviderKey) {
getDataFromDataProvider();
return;
}
// Check we have response in our memory cache.
// error not required. null response in case of failure
SportsJS.mainProcessManager.jsCache.getObjectAsync(dataProviderKey).then(function (res) {
if (!that._isModuleObjectValid) {
return;
}
if (!res || !res.isValid) {
getDataFromDataProvider();
return;
}
var requiresFetch = true;
if (res.isStaleResponse === false) {
requiresFetch = false;
}
memoryCacheResponseHandler({ response: res }, requiresFetch);
});
} else {
that._trace("Data provider missing. Module will not be rendered");
}
});
return promise;
},
// check if the new response received by inlinerefresh is valid or not
_isResponseValidForInlineRefresh: function _isResponseValidForInlineRefresh(newProviderResponse) {
var that = this;
// Check validity of responses.
// check if the new response contains fewer items than the existing response, return false. This is actually a case of removal which is not
// required yet.
if (!that._dataSource || !newProviderResponse || !newProviderResponse.data || (that._dataSource.length > newProviderResponse.data.length)) {
that._trace(SportsJS.Msg.ResponseNotValidForInlineRefresh);
return false;
};
if (that._providerResponse && that._providerResponse.hashCode && newProviderResponse.hashCode) {
//// Check if new response's hashcode is different from current response. If yes, then we want to refresh
if (that._providerResponse.hashCode === newProviderResponse.hashCode) {
that._trace(SportsJS.Msg.ResponseNotValidForInlineRefresh);
// do not modify the state/data of module if the response is not valid. So return immediately
return false;
}
}
if (that._providerResponse.nextRefreshInterval > 0 && newProviderResponse.nextRefreshInterval > 0) {
that._refreshToNoRefreshTries = 0;
}
// refresh to no-refresh
if (that._providerResponse.nextRefreshInterval > 0 && newProviderResponse.nextRefreshInterval <= 0 && that._refreshToNoRefreshTries < that._maxRefreshToNoRefreshTries) {
// live response doesn't go dead in one go. 
that._refreshToNoRefreshTries++;
that._lastResponseRejected = true;
return false;
}
else {
that._lastResponseRejected = false;
}
return true;
},
_registerForInlineRequest: function _registerForInlineRequest(response) {
var that = this;
var defaultRefreshInterval = 10;
//// We want to use defaultRefresh only when we have a response that has IsValid set to false
if (response
&& typeof response.isValid !== "undefined") {
if (response.isValid === true) {
if (response.nextRefreshInterval && response.nextRefreshInterval > 0) {
//// making timer data driven
that._triggerTimer(response.nextRefreshInterval);
}
}
else {
// This will handle scenarios when we dont get data from backend
that._triggerTimer(defaultRefreshInterval);
}
}
},
_doInlineRefresh: function _doInlineRefresh() {
var that = this;
var autoRefreshEnabled = SportsJS.SettingsManager.isAutoRefreshEnabled();
if (!autoRefreshEnabled) {
// handling settings this way keeps things simple for us.
// The other options is to trigger custom event from settings
// That might introduce lot of cases of error.
return WinJS.Promise.wrap();
}
var promise = new WinJS.Promise(function (complete) {
that._fetchdata(true, null).then(function () {
////: TODO:return failure scenario.
complete();
}, function () {
complete();
});
});
return promise;
},
_refreshModuleChrome: function _refreshModuleChrome() {
var that = this;
if (!that._hasChrome) {
return;
}
if (that._isInnerListAnItemsContainer) {
if (that._providerResponse.chromeData && that.chromeData) {
SportsJS.Utilities.observableObjectAwareDeepCopy(that._providerResponse.chromeData, that.chromeData);
}
}
else if (that._bindableProviderResponse && that._providerResponse) {
SportsJS.Utilities.observableObjectAwareDeepCopy(that._providerResponse, that._bindableProviderResponse);
}
},
_refreshListViewInline: function _refreshListViewInline() {
var that = this;
var myList = that._ListControl;
if (myList) {
var dataSource = myList.itemDataSource;
// TODO: Hook data sourceinside this funciton
// Access the item at the index indicated by the invoke event
// Operate on the item if / when it is returned via a 'promise'
// TODO: recheck the procedure below to iterate over all the items. I think we have better methods to do that
// TODO: built in some mechanism to change only items which have changed
// TODO: using data length seems risky to me. Verify this assumption
dataSource.getCount().then(function (listLength) {
if (that._ListControl.groupBy) {
// Implementing a generic logic for canned tiles.
// Each element should have an IsCanned Property on it. We assume only the last item shown might be canned
if (that._dataSource.length > 0) {
var newLastItem = that._dataSource[that._dataSource.length - 1];
if (typeof newLastItem.isCanned !== 'undefined' && !newLastItem.isCanned) {
var cannedBinding = dataSource.createListBinding();
cannedBinding.last().then(function (lastItem) {
cannedBinding.release();
if (lastItem.data.isCanned) {
dataSource.remove(lastItem.key);
listLength--;
}
});
}
}
}
var binding = dataSource.createListBinding();
for (var m = 0, dsMax = that._dataSource.length; m < listLength && m < dsMax; m++) {
binding.fromIndex(m).then(function (item) {
if (item.data.hashCode && that._dataSource[m].hashCode) {
//// See if data has changed
if (item.data.hashCode !== that._dataSource[m].hashCode) {
that._trace(SportsJS.Msg.ListViewItemChanged);
return dataSource.change(item.key, that._dataSource[m]);
}
}
}).then(function () {
binding.release();
});
}
for (var n = listLength; n < that._dataSource.length ; n++) {
dataSource.beginEdits();
dataSource.insertAtEnd(null, that._dataSource[n]);
dataSource.endEdits();
}
});
}
},
// Items container refresh implementation. When we are using observable objects, the inline refresh happens
// when we update the module dataSource. As the update is reflected directly in the dom. This function is only
// required to deal with appends. Removals can be supported if required(chthakur)
_refreshItemsContainerInline: function _refreshItemsContainerInline() {
var that = this;
var myList = that._ListControl;
if (myList) {
var dataSource = myList._dataSource;
dataSource.getCount().then(function (listLength) {
for (var n = listLength; n < that._dataSource.length ; n++) {
dataSource.insertAtEnd(null, that._dataSource[n]);
}
});
}
},
_refreshListInline: function _refreshListInline() {
if (this._hasChrome) {
this._refreshModuleChrome();
}
if (this._isInnerListAnItemsContainer) {
this._refreshItemsContainerInline();
}
else {
this._refreshListViewInline();
}
},
// Key used for JsCache
dataProviderKey: {
get: function get() {
var that = this, key;
if (typeof that.constructUiQuery !== "function") {
return null;
}
var uiQuery = that.constructUiQuery();
if (uiQuery && uiQuery.isValid && that.moduleId) {
key = AppEx.Sports.Services.SportsController.getUrl(uiQuery);
key = key + "&moduleId=" + that.moduleId;
}
return key;
}
},
_clearTimer: function _clearTimer() {
var that = this;
if (that._timerId !== null) {
// SportsJS.Services.AppTimer.deregisterFromFastQueue(that._timerId);
clearTimeout(that._timerId);
that._timerId = null;
}
},
_triggerTimer: function _triggerTimer(timeout) {
var that = this;
that._clearTimer();
that._timerId = setTimeout(function () {
that._inlineRefresh.apply(that);
}, timeout * 1000);
},
// Api to make it clear that module is going to be destroyed.
// Do not want to confuse the api user with cleanUp hence destroy.
destroy: function destroy() {
this.cleanUp(null);
},
cleanUp: function cleanUp(isNavigating) {
var that = this;
if (that._isModuleObjectValid === true) {
if (that._fetchDataTimerId) {
clearTimeout(that._fetchDataTimerId);
}
that._cancelPendingImageLoadTasks();
if (that._msSetImmediateIdentifierList && that._msSetImmediateIdentifierList.length > 0) {
for (var i = 0; i < that._msSetImmediateIdentifierList.length; i++) {
msClearImmediate(that._msSetImmediateIdentifierList[i]);
}
}
if (that.listViewKeydownCallback && that._ListControl) {
that._ListControl.removeEventListener("keydown", that.listViewKeydownCallback, true);
}
// de-register scroll events in case of vertically scrollable module
if (that._ListControl && that._ListControl.element) {
that._ListControl.element.removeEventListener("mousewheel", CommonJS.Immersive.PanoramaPanel.verticalScrollHandler, false);
}
if (that._ListControl && that._ListControl.element && that._moduleScrollEventHandler) {
that._ListControl.element.removeEventListener("scroll", that._moduleScrollEventHandler, false);
}
// de-register keydown event if we are listening for keyboard shortcuts for group grid listview
if (typeof that.groupShortCutHandler === "function" && that._ListControl) {
that._ListControl.removeEventListener("keydown", that._handleKeydownOnListviewItem, true);
}
if (that._moduleResizeEventHandler) {
window.removeEventListener("resize", that._moduleResizeEventHandler, false);
}
if (that._ListControl && that._isInnerListAnItemsContainer) {
that._ListControl.dispose();
}
SportsJS.Utilities.cancelPromiseArray(that._dataPromiseStack);
if (that.loadModuleStack && that.loadModuleStack.length > 0) {
SportsJS.Utilities.cancelPromiseArray(that.loadModuleStack);
}
if (!isNavigating) {
this.element.innerHTML = "";
}
that._clearTimer();
that._trace('module cleanup called');
SportsJS.Utilities.setObjectPropertiesToNull(that);
that._isModuleObjectValid = false;
}
},
_trace: function _trace(text) {
SportsJS.Utilities.trace(this, "SportsJS.UI.SportsModule:" + this._fragmentPath + ":" + this.title, text);
},
_shouldInlineRefresh: false,
getListViewLastItemKey: function getListViewLastItemKey() {
var that = this;
if (that._isInnerListAnItemsContainer) {
that._trace("API is only for ListView");
return WinJS.Promise.Wrap(null);
}
var list = that._ListControl;
if (list) {
var promise = new WinJS.Promise(function (complete) {
var listBinding = list.itemDataSource.createListBinding();
listBinding.last().then(function (lastItem) {
if (lastItem) {
complete(lastItem.key);
}
else {
complete(null);
}
});
});
return promise;
}
return WinJS.Promise.Wrap(null);
},
// All the promises which we want to cancel on cleanUp should be wrapped in this function
// so that we can cancel them on cleanup
// data promise stack
_promiseStack: function _promiseStack(promise) {
var that = this;
if (!promise) {
return promise;
}
if (that._isModuleObjectValid) {
that._dataPromiseStack = that._dataPromiseStack.concat(SportsJS.Utilities.createPromiseArrayCopy(promise));
} else {
if (Array.isArray(promise)) {
SportsJS.Utilities.cancelPromiseArray(promise);
}
else {
SportsJS.Utilities.cancelPromise(promise);
}
}
return promise;
},
_updateStalenessParameters: function _updateStalenessParameters(newResponse) {
var that = this;
if (!that._isModuleObjectValid || !that._providerResponse) {
return;
}
var wasStaleResponse = that._providerResponse.isStaleResponse;
//// update staleness parameters
if (newResponse
&& typeof newResponse.isStaleResponse !== 'undefined'
&& typeof newResponse.lastUpdateTime !== 'undefined') {
that._providerResponse.isStaleResponse = newResponse.isStaleResponse;
that._providerResponse.lastUpdateTime = newResponse.lastUpdateTime;
}
//// fire data refresh if data became fresh
if (wasStaleResponse && !that._providerResponse.isStaleResponse) {
var eventObject = document.createEvent("CustomEvent");
eventObject.initCustomEvent("datarefreshed", true, true, null);
this.element.dispatchEvent(eventObject);
}
},
_hasValidData: false,
// Used to reject the new response
// 1. Either the control already has same response. Based on same hashCode
// 2. Or the control already has a valid response and the newer response is invalid
_canRejectCompleteResponse: function _canRejectCompleteResponse(res) {
var that = this;
// if no old respone, just can't reject
if (!that._providerResponse || !that._hasValidData || that._providerResponse.isValid === false) {
return false;
}
// we are here coz, old response is valid
// check if newer response is invalid then reject
if (!res || res.isValid === false) {
return true;
}
// verify if required properties are present
if (!res.etag || !res.lastUpdateTime || !that._providerResponse.etag || !that._providerResponse.lastUpdateTime) {
SportsJS.Utilities.interfaceException("SportsJS.ModuleControl:_canRejectCompleteResponse", "interface violation");
return false;
}
var canReject = false;
var currentResponseEtag = that._providerResponse.etag;
var newResponseEtag = res.etag;
canReject = (currentResponseEtag === newResponseEtag);
// if has cache
var dataProviderKey = that.dataProviderKey;
if (dataProviderKey) {
// update the cache Expiries in case response is rejected
var tsDiff = res.lastUpdateTime.getTime() - that._providerResponse.lastUpdateTime.getTime();
if (canReject && tsDiff > 0) {
$SpMgr.jsCache.updateObjectExpiry(dataProviderKey, res, { storeToDisk: true });
}
}
return canReject;
},
})
});
})();
