﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.Navigation",
{
// schema for channel in Nav Bar, helps intellisense
ChannelSchema: WinJS.Class.define(function () {
this.pageInfo = {
fragment: null,
page: null,
channelId: null,
};
this.subChannels = [];
}, {
id: null,
title: null,
subTitle: null,
icon: null,
subChannels: null,
pageInfo: null,
state: null,
visible: false
}),
//chthakur - TODO - fix offline FRE, minor edge case
ChannelManager: WinJS.Class.define(function () {
}, {
_platformChannelManager: {
get: function get() {
return PlatformJS.Navigation.mainNavigator.channelManager;
}
},
_promiseManagerInstance: null,
promiseManager: {
get: function get() {
if (!this._promiseManagerInstance) {
this._promiseManagerInstance = new SportsJS.Utilities.PromiseCancellationManager();
}
return this._promiseManagerInstance;
}
},
initialize: function initialize() {
this.refresh();
},
refresh: function refresh() {
var that = this;
// below call modifies, standardChannels, after modifying we need to freeze changes to make them reflect in nav bar
// prefer batching changes and then freeze in one go
that._populateTodaySubChannels(that._platformChannelManager.standardChannels);
that._addNewsPanoToNavBar(that._platformChannelManager.standardChannels);
that._addVideosPanoToNavBar(that._platformChannelManager.standardChannels);
that._addAllLeagueChannelsToNavBar(that._platformChannelManager.standardChannels);
this._makeChannelVisible(that._platformChannelManager.standardChannels, SportsJS.UI.Channels.AllSports);
that.setStandardChannelBar(that._platformChannelManager.standardChannels);
},
reset: function reset() {
this.dispose();
this.refresh();
},
// freeze changes to nav bar
setStandardChannelBar: function setStandardChannelBar(standardChannels) {
this._platformChannelManager.standardChannels = standardChannels;
this._platformChannelManager.setChannelConfigData();
},
dispose: function dispose() {
// put your stuff to dispose there
this.promiseManager.cancelPromises();
},
_populateTodaySubChannels: function _populateTodaySubChannels(standardChannels) {
var todayChannel = this._getChannelFromNavBar(standardChannels, "Home");
if (!todayChannel) {
return;
}
var myteamsSubChannel = SportsJS.Navigation.ChannelManager.MyTeams;
// all the subchannels are programmed from here only, we need to reset the subchannels set earlier
todayChannel.subChannels = [];
var todayNewsType = SportsJS.Utilities.getNewsTypeForPage(SportsJS.UI.PageType.Today);
if (todayNewsType.value === SportsJS.UI.NewsType.bingcategory || todayNewsType.value === SportsJS.UI.NewsType.rss) {
todayChannel.subChannels.push(SportsJS.Navigation.ChannelManager.TodayNews);
}
var isVideoSubChannelEnabled = PlatformJS.Services.appConfig.getBool("EnableTodayHubVideosCluster");
if (isVideoSubChannelEnabled) {
todayChannel.subChannels.push(SportsJS.Navigation.ChannelManager.TodayVideo);
}
todayChannel.subChannels.push(myteamsSubChannel);
},
_addNewsPanoToNavBar: function _addNewsPanoToNavBar(standardChannels) {
var that = this;
var newsPanoChannel = this._getChannelFromNavBar(standardChannels, "NewsPano");
if (PlatformJS.Services.appConfig.getBool("EnableEditorialNewsPano")) {
newsPanoChannel.visible = true;
}
},
_addVideosPanoToNavBar: function _addVideosPanoToNavBar(standardChannels) {
var that = this;
var newsPanoChannel = this._getChannelFromNavBar(standardChannels, "VideosPano");
if (PlatformJS.Services.appConfig.getBool("EnableEditorialVideosPano")) {
newsPanoChannel.visible = true;
}
},
_addAllLeagueChannelsToNavBar: function _addAllLeagueChannelsToNavBar(standardChannels) {
var that = this;
var leagueChannels = this._createLeagueChannels();
var pivotChannel = this._getChannelFromNavBar(standardChannels, "LeagueChannelsPivot");
if (!pivotChannel) {
return;
}
this._removeAllLeagueChannelsFromNavBar(standardChannels);
var pivotIndex = standardChannels.indexOf(pivotChannel);
if (pivotIndex === -1) {
SportsJS.Utilities.unexpectedCodePathException("ChannelManager:_addAllLeagueChannelsToNavBar", "Could not find channel LeagueChannelsPivot in AppConfiguration.xml");
return;
}
standardChannels.splice.apply(standardChannels, [pivotIndex, 0].concat(leagueChannels));
},
_removeAllLeagueChannelsFromNavBar: function _removeAllLeagueChannelsFromNavBar(standardChannels) {
var that = this;
var leagueChannels = this._getAllLeagueChannelsFromNavBar(standardChannels);
leagueChannels.forEach(function (channelData) {
var index = standardChannels.indexOf(channelData);
if (index !== -1) {
standardChannels.splice(index, 1);
}
});
},
_createLeagueChannels: function _createLeagueChannels() {
var that = this;
var leagueChannels = [];
var userLeagues = SportsJS.mainProcessManager.userLeagues;
var leagueLength = userLeagues.length;
userLeagues.forEach(function (league) {
var leagueInfo = $SpMgr.leagueInfoTable[league];
if (!leagueInfo) {
return;
}
var sport = AppEx.Sports.Services.Utils.getSportsFromLeague(league);
// chthakur -> see if we can use existing object in nav, this will help us keep state
var channelData = new SportsJS.Navigation.ChannelSchema();
channelData.id = SportsJS.Utilities.stringFormat("channel_league_{0}", league);
channelData.title = SportsJS.Utilities.getLocLeagueDisplayText(league);
channelData.subTitle = PlatformJS.Services.resourceLoader.getString("SportsHomeSubChannelLabel");
channelData.icon = SportsJS.Utilities.stringFormat("icon{0}", sport);
channelData.subChannels = that._getSubChannelsFromNavLinks(leagueInfo.LeagueName, leagueInfo.NavLinks);
channelData.pageInfo.fragment = "/html/defaultPanoPage.html";
channelData.pageInfo.page = "SportsJS.EntityBase";
channelData.pageInfo.channelId = channelData.id;
channelData.visible = true;
channelData.state = { pageType: SportsJS.UI.PageType.League, leagueType: league };
leagueChannels.push(channelData);
});
return leagueChannels;
},
_getSubChannelsFromNavLinks: function _getSubChannelsFromNavLinks(leagueName, navLinks) {
if (!navLinks) {
return [];
}
var subchannelList = [];
navLinks.forEach(function (link) {
if(!link || !link.Link || !link.Link.Uri) {
return;
}
var subchannel = new SportsJS.Navigation.ChannelSchema();
subchannel.id = leagueName + link.Id;
subchannel.title = link.Title;
subchannel.subChannels = []; // required for subchannel itself
var uriCommand = PlatformJS.Navigation.createCommandFromUri(link.Link.Uri);
if (!uriCommand || !uriCommand.channelInfo || !uriCommand.channelInfo.pageInfo) {
return;
}
subchannel.pageInfo = {};
subchannel.pageInfo.channelId = leagueName + link.Id;
subchannel.pageInfo.page = uriCommand.channelInfo.pageInfo.page;
subchannel.pageInfo.fragment = uriCommand.channelInfo.pageInfo.fragment;
subchannel.state = uriCommand.options;
subchannel.visible = true;
subchannelList.push(subchannel);
});
return subchannelList;
},
_getAllLeagueChannelsFromNavBar: function _getAllLeagueChannelsFromNavBar(standardChannels) {
var leagueChannels = [];
for (var i = 0; i < standardChannels.length; i++) {
if (standardChannels[i].id.indexOf("channel_league_") !== -1) {
leagueChannels.push(standardChannels[i]);
}
}
return leagueChannels;
},
_getChannelFromNavBar: function _getChannelFromNavBar(standardChannels, id) {
if (!standardChannels || !id) {
return null;
}
for (var kk = 0; kk < standardChannels.length; kk++) {
if (standardChannels[kk].id === id) {
return standardChannels[kk];
}
}
return null;
},
_makeChannelVisible: function _makeChannelVisible(standardChannels, id) {
var channel = this._getChannelFromNavBar(standardChannels, id);
if (!channel) {
// this wouldn't happend
return;
}
channel.visible = true;
}
}, {
TodayNews: {
get: function get() {
return Object.freeze({
id: "news",
title: "CategoryNewsClusterTitle",
pageInfo: {
fragment: "/leagues/common/News/NewsPanoPage.html",
page: "SportsJS.News.NewsPano",
channelId: "TodayNews",
},
subChannels: [],
state: {
type: "bingcategory",
league: "",
entity: SportsJS.UI.EntityType.Today,
id: "sports"
}
});
}
},
TodayVideo: {
get: function get() {
return Object.freeze({
id: SportsJS.UI.ClusterType.Video,
title: "VideoClusterLabel",
pageInfo: {
fragment: "/leagues/common/Video/VideoPage/VideoPage.html",
page: "SportsJS.Common.Video.VideoPage",
channelId: "TodayVideo",
},
subChannels: [],
state: {
leagueName: SportsJS.UI.LeagueType.all,
editorialCollectionType: AppEx.Sports.Services.TypeDefs.EditorialCollectionType.videos,
entityType: SportsJS.UI.EntityType.Today
}
});
}
},
MyTeams: {
get: function get() {
return Object.freeze({
id: SportsJS.UI.ClusterType.MyTeams,
title: "MyTeams",
pageInfo: {
fragment: "/leagues/today/MyTeamsPage/MyTeamsPage.html",
page: "SportsJS.Today.MyTeamsPage",
channelId: "MyTeams",
},
subChannels: [],
state: {
leagueName: SportsJS.UI.LeagueType.all,
entityType: SportsJS.UI.EntityType.Team
}
});
}
},
}),
});
})();
