﻿/********************************************************
*                                                        *
*   © Microsoft. All rights reserved.                    *
*                                                        *
*********************************************************/
(function () {
"use strict";
WinJS.Namespace.define("SportsJS",
{
NavController: WinJS.Class.define(function () {
this.initialize();
},
{
initialize: function initialize() {
// Register sports app launcher scheme with platform
Platform.Utilities.AppExUri.addScheme(SportsJS.AppLauncherScheme);
// Register the list of controllers for sports
PlatformJS.Navigation.addController(SportsJS.NavControllers.application, this.applicationController);
PlatformJS.Navigation.addController(SportsJS.NavControllers.league, this.leagueController);
PlatformJS.Navigation.addController(SportsJS.NavControllers.team, this.teamController);
PlatformJS.Navigation.addController(SportsJS.NavControllers.player, this.playerController);
PlatformJS.Navigation.addController(SportsJS.NavControllers.match, this.matchController);
PlatformJS.Navigation.addController(SportsJS.NavControllers.news, this.newsController);
PlatformJS.Navigation.addController(SportsJS.NavControllers.favorites, this.favoritesController);
PlatformJS.Navigation.addController(SportsJS.NavControllers.search, this.searchController);
PlatformJS.Navigation.addController(SportsJS.NavControllers.ecv, this.ecvController);
PlatformJS.Navigation.addController(SportsJS.NavControllers.page, this.pageController);
PlatformJS.Navigation.addController(SportsJS.NavControllers.editorial, this.editorialController);
PlatformJS.Navigation.addController(SportsJS.NavControllers.allsports, this.allsportsController);
PlatformJS.Navigation.addController(SportsJS.NavCommand.slideshows, this.slideshowcontroller);
PlatformJS.Navigation.addFeedbackEntityView();
},
// Default app level controller
applicationController: {
default: function (args) {
args = SportsJS.NavHelper.convertObjectKeysToLowerCase(args);
SportsJS.NavHelper.handleGlobalArguments(args);
return SportsJS.NavHelper.homeNavigationAction();
},
view: function view(args) {
if (!args) {
return SportsJS.NavHelper.homeNavigationAction();
}
var state = {};
args = SportsJS.NavHelper.convertObjectKeysToLowerCase(args);
SportsJS.NavHelper.handleGlobalArguments(args);                    
if (args.entitytype === SportsJS.NavEntityType.article) {
var pageId;
var contentId;
if (args.pageid) {
pageId = args.pageid;
contentId = args.contentid;
}
else if (args.articleid) {
pageId = args.articleid;
}
var instrumentationIdForUrlInvocation = 2;
state = SportsJS.Utilities.createArticleReaderOptions(pageId, contentId,
instrumentationIdForUrlInvocation, args.page, args.market);
return PlatformJS.Navigation.createNavigationAction("ArticleReader", state);
}
else if (SportsJS.Utilities.stringCompareIgnoreCase(args.entitytype, SportsJS.NavEntityType.partnerpano)) {
if (!args.sourceid) {
return SportsJS.NavHelper.homeNavigationAction();
}
/* Match the sourceid in the sources data and create the dynamicInfo accordingly */
var sources = new PlatformJS.FeaturedPartners.Sources();
return sources.getSourceForID(args.sourceid).then(function (sourceItem) {
return sourceItem;
}, function () {
return;
});
}
else if (args.entitytype === SportsJS.NavEntityType.slideshow) {                                                
SportsJS.Telemetry.logSlideshowClick(args.pageId);
state.slideshowId = args.pageId;
return PlatformJS.Navigation.createNavigationAction(SportsJS.UI.PageType.Slideshow, state);
}
else if (args.entitytype === SportsJS.NavEntityType.video) {
if (!args.contentid) {
return SportsJS.NavHelper.homeNavigationAction();
}
var videoOptions = {
videoSource: args.contentid,
};
var navToVideo = function () {
CommonJS.MediaApp.Controls.MediaPlayback.fullscreenPlayback(videoOptions.videoSource, videoOptions);
};
return navToVideo;
}
else if (args.entitytype === SportsJS.NavEntityType.pano) {
if (args.panoid) {
switch (args.panoid) {
case SportsJS.UI.PanoType.allsports:
return PlatformJS.Navigation.createCommandFromUri("//allsports");
case SportsJS.UI.PanoType.news:
var newsState = {
type: args.type ? args.type : "bingcategory",
league: args.league ? args.league : "",
entity: args.entity ? args.entity : SportsJS.UI.EntityType.Today,
id: args.id ? args.id : "sports"
};
return PlatformJS.Navigation.createNavigationAction(SportsJS.UI.PageType.News, newsState);
case SportsJS.UI.PanoType.video:
var videoState = {
editorialCollectionType: args.editorialCollectionType ? args.editorialCollectionType : AppEx.Sports.Services.TypeDefs.EditorialCollectionType.videos,
leagueName: args.leagueName ? args.leagueName : "today",
entityType: args.entityType ? args.entityType : SportsJS.UI.EntityType.Today
};
return PlatformJS.Navigation.createNavigationAction(SportsJS.UI.Channels.Video, videoState);
case SportsJS.UI.PanoType.allnews:
var allNewsArgs = {
id: args.id ? args.id : "News",
pagetype: args.pagetype ? args.pagetype : SportsJS.UI.PageType.EditorialCollection,
leagueType: args.leagueType ? args.leagueType : SportsJS.UI.LeagueType.all,
leagues: args.leagues ? args.leagues : "ms-client:userLeagues",
};
return PlatformJS.Navigation.createNavigationAction("SportsGenericPage", allNewsArgs);
case SportsJS.UI.PanoType.allvideo:
var allVideoArgs = {
id: args.id ? args.id : "Video",
pagetype: args.pagetype ? args.pagetype : SportsJS.UI.PageType.EditorialCollection,
leagueType: args.leagueType ? args.leagueType : SportsJS.UI.LeagueType.all,
leagues: args.leagues ? args.leagues : "ms-client:userLeagues",
};
return PlatformJS.Navigation.createNavigationAction("SportsGenericPage", allVideoArgs);
}
}
}
else if (args.entitytype) {
var entityType = args.entitytype;
if (PlatformJS.Navigation.entityViewMap && PlatformJS.Navigation.entityViewMap[entityType]) {
return PlatformJS.Navigation.entityViewMap[entityType](args);
}
}
return SportsJS.NavHelper.homeNavigationAction();
}
},
// Controller to navigate to all the league pages
leagueController: {
default: function (args) {
var state = {};
args = SportsJS.NavHelper.convertObjectKeysToLowerCase(args);
SportsJS.NavHelper.handleGlobalArguments(args);
if (args.id && SportsJS.Utilities.isValidLeagueTypeStrict(args.id)) {
state.leagueType = args.id;
var targetChannel = SportsJS.UI.EntityType.League + SportsJS.UI.PageType.Home;
return PlatformJS.Navigation.createNavigationAction(targetChannel, state);
}
return SportsJS.NavHelper.homeNavigationAction();
}
},
// Controller to navigate to all the team pages
teamController: {
default: function (args) {
var state = {};
args = SportsJS.NavHelper.convertObjectKeysToLowerCase(args);
SportsJS.NavHelper.handleGlobalArguments(args);
if (args.id && args.league && SportsJS.Utilities.isValidLeagueTypeStrict(args.league)) {
state.leagueType = args.league;
state.teamId = args.id;
var targetChannel = SportsJS.UI.PageType.Team;
return PlatformJS.Navigation.createNavigationAction(targetChannel, state);
}
return SportsJS.NavHelper.homeNavigationAction();
}
},
// Controller to navigate to all the player pages
playerController: {
default: function (args) {
var state = {};
args = SportsJS.NavHelper.convertObjectKeysToLowerCase(args);
SportsJS.NavHelper.handleGlobalArguments(args);
if (args.id && args.league && SportsJS.Utilities.isValidLeagueTypeStrict(args.league)) {
state.leagueType = args.league;
state.playerId = args.id;
if (args.name) {
state.playerFullName = args.name;
}
var targetChannel = SportsJS.UI.PageType.Player;
return PlatformJS.Navigation.createNavigationAction(targetChannel, state);
}
return SportsJS.NavHelper.homeNavigationAction();
}
},
// Controller to navigate to all the match pages
matchController: {
default: function (args) {
var state = {};
args = SportsJS.NavHelper.convertObjectKeysToLowerCase(args);
SportsJS.NavHelper.handleGlobalArguments(args);
if (args.id && args.league && SportsJS.Utilities.isValidLeagueTypeStrict(args.league)) {
state.leagueType = args.league;
state.matchId = args.id;
var targetChannel = SportsJS.UI.PageType.Match;
return PlatformJS.Navigation.createNavigationAction(targetChannel, state);
}
return SportsJS.NavHelper.homeNavigationAction();
}
},
// Controller to navigate to all the news pages
newsController: {
default: function (args) {
var state = {};
args = SportsJS.NavHelper.convertObjectKeysToLowerCase(args);
SportsJS.NavHelper.handleGlobalArguments(args);
if (args.league && SportsJS.Utilities.isValidLeagueTypeStrict(args.league)) {
state.league = args.league;
}
if (args.entity) {
state.entity = args.entity;
state.type = SportsJS.UI.NewsType.bingcategory;
}
if (args.id) {
state.id = args.id;
}
if (args.NewsQuery) {
state.query = args.NewsQuery;
}
if (args.NewsType) {
state.type = args.NewsType;
}
return PlatformJS.Navigation.createNavigationAction(SportsJS.UI.PageType.News, state);
}
},
// Controller to navigate to all the editorial pages. Video/preview/recap etc
editorialController: {
default: function (args) {
var state = {};
var pageArgs = {};
var channel = null;
SportsJS.Utilities.deepCopyJsObject(args, pageArgs);
SportsJS.NavHelper.handleGlobalArguments(args);
if (!pageArgs.leagueName || !SportsJS.Utilities.isValidLeagueTypeStrict(pageArgs.leagueName) || !pageArgs.id || !pageArgs.editorialCollectionType) {
// null fails
return PlatformJS.Navigation.createNoopAction();
}
// convert strings to integers. Editorial page accepts enum integer value
if (pageArgs.id && pageArgs.editorialCollectionType) {
pageArgs.id = AppEx.Sports.Services.TypeDefs.EditorialCollectionType[pageArgs.id]; //covert string to enum int
pageArgs.editorialCollectionType = AppEx.Sports.Services.TypeDefs.EditorialCollectionType[pageArgs.editorialCollectionType];
}
//id/editorialCollectionType are integers
if (typeof pageArgs.id === "undefined" || pageArgs.id === null || typeof pageArgs.editorialCollectionType === "undefined" || pageArgs.editorialCollectionType === null) {
// null fails
return PlatformJS.Navigation.createNoopAction();
}
if (AppEx.Sports.Services.TypeDefs.EditorialCollectionType.video === pageArgs.editorialCollectionType) {
return PlatformJS.Navigation.createNavigationAction(SportsJS.UI.Channels.Video, pageArgs);
} else if (AppEx.Sports.Services.TypeDefs.EditorialCollectionType.preview === pageArgs.editorialCollectionType) {
return PlatformJS.Navigation.createNavigationAction(SportsJS.UI.Channels.Preview, pageArgs);
} else if (AppEx.Sports.Services.TypeDefs.EditorialCollectionType.recap === pageArgs.editorialCollectionType) {
return PlatformJS.Navigation.createNavigationAction(SportsJS.UI.Channels.Recap, pageArgs);
} else {
return PlatformJS.Navigation.createNoopAction();
}
}
},
// Controller to navigate to the favorites page
favoritesController: {
default: function (args) {
args = SportsJS.NavHelper.convertObjectKeysToLowerCase(args);
SportsJS.NavHelper.handleGlobalArguments(args);
return PlatformJS.Navigation.createNavigationAction(SportsJS.UI.PageType.MyTeams);
}
},
//Controller to navigate to slideshowpage
slideshowController: {
default: function (args) {
var state = {};
args = SportsJS.NavHelper.convertObjectKeysToLowerCase(args);
SportsJS.NavHelper.handleGlobalArguments(args);
state.entity = args.entity;
return SportsJS.NavHelper.createNavigationAction(SportsJS.UI.PageType.Slideshow, state);
},
},
// Controller to navigate to the all sports page
allsportsController: {
default: function (args) {
args = SportsJS.NavHelper.convertObjectKeysToLowerCase(args);
SportsJS.NavHelper.handleGlobalArguments(args);
return PlatformJS.Navigation.createNavigationAction(SportsJS.UI.PageType.AllSports);
}
},
// Controller to perform search
searchController: {
default: function (args) {
var searchIt = function () {
args = SportsJS.NavHelper.convertObjectKeysToLowerCase(args);
SportsJS.NavHelper.handleGlobalArguments(args);
if (args.q) {
SportsJS.mainProcessManager.search.searchBoxQuery({ queryText: args.q });
}
};
return searchIt;
}
},
// Controller for ECV            
ecvController: {
default: function (args) {
var league = args ? args.league : null;
var ecvInfo = SportsJS.Utilities.ECV.getEcvNavigationInfo(league, args);
if (!ecvInfo || !ecvInfo.channelId || !ecvInfo.state) {
return {};
}
return PlatformJS.Navigation.createNavigationAction(ecvInfo.channelId, ecvInfo.state);
}
},
// Controller for page            
pageController: {
default: function (args) {
var pageType = args ? args.pagetype : null;
var pageId = args ? args.id : null;
if (!pageId || !pageType) {
return SportsJS.NavHelper.homeNavigationAction();
}
var pageArgs = {};
if (pageType === "entity") {
if (!args.entityId || !args.entityType || !args.leagueType) {
return SportsJS.NavHelper.homeNavigationAction();
} else {
SportsJS.Utilities.deepCopyJsObject(args, pageArgs);
pageArgs.pageType = SportsJS.Utilities.stringProperCase(pageArgs.entityType);
return PlatformJS.Navigation.createNavigationAction("EntityBase", pageArgs);
}
} else {
SportsJS.Utilities.deepCopyJsObject(args, pageArgs);
return PlatformJS.Navigation.createNavigationAction("SportsGenericPage", pageArgs);
}
}
}
}),
// Enumeration of navigation controllers used in Sports
NavControllers: Object.freeze({
application: "application",
league: "league",
team: "team",            
player: "player",
match: "match",
news: "news",
favorites: "favorites",
allsports: "allsports",
search: "search",
page: "page",
ecv: "ecv",
editorial: "editorial"
}),
NavCommand: Object.freeze({
view: "view"
}),
NavEntityType: Object.freeze({
article: "article",
partnerpano: "partnerpano",
slideshow: "slideshow",
pano: "pano",
video: "video",
}),
Validation: {
// Validates if the given league is a valid user league
isValidUserLeague: function isValidUserLeague(league) {
return SportsJS.Utilities.isValidLeagueTypeStrict(league)
&& SportsJS.mainProcessManager.isValidUserLeague(league);
}
},
NavHelper: {
// Creates an action to navigate to home page
homeNavigationAction: function homeNavigationAction() {
return PlatformJS.Navigation.createNavigationAction("Home");
},
// Converts keys in the input object to lower case
convertObjectKeysToLowerCase: function convertObjectKeysToLowerCase(obj) {
if (obj && typeof obj === "object") {
for (var key in obj) {
if (obj.hasOwnProperty(key) && typeof key === "string") {
obj[key.toLowerCase()] = obj[key];
}
}
}
return obj;
},
handleGlobalArguments: function handleGlobalArguments(args) {
if (args && args.preview) {
if (typeof args.preview === "string" && args.preview.toLowerCase() === "true") {
SportsJS.mainProcessManager.cmsPreviewEnabled = true;
}
else if (typeof args.preview === "string" && args.preview.toLowerCase() === "false") {
SportsJS.mainProcessManager.cmsPreviewEnabled = false;
}
}
}
},
// App launcher scheme for Sports
AppLauncherScheme: {
get: function get() {
return Platform.Configuration.ConfigurationManager.custom.getString("AppLauncherScheme", "bingsports");
}
}
});
})();
