﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS", {
/// <summary>
/// base class for sports pages. adheres to IPage interface defined by platform team
/// </summary>
Page: WinJS.Class.define(
/// <summary>
/// Constructor for your IPage class
/// </summary>
/// <param name="state">
/// The state object passed to WinJS.Navigation.navigate or the state object
/// apreserved when the page has been navigated away from
/// </param>
function (state) {
this._basePageConstructor(state);
},
{
_basePageConstructor: function _basePageConstructor(state) {                
//profile start of page load
this._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.Start, null);
//profile start of perceived page load
this._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.Start, SportsJS.UI.ProfilerTagType.PerceivedLoad);
//// set dark theme to platform's assets.
CommonJS.setTheme("sportsTheme", true);
var i = 0;
var stateObj = state;
if (stateObj && stateObj.searchMeta && stateObj.searchMeta.navConfig && stateObj.searchMeta.navConfig.cluster) {
this._visibleCluster = stateObj.searchMeta.navConfig.cluster;
}
////TODO: SportsJS.Config.Clusters.Schedule is pending for second drop of migration.
SportsJS.mainProcessManager.currentPage = this;
if (this._leagueName) {
SportsJS.mainProcessManager.snappedSport = this._leagueName;
}
this._data = {};
var that = this;
this._stateData = state || { leagueType: this._leagueType };
this._panoramaState = state && state.panoramaState ? state.panoramaState : null;
this._panoramaControl = SportsJS.Utilities.getCurrentPagePanoControl();
this._setUpPageRootElement();
this._setAutomationId();
this._trace(SportsJS.Msg.ObjectionConstruction);
this._baseInitBottomEdgy();
this._telemetryLogged = false;
},
_progressbarHideBlockingClusters: null,
_networkStatusChangedEventHandler: null,
_clusters: null,
_clusterConfig: null,
_stateData: null,
_isPageObjectValid: true,
_dataPromiseStack: [],
_leagueType: null,
_panoramaState: null,
_isPageDataBad: false,
_panoramaControl: null,
_isAnyClusterLoadFail: false,
_maxNumberOfClustersToWaitBeforePageLoad: 0,
_refreshType: SportsJS.UI.refreshType.None,
_telemetryLogged: false,
getPageImpressionContext: function getPageImpressionContext() {
return "/" + this._pageType;
},
_logTelemetry: function _logTelemetry() {
throw new Error("_logTelemetry implementation missing");
},
leagueType: {
get: function get() {
if (this._leagueType) {
return this._leagueType;
}                    
else {
return null;
}
}
},
pageUri: {
get: function get() {
throw new Error("pageUri implementation is missing");
}
},
_isDeeplinkSharable: false,
// Says whether or not this page's deeplink 
// can be shared via the Share contract
isDeeplinkSharable: {
get: function get() {
return this._isDeeplinkSharable;
}
},
// Gets a promise which on completion provides the data
// to be used for sharing rich content from this page
shareDataProvider: {
get: function get() {
return WinJS.Promise.wrap(null);
}
},
// Gets a promise which on completion provides the 
// html content that's to be shared from this page
shareContentProvider: {
get: function get() {
return null;
}
},
pageId: {
get: function get() {
return this.pageUri;
}
},
_pageTitle: null,
pageTitle: {
get: function get() {
return this._pageTitle;
}
},
_pageType: null,
pageType: {
get: function get() {
if (this._pageType) {
return this._pageType;
}
throw new Error("required _pageType is missing");
}
},
_element: null,
element: function element() {
return this._element;
},
_pageConfig: null,
pageConfig: {
get: function get() {
if (this._pageConfig) {
return this._pageConfig;
}
throw new Error("required _pageConfig is missing");
}
},
//required part of sports page interface
_pageInitAsync: function _pageInitAsync(isRefresh, progressResponse) {
throw new Error("required implementation for _pageInitAsync is missing");
},
// IPAGE interface
/// <summary>
/// This function is invoked by the UX Framework when the page is being navigated away and when the app is suspending.
/// Return any data that you need to resurrect your UX when the page is recreated
/// Keep this state object as small as possible
/// </summary>
/// <returns>
/// This function must return a JSON object that can be serializable. Do not pass a Managed object
/// </returns>
getPageState: function getPageState() {
this._stateData = this._stateData || {};
this._stateData.panoramaState = this.getPanoramaState();
return this._stateData;
},
// specifies the memory leak factor
countWeight: {
get: function get() {
var that = this;
if (!that._isPageObjectValid) { return; }
return SportsJS.Utilities.getMemoryContributionWeightFactorForPage();
}
},
/// <summary>
/// abstract function: return cluster config array, requires definition in derived class
/// </summary>
/// <returns>
/// list of cluster config objects
/// </returns>
getClusterConfig: function getClusterConfig() {
throw new Error("getClusterConfig should be defined in derived page class");
},
/// <summary>
/// This function is invoked by the UX Framework when the page is being created and when
/// it is necessary to bind data to the UX.
/// </summary>
/// <returns>
/// Returns a promise that contains data to bind the UX to
/// </returns>
getPageData: function getPageData() {
var that = this;
if (!that._isPageObjectValid) {
return new WinJS.Promise(null);
}
// TODO (chthakur) - fix bad name - seems like it should return false if we are visiting page for the first time, but that doesn't seems to be the case
var isPageVisited = SportsJS.Utilities.getPageVisitedStatus(that.pageId);
if (!isPageVisited) {
return new WinJS.Promise(function (complete) {
that.pageRenderErrorHandler();
complete(null);
});
}
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.Start, "getPageData");
that._data = new WinJS.Binding.List();
CommonJS.Progress.showProgress(CommonJS.Progress.headerProgressType);
that._trace(SportsJS.Msg.GetDataRequestReceived);
var promise = new WinJS.Promise(function (complete, error) {
// Progress handling: should have been more cleaner, but we do not have control over getPageData. 
var _pageInitPromise = that._promiseStack(that._pageInitAsync((that._refreshType === SportsJS.UI.refreshType.Forced), that._progressDataResponse));
that._progressDataResponse = null; // is consumed. reset it
_pageInitPromise.then(function (pageData) {
// we return valid pageData only
that._setPanoramaStyle();
that._promiseStack(that._loadRequiredFragments()).then(function () {
//TODO(chthakur) - no error for load fragments as if one of the fragment failed to load,
//we'll show error in specific cluster                            
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.End, "getPageData");
that._timeoutWrapper(function () {
if (pageData && pageData.status === $SpMgr.enumStrings.PageStatus[Microsoft.AppEx.Sports.SportsEnums.PageStatus.success]) {
that._pageDataInitialized();
complete(pageData);
}
else if (pageData && pageData.status === $SpMgr.enumStrings.PageStatus[Microsoft.AppEx.Sports.SportsEnums.PageStatus.noDataAvailable]) {
SportsJS.Page.showNoDataPageError();
complete(null);
}
else {
// Treat unrecognized status as error
that.pageRenderErrorHandler();
// platform not handling error, wrap in complete 
complete(null);
}
// verify if normal first getPageData scenario. if that is the case, check and schedule refresh if required
if (that._refreshType === SportsJS.UI.refreshType.None) {
// should have been more cleaner, but we do not have control over getPageData
that._schedulePageRefresh(pageData);
}
}, that.pageDataTimeout);
});
}, function (errRes) {
if (SportsJS.Utilities.isCancellationError(errRes)) {
// simple return, no error if the promise has been cancelled
return;
}
that.pageRenderErrorHandler();
// error(null); //platform not handling error, wrap in complete 
complete(null);
});
});
return promise;
},
_networkOnlineEventHandlerInstance: {
get: function get() {
if (!this.onlineEventHandler) {
this.onlineEventHandler = this._networkOnlineEventHandler.bind(this);
}
return this.onlineEventHandler;
}
},
_networkOfflineEventHandlerInstance: {
get: function get() {
if (!this.offlineEventHandler) {
this.offlineEventHandler = this._networkOfflineEventHandler.bind(this);
}
return this.offlineEventHandler;
}
},
_networkOnlineEventHandler: function _networkOnlineEventHandler() {
var that = this;
if (that._isPageDataBad) {
that._refreshPage();
return;
}
that._setPanoramaWatermark();
},
_networkOfflineEventHandler: function _networkOfflineEventHandler() {
var that = this;
that._setPanoramaWatermark();
},
_refreshPage: function _refreshPage() {
if (this.bottomEdgy) {
this.bottomEdgy.refreshEdgy();
}
this._refreshType = SportsJS.UI.refreshType.Forced;
// TODO: angoe Evaluate if this can be optimized instead of removing the clusters everytime on page refresh.
this._clusters = SportsJS.Utilities.getClusterControlsInsidePagePano();
this._cleanUpOnRefresh();
this._previousClusterRenderPromise = null; // reset this variable. Ordering will start from beginning
CommonJS.Error.removeError();
this.forceRefresh();
},
forceRefresh: function forceRefresh() {
this._resetBottomEdgy();
CommonJS.forceRefresh();
},
// Progress implementation.
// overall summary here
// 1. Fetch data.
// 2. Schedule next getch if data is stale
// 3. Verrify if new data is fresh. 
// 4. schedule forcerefresh by keeping the new data in variable _progressDataResponse
// 5. Force refresh will trigger getPageData again
// 6. Check in getPageData if we have _progressDataResponse
// 7. if _progressDataResponse is available(will be as we fired getPageData after saving the response in _progressDataResponse), generate new cluster config & pageData and return pageData
_schedulePageRefresh: function _schedulePageRefresh(pageData) {
var schedulePageRefreshDelay = 200; //ms
var that = this;
// schedule page refresh. 
if (!pageData || pageData.maxAge > 0 || !that.model || !that._modelResponse) {
return;
}
that._timeoutWrapper(function () {
var refresh = true;
that._promiseStack(that.model.getData(refresh)).then(function (progressData) {
// TODO - chthakur - we should ideally have dependency on etag and not on hashcode. But 304 has stopped working due to akamai issues.
// revisit this for blue RP. Hash code is mandatory here. if not present in failure scenarios, there will be delay(as it will happen on nav away) in update in worst case
if (progressData && progressData.isValid && progressData.maxAge > 0 && that._modelResponse.hashCode !== progressData.hashCode) {
that._progressDataResponse = progressData;
that._refreshPage();
}
});
}, schedulePageRefreshDelay);
},
// Put all the code which is dependent on successfull data initialization of the page
_pageDataInitialized: function _pageDataInitialized() {
//virtual function
// override in derived class
},
/// <summary>
/// This function is invoked by the UX Framework when the data binding is complete
/// </summary>
/// <returns>
/// Nothing
/// </returns>
onBindingComplete: function onBindingComplete() {
SportsJS.Networking.addEventListener('networkonline', this._networkOnlineEventHandlerInstance, false);
SportsJS.Networking.addEventListener('networkoffline', this._networkOfflineEventHandlerInstance, false);
},
/// <summary>
/// Set this property to true if you want the back button to appear in the navbar
/// This is used for immersive pages
/// </summary>
isImmersive: false,
/// <summary>
/// This function is invoked by the UX Framework when the layout has changed
/// </summary>
/// <param name="layoutState">
/// The current layout state
/// </param>
/// <returns>
/// Nothing
/// </returns>
onLayoutChange: function onLayoutChange(layoutState) {
var that = this;
if (this._panoramaControl) {
this._panoramaControl.onLayoutChange(layoutState);
}
// TODO - chthakur -> arengak - is this required?
if (typeof layoutState !== 'undefined' && layoutState === Windows.UI.ViewManagement.ApplicationViewState.snapped) {
//TODO(chthakur) league name will be replaced with sports name after the pending ETW/nav checkin
SportsJS.mainProcessManager.snappedSport = that._leagueName;
var snapPageInfo = {
pageInfo: {
fragment: "/leagues/common/SnapView/SnapViewPage.html",
page: "SportsJS.SnapViewHome"
},
resetHistory: true,
state: { leagueType: SportsJS.mainProcessManager.snappedSport }
};
return snapPageInfo;
}
},
/// <summary>
/// This function is invoked by the device has been roated
/// </summary>
/// <param name="event">
/// orientation change event
/// </param>
/// <returns>
/// Nothing
/// </returns>
onOrientationChange: function onOrientationChange(event) {
if (this._panoramaControl) {
this._panoramaControl.onOrientationChange(event);
}
},
/// <summary>
/// This function is invoked when dpi changes ("Make everything on your screen bigger" setting)
/// </summary>
/// <param name="event">
/// Dpi change event
/// </param>
/// <returns>
/// Nothing
/// </returns>
onDpiChange: function onDpiChange(event) {
if (this._panoramaControl && this._panoramaControl.onDpiChange) {
this._panoramaControl.onDpiChange(event);
}
},
/// <summary>
/// Handles window resize event. Occurs when:
///  - changing resolution in control panel
///  - WINDOWS+ARROW when using multiple monitors
/// </summary>
/// <param name="event">
/// resize event
/// </param>
/// <returns>
/// Nothing
/// </returns>
onWindowResize: function onWindowResize(event) {
if (this._panoramaControl && this._panoramaControl.onWindowResize) {
this._panoramaControl.onWindowResize(event);
}
},
/// <summary>
/// This function is invoked by Platform when we resume the app from suspend state
/// </summary>
/// <param name="event">
/// resume event
/// </param>
onResuming: function onResuming(event) {
if (!this._panoramaState) {
// We will restore the panorama state from the state data that is saved
// This will ensure we go back to the cluster where we were at resume time
var state = this._stateData;
this._panoramaState = state && state.panoramaState ? state.panoramaState : null;
}
},
dispose: function dispose() {
// this function is called up after navigate away, we have already cleaned up the states.
// get PanoControl from page
var panoramaControl = SportsJS.Utilities.getCurrentPagePanoControl();
if (panoramaControl) {
panoramaControl.dispose();
}
},
leagueName: {
get: function get() {
return this._leagueName;
}
},
_trace: function _trace(text) {
if (!this._pageDataInitialized) {
return;
}
var traceId = typeof this.getTraceId === "function" ? this.getTraceId() : "Traceid not-Set";
SportsJS.Utilities.trace(this, traceId, text);
},
_traceMsProfileMarkInfo: function _traceMsProfileMarkInfo(markType, fn) {
var info = {
markType: markType,
entityType: SportsJS.UI.ProfilerEntityType.Page,
page: this.pageUri,
func: fn ? fn : null
};
SportsJS.Utilities.sportsMsWriteProfilerMark(info);
},
onNavigateAway: function onNavigateAway(event) {
var that = this;
if (!that._isPageObjectValid) { return; }
that._clusters = SportsJS.Utilities.getClusterControlsInsidePagePano();
SportsJS.Networking.removeEventListener('networkonline', that._networkOnlineEventHandlerInstance);
SportsJS.Networking.removeEventListener('networkoffline', that._networkOfflineEventHandlerInstance);
// chthakur - ideally element should have queryselector. Observed snap mode with element not being an dom element
var element = that.element && that.element.querySelector ? that.element.querySelector(".platformMainContent") : null;
if (element) {
element.style.visibility = "hidden";
}
that._trace("Navigated away");
// trace above as cleanup cleansup the whole object
var isNavigating = event === PlatformJS.Navigation.BackNavigation || event === PlatformJS.Navigation.NewNavigation ? true : false;
that._cleanUp(isNavigating);
// hide edgies. If we navigate away quickly from page before letting the page load completely, the edgy takes time to hide
var appbarDoms = WinJS.Utilities.query(".win-appbar");
if (appbarDoms !== null) {
for (var i = 0; i < appbarDoms.length; i++) {
appbarDoms[i].style.visibility = "hidden";
}
}
},
pageInfo: {
get: function get() {
var pageInfo = {};
if (window.channel && window.channel.pageInfo) {
pageInfo = window.channel.pageInfo;
}
return pageInfo;
}
},
_setAutomationId: function _setAutomationId() {
var currentPageType = this.pageType;
if (currentPageType === SportsJS.UI.PageType.League) {
currentPageType = SportsJS.UI.PageType.Home;
}
var mainPanorama = document.querySelector(".mainPanorama");
if (mainPanorama) {
SportsJS.Utilities.setAutomationId(mainPanorama, SportsJS.UI.AutomationComponentType.Panorama, currentPageType);
var headerTitle = mainPanorama.querySelector(".immersiveHeaderTitle");
if (headerTitle) {
SportsJS.Utilities.setAutomationId(headerTitle, SportsJS.UI.AutomationComponentType.PanoramaHeaderTitle, currentPageType);
}
var headerSubTitle = mainPanorama.querySelector(".immersiveHeaderSubTitle");
if (headerSubTitle) {
SportsJS.Utilities.setAutomationId(headerSubTitle, SportsJS.UI.AutomationComponentType.PanoramaHeaderSubTitle, currentPageType);
}
var panel = mainPanorama.querySelector(".platformPanorama");
if (panel) {
SportsJS.Utilities.setAutomationId(panel, SportsJS.UI.AutomationComponentType.PanoramaPanel, currentPageType);
}
}
},
// All the promises which we want to cancel on navigate away should be wrapped in this function
// so that we can cancel them on cleanup
// data promise stack
_promiseStack: function _promiseStack(promise) {
var that = this;
if (!promise) {
return promise;
}
if (that._isPageObjectValid) {
that._dataPromiseStack = that._dataPromiseStack.concat(SportsJS.Utilities.createPromiseArrayCopy(promise));
}
else {
if (Array.isArray(promise)) {
SportsJS.Utilities.cancelPromiseArray(promise);
}
else {
SportsJS.Utilities.cancelPromise(promise);
}
}
return promise;
},
// Promise to last renderer cluster
_previousClusterRenderPromise: null,
// CallBack called from cluster when cluster is ready to fetch/render
// We can make this a promise. Avoiding it here. Doesn't seem like a visible benefit. Promises introduce complexity with chaining & all
// Algo: for ordered datafetch & rendering
// 1. Data fetch for all the clusters are fired as and when cluster is ready
// 2. After the Data-fetch is complete. The rendering for that cluster is fired if the cluster before in the rendering order has either done rendering or timed out
_clusterReadyHandler: function _clusterReadyHandler(cluster, clusterRenderComplete, bypassCache) {
var that = this;
if (!that._isPageObjectValid) {
return;
}
that.triggerClusterFetchRender(cluster, clusterRenderComplete, bypassCache);
},
// Triggers the cluster fetch immediately.  
// Triggers render based on if last cluster in rendering order has either rendered or timeout
triggerClusterFetchRender: function triggerClusterFetchRender(cluster, clusterRenderComplete, bypassCache) {
var that = this;
var previousClusterRenderPromise = that._promiseStack(that._previousClusterRenderPromise);
var processSpeedFactor = SportsJS.mainProcessManager.processorSpeedFactor;
var timeout = 1000 + 1000 * processSpeedFactor; // 1s + processor based timeout
var delayBetweenClusters = 10; // adding 50ms to a page with 5 clusters
var fetchProxyPromise;
if (cluster.fetchProxy) {
fetchProxyPromise = that._promiseStack(cluster.fetchProxy(bypassCache));
}
if (!previousClusterRenderPromise) {
previousClusterRenderPromise = WinJS.Promise.wrap(true);
}
var currentClusterRenderCompletePromise = new WinJS.Promise(function (c) {
previousClusterRenderPromise.then(function () {
fetchProxyPromise = fetchProxyPromise ? fetchProxyPromise : WinJS.Promise.wrap(true);
var fetchRenderProxy = new WinJS.Promise(function (c1, e1) {
fetchProxyPromise.then(function (success) {
if (!success) {
// TODO(chthakur) -> due to previous dependency, we are returning false on failure, ideally we should rely on error handler
clusterRenderComplete();
// we need to unblock rendering for next cluster here too
e1();
return;
}
// reset the timer before starting render
$SpMgr.uiThreadTimer.reset();
var renderProxyPromise;
if (cluster.renderProxy) {
renderProxyPromise = that._promiseStack(cluster.renderProxy());
}
else {
renderProxyPromise = WinJS.Promise.wrap(true);
}
renderProxyPromise.then(function (res) {
clusterRenderComplete(); // adding this inside timeout will delay the current cluster rendering
that._promiseStack(WinJS.Promise.timeout(delayBetweenClusters)).then(function () {
c1();
}, function (errRes) {
if (SportsJS.Utilities.isCancellationError(errRes)) {
// stop processing if promise has been cancelled
return;
}
c1(); //else complete, this wouldn't happen. Her for sake of completeness
});
}, function (errRes) {
if (SportsJS.Utilities.isCancellationError(errRes)) {
// stop processing if promise has been cancelled
return;
}
clusterRenderComplete(); // platform expects complete handler call only
e1();
});
}, function (errRes) {
if (SportsJS.Utilities.isCancellationError(errRes)) {
// stop processing if promise has been cancelled
return;
}
clusterRenderComplete(); // platform expects complete handler call only
e1();
});
});
// promise which times out in "timeout" milliseconds
var promiseThatTimesOut = new WinJS.Promise(function (c2) {
WinJS.Promise.timeout(timeout).then(function (res) {
c2(); // output doesn't matter
}, function (err) {
c2(); // output doesn't matter
});
});
WinJS.Promise.any([promiseThatTimesOut, fetchRenderProxy]).then(function (err) {
c(); // we complete the currentClusterRenderCompletePromise
}, function (err) {
c(); // we complete the currentClusterRenderCompletePromise
});
}, function (errRes) {
if (SportsJS.Utilities.isCancellationError(errRes)) {
// stop processing if promise has been cancelled
return;
}
// We should never end up here other than cancellation error.
c(); // we complete the currentClusterRenderCompletePromise
});
});
that._previousClusterRenderPromise = currentClusterRenderCompletePromise;
},
injectRenderConfigInClusterConfigs: function injectRenderConfigInClusterConfigs() {
var that = this;
if (!that._data) {
return;
}
//// TODO(saarya): We might want to have a renderComplete event on the cluster which the page can register for.
//// With the current design, doing it is a bit tricky as page doesnt get cluster controls during init.
//// Visit again once moved to pano control.
var onClusterRenderComplete = that.getClusterRenderCompleteCallback();
var _clusterConfig = this._clusterConfig;
var maxNumberOfClustersToWaitToCallPageLoad = 0;
var maxRealizedClustersOnPageLoad = PlatformJS.Services.configuration.getDictionary("Panorama").getInt32("NumClustersToLoad");
var renderCompleteSkipList = ["PlatformJS.Ads.AdsWrapperControl"];
for (var k = 0; k < _clusterConfig.length; k++) {
var hasRenderComplete = false;
if (_clusterConfig[k]) {
var contentControl = _clusterConfig[k].clusterContent ? _clusterConfig[k].clusterContent.contentControl : null;
//// In Pano control, only the contentOptions get passed to clusterControl
//// TODO(saarya) : Remove else part once migration is complete
if (renderCompleteSkipList.indexOf(contentControl) !== -1) {
_clusterConfig[k].onRenderComplete = null;
} else if (_clusterConfig[k].clusterContent && _clusterConfig[k].clusterContent.contentOptions) {
_clusterConfig[k].clusterContent.contentOptions.onClusterRenderInit = that._clusterReadyHandler.bind(that);
_clusterConfig[k].clusterContent.contentOptions.onRenderComplete = onClusterRenderComplete;
_clusterConfig[k].clusterContent.contentOptions.currentPageControl = that;
hasRenderComplete = true;
}
else {
_clusterConfig[k].onRenderComplete = onClusterRenderComplete;
hasRenderComplete = true;
}
// we need to wait for realized clusters only
if (hasRenderComplete && k < maxRealizedClustersOnPageLoad) {
maxNumberOfClustersToWaitToCallPageLoad++;
}
that._data.push(_clusterConfig[k]);
}
else {
//// Skip clusters with invalid config. Trace is enough
that._trace(SportsJS.Msg.ClusterConfigNotFound);
}
}
this._maxNumberOfClustersToWaitBeforePageLoad = maxNumberOfClustersToWaitToCallPageLoad;
},
// setup pageroot element, apply appropriate classes
// TODO (chthakur) - handle the page reload when we move backgrounds to azure
_setUpPageRootElement: function _setUpPageRootElement() {
this.element = SportsJS.Page.setPageTheme(".sportsPanoPageFragment", this._leagueType);
},
_cleanUp: function _cleanUp(isNavigating) {
CommonJS.Progress.resetProgress(CommonJS.Progress.headerProgressType);
this._clusterCleanUp(isNavigating);
this._cleanUpDataPromises();
this._disposeBottomEdgy();
SportsJS.Utilities.setObjectPropertiesToNull(this);
// Semantic zoom uses ListView on almost all the pages. Call is safe if there is no semantic zoom. Minimal cost. msSetImmediate as this is not required immediately
msSetImmediate(function () {
WinJS.UI.ListView.triggerDispose();
});
this._isPageObjectValid = false;
},
_cleanUpOnRefresh: function _cleanUpOnRefresh() {
CommonJS.Progress.resetProgress(CommonJS.Progress.headerProgressType);
this._clusterCleanUp(null);
this._cleanUpDataPromises();
this._isPageDataBad = false;
this._clusterConfig = null;
this._isAnyClusterLoadFail = false;
},
_cleanUpDataPromises: function _cleanUpDataPromises() {
SportsJS.Utilities.cancelPromiseArray(this._dataPromiseStack);
},
_clusterCleanUp: function _clusterCleanUp(isNavigating) {
var that = this;
if (!that._isPageObjectValid) { return; }
var refreshPanoramaWatermarkBinding = that._getRefreshPanoramaWatermarkBinding();
for (var kk = 0; kk < that._clusters.length; kk++) {
var cluster = that._clusters[kk];
var clusterElement = cluster.element ? cluster.element : (cluster._domElement ? cluster._domElement : null);
if (clusterElement) {
clusterElement.removeEventListener("datarefreshed", refreshPanoramaWatermarkBinding);
}
if ((typeof cluster.cleanUp === "function")) {
cluster.cleanUp(isNavigating);
}
}
},
_onDataLoadComplete: function _onDataLoadComplete() {
/*TODO(chthakur): implement */
},
_onFirstViewComplete: function _onFirstViewComplete() {
var that = this;
if (!that._isPageObjectValid) {
return;
}
this._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.End, SportsJS.UI.ProfilerTagType.PerceivedLoad);
CommonJS.Progress.hideProgress(CommonJS.Progress.headerProgressType);
SportsJS.mainProcessManager.processListener.onPerceivedPageLoad({ pageUri: that.pageUri });
},
_fireTelemetryEvent: function _fireTelemetryEvent() {
if (this._telemetryLogged === false) {
this._telemetryLogged = true;
this._logTelemetry();
}
},
_onRenderComplete: function _onRenderComplete() {
var that = this;
if (!that._isPageObjectValid) {
return;
}
this._fireTelemetryEvent();
that._setPanoramaWatermark();
var panoClusters = SportsJS.Utilities.getClusterControlsInsidePagePano();
for (var kk = 0; kk < panoClusters.length; kk++) {
that._addRefreshPanoramaWaterMarkListener(panoClusters[kk]);
}
CommonJS.Progress.hideProgress(CommonJS.Progress.headerProgressType);
//TODO(chthakur): handle by generating events rather
if (that.scrollToCluster && typeof that.scrollToCluster === 'function') {
that.scrollToCluster();
}
// profile end of page load
this._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.End, null);
SportsJS.mainProcessManager.processListener.onPageLoad({ pageType: that.pageUri});
},
_addRefreshPanoramaWaterMarkListener: function _addRefreshPanoramaWaterMarkListener(cluster) {
var that = this;
if (!cluster) {
return;
}
var refreshPanoramaWatermarkBinding = that._getRefreshPanoramaWatermarkBinding();
var clusterElement = cluster.element ? cluster.element : (cluster._domElement ? cluster._domElement : null);
if (clusterElement) {
clusterElement.removeEventListener("datarefreshed", refreshPanoramaWatermarkBinding);
clusterElement.addEventListener("datarefreshed", refreshPanoramaWatermarkBinding);
}
},
_setPanoramaWatermark: function _setPanoramaWatermark() {
var that = this;
var currentDate = new Date();
var isStaleResponse = false;
// update times less than this date will be considered invalid, this is protection against showing the default 1/1/1 coming from C#. 
// 1/1/1 looks too bad. This will help filter the bad value right now. Proper fix to come in march
var minUpdateTime = new Date(2012, 0, 1); 
var lastUpdateTime = currentDate;
var panoControl = SportsJS.Utilities.getCurrentPagePanoControl();
var panoClusters = SportsJS.Utilities.getClusterControlsInsidePagePano();
if (!panoControl || !panoClusters) {
return;
}
//// get isStaleResponse
for (var clusterIndex = 0; clusterIndex < panoClusters.length; clusterIndex++) {
var cluster = panoClusters[clusterIndex];
if (cluster.isStaleResponse) {
isStaleResponse = true;
break;
}
}
if (SportsJS.Networking.isInternetAvailable && !isStaleResponse && !that._isAnyClusterLoadFail) {
panoControl.watermark = " ";
return;
}
//// get lastUpdateTime
for (var lastUpdateIndex = 0; lastUpdateIndex < panoClusters.length; lastUpdateIndex++) {
var lastUpdateCluster = panoClusters[lastUpdateIndex];
if (!lastUpdateCluster || !lastUpdateCluster.lastUpdateTime) {
continue;
}
if (typeof lastUpdateCluster.lastUpdateTime === "string") {
var updateTime = Date.parse(lastUpdateCluster.lastUpdateTime);
if (!isNaN(updateTime)) {
lastUpdateCluster.lastUpdateTime = new Date(updateTime);
} 
}
if (!(lastUpdateCluster.lastUpdateTime instanceof Date)) {
SportsJS.Utilities.interfaceException("SportsJS.PageBase:_setPanoramaWatermark", "lastUpdateTime has to be an instance of Date");
// last update time for current cluster is not comparable
continue;
} else if (lastUpdateCluster.lastUpdateTime < minUpdateTime) {
// not a valid date for watermark
continue;
}
if (lastUpdateCluster.lastUpdateTime < lastUpdateTime) {
lastUpdateTime = lastUpdateCluster.lastUpdateTime;
}
}
try {
var shortDate = Windows.Globalization.DateTimeFormatting.DateTimeFormatter.shortDate.format(lastUpdateTime);
var shortTime = Windows.Globalization.DateTimeFormatting.DateTimeFormatter.shortTime.format(lastUpdateTime);
}
catch (ex) {
// if there are any errors thrown, we will simply swallow and return, as these are not fatal
that._trace("_setPanoramaWatermark: Error in setting panorama watermark");
panoControl.watermark = " ";
return;
}
if (SportsJS.Networking.isInternetAvailable) {
if (isStaleResponse) {
panoControl.watermark = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("PanoWatermarkCachedDataOnline"), shortDate, shortTime);
}
else {
panoControl.watermark = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("PanoOnlineWatermark"), shortDate, shortTime);
}
}
else {
panoControl.watermark = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("PanoOfflineWatermark"), shortDate, shortTime);
}
},
_refreshPanoramaWatermarkBinding: null,
_getRefreshPanoramaWatermarkBinding: function _getRefreshPanoramaWatermarkBinding() {
var that = this;
if (!that._refreshPanoramaWatermarkBinding) {
that._refreshPanoramaWatermarkBinding = that._refreshPanoramaWatermark.bind(that);
}
return that._refreshPanoramaWatermarkBinding;
},
_refreshPanoramaWatermark: function _refreshPanoramaWatermark() {
var that = this;
that._setPanoramaWatermark();
},
getPanoramaState: function getPanoramaState() {
var panoControl = SportsJS.Utilities.getCurrentPagePanoControl();
return panoControl ? panoControl.getPanoramaState() : null;
},
/// <summary>
/// This function returns the callback for clusters to invoke when render is complete
/// </summary>
getClusterRenderCompleteCallback: function getClusterRenderCompleteCallback() {
var page = this;
var numRenderedClusters = 0;
var numFirstViewClusters = 0;
var numFailedClusters = 0;
return (function (isRenderSuccess) {
// we work on control, news is dispatching the event by element, get control if element is not winControl
var cluster = this.winControl ? this.winControl : this;
//TODO(chthakur): work on this limit. Seems ok right now
// Limit imposed by platform only rendering 5 items on initial page load. Default to 2(wouldn't happen)
var maxNumberOfClustersToWait = page._maxNumberOfClustersToWaitBeforePageLoad ? page._maxNumberOfClustersToWaitBeforePageLoad : 2;
//number of clusters to wait for before we remove loader
var maxNumberOfClustersToWaitForFirstView = 1;
var blockingClusters = page._getProgressbarHideBlockingClusters();
var numberOfClustersToWait = blockingClusters.length < maxNumberOfClustersToWait ? blockingClusters.length : maxNumberOfClustersToWait;                    
var clusterIndex = blockingClusters.indexOf(cluster.id);
if (clusterIndex !== -1) {
numRenderedClusters++;
}
// In case of external clusters isRenderSuccess parameter is an object, but the very fact that this callback is called only on successful rendering in those cases, makes our job easy with this check
if (!isRenderSuccess) {
page._isAnyClusterLoadFail = true;
numFailedClusters++;
}
//only clusters starting from 0 are allowed to increment the first view variable
if (clusterIndex < maxNumberOfClustersToWaitForFirstView) {
numFirstViewClusters++;
}
if (numFirstViewClusters === maxNumberOfClustersToWaitForFirstView) {
page._onFirstViewComplete();
numFirstViewClusters++; // disable multiple calls
}
// if a max of only 2 clusters are being shown, assume that page data is not good enough and set it for autorefresh
// if internal page clusters have failed to load it is very likely that external clusters (news, hero) also would have failed.
if ((numberOfClustersToWait >= 2) && (numberOfClustersToWait - numFailedClusters <= 2)) {
page._isPageDataBad = true;
}
if (numRenderedClusters === numberOfClustersToWait) {
page._onRenderComplete();
} else if (numRenderedClusters > numberOfClustersToWait) {
// we need to check for staleness water mark on every cluster render complete
page._refreshPanoramaWatermark();
page._addRefreshPanoramaWaterMarkListener(cluster);
}
});
},
/// <summary>
/// This function scrolls to appropriate cluster on pageload
/// </summary>
scrollToCluster: function scrollToCluster() {
var that = this;
var pc = SportsJS.Utilities.getCurrentPagePanoControl();
if (!that.getClusterConfig || !that._visibleCluster || !pc) {
// do nothing if appropriate config is not defined
return;
}
var visibleCluster = that._visibleCluster.toLowerCase();
var clusterConfig = that.getClusterConfig();
if (!clusterConfig || !clusterConfig.length) {
return;
}
for (var i = 0; i < clusterConfig.length; i++) {
if (clusterConfig[i] && clusterConfig[i].clusterContent
&& clusterConfig[i].clusterContent.contentOptions
&& clusterConfig[i].clusterContent.contentOptions.id) {
var clusterId = clusterConfig[i].clusterContent.contentOptions.id.toLowerCase();
if (clusterId.indexOf(visibleCluster) !== -1) {
pc.currentClusterIndex = i;
return;
}
}
}
},
// load cluster fragments to ensure the css/js is available when cluster gets used
// This change will help us eliminate adding js/css to the page. This page is required for building
// page dynamically
_loadRequiredFragments: function _loadRequiredFragments() {
var that = this;
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.Start, "loadRequiredFragments");
var p = new WinJS.Promise(function (complete) {
var clusterConfigs = that._clusterConfig;
// complete is just to show that all valid fragments has been loaded.
// error handler is not required. if particular fragment is not loaded for any xyz reason,
// the correspoding cluster will not be loaded, which is fair
if (!clusterConfigs || clusterConfigs.length === 0) {
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.End, "loadRequiredFragments");
complete(true);
return;
}
// TODO(chthakur): remove cluster fragment loading from here. This will go away once all the pages start using
// _loadAndValidateClusterFragments
var fragmentInfo = [];
for (var kk = 0, maxkk = clusterConfigs.length; kk < maxkk; kk++) {
if (clusterConfigs[kk]
&& clusterConfigs[kk].clusterContent
&& clusterConfigs[kk].clusterContent
&& clusterConfigs[kk].clusterContent.contentOptions
&& clusterConfigs[kk].clusterContent.contentOptions.fragmentPath) {
fragmentInfo.push({ path: clusterConfigs[kk].clusterContent.contentOptions.fragmentPath, clusterConfig: clusterConfigs[kk] });
}
}
var fragmentPromises = [];
for (var fragmentIndex = 0; fragmentIndex < fragmentInfo.length; fragmentIndex++) {
fragmentPromises.push(WinJS.UI.Fragments.cache(fragmentInfo[fragmentIndex].path));
}
WinJS.Promise.join(fragmentPromises).then(function (res) {
//this will ensure all valid fragments has been loaded
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.End, "loadRequiredFragments");
complete(true);
}, function (error) {
var errorKeys = Object.keys(error);
for (var errorIndex = 0; errorIndex < errorKeys.length; errorIndex++) {
that._trace("Fragment not found: " + fragmentInfo[errorKeys[errorIndex]].path);
}
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.End, "loadRequiredFragments");
complete(true);
});
});
return p;
},
// load cluster fragments to ensure the css/js is available when cluster gets used
// This change will help us eliminate adding js/css to the page. This page is required for building
// page dynamically
_loadAndValidateClusterFragments: function _loadAndValidateClusterFragments(clusterConfigs) {
var that = this;
var p = new WinJS.Promise(function (complete) {
// complete is just to show that all valid fragments has been loaded.
// error handler is not required. if particular fragment is not loaded for any xyz reason,
// the corresponding cluster will not be loaded, which is fair
if (!clusterConfigs || clusterConfigs.length === 0) {
complete(clusterConfigs);
return;
}
var fragmentInfo = [];
for (var kk = 0, maxkk = clusterConfigs.length; kk < maxkk; kk++) {
if (clusterConfigs[kk]
&& clusterConfigs[kk].clusterContent
&& clusterConfigs[kk].clusterContent
&& clusterConfigs[kk].clusterContent.contentOptions
&& clusterConfigs[kk].clusterContent.contentOptions.fragmentPath) {
fragmentInfo.push({ path: clusterConfigs[kk].clusterContent.contentOptions.fragmentPath, clusterConfig: clusterConfigs[kk] });
}
}
var fragmentPromises = [];
for (var fragmentIndex = 0; fragmentIndex < fragmentInfo.length; fragmentIndex++) {
fragmentPromises.push(WinJS.UI.Fragments.cache(fragmentInfo[fragmentIndex].path));
}
WinJS.Promise.join(fragmentPromises).then(function (res) {
//this will ensure all valid fragments has been loaded
complete(clusterConfigs);
}, function (error) {
var errorKeys = Object.keys(error);
for (var errorIndex = 0; errorIndex < errorKeys.length; errorIndex++) {
var info = fragmentInfo[errorKeys[errorIndex]];
var index = clusterConfigs.indexOf(info.clusterConfig);
//remove the cluster from config if the corresponding fragment is invalid
if (index !== -1) {
clusterConfigs.splice(index, 1);
}
that._trace("Fragment not found: " + info.path);
}
complete(clusterConfigs);
});
});
return p;
},
/// <summary>
/// Default semantic zoom renderer for sports app
/// </summary>
_semanticZoomRenderer: function _semanticZoomRenderer(itemPromise) {
return {
element: itemPromise.then(function (item) {
var div = document.createElement("div");
WinJS.Utilities.addClass(div, "sportsDefaultSemanticZoom");
var clusterTitle = (item && item.data && item.data.clusterTitle) ? item.data.clusterTitle : PlatformJS.Services.resourceLoader.getString("SemanticViewTileDefaultText");
var zoomTemplateData = {
clusterTitle: clusterTitle,
moduleInfo: {
fragmentPath: "/leagues/common/SemanticZoom/defaultSemanticZoom.html",
templateId: "sportsDefaultSemanticZoomTemplate"
}
};
CommonJS.loadModule(zoomTemplateData.moduleInfo, zoomTemplateData, div); // async
return div;
})
};
},
/// <summary>
/// Default semantic zoom renderer for sports app
/// </summary>
semanticZoomRenderer: {
get: function get() {
this._semanticZoomRenderer.supportedForProcessing = true;
return this._semanticZoomRenderer;
}
},
/// <summary>
/// This function returns an array of ProgressbarHideBlockingCluster ids
/// </summary>
_getProgressbarHideBlockingClusters: function _getProgressbarHideBlockingClusters() {
var that = this;
if (this._progressbarHideBlockingClusters) {
return this._progressbarHideBlockingClusters;
}
var blockingClusters = [];
var clusterConfigs = [];
//// Pages that inherit from BasePage will have a getClusterConfig method that returns cluster configs,
//// else we will get the clusterConfigs from groupsConfig property
if (that.getClusterConfig) {
clusterConfigs = that.getClusterConfig();
}
else if (that.groupsConfig) {
clusterConfigs = that.groupsConfig;
}
//// We want to be able to mark a cluster as non-blocking,
//// in which case the page will not wait for it before hiding ProgressBar
for (var i = 0; i < clusterConfigs.length; i++) {
if (clusterConfigs[i]
&& clusterConfigs[i].clusterContent
&& clusterConfigs[i].clusterContent.contentOptions
&& clusterConfigs[i].clusterContent.contentOptions.id) {
var clusterId = clusterConfigs[i].clusterContent.contentOptions.id;
if (typeof clusterConfigs[i].isProgressbarHideBlocking !== 'undefined') {
if (clusterConfigs[i].isProgressbarHideBlocking === true) {
blockingClusters.push(clusterId);
}
}
else {
blockingClusters.push(clusterId);
}
}
}
this._progressbarHideBlockingClusters = blockingClusters;
return this._progressbarHideBlockingClusters;
},
pageRenderErrorHandler: function pageRenderErrorHandler() {
CommonJS.Progress.hideProgress(CommonJS.Progress.headerProgressType);
var that = this;
that._isPageDataBad = true;
var isInternetAvailable = SportsJS.Networking.isInternetAvailable;
var errorType = isInternetAvailable ? CommonJS.Error.STANDARD_ERROR : CommonJS.Error.NO_INTERNET;
CommonJS.Error.showError(errorType,
function () {
that._refreshPage();
});
if (!isInternetAvailable) {
SportsJS.Networking.addEventListener('networkonline', that._networkOnlineEventHandlerInstance, false);
}
},
/// <summary>
/// Gets the traceId for tracing/logging
/// </summary>
getTraceId: function getTraceId() {
var that = this;
return that.pageUri;
},
_bottomEdgy: null,
bottomEdgy: {
get: function get() {
if (this._bottomEdgy === null) {
this._bottomEdgy = new SportsJS.Controls.BottomEdgy();
if (this.element && this._bottomEdgy && this._bottomEdgy.element) {
this.element.appendChild(this._bottomEdgy.element);
}
}
return this._bottomEdgy;
},
set: function set(value) {
this._bottomEdgy = value;
}
},
_disposeBottomEdgy: function _disposeBottomEdgy() {
if (this.bottomEdgy) {
this._bottomEdgy.cleanUp();
if (this.bottomEdgy.element) {
this.element.removeChild(this._bottomEdgy.element);
}
this._bottomEdgy = null;
}
},
_baseInitBottomEdgy: function _baseInitBottomEdgy() {
var that = this;
if (this.pageType === SportsJS.UI.PageType.AllSports
|| this.pageType === SportsJS.UI.PageType.MyTeams) {
this._addHelpButtonToBottomEdgy();
return;
}
// Lazy loading possible by adding an eventlistener in bottom edgy and then adding these on first beforeshow. But, that might criple the bottomEdgyShowing up.
// can revaluate later if for perf
var refreshButton = new SportsJS.Controls.RefreshBottomEdgyButton(null, { refreshCallBack: that._refreshButtonClick.bind(that) });
that.bottomEdgy.addButton(refreshButton);
if (!SportsJS.Utilities.isLegendBlocked() && SportsJS.Utilities.hasLegendForSport(that._leagueType) && SportsJS.Utilities.hasLegendForPage(that._pageType)) {
var legendButton = new SportsJS.Controls.LegendBottomEdgyButton(null, { sportsType: this._leagueType, pageType: this._pageType });
that.bottomEdgy.addButton(legendButton);
}
this._addHelpButtonToBottomEdgy();
},
_refreshButtonClick: function _refreshButtonClick() {
SportsJS.Telemetry.logAppBarClick(SportsJS.Telemetry.ElementType.Refresh);
this._refreshPage();
},
_resetBottomEdgy: function _resetBottomEdgy() {
this._disposeBottomEdgy();
this._baseInitBottomEdgy();
},
_addHelpButtonToBottomEdgy: function _addHelpButtonToBottomEdgy() {
var that = this;
var uri = PlatformJS.Services.appConfig.getString("HelpURL");
if (!uri) {
// do not add button if URI is not configured
return;
}
var helpButtonData = {
title: PlatformJS.Services.resourceLoader.getString("AppHelp"),
icon: SportsJS.UI.IconType.help,
onclick: SportsJS.Page._showHelp.bind(this),
className: "helpBtn",
buttonId: "HelpButton"
};
var helpButton = new SportsJS.Controls.BottomEdgyButton(null, helpButtonData);
this.bottomEdgy.addButton(helpButton);
return;
},
_setPanoramaStyle: function _setPanoramaStyle() {
var that = this;
if (!that._data) {
return;
}
var heroClusterPresent = false;
var isCompactPano = false;
var _clusterConfig = this._clusterConfig;
for (var k = 0; k < _clusterConfig.length; k++) {
if (!_clusterConfig[k] || !_clusterConfig[k].clusterContent) {
continue;
}
if (_clusterConfig[k].clusterContent.contentControl && _clusterConfig[k].clusterContent.contentControl.indexOf("SportsHeroControl") !== -1) {
heroClusterPresent = true;
}
if (_clusterConfig[k].clusterContent.contentOptions && _clusterConfig[k].clusterContent.contentOptions.enableCompactPano) {
isCompactPano = true;
}
if (heroClusterPresent && isCompactPano) {
break;
}
}
if (!heroClusterPresent) {
that._removePanoramaInertiaBackground();
}
else {
that._setPanoramaInertiaBackground();
}
if (isCompactPano) {
that._setCompactPanorama();
} else {
that._removeCompactPanorama();
}
},
_setPanoramaInertiaBackground: function _setPanoramaInertiaBackground() {
var element = document.querySelector(".mainPanorama");
if (!element) {
return;
}
WinJS.Utilities.addClass(element, "platformPanoramaFlushLeft");
// set bleeding
var panoControl = SportsJS.Utilities.getCurrentPagePanoControl();
if (panoControl) {
panoControl.showInertiaBackground = true;
}
},
_removePanoramaInertiaBackground: function _removePanoramaInertiaBackground() {
var element = document.querySelector(".mainPanorama");
if (!element) { return; }
WinJS.Utilities.removeClass(element, "platformPanoramaFlushLeft");
// set bleeding
var panoControl = SportsJS.Utilities.getCurrentPagePanoControl();
if (panoControl) {
panoControl.showInertiaBackground = false;
}
},
_setCompactPanorama: function _setCompactPanorama() {
var panoNode = document.querySelector(".platformPanorama");
if (panoNode && panoNode.winControl) {
panoNode.winControl.compactPanorama = true;
}
},
_removeCompactPanorama: function _removeCompactPanorama() {
var panoNode = document.querySelector(".platformPanorama");
if (panoNode && panoNode.winControl) {
panoNode.winControl.compactPanorama = false;
}
},
pageDataTimeout: 10,
_timeoutWrapper: function _timeoutWrapper(fn, timeout) {
var that = this;
that._promiseStack(WinJS.Promise.timeout(timeout)).then(function () {
if (fn && typeof fn === "function") {
fn();
}
}, function (errRes) {
if (SportsJS.Utilities.isCancellationError(errRes)) {
return;
}
if (fn && typeof fn === "function") {
fn();
}
});
}
},
{
//TODO(chthakur): naive version -> figure out a way to send league with page explicitly
// used only in case of home page where state is not being received in page constructor correctly
getSportsFromPageInfo: function getSportsFromPageInfo(state) {
if (state && state.leagueType && SportsJS.Utilities.isValidLeagueType(state.leagueType)) {
return state.leagueType;
}
var sports;
if (window.channel && window.channel.id === "Home" && window.channel.state && window.channel.state.leagueType) {
sports = window.channel.state.leagueType;
}
return sports;
},
_showHelp: function _showHelp(event) {
var that = this;
if (!event || !event.srcElement) {
return;
}
SportsJS.Telemetry.logAppBarClick(SportsJS.Telemetry.ElementType.Help);
try {
var uri = PlatformJS.Services.appConfig.getString("HelpURL");
Platform.Telemetry.FlightRecorder.setImpressionNavMethod(Platform.Telemetry.ImpressionNavMethod.appBar);
PlatformJS.Navigation.navigateTo(uri);
} catch (e) {
//eat up
}
},
areStateEqual: function areStateEqual(firstState, secondState) {
if (typeof firstState === "undefined" || typeof secondState === "undefined") {
return false;
}
if (firstState === null || secondState === null) {
// State can be null for today's page
if (firstState === secondState) {
return true;
} else {
return false;
}
}
// Compare state
if (firstState.leagueType === secondState.leagueType && firstState.teamId === secondState.teamId) {
return true;
}
return false;
},
// set theme for sports page
setPageTheme: function setPageTheme(elementSelector, theme) {
var element = document.querySelector(elementSelector);
if (!element) {
return;
}
if (theme && SportsJS.Utilities.isValidSportType(theme)) {
WinJS.Utilities.addClass(element, theme);
} else if (theme && SportsJS.Utilities.isValidLeagueType(theme)) {
var sports = AppEx.Sports.Services.Utils.getSportsFromLeague(theme);
WinJS.Utilities.addClass(element, sports);
} else {
WinJS.Utilities.addClass(element, "default");
}
return element;
},
setSportsPageRootElement: function setSportsPageRootElement(elementSelector, leagueType) {
var element = document.querySelector(elementSelector);
if (element && leagueType) {
var cssClass = "sports" + SportsJS.Utilities.stringProperCase(leagueType);
WinJS.Utilities.addClass(element, cssClass);
var gameType = AppEx.Sports.Services.Utils.getSportsFromLeague(leagueType);
WinJS.Utilities.addClass(element, gameType);
}
return element;
},
showNoDataPageError: function showNoDataPageError(errorText) {
var that = this;
CommonJS.Progress.hideProgress(CommonJS.Progress.headerProgressType);
CommonJS.Error.showError(CommonJS.Error.STANDARD_ERROR);
if (!CommonJS.Error._errorControl || !CommonJS.Error._errorControl.element) {
return;
}
//// Replace PlatformErrorTitle with No Data Available. Hide platformErrorButton and platformErrorDescription
var platformErrorTitle = CommonJS.Error._errorControl.element.querySelector(".platformErrorTitle");
if (platformErrorTitle) {
errorText = errorText ? errorText : PlatformJS.Services.resourceLoader.getString("NoDataText");
platformErrorTitle.innerHTML = errorText;
}
//Replace "!" with "i" iconn
var iconError = CommonJS.Error._errorControl.element.querySelector(".iconError");
if (iconError) {
iconError.innerHTML = "&#xE014;";
}
//Hide Error Description
var platformErrorDescription = CommonJS.Error._errorControl.element.querySelector(".platformErrorDescription");
if (platformErrorDescription) {
WinJS.Utilities.addClass(platformErrorDescription, "platformHide");
}
//Hide Error Button
var platformErrorButton = CommonJS.Error._errorControl.element.querySelector(".platformErrorButton");
if (platformErrorButton) {
WinJS.Utilities.addClass(platformErrorButton, "platformHide");
}
},
})
});
})();
