﻿(function () {
"use strict";
WinJS.Namespace.define("SportsJS", {
ProcessListener: WinJS.Class.define(
/// <summary>
/// Constructor for your IProcessListener class
/// </summary>
function () {
//Register roaming data changed event handler
Windows.Storage.ApplicationData.current.addEventListener("datachanged", this.roamingDataChangedHandler.bind(this));
},
{
/// <summary>
/// Handles layout change event
/// </summary>
/// <param name="event">
/// Layout change event
/// </param>
/// <returns>
/// Nothing
/// </returns>
onLayoutChange: function onLayoutChange(event) {
},
/// <summary>
/// Handles orientation change event
/// </summary>
/// <param name="event">
/// Orientation change event
/// </param>
/// <returns>
/// Nothing
/// </returns>
onOrientationChange: function onOrientationChange(event) { },
/// <summary>
/// Handles Suspend event
/// </summary>
/// <param name="event">
/// Suspend event
/// </param>
/// <returns>
/// Nothing
/// </returns>
onSuspending: function onSuspending(event) {
var sessionState = WinJS.Application.sessionState;
sessionState.lastSuspendTime = new Date().getTime();
},
/// <summary>
/// Handles Checkpoint event
/// </summary>
/// <param name="event">
/// Suspend suspend event
/// </param>
/// <returns>
/// Nothing
/// </returns>
onCheckpoint: function onCheckpoint(event) { },
/// <summary>
/// Handles Resume event
/// </summary>
/// <param name="event">
/// resume event
/// </param>
/// <returns>
/// Nothing
/// </returns>
onResuming: function onResuming(event) {
SportsJS.Networking.updateNetworkStatus();
if (SportsJS.Utilities.isAppStateStale()
&& WinJS.Navigation.location.page
&& WinJS.Navigation.location.page !== 'SportsJS.Today.TodayHomePage') {
PlatformJS.Navigation.navigateToChannel('Home');
return;
}
if (SportsJS.Networking.isInternetAvailable) {
if (PlatformJS.Navigation.mainNavigator && PlatformJS.Navigation.mainNavigator.currentIPage) {
var currentPage = PlatformJS.Navigation.mainNavigator.currentIPage;
if (currentPage._refreshPage) {
currentPage._refreshPage();
}
}
}
},
// Raise this event on first time app launch
onFirstTimeAppLaunch: function onFirstTimeAppLaunch() {
},
// Raise this event on perceived page load
onPerceivedPageLoad: function onPerceivedPageLoad(event) {
// protected against multiple invocations inside
SportsJS.mainProcessManager.processListener.onFirstPerceivedPageLoad(event);
},
// Raise this event on First perceived page load
onFirstPerceivedPageLoad: function onFirstPerceivedPageLoad(event) {
var that = this;
// successfull app initialization is pre-requisite to it now
if (!SportsJS.mainProcessManager.isAppInitialized || SportsJS.mainProcessManager._isFirstPerceivedPageLoad === false) {
return;
}
SportsJS.mainProcessManager._isFirstPerceivedPageLoad = false;
var profileMark = "Sports:onFirstPerceivedPageLoad";
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":s");
WinJS.UI.enableAnimations();
CommonJS.Progress.canDestroySplash(true);
CommonJS.Progress.destroySplash(true);
var processorSpeedFactor = SportsJS.mainProcessManager.processorSpeedFactor;
var timeoutDuration = 0;
if (processorSpeedFactor > 1) {
// skipping processors which are faster (factor = 1)
timeoutDuration = (processorSpeedFactor - 1) * 1000;
}
// startup optimization: delaying share and nav bar initialization by 2s
WinJS.Promise.timeout(timeoutDuration).then(function () {
new SportsJS.Share();
// we need to do this once initially. This takes effect if user has already set some leagues
SportsJS.mainProcessManager.channelManager.initialize();
var settingsPane = Windows.UI.ApplicationSettings.SettingsPane.getForCurrentView();
settingsPane.addEventListener("commandsrequested", that.onSettingsCommandRequested);
});
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":e");
},
// Raise this event onpage load
onPageLoad: function onPageLoad(event) {
// protected against multiple invocations inside
SportsJS.mainProcessManager.processListener.onFirstPageLoad(event);                
},
// Raise this event on First page load
onFirstPageLoad: function onFirstPageLoad(event) {
// successfull app initialization is pre-requisite to it now
if (!SportsJS.mainProcessManager.isAppInitialized || SportsJS.mainProcessManager._isFirstPageLoad === false) {
return;
}
SportsJS.mainProcessManager._isFirstPageLoad = false;
SportsJS.mainProcessManager.isFREPage = false;
var profileMark = "Sports:onFirstPageLoad";
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":s");
if (SportsJS.mainProcessManager.search) {
SportsJS.mainProcessManager.search.initialize(0);
}
// intitalize tile notifications.
SportsJS.SecondaryTile.initializeSecondaryTiles();
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":e");
},
onBeforeActivate: function onBeforeActivate() {                
if ($AppMgr.isFirstTimeLaunch !== true) {
return WinJS.Promise.wrap(true);
}
// In case of first launch, prefetch data (try making the data available in cache) of visble clusters to help improve the boot time.
// Assume: Hero and get started clusters are the first two visble clusters.
var promises = [];
var heroSetting = SportsJS.Utilities.getHeroClusterSetting(SportsJS.UI.PageType.Today);
if (heroSetting !== SportsJS.UI.HeroType.disabled) {
promises.push($AppMgr.model.prefetchTodayHeroData(heroSetting));
}
var isGettingStartedEnabled = PlatformJS.Services.appConfig.getBool("EnableGettingStartedCluster");
if (isGettingStartedEnabled) {
promises.push($AppMgr.model.prefetchGetStartedData());
}
promises.push($AppMgr.model.getData(false));
// give sometime for data fetch call to run
promises.push(WinJS.Promise.timeout(100));
return WinJS.Promise.any(promises);
},
/// <summary>
/// Handles activation event
/// </summary>
/// <param name="event">
/// activation event
/// </param>
/// <returns>
/// Nothing
/// </returns>
onActivated: function onActivated(event) {
var isImmediateLoad = this._isImmediateLoad(event);
var that = this;
var profileMark = "Sports:Services:AppDataCall";
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":s");
var initPromises = [SportsJS.Services.initializeAync(isImmediateLoad), WinJS.UI.Fragments.renderCopy("/lazydefault.html")];
return WinJS.Promise.join(initPromises).then(function (res) {
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":e");
// chthakur - how about this? bad code - this forces the isFreOffline flag to false.
// if we are here, this means the freOffline is over. chthakur - fix this going forward for blue. Keep it minimal right now
SportsJS.Utilities.isFirstRunOfflineExperience();
if (event.detail.kind === Windows.ApplicationModel.Activation.ActivationKind.launch
&& event.detail.tileId !== "App"
&& event.detail.arguments) {
return that.handleTileActivation(event);
}
else if (event.detail.kind === Windows.ApplicationModel.Activation.ActivationKind.search && event.detail.queryText) {
SportsJS.mainProcessManager.search.searchBoxQuery({ queryText: event.detail.queryText });
}
else if (event.detail.kind === Windows.ApplicationModel.Activation.ActivationKind.protocol) {
var uri = event.detail.uri.rawUri;
var action = PlatformJS.Navigation.createCommandFromUri(uri);
if (WinJS.Promise.is(action)) {
return action;
} else if (action.channelInfo) {
return { pageInfo: action.channelInfo.pageInfo, state: action.options };
} else {
action();
}
}
else if (SportsJS.Utilities.isAppStateStale()
&& WinJS.Navigation.location.page
&& WinJS.Navigation.location.page !== 'SportsJS.Today.TodayHomePage') {
return {
pageInfo: {
fragment: "/leagues/today/HomePage/TodayHomePage.html",
page: "SportsJS.Today.TodayHomePage"
}
};
}
}, function (err) {
// go to offline FRE experience
if (SportsJS.Utilities.isFirstRunOfflineExperience()) {
return that.onFirstRunOfflineExperience();
}
return {
pageInfo: {
fragment: "/leagues/today/HomePage/TodayHomePage.html",
page: "SportsJS.Today.TodayHomePage"
}
};
});
},
roamingDataChangedHandler: function roamingDataChangedHandler(event) {
var that = this;
// We only knw that some roaming setting has changed
// Fire this just in case leagues changed              
that.onUserLeaguesChanged(event);
},
// fired when user has reordered his set of leagues
onUserLeaguesReordered: function onUserLeaguesReordered(event) {
SportsJS.mainProcessManager.channelManager.reset();
},
// fired when user has modified his set of leagues or roaming settings change
onUserLeaguesChanged: function onUserLeaguesChanged(event) {
SportsJS.mainProcessManager.channelManager.reset();
},
handleTileActivation: function handleTileActivation(event) {
var currentLayout = Windows.UI.ViewManagement.ApplicationView.value;
if (currentLayout === Windows.UI.ViewManagement.ApplicationViewState.snapped) {
return;
}
try {
var state = JSON.parse(event.detail.arguments);
////this case will be executed when app is upgraded with another version and there are already pinned tiles from old version.
////in the old version pinned tiles, there is no leagueType information. Creating leagueType information for correct invocation of pinned tile.
if (state && state.sportsType && !SportsJS.Utilities.isValidLeagueTypeStrict(state.leagueType)) {
state.leagueType = state.sportsType;
}
if (state && state.target === "DynamicPano.DynamicCategoryPano") {
var dynamicInfo = state.data;
if (dynamicInfo) {
dynamicInfo.entrypoint = "secondarytile";
}
return {
pageInfo: {
channelId: state.data && state.data.id,
fragment: "common/DynamicPano/html/DynamicPano.html",
page: "DynamicPanoJS.DynamicPano"
},
state: {
dynamicInfo: dynamicInfo,
}
};
}
else {
return {
pageInfo: {
fragment: state.fragment,
page: state.page
},
state: state
};
}
} catch (ex) {
// parsing tile arguments failed... Its better to navigate to home instead of not doing anything.
return {
pageInfo: {
fragment: "/leagues/today/HomePage/TodayHomePage.html",
page: "SportsJS.Today.TodayHomePage"
},
state: null
};
}
},
onFirstRunOfflineExperience: function onFirstRunOfflineExperience() {
var nav = {
pageInfo: {
fragment: "/leagues/allsports/HomePage/AllSportsHomePage.html",
page: "SportsJS.AllSports.HomePage"
},
state: { leagueType: $SpMgr.getLeagueString(Microsoft.AppEx.Sports.SportsEnums.League.all) }
};
return nav;
},
onSettingsCommandRequested: function onSettingsCommandRequested(event) {
SportsJS.Settings.onCommandsRequested(event);
},
//TODO: verify below one. I assume this is not working. chthakur -> arengak + gtiwari
showSettings: function showSettings() {
var settingsdiv = document.querySelector('#SportsSettingsPage');
if (settingsdiv && settingsdiv.winControl) {
settingsdiv.winControl.show();
} else {
CommonJS.Settings.showDefaultSettingsFlyout();
}
},
//// This is called both on config and market update.
onUpdatedConfig: function onUpdatedConfig() {
this._onConfigOrMarketUpdate();
},
//// Keep Market update specific stuff here.
onUpdatedMarket: function onUpdatedMarket() {
//// TODO(saarya): onUpdatedConfig in always called when market is changed since market specific config would be loaded.
//// So ideally, we dont need to do the samer things again here. But platform resets the top edgy after calling into onUpdatedConfig.
//// This forces me to redo the same things again. [Can get rid of the 2 other calls but won't gain much, ideally all 3 should be removed]
//// Following up with platform on this.
this._onConfigOrMarketUpdate();
if (SportsJS.Settings) {
SportsJS.Settings.reInitializeSettingsUI();
}
},
//// Keep things that need to be done on both config and market update here.
_onConfigOrMarketUpdate: function _onConfigOrMarketUpdate() {
SportsJS.mainProcessManager.channelManager.reset();
SportsJS.SecondaryTile.updateAllTiles();
},
//// This handles scenarios where page doesn't handle firing load event, and hence we load immediately.
_isImmediateLoad: function _isImmediateLoad(event) {
return event && event.detail && event.detail.tileId && event.detail.tileId.match("DynamicPano.DynamicCategoryPano$");
},
})
});
})();
