﻿(function () {
"use strict";
WinJS.Namespace.define("SportsJS",
{
Search: WinJS.Class.define(function () {
this._searchProvider = new AppEx.Sports.Services.AppSearchProvider();
this._initializeSearchPane();
},
{
_searchProvider: null,
_searchProviderPromise: null,
_autoSuggestPromise: null,
_searchPane: null,
_searchBoxQueryListener: null,
_searchBoxSuggestionsListener: null,
_searchBoxResultSuggestionChosenListener: null,
_initializeSearchPane: function _initializeSearchPane() {
var that = this;
if (!that._searchPane) {
that._searchPane = Windows.ApplicationModel.Search.SearchPane.getForCurrentView();
// attaching search and autocomplete handlers
that._searchBoxQueryListener = that.searchBoxQuery.bind(that);
that._searchBoxSuggestionsListener = that.searchBoxSuggestions.bind(that);
that._searchBoxResultSuggestionChosenListener = that.searchBoxResultSuggestionChosen.bind(that);
that._searchPane.addEventListener("querysubmitted", that._searchBoxQueryListener, false);
that._searchPane.addEventListener("suggestionsrequested", that._searchBoxSuggestionsListener, false);
that._searchPane.addEventListener("resultsuggestionchosen", that._searchBoxResultSuggestionChosenListener, false);
that._searchPane.placeholderText = PlatformJS.Services.resourceLoader.getString("searchboxPlaceHolderText");
}
},
_getSearchProviderPromise: function _getSearchProviderPromise() {
if (this._searchProvider.isUninitialized) {
this.initialize(0);
}
return this._searchProviderPromise;
},
initialize: function initialize(delayInMilliseconds) {
var that = this;
if (!delayInMilliseconds) {
delayInMilliseconds = 0;
}
this._searchProviderPromise = this._searchProvider.initializeAsync(delayInMilliseconds);
},
// Responsible for updating the search data sets.
updateSearchData: function updateSearchData() {
this.initialize(0);
},
// Returns response of search query
query: function query(query) {
var that = this;
var p = new WinJS.Promise(function (complete, error) {
that._getSearchProviderPromise().then(function () {
that._searchProvider.queryAsync(query).then(function (res) {
if (res) {
complete(res);
}
else {
// Indicate no match using null
complete(null);
}
}, that._searchDefaultErrorHandler);
}, that._searchDefaultErrorHandler);
},
function (error) {
error(null);
});
return p;
},
// Returns list of suggestions for given prefix
suggestions: function suggestions(query) {
var that = this;
var p = new WinJS.Promise(function (complete, error) {
that._getSearchProviderPromise().then(function () {
that._searchProvider.autoCompleteQueryAsync(query).then(function (res) {
if (SportsJS.Utilities.isEnumerable(res)) {
complete(res);
}
else {
// indicate no suggestions using empty array
complete([]);
}
}, that._searchDefaultErrorHandler);
}, that._searchDefaultErrorHandler);
});
return p;
},
//// Returns list of suggestions of the given entity type and prefix
entitySuggestions: function entitySuggestions(query, entityType) {
var that = this;
var p = new WinJS.Promise(function (complete, error) {
that._getSearchProviderPromise().then(function () {
that._searchProvider.autoCompleteEntitiesAsync(query, entityType).then(function (res) {
if (SportsJS.Utilities.isEnumerable(res)) {
complete(res);
}
else {
// Indicate no suggestions using empty array
complete([]);
}
}, that._searchDefaultErrorHandler);
}, that._searchDefaultErrorHandler);
}, that._searchDefaultErrorHandler);
return p;
},
_getDisambiguatedName: function _getDisambiguatedName(entityname, suggestion)
{
return (entityname + ":" + suggestion);
},
// Returns list of suggestions for particular suffix and adapt it to searchBox
searchBoxSuggestions: function searchBoxSuggestions(e) {
var that = this;
// Cancel the last auto suggest promise as we have a new request now
if (that._autoSuggestPromise !== null) {
that._autoSuggestPromise.cancel();
}
if (!(e && e.queryText && e.request)) {
return;
};
// Get a deferral so that we can respond to the suggestions request asynchronously.
var deferral = e.request.getDeferral();
that._autoSuggestPromise = that.suggestions(e.queryText);
that._autoSuggestPromise.then(function (suggestionList) {
var sameEntityNameDict = {};
var disambiguatedName;
var i = 0;
for (i = 0; i < suggestionList.length; i++) {
if (suggestionList[i].entityMatches &&
suggestionList[i].entityMatches[0] &&
suggestionList[i].entityMatches[0].matchingEntity &&
suggestionList[i].entityMatches[0].matchingEntity.suggestionDescription) {
disambiguatedName = that._getDisambiguatedName(suggestionList[i].entityMatches[0].matchingEntity.name, suggestionList[i].entityMatches[0].matchingEntity.suggestionDescription);
if (sameEntityNameDict[disambiguatedName]) {
sameEntityNameDict[disambiguatedName]++;
}
else {
sameEntityNameDict[disambiguatedName] = 1;
}
}
}
for (i = 0; i < suggestionList.length; i++) {
var imageUrl = AppEx.Sports.Services.AppSearchProvider.suggestionImageUrlDefault;
var description = "";
if (suggestionList[i]
&& suggestionList[i].entityMatches
&& suggestionList[i].entityMatches[0]
&& suggestionList[i].entityMatches[0].matchingEntity) {
if (suggestionList[i].entityMatches[0].matchingEntity.suggestionImageUrl) {
imageUrl = suggestionList[i].entityMatches[0].matchingEntity.suggestionImageUrl;
}
if (suggestionList[i].entityMatches[0].matchingEntity.suggestionDescription) {
description = suggestionList[i].entityMatches[0].matchingEntity.suggestionDescription;
disambiguatedName = that._getDisambiguatedName(suggestionList[i].entityMatches[0].matchingEntity.name, suggestionList[i].entityMatches[0].matchingEntity.suggestionDescription);
if (sameEntityNameDict[disambiguatedName] > 1) {
var league = suggestionList[i].entityMatches[0].matchingEntity.attributes.sports;
if (league) {
description = SportsJS.Utilities.getLocLeagueDisplayText(league);
}
}
}
}
var imageUri = new Windows.Foundation.Uri(imageUrl);
var imageSource = Windows.Storage.Streams.RandomAccessStreamReference.createFromUri(imageUri);
var suggestionJsObj = SportsJS.Utilities.nativeObjectToJsObject(suggestionList[i]);
var tag = SportsJS.Utilities.jsonStringify(suggestionJsObj);
e.request.searchSuggestionCollection.appendResultSuggestion(
suggestionList[i].suggestionText,description, tag, imageSource, "");
}
try {
// Completing deferral when we didn't add any suggestion causes issues
if (e.request.searchSuggestionCollection.size > 0) {
deferral.complete();
}
} catch (e) {
// do nothing
}
}, that._searchDefaultErrorHandler);
},
searchBoxResultSuggestionChosen: function searchBoxResultSuggestionChosen(e) {
if (e.tag) {
var searchResult = JSON.parse(e.tag);
if (searchResult) {
this._navigateToResultPage(searchResult);
}
}
},
// Query for search box item and navigate to desired page in the application
searchBoxQuery: function searchBoxQuery(e) {
var that = this;
SportsJS.Telemetry.logSearchText(e.queryText);
that.query(e.queryText).then(function (res) {
that._navigateToResultPage(res);
}, that._searchDefaultErrorHandler);
},
_navigateToResultPage: function _navigateToResultPage(res) {
SportsJS.Telemetry.logSearchEntity(res);
if (res) {
var searchMeta = SportsJS.Search.getNavConfig(res);
if (searchMeta && searchMeta.navConfig && searchMeta.navConfig.channel) {
//TODO(chthakur): freeze dependency with platform team, handle home case here. Channel when we are homepage
// is an exception
//support navigation to cluster even if we are same page. Usefull for speech
PlatformJS.Navigation.navigateToChannel(searchMeta.navConfig.channel, { leagueType: searchMeta.navConfig.sports, searchMeta: searchMeta });
}
}
else {
PlatformJS.Navigation.navigateToChannel("SportsNoResultsPage", {  });
}
},
_searchDefaultErrorHandler: function _searchDefaultErrorHandler(error) {
// do nothing
},
//TODO(chthakur): support destruction completely. Right now bare minimum is done
destroy: function destroy() {
var that = this;
if (that._searchPane) {
that._searchPane.removeEventListener("querysubmitted", that._searchBoxQueryListener, false);
that._searchPane.removeEventListener("suggestionsrequested", that._searchBoxSuggestionsListener, false);
that._searchPane.removeEventListener("resultsuggestionchosen", that._searchBoxResultSuggestionChosenListener, false);
}
that._searchPane = null;
}
},
{
// get config required for navigation to pages.
// Config is derived from search result tokens.
// if league is not present use the current league.
// For example if user types standings. navigate to current league standings
getNavConfig: function getNavConfig(response) {
if (!response || !response.grammarMatch
|| !response.grammarMatch.matchingEntity || !response.grammarMatch.matchingEntity.id
|| !SportsJS.Search.isSearchNavObjectFormat(response.grammarMatch.matchingEntity.id)) {
return null;
}
var matchResponse = {};
var sports = "";
var entityType = "";
if (response.entityMatches && response.entityMatches.length > 0 && response.entityMatches[0] && response.entityMatches[0].matchingEntity) {
var matchingEntity = response.entityMatches[0].matchingEntity;
matchResponse.entity = matchingEntity.name;
if (matchingEntity.attributes && matchingEntity.attributes.localid) {
matchResponse.entityId = matchingEntity.attributes.localid;
}
else {
matchResponse.entityId = matchingEntity.id;
}
if (matchingEntity.attributes && matchingEntity.attributes.sports) {
sports = matchingEntity.attributes.sports;
}
if (matchingEntity.type) {
matchResponse.entityType = matchingEntity.type;
}
}
try {
var parsedVal = JSON.parse(response.grammarMatch.matchingEntity.id);
// cluster->get from parsedVal, page->entity type, sports->attributes.sports, entityid->id in proper case
matchResponse.navConfig = SportsJS.Search.getNavConfigFromSearchNavObject(parsedVal, sports);
}
catch (e) {
// continue
}
var navConfig = matchResponse.navConfig;
if (navConfig && navConfig.sports && navConfig.page) {
// In our grammar, we use "home" as page name for both "leagues home" page as well as "today" page.
// However, for "leagues home" page "sports" field can not be "all". We make use of this difference
// while setting the channel.
if (navConfig.page === SportsJS.UI.PageType.Home && navConfig.sports !== SportsJS.UI.LeagueType.all) {
navConfig.channel = SportsJS.UI.EntityType.League + navConfig.page;
} else {
navConfig.channel = navConfig.page;
}
}
// nav is search triggered
matchResponse.searchTriggered = true;
return matchResponse;
},
getNavConfigFromSearchNavObject: function getNavConfigFromSearchNavObject(navObject, sports) {
var navConfig = {};
var Utils = SportsJS.Utilities;
if (navObject && navObject.sports && navObject.page && navObject.cluster) {
// format recognized
navConfig.page = navObject.page;
navConfig.page = navConfig.page.replace('{' + AppEx.Sports.Services.AppSearchProvider.flavorTeam + '}', SportsJS.UI.EntityType.Team);
navConfig.page = navConfig.page.replace('{' + AppEx.Sports.Services.AppSearchProvider.flavorPlayer + '}', SportsJS.UI.EntityType.Player);
navConfig.page = Utils.toValidPageTypeCase(navConfig.page);
navConfig.sports = Utils.toValidLeagueTypeCase(navObject.sports);
navConfig.cluster = Utils.toValidClusterTypeCase(navObject.cluster);
if (sports) {
navConfig.sports = Utils.toValidLeagueTypeCase(sports);
}
if (Utils.isValidLeagueType(navConfig.sports)
&& Utils.isValidPageType(navConfig.page)
&& Utils.isValidClusterType(navConfig.cluster)) {
return navConfig;
}
return null;
}
return null;
},
//Format for object expected: ["Key": "{\"sports\":\"{flavor.league}\",\"page\":\"home\",\"cluster\":\"leagueleadingplayers\"}"]
isSearchNavObjectFormat: function isSearchNavObjectFormat(str) {
//TODO: (chthakur) naive check, evaluate if more complex is required
//we send json from backend. for example:
if (str && str.indexOf("sports") !== -1 && str.indexOf("page") !== -1 && str.indexOf("cluster") !== -1) {
return true;
}
return false;
},
})
});
})();
