﻿/********************************************************
*                                                        *
*   © Microsoft. All rights reserved.                    *
*                                                        *
*********************************************************/
(function () {
"use strict";
WinJS.Namespace.define("SportsJS",
{
Share: WinJS.Class.define(function () {
this.initialize();
},
{
_initialized: false,
initialize: function initialize() {
var that = this;
if (!that._initialized) {
// Get the instance of DataTransferManager class that's been assigned to the current windows
var dataTransferManager = Windows.ApplicationModel.DataTransfer.DataTransferManager.getForCurrentView();
// datarequested event is fired when a user presses the share charm
dataTransferManager.addEventListener("datarequested", function (e) {
if (Platform.Configuration.ConfigurationManager.instance.isEmbargoed) {
// do not share, if blocked
return;
}
var request = e.request;
var deferral = request.getDeferral();
// gather data for sharing from the current page
var currentPage = PlatformJS.Navigation.currentIPage;
try {
// If the page has a handleShareRequest handler, invoke the handler first
if (currentPage.handleShareRequest) {
currentPage.handleShareRequest(request);
}
var pageTitle = currentPage.pageTitle;
if (pageTitle) {
var pageTitleSuffix = PlatformJS.Services.resourceLoader.getString("TodayHomePageTitle");
// If we don't do this we'll get "Bing Sports - Bing Sports" for home page
if (pageTitle !== pageTitleSuffix) {
pageTitleSuffix = " - " + pageTitleSuffix;
if (document.dir === "rtl") {
pageTitleSuffix = that._addRtlMark(pageTitleSuffix);
}
pageTitle += pageTitleSuffix;
}
}
else {
pageTitle = PlatformJS.Services.resourceLoader.getString("SharedLinkTitle");
}
var pageUri = currentPage.sharingUrl ? currentPage.sharingUrl : currentPage.pageUri;
var description = currentPage.shareDescription;
if (!description) {
description = "";
}
var text = currentPage.shareText;
if (!text) {
text = pageUri;
}
// If we can share deep link for the page, we'll share it. Else, we'll just set the title for share.
if (currentPage.isDeeplinkSharable) {
request.data.setDataProvider(Windows.ApplicationModel.DataTransfer.StandardDataFormats.html, function (dataRequest) {
that._htmlDataProvider(dataRequest, currentPage);
});
that._setUriDataPackage(request.data, pageUri, pageTitle, description, text);
deferral.complete();
SportsJS.Telemetry.logShare(currentPage._entityData);
}
else {
that._handleShareFailure(request);
}
} catch (e) {
// Nothing to share. Complete deferral.
deferral.complete();
}
});
that._initialized = true;
}
},
// Sets the windows app link
_setUriDataPackage: function _setUriDataPackage(data, uriString, title, description, text) {
if (!uriString) {
throw new Error("required uriString is missing");
}
var uri = new Windows.Foundation.Uri(uriString);
data.properties.title = title;
data.properties.description = description;
data.setUri(uri);
data.setText(text);
},
_htmlDataProvider: function _htmlDataProvider(request, currentPage) {
var deferral = request.getDeferral();
try {
var shareContentProvider = this._getShareContentProvider();
if (shareContentProvider) {
shareContentProvider.then(function (htmlOutput) {
if (htmlOutput) {
var htmlFormat = Windows.ApplicationModel.DataTransfer.HtmlFormatHelper.createHtmlFormat(htmlOutput);
request.setData(htmlFormat);
}
deferral.complete();
},
function () {
deferral.complete();
});
}
else {
deferral.complete();
}
}
catch (e) {
deferral.complete();
}
},
_handleShareFailure: function _handleShareFailure(request) {
var shareDisplayText = PlatformJS.Services.resourceLoader.getString("NoSharingSupport");
if (shareDisplayText) {
request.failWithDisplayText(shareDisplayText);
}
},
_getAttributionBasedOnLeague: function _getAttributionBasedOnLeague(league) {
var statsAttribution = PlatformJS.Services.resourceLoader.getString("StatsAttributionForShare");
var currentDate = new Date();
statsAttribution = SportsJS.Utilities.stringFormat(statsAttribution, currentDate.getFullYear());
var attribution = {
statsAttribution: SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("AttributionFormatForShare"), statsAttribution),
leagueAttribution: ""
};
if (league === $SpMgr.enumStrings.LeagueType[Microsoft.AppEx.Sports.SportsEnums.League.mlb]) {
attribution.leagueAttribution = PlatformJS.Services.resourceLoader.getString("MlbDataAttribution");
}
else if (league === $SpMgr.enumStrings.LeagueType[Microsoft.AppEx.Sports.SportsEnums.League.epl]) {
attribution.leagueAttribution = PlatformJS.Services.resourceLoader.getString("SoccerDataAttribution");
}
return attribution;
},
_adaptTemplateToRTL: function _adaptTemplateToRTL(template) {
if (template && document.dir === "rtl") {
return template.replace(/\bleft\b/g, "center").replace(/\bright\b/g, "left").replace(/\bcenter\b/g, "right");
}
return template;
},
_prepareTemplate: function _prepareTemplate(templatePath) {
var that = this;
var promise = new WinJS.Promise(function (complete, error) {
var tempDiv = document.createElement('div');
WinJS.UI.Fragments.renderCopy(templatePath, tempDiv).then(function (templateFragment) {
var templateHtml = that._adaptTemplateToRTL(templateFragment.innerHTML);
WinJS.Utilities.setInnerHTML(templateFragment, toStaticHTML(templateHtml));
WinJS.UI.processAll(templateFragment).then(function () {
var deepLinkLine = tempDiv.querySelector(".deepLinkLine");
if (deepLinkLine) {
var deepLinkHtml = that._getDeepLinkHtml();
if (deepLinkHtml) {
WinJS.Utilities.setInnerHTML(deepLinkLine, deepLinkHtml);
}
}
complete(tempDiv);
},
function () {
error();
});
},
function () {
error();
});
});
return promise;
},
_getDeepLinkHtml: function _getDeepLinkHtml() {
var currentPage = PlatformJS.Navigation.currentIPage;
if (currentPage && currentPage.isDeeplinkSharable) {
var deepLinkDescription = PlatformJS.Services.resourceLoader.getString("/platform/win8ShareLink").format(CommonJS.getAppName());
var deepLink = "<a style='color: color: rgb(0, 130, 153);' href='" + currentPage.pageUri + "'>" + deepLinkDescription + "</a>";
var deepLinkHtml = PlatformJS.Services.resourceLoader.getString("/platform/win8Share").format(PlatformJS.Services.resourceLoader.getString("/platform/win8Brand"), deepLink);
return deepLinkHtml;
}
return null;
},
_getShareContentProvider: function _getShareContentProvider() {
var currentPage = PlatformJS.Navigation.currentIPage;
var shareDetails = this._getShareDetails(currentPage);
var shareDataProvider = shareDetails.shareDataPromise ? shareDetails.shareDataPromise : null;
var template = shareDetails.template ? shareDetails.template : null;
if (shareDataProvider && template) {
var that = this;
var promise = new WinJS.Promise(function (complete, error) {
shareDataProvider.then(function (shareData) {
that._prepareTemplate(template).then(function (rootDiv) {
WinJS.Binding.processAll(rootDiv, shareData).then(function () {
complete(rootDiv.innerHTML);
},
function () {
error();
});
},
function () {
error();
});
},
function () {
error();
});
});
return promise;
}
return WinJS.Promise.wrap(PlatformJS.Navigation.currentIPage.pageUri);
},
_getShareDetails: function _getShareDetails(currentPage) {
var shareDataPromise, template, shareData;
if (currentPage._pageType) {
var pageType = currentPage._pageType;
if (pageType === "League" || pageType === "Home") {
shareData = {
leagueName: currentPage.pageTitle ? currentPage.pageTitle : SportsJS.Utilities.getLocLeagueDisplayText(currentPage._leagueType),
description: PlatformJS.Services.resourceLoader.getString("ShareLeagueMessage")
};
shareDataPromise = WinJS.Promise.wrap(shareData);
template = "/leagues/common/Share/LeagueShareTemplate.html";
} else if (pageType === "Team") {
shareDataPromise = this._getTeamShareDataPromise(currentPage._leagueName, currentPage._entityId, currentPage._pageTitle);
template = "/leagues/common/Share/TeamShareTemplate.html";
} else if (pageType === "Player") {
shareDataPromise = this._getPlayerShareDataPromise(currentPage._leagueName, currentPage._entityId);
template = "/leagues/common/Share/PlayerShareTemplate.html";
} else if (pageType === "Editorial") {
shareData = {
leagueName: currentPage.pageTitle ? currentPage.pageTitle : SportsJS.Utilities.getLocLeagueDisplayText(currentPage._leagueType),
description: PlatformJS.Services.resourceLoader.getString("ShareLeagueMessage")
};
shareDataPromise = WinJS.Promise.wrap(shareData);
template = "/leagues/common/Share/LeagueShareTemplate.html";
}
} else {
if (currentPage._articleManager) {
shareDataPromise = WinJS.Promise.wrap(currentPage._shareData);
template = "/leagues/common/Share/ArticleShareTemplate.html";
}
}
return { shareDataPromise: shareDataPromise, template: template };
},
// Team share data consists of 2 parts
// Team stats that come from the season summary scenario
// Last game and next game that come from the schedule scenario
// We'll call out to the 2 ui scenarios, and merge the output as desired
_getTeamShareDataPromise: function _getTeamShareDataPromise(leagueName, teamId, pageTitle) {
var that = this;
var promise = new WinJS.Promise(function (complete, error) {
var controller = AppEx.Sports.Services.SportsController();
var seasonSummaryQuery = new AppEx.Sports.Services.TypeDefs.Request.TeamSeasonSummaryQuery(leagueName, teamId);
var scheduleQuery = new AppEx.Sports.Services.TypeDefs.Request.TeamScheduleQuery(leagueName, teamId, 0);
var seasonSummaryRequest = controller.request(seasonSummaryQuery);
var scheduleRequest = controller.request(scheduleQuery);
seasonSummaryRequest.then(function (seasonSummaryRes) {
scheduleRequest.then(function (scheduleRes) {
if (seasonSummaryRes && scheduleRes && seasonSummaryRes.isValid && scheduleRes.isValid) {
var seasonSummary = SportsJS.Utilities.nativeObjectToJsObject(seasonSummaryRes);
var schedule = SportsJS.Utilities.nativeObjectToJsObject(scheduleRes);
var game1 = null;
var game2 = null;
if (schedule && schedule.teamSchedule && schedule.teamSchedule.length > 0) {
var lastGameIndex = 0;
for (var i = 0; i < schedule.teamSchedule.length; i++) {
var gameInfo = schedule.teamSchedule[i];
if (gameInfo.status === "Final") {
lastGameIndex = i;
}
}
game1 = schedule.teamSchedule[lastGameIndex];
// If there's a future game choose it
// If not, choose 2 past games
if ((lastGameIndex + 1) < schedule.teamSchedule.length) {
game2 = schedule.teamSchedule[lastGameIndex + 1];
}
else if ((lastGameIndex - 1) >= 0) {
game2 = game1;
game1 = schedule.teamSchedule[lastGameIndex - 1];
}
}
if (!game1 || !game2) {
error();
return;
}
var attribution = that._getAttributionBasedOnLeague(leagueName);
var teamShareData = {
fullName: pageTitle,
stat1: seasonSummary.teamSeasonSummaryData[0].stat1,
stat2: seasonSummary.teamSeasonSummaryData[0].stat2,
stat3: seasonSummary.teamSeasonSummaryData[0].stat3,
stat4: seasonSummary.teamSeasonSummaryData[0].stat4,
scheduleTableTitle: PlatformJS.Services.resourceLoader.getString("TeamScheduleClusterTitle"),
match1: that._getTeamScheduleDataForShare(game1),
match2: that._getTeamScheduleDataForShare(game2),
statsAttribution: attribution.statsAttribution,
leagueAttribution: attribution.leagueAttribution
};
complete(teamShareData);
}
else {
error();
}
},
function () {
error();
});
},
function () {
error();
});
});
return promise;
},
_getTeamScheduleDataForShare: function _getTeamScheduleDataForShare(game) {
var match = {};
match.gameDate = game.gameDate;
match.opponent = game.atOrVs + " " + game.opponentTeamName;
if (game.status === "Final") {
match.result = game.displayStatus + " ";
match.resultColor = "";
if (game.winLoss === "W") {
match.resultColor = "#008A00";
}
else if (game.winLoss === "L") {
match.resultColor = "#CC1122";
}
match.status = game.teamAndOpponentGameScore;
}
else {
match.result = "";
match.resultColor = "";
match.status = game.gameTime;
}
return match;
},
// Player share data consists of 2 parts
// Player details that come from the player bio scenario
// Player stats that come from the Player Stats scenario
// We'll call out to the 2 ui scenarios, and merge the output as desired
_getPlayerShareDataPromise: function _getPlayerShareDataPromise(leagueName, playerId) {
var that = this;
var promise = new WinJS.Promise(function (complete, error) {
var controller = AppEx.Sports.Services.SportsController();
var seasonStatsQuery = new AppEx.Sports.Services.TypeDefs.Request.PlayerStatsQuery(leagueName, playerId);
var playerBioQuery = new AppEx.Sports.Services.TypeDefs.Request.PlayerBioQuery(leagueName, playerId);
var seasonStatsRequest = controller.request(seasonStatsQuery);
var playerBioRequest = controller.request(playerBioQuery);
seasonStatsRequest.then(function (seasonStatsRes) {
playerBioRequest.then(function (playerBioRes) {
if (seasonStatsRes && playerBioRes && seasonStatsRes.isValid && playerBioRes.isValid) {
var seasonStats = SportsJS.Utilities.nativeObjectToJsObject(seasonStatsRes);
var playerBio = SportsJS.Utilities.nativeObjectToJsObject(playerBioRes);
if (!seasonStats || !playerBio || !playerBio.playerFullName || !seasonStats.stats || seasonStats.stats.length <= 0) {
error();
return;
}
var shareSeasonStats = [];
for (var i = 0; i < seasonStats.stats.length; i++) {
shareSeasonStats.push(that._getStatForShare(seasonStats.stats[i]));
}
var attribution = that._getAttributionBasedOnLeague(leagueName);
var arePlayerHeadshotsSharable = SportsJS.Services.ConfigData.arePlayerHeadshotsSharable(leagueName);
var playerShareData = {
fullName: playerBio.playerFullName,
positionAndTeamName: playerBio.position + " - " + playerBio.teamFullName,
headshotUrl: arePlayerHeadshotsSharable ? playerBio.playerHeadshotUrl.srcUrl : "",
shareStats: shareSeasonStats,
statsSubtitle: seasonStats.title,
statsAttribution: attribution.statsAttribution,
leagueAttribution: attribution.leagueAttribution
};
complete(playerShareData);
}
else {
error();
}
},
function () {
error();
});
},
function () {
error();
});
});
return promise;
},
_getStatForShare: function _getStatForShare(stat) {
var shareStat = {
name: stat.statName,
seasonStatValue: stat.seasonStatValue,
careerStatValue: stat.careerStatValue,
separator: stat.statName ? "/" : "",
displayStyle: stat.statName ? "" : "none"
};
return shareStat;
},
/// <summary>
/// This function adds a special zero length RTL character "\u200f" to the begining and end of string. 
/// </summary>
/// <returns>
/// string containing RTL mark character
/// </returns>
_addRtlMark: function _addRtlMark(text) {
return "\u200f" + text + "\u200f";
}
}),
});
})();
