﻿(function () {
"use strict";
WinJS.Namespace.define("SportsJS.Utilities",
{
/// returns page title for leading player cluster and ECV page.
getClusterTitle: function getClusterTitle(titleResourceKey, leagueName, conference, isECV) {
var title = "";
var subTitleKey = "";
//TODO -> shambhu, move this hardcoding out
if (conference) {
try {
subTitleKey = SportsJS.Utilities.stringProperCase(leagueName) + conference + "DivisionSubTitle";
title = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString(titleResourceKey), PlatformJS.Services.resourceLoader.getString(subTitleKey));
}
catch (e) {
title = "";
// ignore, this shouldn;t happen most of the times
}
}
if (!title) {
if (isECV) {
title = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString(titleResourceKey), SportsJS.Utilities.getLocLeagueDisplayText(leagueName));
}
else {
title = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString(titleResourceKey));
}
}
return title;
},
/// Gets the key value pairs from the request
getQueryVariable: function getQueryVariable(request) {
if (!request){
return;
}
var vars = request.split('&');
var paramsDictionary = {};
for (var i = 0; i < vars.length; i++) {
var pair = vars[i].split('=');
if (pair[0]) {
paramsDictionary[decodeURIComponent(pair[0])] = pair[1];
}
}
return paramsDictionary;
},
stringFormat: function stringFormat() {
var args = arguments;
if (!args || args.length < 1) {
throw new Error("stringFormat called with too few arguments");
}
if (args[0] === null) {
throw new Error("format string cannot be null");
}
var formatString = args[0];
var formattedString = formatString.replace(/{(\d+)}/g, function (match, number) {
//// number + 1 since arguments[0] is format string
number = parseInt(number) + 1;
var replacementText = typeof args[number] !== 'undefined' && args[number] !== null ? args[number] : match;
return replacementText;
});
return formattedString;
},
trace: function trace(ctx, tag, text) {
////TODO: write to platform debug file too
if (PlatformJS.isDebug) {
console.log("[SportsApp trace] " + new Date() + " [" + tag + "]:" + text);
}
},
//private function for utils tracing
_trace: function _trace(fn, msg) {
// function to be used for utils tracing, keeping the name similar across the app to _trace, so that moving
// the functions around is easier.
if (!fn || !msg || !PlatformJS.isDebug) {
return;
}
SportsJS.Utilities.trace.call(this, this, fn + ":", msg);
},
// get logos availability entry
checkLogosAvailabilityParam: function checkLogosAvailabilityParam(configParams) {
var showLogos = true;
if (configParams.showLogos === false) {
showLogos = configParams.showLogos;
}
return showLogos;
},
mapCStoJSLeagueType: function mapCStoJSLeagueType(league) {
return $SpMgr.enumStrings.LeagueType[league];
},
getEnumStringsHashFromManagedEnums: function getEnumStringsHashFromManagedEnums(managedEnum) {
var keys = Object.keys(managedEnum);
var hash = {};
for (var kk = 0; kk < keys.length; kk++) {
hash[managedEnum[keys[kk]]] = keys[kk];
}
return hash;
},
getLeagueIconImgClass: function getLeagueIconImgClass(leagueName) {
if (!leagueName) {
return "";
}
return "icon" + leagueName;
},
getLocLeagueDisplayText: function getLocLeagueDisplayText(leagueName) {
var leagueDisplayText = SportsJS.Services.ConfigData.getLeagueDisplayText(leagueName);
return leagueDisplayText;
},
getLocSportsDisplayText: function getLocSportsDisplayText(sportName) {
var sportDisplayText = SportsJS.Services.ConfigData.getSportDisplayText(sportName);
return sportDisplayText;
},
getLocLeagueDisplayTextOfflineFre: function getLocLeagueDisplayTextOfflineFre(leagueName) {
var leagueDisplayText = leagueName;
try {
leagueDisplayText = PlatformJS.Services.resourceLoader.getString(leagueName + "LeagueTitle");
} catch (e) {
leagueDisplayText = leagueName;
}
return leagueDisplayText;
},
getLocSportsDisplayTextOfflineFre: function getLocSportsDisplayTextOfflineFre(sportName) {
var sportDisplayText = sportName;
try {
sportDisplayText = PlatformJS.Services.resourceLoader.getString(sportName + "SportTitle");
} catch (e) {
sportDisplayText = sportName;
}
return sportDisplayText;
},
getLocLeaguePageDisplayText: function getLocLeaguePageDisplayText(leagueName) {
var leagueDisplayText = leagueName;
try {
var formatString = PlatformJS.Services.resourceLoader.getString("LeaguePageTitle");
leagueDisplayText = SportsJS.Utilities.stringFormat(formatString, leagueName);
} catch (e) {
leagueDisplayText = leagueName;
}
return leagueDisplayText;
},
getLocTeamPageDisplayText: function getLocTeamPageDisplayText(leagueName) {
var leagueDisplayText = leagueName;
try {
var formatString = PlatformJS.Services.resourceLoader.getString("TeamPageTitle");
leagueDisplayText = SportsJS.Utilities.stringFormat(formatString, leagueName);
} catch (e) {
leagueDisplayText = leagueName;
}
return leagueDisplayText;
},
getLocPlayerDisplayText: function getLocPlayerDisplayText(leagueName) {
var leagueDisplayText = leagueName;
try {
var formatString = PlatformJS.Services.resourceLoader.getString("PlayerPageTitle");
leagueDisplayText = SportsJS.Utilities.stringFormat(formatString, leagueName);
} catch (e) {
leagueDisplayText = leagueName;
}
return leagueDisplayText;
},
getSportsBackgroundUrl: function getSportsBackgroundUrl(league) {
var leagueType = AppEx.Sports.Services.Utils.getSportsFromLeague(league);
var url = "/assets/" + leagueType + "/bg.jpg";
return url;
},
convertCMSArticle: function convertCMSArticle(result) {
if (!result) {
return null;
}
if (!result.destination) {
// Destination is a must field, but relaxed for Hero page
// In case of Team hero page, it might not have article associated with it - prchando
if (!result.heroImage) {
return null;
}
}
return CommonJS.Utils.convertCMSArticle(result, function (destination) { return AppEx.Sports.Services.Utilities.SportsAppExUriManager.instance.createAppUri(destination); });
},
//// As per PM spec, we have to show FREOffline till user comes online once after starting the app
isFirstRunOfflineExperience: (function () {
var isFREOffline;
return function () {
if (typeof isFREOffline === 'undefined') {
var applicationData = Windows.Storage.ApplicationData.current;
var localSettings = applicationData.localSettings;
var value = localSettings.values["isFREOffline"];
// Note: setting values are written as strings
if (typeof value === "string" && value === "false") {
isFREOffline = false;
}
else {
//// Offline is false
if (SportsJS.Networking.isInternetAvailable) {
isFREOffline = false;
localSettings.values["isFREOffline"] = "false";
}
else {
isFREOffline = true;
var networkOnlineEventHandler = function () {
isFREOffline = false;
localSettings.values["isFREOffline"] = "false";
SportsJS.Networking.removeEventListener('networkonline', networkOnlineEventHandler);
};
SportsJS.Networking.addEventListener('networkonline', networkOnlineEventHandler);
}
}
}
return isFREOffline;
};
})(),
isNavigationBarEnabled: function isNavigationBarEnabled() {
var navBar = document.querySelector("#platformNavigationBar").winControl;
if (navBar.disabled === true) {
return false;
}
return true;
},
disableNavigationBar: function disableNavigationBar() {
var navBar = document.querySelector("#platformNavigationBar").winControl;
if (navBar) {
navBar.disabled = true;
}
},
enableNavigationBar: function enableNavigationBar() {
var navBar = document.querySelector("#platformNavigationBar").winControl;
if (navBar) {
navBar.disabled = false;
}
},
hideTopEdgy: function hideTopEdgy() {
var topEdgy = document.getElementById('platformNavigationBar');
if (topEdgy && topEdgy.winControl) {
var topEdgyControl = topEdgy.winControl;
topEdgyControl.hide();
}
},
hideBottomEdgy: function hideBottomEdgy() {
var bottomEdgy = document.querySelector('.sportsBottomEdgy');
if (bottomEdgy && bottomEdgy.winControl) {
var bottomEdgyControl = bottomEdgy.winControl;
bottomEdgyControl.hide();
}
},
//purge event queue by calling all the functions in the event queue
purgeEventQueue: function purgeEventQueue(eventQueue) {
if (!eventQueue) {
return;
}
for (var ii = 0; ii < eventQueue.length; ii++) {
if (eventQueue[ii] && typeof eventQueue[ii] === "function") {
eventQueue[ii]();
eventQueue[ii] = null;
}
}
},
// Wrapper over navigate To for sports
navigateTo: function navigateTo(uri) {
if (!uri) {
return;
}
if (uri.indexOf("http://") !== -1) {
PlatformJS.Navigation.navigateToChannel("SportsFrame", { sourceUrl: uri });
return;
}
PlatformJS.Navigation.navigateTo(uri);
},
isArray: function isArray(obj) {
return Object.prototype.toString.call(obj) === '[object Array]';
},
isEnumerable: function isEnumerable(obj) {
return obj && obj.length && typeof obj.length === "number";
},
// wrappers to help ease measurements
jsonParse: function jsonParse(resString) {
var resObject;
if (resString === null) {
return resObject;
}
var profileMark = "Sports:jsonParse";
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":s");
try {
resObject = JSON.parse(resString);
} catch (e) {
resObject = null;
}
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":e");
return resObject;
},
// wrappers to help ease measurements
jsonStringify: function jsonStringify(resObject) {
var result;
if (result === null) {
return null;
}
var profileMark = "Sports:jsonStringify";
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":s");
try {
result = JSON.stringify(resObject);
} catch (e) {
result = null;
}
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":e");
return result;
},
setAutomationId: function setAutomationId(domElement, componentType, prefix) {
if (domElement && componentType && SportsJS.UI.AutomationComponentType[componentType]) {
domElement.id = "sports" + prefix + componentType;
}
},
cancelPromiseArray: function cancelPromiseArray(promises) {
if (!promises || !Array.isArray(promises)) {
return;
}
for (var kk = 0; kk < promises.length; kk++) {
var promise = promises[kk];
if (promise && promise.cancel && typeof promise.cancel === 'function') {
promise.cancel();
}
promises[kk] = "cancelled";
}
},
cancelPromise: function cancelPromise(promise) {
if (promise && promise.cancel && typeof promise.cancel === 'function') {
promise.cancel();
}
},
createPromiseArrayCopy: function createPromiseArrayCopy(promise) {
var outPromiseArray = [];
if (!promise) {
return outPromiseArray;
}
if (Array.isArray(promise)) {
for (var kk = 0; kk < promise.length; kk++) {
outPromiseArray.push(promise[kk]);
}
}
else {
outPromiseArray.push(promise);
}
return outPromiseArray;
},
isCancellationError: function isCancellationError(error) {
if (!error) {
return false;
}
if (Array.isArray(error)) {
for (var kk = 0; kk < error.length; kk++) {
if (error[kk] && error[kk].message === "Canceled") {
return true;
}
}
}
else {
return (error && error.message === "Canceled");
}
},
setObjectPropertiesToNull: function setObjectPropertiesToNull(obj) {
if (!obj) {
return;
}
var keys = Object.keys(obj);
//// Below code nullifies element as well. This causes issues if control has eventProperties defined.
//// setting eventProperties to null tries to remove any corresponding event handlers from element
//// The code crashes if element is null
//// Hence, we would set element to null at end
for (var kk = 0; kk < keys.length; kk++) {
var key = keys[kk];
if (key === 'element' || key === '_domElement') {
continue;
}
obj[keys[kk]] = null;
}
obj.element = null;
obj._domElement = null;
},
// Speed factor, intel is one, others are multiple of one
// This is required for rendering timeouts
getProcessorSpeedFactor: function getProcessorSpeedFactor() {
var arch = Windows.ApplicationModel.Package.current.id.architecture;
//enum from http://msdn.microsoft.com/en-us/library/windows/desktop/windows.system.processorarchitecture.aspx
var factor = 1;
if (arch === 5) {
// archString = "Arm";
factor = 3; // 3 times slower
}
return factor;
},
getMemoryContributionWeightFactorForPage: function getMemoryContributionWeightFactorForPage() {
var weight = 1; // weight for all pages set to 1
return weight;
},
sanitizeNewsQuery: function sanitizeNewsQuery(query) {
var sanitizedQuery = query;
if (!query) {
return query;
}
sanitizedQuery = query.replace(/&/g, " ");
sanitizedQuery = sanitizedQuery.replace(/\//g, "-");
return sanitizedQuery;
},
/// <summary>
/// adding a wrapper over actual profile mark
/// This will help us add common format changes quickly
/// adding sports explicity in the name to avoid name confusion with msWriteProfilerMark
/// <param name="type">type is SportsJS.UI.ProfilerEntityType</param>
/// <param name="info">{ sports: sportstype, page: pagename, cluster: clustertype, module: moduletype}</param>
/// </summary>
sportsMsWriteProfilerMark: function sportsMsWriteProfilerMark(info) {
var maxLength = 32;
if (!info) { return; }
if (typeof info === "string") {
msWriteProfilerMark(info);
return;
}
var isValidMarkInfo = false;
var profileMark = "Sports:";
switch (info.entityType) {
case SportsJS.UI.ProfilerEntityType.Page:
if (info.page && info.markType) {
profileMark += info.page + ":";
profileMark = info.func ? profileMark + info.func + ":" : profileMark;
profileMark += info.markType;
isValidMarkInfo = true;
}
break;
case SportsJS.UI.ProfilerEntityType.Cluster:
if (info.page && info.cluster && info.markType) {
profileMark += info.page + ":";
profileMark += info.cluster + ":";
profileMark = info.func ? profileMark + info.func + ":" : profileMark;
profileMark += info.markType;
isValidMarkInfo = true;
}
break;
case SportsJS.UI.ProfilerEntityType.Func:
// todo(chthakur) - to be supported
isValidMarkInfo = false;
break;
}
if (isValidMarkInfo) {
msWriteProfilerMark(profileMark);
}
},
nativeObjectToJsObject: function nativeObjectToJsObject(nativeObject, convertArrayElementsToProperties, isRecurse) {
var jsObject = {};
var profileMark = "Sports:nativeObjectToJsObject";
if (!isRecurse) {
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":s");
}
SportsJS.Utilities.deepCopyJsObject(nativeObject, jsObject, convertArrayElementsToProperties, isRecurse);
if (!isRecurse) {
SportsJS.Utilities.sportsMsWriteProfilerMark(profileMark + ":e");
}
return jsObject;
},
// This function is not aware of winRT. This is normal JS deepcopy
deepCopyJsObject: function deepCopyJsObject(src, dest, convertArrayElementsToProperties, isRecurse) {
var jsObject = dest ? dest : {};
var nativeObject = src;
try {
for (var p in nativeObject) {
var curProp = nativeObject[p];
// property is object
if (curProp && typeof curProp === "object") {
//property is array
if (typeof curProp.length === 'number' && !(curProp.propertyIsEnumerable('length'))) {
var jsArray = SportsJS.Utilities.nativeArrayToJsArray(curProp, convertArrayElementsToProperties);
// In order to be able to bind array elements, they need to be converted to direct properties of the object.
// for js cache perf reasons keep only either direct properties on array. 
if (convertArrayElementsToProperties) {
var len = jsArray.length;
for (var i = 0; i < len; i++) {
jsObject[p + i.toString()] = jsArray[i];
}
} else {
jsObject[p] = jsArray;
}
}
//// For DateTimeOffset type, properties get converted into get/set methods which are getting dropped by this converter
else if (curProp instanceof Date) {
jsObject[p] = curProp;
}
else {
jsObject[p] = SportsJS.Utilities.nativeObjectToJsObject(curProp, convertArrayElementsToProperties, true);
}
}
else {
var val = null;
try {
if (p === "hashCode" && typeof curProp === "number") {
val = curProp.toString();
}
else {
val = curProp;
}
}
catch (e) { }
jsObject[p] = val;
}
}
}
catch (e) {
// Conversion from WinRT to jsObject failed. Some properties might be null. 
}
},
// Copies the metadata from query service response. For perf reasons, we need to avoid copying the
// csResponse completely
copyCsResponseMeta: function copyCsResponseMeta(csResponse, jsResponse) {
if (!csResponse) {
return jsResponse;
}
jsResponse.hashCode = csResponse.hashCode;
jsResponse.etag = csResponse.etag;
jsResponse.isStaleResponse = csResponse.isStaleResponse;
jsResponse.isValid = csResponse.isValid;
jsResponse.lastUpdateTime = csResponse.lastUpdateTime;
jsResponse.progressResponseNotModified = csResponse.progressResponseNotModified;
jsResponse.nextRefreshInterval = csResponse.nextRefreshInterval;
jsResponse.maxAge = csResponse.maxAge;
return jsResponse;
},
// Copies the sportsResponseMeta - metadata from query service response.
copyCsSportsResponseMeta: function copyCsSportsResponseMeta(csResponse, jsResponse) {
if (!csResponse) {
return jsResponse;
}
jsResponse.hashCode = csResponse.etag;
jsResponse.etag = csResponse.etag;
jsResponse.isStaleResponse = csResponse.isStaleResponse;
jsResponse.lastUpdateTime = csResponse.lastUpdateTime;
jsResponse.progressResponseNotModified = csResponse.serverResponseNotModified;
jsResponse.requestUrl = csResponse.requestUrl;
jsResponse.responseFailed = csResponse.responseFailed;
jsResponse.maxAge = csResponse.maxAge;
return jsResponse;
},
/// <summary>
/// executeFunctionByName - calls the function given its name string
/// <param name="context">context in which the function string is valid</param>
/// </summary>
executeFunctionByName: function executeFunctionByName(context, functionName) {
context = context || window;
var args = Array.prototype.slice.call(arguments, 2);
var namespaces = functionName.split(".");
var funcName = namespaces.pop();
for (var i = 0; i < namespaces.length; i++) {
if (!context[namespaces[i]]) { return null; }
context = context[namespaces[i]];
}
var retVal;
var functionObject = context[funcName];
if (typeof functionObject === "function") {
retVal = functionObject.apply(context, args);
}
return retVal;
},
//we need to make a deep copy of the object to make changes visible in the DOM
// using src dest object.
// There is a potential of one optimization here:
// 1. we should only change those properties of objects which have changed. This will help
// reduce dom refreshes. Will get back to this is refresh is found to be a contraints
observableObjectAwareDeepCopy: function observableObjectAwareDeepCopy(src, dest) {
SportsJS.Utilities.deepCopyJsObject(src, dest);
return true;
},
nativeArrayToJsArray: function nativeArrayToJsArray(nativeArray, convertArrayElementsToProperties) {
var jsArray = [];
if (nativeArray) {
for (var kk = 0, max = nativeArray.length; kk < max; kk++) {
var nativeObject = nativeArray[kk];
if (typeof nativeObject === "number" || typeof nativeObject === "string") {
jsArray.push(nativeObject);
}
else {
jsArray.push(SportsJS.Utilities.nativeObjectToJsObject(nativeObject, convertArrayElementsToProperties, true));
}
}
}
return jsArray;
},
_toValidTypeCase: function _toValidTypeCase(type, typeMap) {
if (!type || !typeMap) { return null; };
var typeMapsKeys = Object.keys(typeMap);
type = type.toLowerCase();
for (var t = 0, max = typeMapsKeys.length; t < max; t++) {
var key = typeMapsKeys[t];
if (key.toLowerCase() === type || typeMap[key].toLowerCase() === type) {
return typeMap[key];
}
}
return null;
},
// do not use ignore case version unless the type is populated from outside app
toValidGameStateTypeCase: function toValidGameStateTypeCase(gameState) {
return SportsJS.Utilities._toValidTypeCase(gameState, SportsJS.UI.GameState);
},
// do not use ignore case version unless the type is populated from outside app
toValidLeagueTypeCase: function toValidLeagueTypeCase(leagueType) {
return AppEx.Sports.Services.Utils.toValidLeagueTypeCase(leagueType);
},
// do not use ignore case version unless the type is populated from outside app
toValidPageTypeCase: function toValidPageTypeCase(pageType) {
return SportsJS.Utilities._toValidTypeCase(pageType, SportsJS.UI.PageType);
},
// do not use ignore case version unless the type is populated from outside app
toValidClusterTypeCase: function toValidClusterTypeCase(clusterType) {
return SportsJS.Utilities._toValidTypeCase(clusterType, SportsJS.UI.ClusterType);
},
// do not use ignore case version unless the type is populated from outside app
_isValidTypeIgnoreCase: function _isValidTypeIgnoreCase(type, typeMap) {
if (!type) { return false; };
var typeMapsKeys = Object.keys(typeMap);
type = type.toLowerCase();
for (var t = 0, max = typeMapsKeys.length; t < max; t++) {
var key = typeMapsKeys[t];
if (key.toLowerCase() === type || typeMap[key].toLowerCase() === type) {
return true;
}
}
return false;
},
// do not use ignore case version unless the type is populated from outside app
isValidGameStateTypeIgnoreCase: function isValidGameStateTypeIgnoreCase(gameState) {
return SportsJS.Utilities._isValidTypeIgnoreCase(gameState, SportsJS.UI.GameState);
},
// do not use ignore case version unless the type is populated from outside app
isValidPageTypeIgnoreCase: function isValidPageTypeIgnoreCase(pageType) {
return SportsJS.Utilities._isValidTypeIgnoreCase(pageType, SportsJS.UI.PageType);
},
// do not use ignore case version unless the type is populated from outside app
isValidClusterTypeIgnoreCase: function isValidClusterTypeIgnoreCase(clusterType) {
return SportsJS.Utilities._isValidTypeIgnoreCase(clusterType, SportsJS.UI.ClusterType);
},
// check for valid sports type strictly, all, none, today not allowed
isValidLeagueTypeStrict: function isValidLeagueTypeStrict(leagueType) {
if (leagueType && AppEx.Sports.Services.Utils.isValidLeagueTypeStrict(leagueType)) {
return true;
}
return false;
},
isValidLeague: function isValidLeague(league) {
if (league && AppEx.Sports.Services.Utils.isValidLeagueType(league)) {
return true;
}
return false;
},
isValidSportType: function isValidSportType(sportType) {
if (sportType && AppEx.Sports.Services.Utils.isValidSportType(sportType)) {
return true;
}
return false;
},
isValidLeagueType: function isValidLeagueType(leagueType) {
if (leagueType && AppEx.Sports.Services.Utils.isValidLeagueType(leagueType)) {
return true;
}
return false;
},
isValidPageType: function isValidPageType(pageType) {
if (pageType && SportsJS.UI.PageType[pageType]) {
return true;
}
return false;
},
isValidClusterType: function isValidClusterType(clusterType) {
if (clusterType && SportsJS.UI.ClusterType[clusterType]) {
return true;
}
return false;
},
isValidSportsEntityType: function isValidSportsEntityType(entityType) {
if (entityType && SportsJS.UI.EntityType[entityType]) {
return true;
}
return false;
},
// Normalizes league/team/player state into entity state
entityStateAdapter: function entityStateAdapter(state) {
if (!state) {
return;
}
if (state.searchMeta) {
// search 
state.entityId = state.searchMeta.entityId;
state.entityType = state.searchMeta.entityType;
} else if (state.playerId) {
state.entityId = state.playerId;
state.entityType = SportsJS.UI.EntityType.Player;
} else if (state.teamId) {
state.entityId = state.teamId;
state.entityType = SportsJS.UI.EntityType.Team;
} else if (state.matchId) {
state.entityId = state.matchId;
state.entityType = SportsJS.UI.EntityType.Match;
}            
else {
// Default for entity page is league page
state.entityId = state.leagueType;
state.entityType = SportsJS.UI.EntityType.League;
}
return state;
},
getCurrentPagePanoControl: function getCurrentPagePanoControl() {
var panoControl = null;
var panoElement = document.querySelector(".mainPanorama");
if (!panoElement) {
//support both id and class
panoElement = document.querySelector("#mainPanorama");
}
panoControl = panoElement !== null ? panoElement.winControl : null;
return panoControl;
},
getClusterControlsInsidePagePano: function getClusterControlsInsidePagePano() {
var that = this;
var clusterControls = [];
var panoControl = SportsJS.Utilities.getCurrentPagePanoControl();
if (panoControl) {
var panoSurface;
// TODO(chthakur) - relying of private properties, check with Eric if platform can expose all the controls list in one API
if (!panoControl || !panoControl._virtualizer || !panoControl._virtualizer._realized) {
return clusterControls;
}
var item = panoControl._virtualizer._realized.first;
while (item) {
if (item.winControl) {
clusterControls.push(item.winControl);
}
item = item.next;
}
}
return clusterControls;
},
getCurrentDay: function getCurrentDay() {
var weekArray = ["MON", "TUE", "WED", "THU", "FRI", "SAT", "SUN"];
var today = new Date();
var day = weekArray[today.getDay()];
return day;
},
fallbackResponsePromise: function fallbackResponsePromise() {
var promise = new WinJS.Promise(function (complete) {
complete({ data: [], response: { isValid: false } });
});
return promise;
},
dataFetchErrorCallBack: function dataFetchErrorCallBack(complete) {
complete({ data: [], response: { isValid: false } });
},
//// TODO(saarya): This should be modified to send user's selected leagues once we have that setting in place
getUserLeagues: function getUserLeagues() {
return SportsJS.mainProcessManager.userLeagues;
},
reorderUserLeagues: function reorderUserLeagues(leagueOrder) {
SportsJS.mainProcessManager.reorderUserLeagues(leagueOrder);
},
getClusterTitleFromConfigParams: function getClusterTitleFromConfigParams(configParams){
if (!configParams || !configParams.title || !configParams.title.text) {
return "";
}
return configParams.title.text;
},
getClusterIdFromConfigParams: function getClusterIdFromConfigParams(configParams){
if (!configParams || !configParams.id ) {
return "";
}
return configParams.id;
},
// returns URI handler for navigation from configParams
getClusterTitleUriHandlerFromConfigParams: function getClusterTitleUriHandlerFromConfigParams(configParams){
if (!configParams || !configParams.title || !configParams.title.uri) {
return null;
}
var navigateTo = function () {
PlatformJS.Navigation.navigateTo(configParams.title.uri);
};
return navigateTo;
},
stringProperCase: function stringProperCase(str) {
var strOut = str;
if (str && str.length > 0) {
strOut = str.substr(0, 1).toUpperCase();
strOut = str.length > 1 ? strOut + str.substr(1).toLowerCase() : strOut;
}
return strOut;
},
/// <summary>
/// TODO(saarya): Temporary workaround to set cluster config on cluster.
/// Will go away once clusters move to config functions.
/// </summary>
setOptions: function setOptions(control, options) {
if (typeof options === "object") {
for (var key in options) {
var value = options[key];
if (value) {
control[key] = value;
}
}
}
},
showProgressBar: function showProgressBar() {
CommonJS.Progress.showProgress(CommonJS.Progress.headerProgressType);
//// Hiding ProgressBar after 10s by default to handle cases where clusters misbehave
setTimeout(function () {
CommonJS.Progress.hideProgress(CommonJS.Progress.headerProgressType);
}, 4000);
},
IsLeagueHeadlinesEnabled: function IsLeagueHeadlinesEnabled() {
return PlatformJS.Services.appConfig.getBool(AppEx.Sports.Services.Utilities.Globalization.getCurrentMarket().toLowerCase().match(/en-/) ? "EnableLeagueHeadlinesClusterEN" : "EnableLeagueHeadlinesClusterAll");
},
getColorMapping: function getColorMapping(colorText) {
var fallBackColor = "headerFontDark";
if (colorText === "Light") {
return "headerFontLight";
}
else if (colorText === "Dark") {
return "headerFontDark";
}
else {
return fallBackColor;
}
},
getCMSHeroMarketString: function getCMSHeroMarketString(heroSetting) {
var market = null;
if (heroSetting === SportsJS.UI.HeroType.image || heroSetting === SportsJS.UI.HeroType.useenus) {
market = "en-us";
}
else if (heroSetting === SportsJS.UI.HeroType.useenww || heroSetting === SportsJS.UI.HeroType.enwwimage) {
market = "en-ww";
}
else {
market = AppEx.Sports.Services.Utilities.Globalization.getCurrentMarket().toLowerCase();
}
return market;
},
getHeroClusterSetting: function getHeroClusterSetting(pageType) {
var heroClusterConfig = PlatformJS.Services.appConfig.getDictionary("HeroClusterMarketConfiguration");
var heroconfig = heroClusterConfig[pageType.toLowerCase()];
//if no market config is defined for this market
if (!heroconfig) {
//get the en-* config from appconfiguration.xml
if (AppEx.Sports.Services.Utilities.Globalization.getCurrentMarket().toLowerCase().match(/en-/)) {
heroClusterConfig = PlatformJS.Services.appConfig.getDictionary("HeroClusterMarketConfigurationEN");
}
else {
//get the default config from appconfiguration.xml
heroClusterConfig = PlatformJS.Services.appConfig.getDictionary("HeroClusterMarketConfigurationDefault");
}
heroconfig = heroClusterConfig[pageType.toLowerCase()];
}
if (heroconfig && heroconfig.value) {
return heroconfig.value;
}
return SportsJS.UI.HeroType.disabled;
},
//get tile data from pageData request of a league
getSecondaryTileDataAsync: function getSecondaryTileDataAsync(leagueType) {
var isRefresh = false;
var pageArgs = { entityType: SportsJS.UI.PageType.League, leagueType: leagueType };
var modelInstance = new SportsJS.PageModel({ pageType: "entity", pageId: "", pageArgs: pageArgs });
return modelInstance.getData(isRefresh).then(function (response) {
if(response && response.pageData && response.pageData.tileData) {
return response.pageData.tileData;
}
else {
return null;
}           
});
},
getCurrentNewsVersion: function getCurrentNewsVersion() {
var newsVersionConfig = PlatformJS.Services.appConfig.getDictionary("NewsVersionConfig");
var newsVersion = newsVersionConfig ? newsVersionConfig["CurrentVersion"] : null;
if (!newsVersion || !newsVersion.value) {
newsVersion = "1.0";
}
else {
newsVersion = newsVersion.value;
}
return newsVersion;
},
getNewsServiceName: function getNewsServiceName() {
var newsVersion = SportsJS.Utilities.getCurrentNewsVersion();
var newsVersionConfig = PlatformJS.Services.appConfig.getDictionary("NewsVersionConfig");
var serviceName = newsVersionConfig ? newsVersionConfig["NewsServiceVersion" + newsVersion] : null;
if (!serviceName || !serviceName.value) {
serviceName = "News";
}
else {
serviceName = serviceName.value;
}
return serviceName;
},
getNewsTypeForPage: function getNewsTypeForPage(pageType) {
var marketbasedNewsType = PlatformJS.Services.appConfig.getDictionary("MarketNewsType");
var pageNewsType = marketbasedNewsType[pageType.toLowerCase()];
return pageNewsType;
},
// construct cluster title using year info. This function works using resource key and year
// if year is empty or null, we should return the title using resouce key
constructClusterTitleWithYearFromResourceKey: function constructClusterTitleWithYearFromResourceKey(titleResourceKey, year) {
var clusterTitle = PlatformJS.Services.resourceLoader.getString(titleResourceKey);
var clusterTitleFormatWithYear = PlatformJS.Services.resourceLoader.getString("clusterTitleFormatWithYear");
if (year && year !== "") {
clusterTitle = SportsJS.Utilities.stringFormat(clusterTitleFormatWithYear, year, clusterTitle);
}
return clusterTitle;
},
// construct cluster title using year info. This function works using localized cluster title and year
// if year is empty or null, we should return the original cluster Title
constructClusterTitleWithYear: function constructClusterTitleWithYear(clusterTitle, year) {
var clusterTitleFormatWithYear = PlatformJS.Services.resourceLoader.getString("clusterTitleFormatWithYear");
if (year && year !== "") {
clusterTitle = SportsJS.Utilities.stringFormat(clusterTitleFormatWithYear, year, clusterTitle);
}
return clusterTitle;
},
// function to check whether the given element is on the screen.
// If the given element is not valid then it will return false
isOnScreen: function isOnScreen(element) {
if (!element) { return false; }
var screenWidth = $SpMgr.screenSize.width;
var screenHeight = $SpMgr.screenSize.height;
// 5% left and right of the screen -- actually not required but keeping it wont be an issue
var tolerencePercentageFactor = 0.05;
var tolerence = screenWidth * tolerencePercentageFactor;
try {
var moduleRect = element.getBoundingClientRect();
return (moduleRect.right > -tolerence && moduleRect.left < (screenWidth + tolerence) && moduleRect.top <= screenHeight);
} catch (e) {
return false;
}
},
// ImgControl - implemented to take care of imagefall back
ImgControl: WinJS.Class.define(function (element, options) {
this.element = element || document.createElement("div");
element.winControl = this;
element.setAttribute("role", "img");
WinJS.Utilities.addClass(element, "sportsImgControl");
this.imageElement = document.createElement("div");
WinJS.Utilities.addClass(this.imageElement, "platformImageCardImage");
element.appendChild(this.imageElement);
}, {
element: null,
winControl: null,
_srcUrl: null,
_fallBackUrl: null,
_alt: null,
_title: null,
_imgCard: null,
_imgInfo: null,
_clickHandler: null,
imageElement: null,
imgClick: {
get: function get() {
return this._clickHandler;
},
set: function set(value) {
if (!value || typeof value !== "function") {
return;
}
//TODO: visatyam - should check if itemclick is already registered by someone else and return. There should be some way of verifying if registerclickproxy is called
this._clickHandler = value;
PlatformJS.Utilities.registerItemClickProxy(this.element,
function (domElement) {
return true;
}, this._clickHandler
);
}
},
imgData: {
get: function get() {
return this._src;
},
set: function set(value) {
var that = this;
if (!value) {
return;
}
if (typeof value === "string") {
value = { srcUrl: value };
}
if ($SpMgr.enableEnvDropDown) {
that._srcUrl = AppEx.Sports.Services.Utilities.ImageUrlConstructor.updateImageUrlForDev(value.srcUrl);
}
else {
that._srcUrl = value.srcUrl;
}
var resolutionScale = Windows.Graphics.Display.DisplayProperties.resolutionScale;
if (resolutionScale ===  Windows.Graphics.Display.ResolutionScale.scale140Percent || 
resolutionScale === Windows.Graphics.Display.ResolutionScale.scale180Percent){
that._srcUrl = AppEx.Sports.Services.Utilities.ImageUrlConstructor.getDpiSpecificImageUrl(that._srcUrl, resolutionScale);
}
that._imgInfo = that._getImageInfo(that._srcUrl);
that._fallBackUrl = value.fallBackUrl ? value.fallBackUrl : that._imgInfo.fallBackUrl;
if (that._imgInfo.requiresBlocking === true) {
that._srcUrl = that._fallBackUrl;
}
that._alt = value.alt ? value.alt : that._imgInfo.alt;
that.element.setAttribute("aria-label", that._alt);
that._title = value.title ? value.title : that._imgInfo.alt;
that._height = value.height;
that._width = value.width;
if (SportsJS.Utilities.ImgControl.seenUrls[that._srcUrl] === true) {
that._success();
}
else {
var image = new Image();
image.onload = function () { that._success(); };
image.onerror = function () { that._error(); };
image.src = that._srcUrl;
}
}
},
// on success
_success: function _success() {
var that = this;
if (typeof SportsJS.Utilities.ImgControl.seenUrls[that._srcUrl] === "undefined") {
// only increment count once per image
SportsJS.Utilities.ImgControl.seenUrlsCount++;
}
SportsJS.Utilities.ImgControl.seenUrls[that._srcUrl] = true;
that.imageElement.style.backgroundImage = "url('" + that._srcUrl + "')";
that.element.appendChild(that.imageElement);
},
// on error, use the fallBackUrl
_error: function _error() {
if (this._fallBackUrl && this._fallBackUrl !== "") {
var that = this;
that.imageElement.style.backgroundImage = "url('" + this._fallBackUrl + "')";
that.element.appendChild(that.imageElement);
that._fallBackUrl = null;
//// TODO:chthakur. See if we can removeEventListener here
}
},
_getImageInfo: function _getImageInfo(url) {
var imgInfo = AppEx.Sports.Services.Utilities.ImageUrlConstructor.tryGetImageInfoFromImageUrl(url);
return imgInfo;
},
},
{
// detecting the error images and showing canned img is costly. Cache for optimizing the same
// hash, key -> URL, value true/false. true- means url is present in cache, images do not expire for 10 days once cache
// TODO(chthakur)- evaluate if it is ok to push this info to LocalCache(so that it is available across reboots also). Seems too heavy right now
_seenUrls: {},
seenUrls: {
get: function get() {
var imgControl = SportsJS.Utilities.ImgControl;
if (imgControl._seenUrls === null) {
imgControl._seenUrls = {};
}
if (imgControl.seenUrlsCount > imgControl.maxSeenUrls) {
// purge when it exceeds. very basic mechanism
imgControl._seenUrls = {};
SportsJS.Utilities.ImgControl.seenUrlsCount = 0;
}
return imgControl._seenUrls;
},
},
// count of all the visited img ruls
seenUrlsCount: 0,
maxSeenUrls: 500,
}),
getLeagueCmsMappings: function getLeagueCmsMappings(league) {
var leaguepageids = PlatformJS.Services.appConfig.getDictionary("LeagueCmsIDs");
if (leaguepageids && leaguepageids[league]) {
return leaguepageids[league].value;
} else {
// this should be the case for all newly added leagues. We should always get <leagueName>.js endpoint from CMS
return league + ".js";
}
},
getLeagueTileCmsMappings: function getLeagueTileCmsMappings(league) {
var leaguepageids = PlatformJS.Services.appConfig.getDictionary("LeagueTileCmsIDs");
if (leaguepageids && leaguepageids[league]) {
return leaguepageids[league].value;
} else {
// this should be the case for all newly added leagues. We should always get <leagueName>.xml endpoint from CMS
return league + ".xml";
}
},
hasLegendForSport: function hasLegendForSport(sport) {
if (sport && SportsJS.Utilities.isValidLeagueTypeStrict(sport)) {
return true;
}
return false;
},
hasLegendForPage: function hasLegendForPage(pageType) {
if (pageType === SportsJS.UI.PageType.Frame || pageType === SportsJS.UI.PageType.EditorialCollection) {
return false;
}
return true;
},
createDiv: function createDiv(id, role, label) {
var element = document.createElement("div");
if (id) {
element.id = id;
}
if (role) {
element.setAttribute("role", role);
}
if (label) {
element.setAttribute("aria-label", label);
}
return element;
},
getClusterModuleInsidePagePano: function getClusterModuleInsidePagePano(cluster, module) {
var that = this;
if (!module) {
return null;
}
var clusterControl = null;
var clusters = SportsJS.Utilities.getClusterControlsInsidePagePano();
if (!clusters || clusters.length === 0) {
return null;
}
for (var ii = 0; ii < clusters.length; ii++) {
if (clusters[ii] instanceof cluster) {
clusterControl = clusters[ii];
break;
}
}
if (!clusterControl) {
that._trace("SportsJS.Utilities.getClusterModuleInsidePagePano", "Could not get cluster inside page");
return null;
}
if (!clusterControl.submodules || clusterControl.submodules.length === 0) {
return null;
}
var moduleControl = null;
var submodules = clusterControl.submodules;
for (var jj = 0; jj < submodules.length; jj++) {
if (submodules[jj] instanceof module) {
moduleControl = submodules[jj];
break;
}
}
if (!moduleControl) {
that._trace("SportsJS.Utilities.getClusterModuleInsidePagePano", "Could not get module inside cluster");
return null;
}
return moduleControl;
},
isLeagueSoccerType: function isLeagueSoccerType(league) {
var that = this;
return AppEx.Sports.Services.Utils.isSoccerLeague(league);
},
stringCompareIgnoreCase: function stringCompareIgnoreCase(str1, str2) {
return str1.toLowerCase() === str2.toLowerCase();
},
showPlatformMsgBar: function showPlatformMsgBar(msg) {
var that = this;
var msgbar = new CommonJS.MessageBar(msg, { autoHide: true });
var bottomEdgy = document.querySelector(".sportsBottomEdgy");
if (bottomEdgy && bottomEdgy.winControl) {
bottomEdgy.winControl.hide();
}
var topEdgy = document.querySelector("#platformNavigationBar");
if (topEdgy && topEdgy.winControl) {
topEdgy.winControl.hide();
}
var bLabel = PlatformJS.Services.resourceLoader.getString("CloseButtonLabel");
msgbar.addButton(bLabel, function () { msgbar.hide(); });
msgbar.show();
},
// TODO(saarya) - this code doesn't belong to utilities
checkScheduleDataRefreshValidity: function checkScheduleDataRefreshValidity(currentResponse, previousResponse, currentData, previousData) {
var that = this;
if (currentResponse && previousResponse && previousData && currentData) {
if (currentResponse.timeStamp && previousResponse.timeStamp && (currentResponse.timeStamp < previousResponse.timeStamp)) {
return false;
}
for (var currentIndex = 0; currentIndex < currentData.length; currentIndex++) {
for (var previousIndex = 0; previousIndex < previousData.length; previousIndex++) {
if (currentData[currentIndex].gameCode === previousData[previousIndex].gameCode) {
if (SportsJS.Utilities.isValidGameStateTypeIgnoreCase(previousData[previousIndex].status)
&& SportsJS.Utilities.isValidGameStateTypeIgnoreCase(currentData[currentIndex].status)) {
if ((previousData[previousIndex].status.toLowerCase() !== "pre-game" && currentData[currentIndex].status.toLowerCase() === "pre-game")
|| (previousData[previousIndex].status.toLowerCase() === "final" && currentData[currentIndex].status.toLowerCase() !== "final")) {
return false;
}
}
break;
}
}
}
}
return true;
},
isAppStateStale: function isAppStateStale() {
var sessionState = WinJS.Application.sessionState;
var lastSuspendTime = sessionState.lastSuspendTime;
//// In case of app crash/force termination, the lastSuspend time is not saved.
//// In that case, we would let the platform take care. The platform navigates to today page in that case.
if (!lastSuspendTime) {
return false;
}
var currentTime = new Date().getTime();
var timeSinceLastSuspend = currentTime - lastSuspendTime;
var appStateStaleTime = PlatformJS.Services.appConfig.getString("AppStateStaleTime");
var isAppStateStale = timeSinceLastSuspend > appStateStaleTime ? true : false;
return isAppStateStale;
},
getMiddleTierServer: function getMiddleTierServer() {
if ($SpMgr.enableEnvDropDown) {
return SportsJS.SettingsManager.getMiddleTierServer();
}
var serverNameMap = PlatformJS.Services.appConfig.getDictionary("MiddleTierServerEnvironments");
var serverNameKey = PlatformJS.Services.appConfig.getString("DefaultApplicationServerEnvironmentSetting");
var serverName = serverNameMap && serverNameKey && serverNameMap[serverNameKey] && serverNameMap[serverNameKey].value;
if (!serverName) {
SportsJS.Utilities.interfaceException("SportsJS.Utilities.IEStorage", "unable to get middler tier server name");
}
return serverName;
},
getLKGScheduleDate: function getLKGScheduleDate(league, teamid) {
if (!league) {
return null;
}
var scheduleId = teamid ? league + teamid : league;
return $SpMgr.lkgScheduleDatesContainer.values[scheduleId];
},
setLKGScheduleDate: function setLKGScheduleDate(date, league, teamid) {
if (!date || !league) {
return false;
}
var scheduleId = teamid ? league + teamid : league;
$SpMgr.lkgScheduleDatesContainer.values[scheduleId] = date;
},
//// Page visited is set to true first time user visits the page while online.
//// If false, that means we are offline with no cached data for this page.
getPageVisitedStatus: function getPageVisitedStatus(pageId) {
var isPageVisited;
if ($SpMgr.pageVisitedStatusContainer.values[pageId]) {
isPageVisited = true;
}
else if (SportsJS.Networking.isInternetAvailable) {
$SpMgr.pageVisitedStatusContainer.values[pageId] = true;
isPageVisited = true;
}
else {
isPageVisited = false;
}
return isPageVisited;
},
isLegendBlocked: function isLegendBlocked() {
var isBlocked = false;
//// this variable tells us if we should block legend for specified langs
var shouldBlockLegend = SportsJS.Services.ConfigData.shouldBlockLegend();
if (!shouldBlockLegend) {
isBlocked = false;
}
else {
//// get the set of languages for which legend is blocked
var legendBlockedLangs = SportsJS.Services.ConfigData.getLegendBlockedLangs();
var currentLanguage = AppEx.Sports.Services.Utilities.Globalization.getCurrentLanguage().toLowerCase();
var output = legendBlockedLangs.indexOf(currentLanguage);
if (output.returnValue) {
isBlocked = true;
}
else {
isBlocked = false;
}
}
return isBlocked;
},
initCloudPano: function initCloudPano() {
PlatformJS.Navigation.addCloudPanoEntityView("CloudPano");
},
interfaceException: function interfaceException(moduleName, msg) {
if (!PlatformJS.isDebug) {
return;
}
try {
// throwing Error. as this would happen mostly when required fields are not found
throw new Error(moduleName + msg);
} catch (e) {
}
},
unexpectedCodePathException: function unexpectedCodePathException(moduleName, msg) {
if (!PlatformJS.isDebug) {
return;
}
try {
// throwing Error. as this would happen mostly when required fields are not found
throw new Error(moduleName + msg);
} catch (e) {
}
},
isoDateStringToDateObject: function isoDateStringToDateObject(isoDateString) {
var dateObject;
if (isoDateString && typeof isoDateString === "string") {
var time = Date.parse(isoDateString);
if (!isNaN(time)) {
dateObject = new Date(time);
} else {
SportsJS.Utilities.interfaceException("SportsJS.Utilities.JsResponseCache:getObjectAsync", "parsing lastUpdateTime should never result in NaN");
}
}
return dateObject;
},
// UI thread timer (minimalistic version)
// To track time spent in UI thread and control UI thread yielding.
// TODO: arengak/chthakur: extend the approach/find better approach to control UI thread at app wide.
UiThreadTimer: WinJS.Class.define(function uiThreadTimer_constructor(id, options) {
}, {
// max duration (in ms), a task can block UI thread.
_maxDuration: 200,
// time, at which the task acquired (started blocking) UI thread
_lastUiThreadAcquireTime: null,
// reset the timer
reset: function reset() {
this._lastUiThreadAcquireTime = null;
},
// yields UI thread when the task has spent more than the maxDuration of time in UI thread.
getUiThreadReleasePromise: function getUiThreadReleasePromise() {
var that = this;
var p = WinJS.Promise.wrap(true);
that._lastUiThreadAcquireTime = that._lastUiThreadAcquireTime ? that._lastUiThreadAcquireTime : (new Date()).getTime();
var currentTime = (new Date()).getTime();
var duration = currentTime - that._lastUiThreadAcquireTime;
if (duration > that._maxDuration) {
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:UiThreadTimer:timeout,StartTM");
p = WinJS.Promise.timeout();
p.then(function uiThreadTimer_timeoutComplete() {
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:UiThreadTimer:timeout,StopTM");
that._lastUiThreadAcquireTime = (new Date()).getTime();
}, function uiThreadTimer_timeoutError() {
that.reset();
});
}
return p;
}
}),
/// <summary>
/// Wrapper over browser (IE) localStorage
/// </summary>
IEStorage: WinJS.Class.define(
function () {            
},
{
_localStorage: false,
_initLocalStorage: function _initLocalStorage() {
if (this._localStorage) { return; }
try { // accessing localStorage might throw excpetions                
this._localStorage = window['localStorage'];
} catch (e) {
this._localStorage = null;
}
},
addItem: function addItem(key, item) {
this._initLocalStorage();
if (!this._localStorage || !key || !item) { return false; }
try {
this._localStorage.setItem(key, item);
}
catch (e) {
if (e && e.message === "QuotaExceededError") {
// purging all entries as of now
// TODO: try implementing LRU based purging
this.flushCache();
return false;
}
SportsJS.Utilities.interfaceException("SportsJS.Utilities.IEStorage", "unable to cache the data");
return false;
}
return true;
},
getItem: function getItem(key) {
this._initLocalStorage();
if (!this._localStorage || !key) { return null; }
return this._localStorage[key];
},
hasKey: function hasKey(key) {
this._initLocalStorage();
return (this._localStorage && !!this._localStorage[key]);
},
flushCache: function flushCache() {
this._initLocalStorage();
try {             
if (this._localStorage) { this._localStorage.clear(); }
} catch (e) {
this._localStorage = null;
}
}
}),
// JsResponseCache
// Stores response in memory
// selectively push responses to disk based on StoreToDisk value
// Need to support both memory cache & disk cache simultaneosly for reducing the number of changes across
// Storing data at two places is not that costly as we keep referencing the same string in both the caches when it is in memory
// TODO: chthakur - eliminate memory cache entirely.
JsResponseCache: WinJS.Class.define(function (size) {
this._memoryCacheSize = size;
},
{
// size of in memory cache. Disk cache size is specified in AppConfiguration.xml. Look for cache with cacheID "CacheForJSResponses"
_memoryCacheSize: 0,
// cacheId for the disk cache
_cacheId: "CacheForJSResponses",
// Instance of Platform Memory cache
_memoryCacheInstance: null,
_memoryCache: {
get: function get() {
if (!this._memoryCacheInstance) {
this._memoryCacheInstance = new PlatformJS.Utilities.MemoryCache(this._memoryCacheSize);
}
return this._memoryCacheInstance;
}
},
_ieCacheInstance: null,
_ieCache: {
get: function get() {
if (!this._ieCacheInstance) {
this._ieCacheInstance = new SportsJS.Utilities.IEStorage();
}
return this._ieCacheInstance;
}
},
_winSettingCacheInstance: null,
_winSettingCache: {
get: function get() {
if (!this._winSettingCacheInstance) {
this._winSettingCacheInstance = new SportsJS.Utilities.LocalCache(this._cacheId, 20); // max 20 entries in win settings
}
return this._winSettingCacheInstance;
}
},
// Instance of Platform JS CacheService
_diskCacheInstance: null,
_diskCache: {
get: function get() {
if (!this._diskCacheInstance) {
this._diskCacheInstance = PlatformJS.Cache.CacheService.getInstance(this._cacheId);
}
return this._diskCacheInstance;
}
},
// Get the expiry time using meta stored in resObject
// To calculate expiry
// 1. Either maxAge should be there in resObject
// 2. Or, lastUpdateTime & cacheID both should be there in resObject. 
_getObjectExpiry: function _getObjectExpiry(resObject) {
if (!resObject) {
return null;
}
// check if maxAge is not present then can we calculate maxAge from lastUpdateTime and cacheID or not
if ((typeof resObject.maxAge === "undefined" || resObject.maxAge === null) && resObject.cacheID && resObject.lastUpdateTime instanceof Date) {
var cacheDefaultExpiry = AppEx.Sports.Services.SportsController.getCacheDefaultExpiry(resObject.cacheID);
resObject.maxAge = cacheDefaultExpiry - Math.floor(((new Date()).getTime() - resObject.lastUpdateTime.getTime()) / 1000);
}
// maxAge can be zero hence, undefined and null check
if (typeof resObject.maxAge === "undefined" || resObject.maxAge === null) {
SportsJS.Utilities.interfaceException("SportsJS.Utilities.JsResponseCache:_getObjectExpiry", "interface issue while setting expiry ");
return null;
}
var entryExpiresAt = new Date();
var expiry = (new Date()).getTime() + resObject.maxAge * 1000;
entryExpiresAt.setTime(expiry);
return entryExpiresAt;
},
// update the object expiry, based on meta
updateObjectExpiry: function updateObjectExpiry(key, meta, options) {
var that = this;
if (!key || !meta) {
return;
}
this.getObjectAsync(key, options).then(function (resObject) {
if (resObject) {
resObject.lastUpdateTime = meta.lastUpdateTime;
resObject.maxAge = meta.maxAge;
resObject.isStaleResponse = meta.isStaleResponse;
that.addObject(key, resObject, options);
}
});
},
// Add object to the cache
// resObject to be added should have following properties:
// 1. maxAge or lastUpdateTime & cacheID - to help calculate expiry
// 2. etag - unique hash code for the response
// 3. isValid - field indicating whether the response is valid or not
// 4. lastUpdateTime - lastUpdateTime and instance of data for the response.
addObject: function addObject(key, resObject, options) {
// is valid and all ?
if (!resObject || resObject.isValid === false) {
return;
}
var entryExpiresAt = this._getObjectExpiry(resObject);
if (entryExpiresAt) {
resObject.entryExpiresAt = entryExpiresAt;
if (!resObject.etag || typeof resObject.isValid === "undefined" || !(resObject.lastUpdateTime instanceof Date)) {
SportsJS.Utilities.interfaceException("SportsJS.Utilities.JsResponseCache:addObject", "interface issue while adding object");
// violation of add interface, throw exception in debug mode, in prod, just do not store
return;
}
var dataString = SportsJS.Utilities.jsonStringify(resObject);
this.addItem(key, dataString, options);
}
},
// Add item to memory cache. Selectively adds item to disk based on store to disk variable
addItem: function addItem(key, dataString, options) {
var that = this;
if (!key || !dataString) {
return;
}
this._memoryCache.addItem(key, dataString);
if (options && options.storeToDisk === true) {
var storageType = options.storageType ? options.storageType : SportsJS.Consts.storageType.PLATFORM;
setTimeout(function () {
if (storageType === SportsJS.Consts.storageType.IE) {
that._ieCache.addItem(key, dataString);
} else if (storageType === SportsJS.Consts.storageType.WIN_SETTING) {
that._winSettingCache.addItem(key, dataString);
} else if (storageType === SportsJS.Consts.storageType.PLATFORM) {
// we can choose not to clear these
// no hurry storing to disk
// Platform cache write disk is not working very well to write data one after the other quickly
that._diskCache.addEntry(key, dataString);
}
}, 1000);
}
},
// Gets the object stored in cache given the key
getObjectAsync: function getObjectAsync(key, options) {
return this.getItemAsync(key, options).then(function (dataString) {
if (!dataString) { return null;}
var dataObject = SportsJS.Utilities.jsonParse(dataString);
if (dataObject && dataObject.entryExpiresAt) {
var currTS = (new Date()).getTime();
var expiryTS = Date.parse(dataObject.entryExpiresAt);
var tsDiff = currTS - expiryTS;
dataObject.isStaleResponse = (tsDiff > 0) ? true : false;
dataObject.maxAge = Math.round((expiryTS - currTS) / 1000);
} else {
// we definetly do not expect this
SportsJS.Utilities.interfaceException("SportsJS.Utilities.JsResponseCache:getObjectAsync", "Couldn't get response for key <" + key + ">");
dataObject = null;
return dataObject;
}
dataObject.lastUpdateTime = SportsJS.Utilities.isoDateStringToDateObject(dataObject.lastUpdateTime);
return dataObject;
});
},
//getItemAsync - fetches the item in an Async manner. Async API is the only way to get data from diskCache
getItemAsync: function getItemAsync(key, options) {
if (!key) {
return WinJS.Promise.wrap(null);
}
var that = this;
var storageType = (options && options.storageType) ? options.storageType : SportsJS.Consts.storageType.PLATFORM;
// try getting data from InMemoryCache
var dataString = this.getItem(key);
var p = WinJS.Promise.wrap(dataString);
if (storageType === SportsJS.Consts.storageType.IE) {
p = WinJS.Promise.wrap(dataString ? dataString : that._ieCache.getItem(key));
} else if (storageType === SportsJS.Consts.storageType.WIN_SETTING) {
p = WinJS.Promise.wrap(dataString ? dataString : that._winSettingCache.getItem(key));
} else if (storageType === SportsJS.Consts.storageType.PLATFORM) {
if (dataString) {
this._diskCache.findEntry(key); // Helps keep the latest recently used content in disk
p = WinJS.Promise.wrap(dataString);
} else {
p = that._diskCache.findEntry(key).then(function (res) {
return res ? res.dataValue : null;
});
}
}
return p.then(function (resString) {
if (resString) {
that._memoryCache.addItem(key, resString);
}
return resString;
}, function () {
return null;
});
},
// getItem from memory cache
getItem: function getItem(key) {
if (!key) {
return null;
}
return this._memoryCache.getItem(key);
},
flushCache: function flushCache() {
if (this._ieCacheInstance) {
this._ieCacheInstance.flushCache();
this._ieCacheInstance = null;
}
if (this._winSettingCacheInstance) {
this._winSettingCacheInstance.flushCache();
this._winSettingCacheInstance = null;
}
// TODO: arengak - this._diskCacheInstance?? followup with Platform to get flushCache for Platform JS cache if needed.
this._memoryCacheInstance = null;
}
}),
/// <summary>
/// An Local cache with LRU eviction scheme
/// only supports strings upto 4KB, key size less than 256 bytes. 
/// This work without side effects if that is not the case
/// TODO(chthakur): explore alternate backing store. LocalSettings are not perfect for the same
/// </summary>
LocalCache: WinJS.Class.define(
function (id, maxSize) {
/// <summary>
/// Constructor: An in-memory cache with LRU eviction scheme
/// </summary>
/// <param name="maxSize">
/// The maximum size of the cache
/// </param>
this._id = id;
this.maxSize = maxSize;
this._init();
},
{
/// cache id - name of the data container
_id: null,
/// <field>
/// The maximum size of the cache
/// </field>
maxSize: 0,
/// <field>
/// The priority queue
/// </field>
_priorityQueue: null,
/// <field>
/// Lookup table
/// </field>
_lookupTable: null,
_init: function _init() {
this._priorityQueue = [];
this._lookupTable = {};
var containers = Windows.Storage.ApplicationData.current.localSettings.containers;
if (containers.hasKey(this._id)) {
this._lookupTable = containers.lookup(this._id).values;
var keys = Object.keys(this._lookupTable);
for (var kk = 0; kk < keys.length; kk++) {
// on startup LRU is gone. chthakur -> make it more sophisticated if required.
this._priorityQueue.push({ key: keys[kk] });
}
}
else {
var cacheContainer = Windows.Storage.ApplicationData.current.localSettings.createContainer(this._id, Windows.Storage.ApplicationDataCreateDisposition.always);
this._lookupTable = cacheContainer.values;
}
},
_destroy: function _destroy() {
var localSettings = Windows.Storage.ApplicationData.current.localSettings;
var containers = localSettings.containers;
if (containers.hasKey(this._id)) {
localSettings.deleteContainer(this._id);
}
},
flushCache: function flushCache() {
this._destroy();
this._init();
},
addItem: function addItem(key, item) {
/// <summary>
/// Adds an item to the cache
/// </summary>
/// <param name="key">
/// The key of the item
/// </param>
/// <param name="item">
/// The item itself
/// </param>
/// <returns>
/// Nothing
/// </returns>
// Check if the item is valid for storing
if (typeof item === "string") {
if (!key || !item || item.length > 4096 || key.length > 250) {
// do not add if size of string is more than 4KB
return false;
}
} else {
// not supported
return false;
}
var hasKey = !!this.getItem(key);// the output is to be used as a boolean
try {
// prone to key > 256bytes failure, prone to item > 4k failure
this._lookupTable[key] = item;
} catch (e) {
return false;
}
if (!hasKey) {
this._priorityQueue.push({ key: key });
if (this._priorityQueue.length > (this.maxSize - 1)) {
this._lookupTable.remove(this._priorityQueue[0].key);
this._priorityQueue = this._priorityQueue.slice(1);
}
}
return true;
},
getItem: function getItem(key) {
/// <summary>
/// Retrieves an item from the cache
/// </summary>
/// <param name="key">
/// The key of the item
/// </param>
/// <returns>
/// Returns the item or null if it is not found
/// </returns>
if (!this.hasKey(key)) {
return null;
}
var item;
try {
// prone to key > 256bytes failure
item = this._lookupTable[key];
} catch (e) {
return item;
}
if (item) {
for (var i = 0; i < this._priorityQueue.length; i++) {
var entry = this._priorityQueue[i];
if (entry.key === key) {
this._priorityQueue.splice(i, 1);
this._priorityQueue.push(entry);
break;
}
}
}
return item;
},
hasKey: function hasKey(key) {
/// <summary>
/// Retrieves an item from the cache
/// </summary>
/// <param name="key">
/// The key of the item
/// </param>
/// <returns>
/// Returns the item or null if it is not found
/// </returns>
var keyExists = false;
try {
// prone to key > 256bytes failure
keyExists = this._lookupTable.hasKey(key);
} catch (e) {
return false;
}
return keyExists;
},
}),
//// TODO(move this out) - this code doesn't belong here. No business logic in utilities
//// The templates for leading teams and leading players assume 3 entities.
//// In case there are less, we would pad the list with dummy entities
//// Ideally, this should have been done in C#. 
//// But modifying the collection in c# throws exception since responseData is readOnlyArray.
padDummyLeadingEntities: function padDummyLeadingEntities(leadingEntitesList) {
for (var entitiesType in leadingEntitesList) {
var leadingEntites = leadingEntitesList[entitiesType];
var entityKeys = ["entities0", "entities1", "entities2"];
var dummyEntity = SportsJS.Utilities.nativeObjectToJsObject(new Microsoft.AppEx.Sports.Schemas.TypeDefs.LeadingEntityType());
for (var i = 0; i < entityKeys.length; i++) {
var key = entityKeys[i];
if (!leadingEntites[key]) {
leadingEntites[key] = dummyEntity;
}
}
}
},
createDivWithClassName: function createDivWithClassName(className) {
var element = document.createElement('div');
WinJS.Utilities.addClass(element, className);
return element;
},
error: function error(tag, msg) {
if (!tag || !msg || !PlatformJS.isDebug) {
return;
}
throw new Error("[" + tag + "]: " + msg);
},
setTimer: function setTimer(timerId, fn, ctx, timeout) {
if (!fn || !timeout || typeof fn.bind !== 'function') {
return;
}
SportsJS.Utilities.clearTimer(timerId);
timerId = setTimeout(fn.bind(ctx), timeout * 1000);
return timerId;
},
clearTimer: function clearTimer(timerId) {
if (timerId) {
clearTimeout(timerId);
timerId = null;
}
return timerId;
},
dispatchCustomEvent: function dispatchCustomEvent(element, eventName, detail) {
if (!element || !eventName) {
return null;
}
var that = this;
var eventObject = document.createEvent("CustomEvent");
eventObject.initCustomEvent(eventName, true, true, detail ? detail : null);
element.dispatchEvent(eventObject);
},
//// EventListener manager
EventListenerManager: WinJS.Class.define(function (options) {
var that = this;
that._listenerQueue = [];
}, {
_listenerQueue: null,
addEventListener: function addEventListener(element, event, listener, ctx, useCapture) {
var that = this;
if (!element || !event || !listener || !ctx || typeof element.addEventListener !== 'function' || typeof listener.bind !== 'function') {
return false;
}
var listenerBinding = listener.bind(ctx);
element.addEventListener(event, listenerBinding, useCapture ? useCapture : false);
that._listenerQueue.push({
element: element,
event: event,
listener: listener,
listenerBinding: listenerBinding,
});
return true;
},
removeEventListener: function removeEventListener(element, event, listener) {
var that = this;
if (!element || !event || !listener || typeof element.removeEventListener !== 'function') {
return false;
}
for (var i = 0; i < that._listenerQueue.length; i++) {
var evtListener = that._listenerQueue[i];
if (evtListener.element === element && evtListener.event === event && evtListener.listener === listener) {
var listenerBinding = evtListener.listenerBinding;
element.removeEventListener(event, listenerBinding);
that._listenerQueue.splice(i, 1);
}
}
return true;
},
purgeEventListeners: function purgeEventListeners() {
var that = this;
for (var i = 0; i < that._listenerQueue.length; i++) {
var evtListener = that._listenerQueue[i];
evtListener.element.removeEventListener(evtListener.event, evtListener.listenerBinding);
}
},
}, {}),
//// PromiseCancellation manager
PromiseCancellationManager: WinJS.Class.define(function (options) {
var that = this;
that._promiseStack = [];
}, {
_promiseStack: null,
addPromise: function addPromise(promise, isObjectValid) {
var that = this;
if (!promise) {
return promise;
}
if (isObjectValid) {
that._promiseStack = that._promiseStack.concat(SportsJS.Utilities.createPromiseArrayCopy(promise));
} else {
if (Array.isArray(promise)) {
SportsJS.Utilities.cancelPromiseArray(promise);
}
else {
SportsJS.Utilities.cancelPromise(promise);
}
}
return promise;
},
cancelPromises: function cancelPromises() {
var that = this;
SportsJS.Utilities.cancelPromiseArray(that._promiseStack);
},
}),
///// Utility function to extract items from an IListDataSource
getItemsFromIListDataSource: function getItemsFromIListDataSource(listDataSource) {
if (!listDataSource) {
return;
}
var getItemPromises = [];
return listDataSource.getCount().then(function (c) {
for (var i = 0; i < c; i++) {
getItemPromises.push(listDataSource.itemFromIndex(i));
}
return WinJS.Promise.join(getItemPromises);
});
},
//// Utility function to update an IListDataSource with new items.
//// Supports add, delete and update.(only if list is observable)
//// Requirements: Each item should have a unique id to identify it.  Match is id based
////               HashCode is needed for updating. Update only happens if hashCode changed
refreshIListDataSource: function refreshIListDataSource(listDataSource, newItems, isObservable) {
var that = this;
if (!listDataSource || !newItems || newItems.length === 0) {
return WinJS.Promise.wrapError(null);
}
var refreshPromises = [];
listDataSource.beginEdits();
return SportsJS.Utilities.getItemsFromIListDataSource(listDataSource).then(function (oldItems) {
var i, max;
var newItem, result;
/// Remove the items that dont exist anymore, else update if hashcode changed
for (i = 0, max = oldItems.length; i < max; i++) {
var oldItem = oldItems[i];
result = SportsJS.Utilities.tryGetItemIndex(oldItem.data.id, newItems);
if (!result.success) {
return WinJS.Promise.wrapError();
}
var newIndex = result.value;
if (newIndex === -1) {
refreshPromises.push(listDataSource.remove(oldItem.key));
}
else {
if (isObservable) {
newItem = newItems[newIndex];
if (typeof oldItem.data.hashCode !== 'undefined' &&
typeof newItem.hashCode !== 'undefined' &&
oldItem.data.hashCode !== newItem.hashCode) {
SportsJS.Utilities.observableObjectAwareDeepCopy(newItem, oldItem.data);
}
}
}
}
//// Add new items
var previousItemPromise = WinJS.Promise.wrap(null);
for (i = 0, max = newItems.length; i < max; i++) {
newItem = newItems[i];
result = SportsJS.Utilities.tryGetItemIndex(newItem.id, oldItems);
if (!result.success) {
return WinJS.Promise.wrapError();
}
var oldIndex = result.value;
previousItemPromise = previousItemPromise.then(function (previousItem) {
if (oldIndex === -1) {
if (isObservable) {
newItem = WinJS.Binding.as(newItem);
}
if (!previousItem) {
return listDataSource.insertAtStart(null, newItem);
}
else {
return listDataSource.insertAfter(null, newItem, previousItem.key);
}
}
else {
var oldDataItem = oldItems[oldIndex];
return WinJS.Promise.wrap(oldDataItem);
}
});
}
listDataSource.endEdits();
refreshPromises.push(previousItemPromise);
return WinJS.Promise.join(refreshPromises);
});
},
//// Returns the index of an item in a list of items
//// when item has a unique id to identify it
tryGetItemIndex: function tryGetItemIndex(itemId, list) {
var that = this;
var result = { success: false, value: null };
if (!itemId || !list || list.length === 0) {
return result;
}
for (var i = 0, max = list.length; i < max; i++) {
if (list[i].id) {
if (itemId === list[i].id) {
result.success = true;
result.value = i;
return result;
}
}
else if (list[i].data && list[i].data.id) {
if (itemId === list[i].data.id) {
result.success = true;
result.value = i;
return result;
}
}
else {
return result;
}
}
result.success = true;
result.value = -1;
return result;
},
getEditorialArticleInfos: function getEditorialArticleInfos(newsArticles) {
if (!newsArticles || newsArticles.length === 0) {
return null;
}
//// editorialArticleInfos has one property articleInfos which is an array of editorial articleIds to power ArticleReader back/forward buttons.
var editorialArticleInfos = {
articleInfos: []
};
for (var i = 0, imax = newsArticles.length; i < imax; i++) {
var article = newsArticles[i];
if (article.type === "article") {
var articleId = article.contentid ? article.articleid + "/" + article.contentid : article.articleid;
if (articleId) {
editorialArticleInfos.articleInfos.push({
articleId: articleId,
});
}
}
}
if (editorialArticleInfos.articleInfos.length === 0) {
return null;
}
return editorialArticleInfos;
},
decorateEditorialInfoWithAdsInfo: function decorateEditorialInfoWithAdsInfo(editorialArticleInfos) {
if (!editorialArticleInfos || !editorialArticleInfos.articleInfos) {
return null;
};
var editorialArticleInfosWithAds = {
articleInfos: []
};
for (var i = 0, imax = editorialArticleInfos.articleInfos.length; i < imax; i++) {
var articleInfo = editorialArticleInfos.articleInfos[i];
var articleId = editorialArticleInfos.articleInfos[i].articleId;
editorialArticleInfosWithAds.articleInfos.push({
articleId: articleId,
});
}
if (editorialArticleInfosWithAds.articleInfos.length === 0) {
return null;
}
var articleReaderAdConfig = SportsJS.Utilities.getArticleReaderAdsConfig();
var adConfig = PlatformJS.Services.appConfig.getDictionary("Ads2");
var applicationId = (adConfig && adConfig.ApplicationID) ? adConfig.ApplicationID.value : "";
PlatformJS.Utilities.annotateArticleInfosWithAdInfo(editorialArticleInfosWithAds.articleInfos, articleReaderAdConfig, applicationId);
return editorialArticleInfosWithAds;
},
getEditorialArticleInfoWithAds: function getEditorialArticleInfoWithAds(newsArticles) {
var editorialArticleInfo = SportsJS.Utilities.getEditorialArticleInfos(newsArticles);
var editorialArticleInfoWithAds = SportsJS.Utilities.decorateEditorialInfoWithAdsInfo(editorialArticleInfo);
if (!editorialArticleInfo || !editorialArticleInfo.articleInfos || editorialArticleInfo.articleInfos.length === 0) {
return null;
}
return editorialArticleInfoWithAds;
},
setClusterArticles: function setClusterArticles(newsArticles) {
var editorialArticleInfos = SportsJS.Utilities.getEditorialArticleInfoWithAds(newsArticles);
if (!editorialArticleInfos || !newsArticles) {
return;
}
for (var ii = 0, iimax = newsArticles.length; ii < iimax; ii++) {
newsArticles[ii].clusterArticles = editorialArticleInfos;
}
},
getArticleReaderAdsConfig: function getArticleReaderAdsConfig() {
var articleAdConfigString = PlatformJS.Services.configuration.getDictionary("Ads2").getString("ArticleReaderAdConfig");
if (articleAdConfigString) {
try {
return JSON.parse(articleAdConfigString);
} catch (e) {
return null;
}
}
return null;
},
_findArticleReaderAdConfigById: function _findArticleReaderAdConfigById(articleReaderAdConfigs, adName) {
for (var i = 0, configLength = articleReaderAdConfigs.length; i < configLength; i++) {
if (articleReaderAdConfigs[i] && articleReaderAdConfigs[i].ID.value === adName) {
return articleReaderAdConfigs[i];
}
}
return null;
},
getArticleAdDetails: function getArticleAdDetails(adConfig) {
if (!adConfig || !adConfig.AdUnitID || !adConfig.AdType) {
return null;
}
var articleReaderAdConfig = { type: adConfig.AdType.value, adUnitId: adConfig.AdUnitID };
return articleReaderAdConfig;
},
getEditorialCollectionId: function getEditorialCollectionId(leagueName, editorialCollectionType, entityType, entityId, isUniqueEndpoint) {
var that = this;
var sportsEntityType = SportsJS.UI.EntityType;
if (!SportsJS.Utilities.isValidLeague(leagueName)
|| !AppEx.Sports.Services.Utils.isValidEditorialCollectionType(editorialCollectionType)
|| !SportsJS.Utilities.isValidSportsEntityType(entityType)) {
return null;
}
var collectionId = "";
switch (entityType) {
case sportsEntityType.Today:
collectionId += entityType;
break;
case sportsEntityType.League:
var endpoint = SportsJS.Utilities.getLeagueCmsMappings(leagueName);
if (!endpoint || endpoint.indexOf(".") === -1) {
return null;
}
collectionId += endpoint.slice(0, endpoint.indexOf("."));
break;
case sportsEntityType.Team:
case sportsEntityType.Player:
if (!entityId) {
return null;
}
collectionId += leagueName + "_" + entityType + "_" + entityId;
break;
case sportsEntityType.Match:
//// Currently, we dont have game specific preview recap endpoints, hence not appending entityType and entityId
if (editorialCollectionType === AppEx.Sports.Services.TypeDefs.EditorialCollectionType.preview || editorialCollectionType === AppEx.Sports.Services.TypeDefs.EditorialCollectionType.recap) {
collectionId += leagueName;
}
else {
if (!entityId) {
return null;
}
collectionId += leagueName + "_" + entityType + "_" + entityId;
}
break;
default:
return null;
}
if (isUniqueEndpoint) {
if (typeof editorialCollectionType !== "string") {
editorialCollectionType = $SpMgr.enumStrings.EditorialCollectionType[editorialCollectionType];
}
collectionId += editorialCollectionType;
}
return collectionId;
},
createArticleReaderOptions: function createArticleReaderOptions(articleId, contentId, source, page, market, clusterArticles) {
if (articleId) {
if (contentId) {
articleId = articleId + '/' + contentId;
}
var providerType = "AppEx.Common.ArticleReader.BedrockArticleProvider";
var providerConfiguration = PlatformJS.Collections.createStringDictionary();
// if it is preview data then call the non caching bedrock article service
if ($SpMgr.cmsPreviewEnabled) {
providerConfiguration.insert("queryServiceId", "RenderProxy_BedrockArticlesNoCache");
providerConfiguration.insert("fallbackQueryServiceId", "BedrockArticlesNoCache");
} else {
providerConfiguration.insert("queryServiceId", "RenderProxy_BedrockArticles");
providerConfiguration.insert("fallbackQueryServiceId", "BedrockArticles");
}
var mkt = market ? market.toLowerCase() : AppEx.Sports.Services.Utilities.Globalization.getCurrentMarket().toLowerCase();
providerConfiguration.insert("market", mkt);
providerConfiguration.insert("articleId", articleId);
if (clusterArticles) {
providerConfiguration.insert("articleInfos", SportsJS.Utilities.jsonStringify(clusterArticles));
}
//// Article reader has a light background
CommonJS.setTheme("", false);
try {
return {
providerType: providerType,
providerConfiguration: providerConfiguration,
initialArticleId: articleId,
market: mkt,
source: source,
page: page,
enableSharing: true,
};
}
catch (e) {
console.log(e);
}
}
},
removeDuplicateArticles: function removeDuplicateArticles(articles) {
var articleList = [], temp = [];
for (var i = 0; i < articles.length; i++) {
if (temp[articles[i].articleId] !== 1) {
temp[articles[i].articleId] = 1;
articleList.push(articles[i]);
}
}
return articleList;
},
launchArticle: function launchArticle(articleId, contentId, source, page, clusterArticles, market) {
if (clusterArticles && clusterArticles.articleInfos) {
clusterArticles.articleInfos = SportsJS.Utilities.removeDuplicateArticles(clusterArticles.articleInfos);
}
var state = SportsJS.Utilities.createArticleReaderOptions(articleId, contentId, source, page, market, clusterArticles);
if (state) {
PlatformJS.Navigation.navigateToChannel("ArticleReader", state);
}
},
ParseTextNodesWorker: function ParseTextNodesWorker(node) {
var that = this;
var nodeText = "";
if (node) {
if (node.nodeType === 3) {
nodeText = node.data;
} else if (node.nodeType === 1 && node.childNodes) {
var nodeTagName = node.tagName.toUpperCase();
if (!(nodeTagName === 'SCRIPT') && !(nodeTagName === 'STYLE')) {
for (var i = 0; i < node.childNodes.length; i++) {
nodeText = nodeText + SportsJS.Utilities.ParseTextNodesWorker(node.childNodes[i]);
}
}
}
}
return nodeText;
},
ParseTextNodes: function ParseTextNodes(root) {
return SportsJS.Utilities.ParseTextNodesWorker(root.body);
},
ExtractHtmlText: function ExtractHtmlText(node) {
if (node) {
node = node.replace(/<[^<]*?>/g, "");
node = node.replace(/&nbsp;/g, " ");
node = node.replace(/&[a-zA-Z]*?;/g, "");
node = node.replace(/\s+/g, " ");
} else {
node = "";
}
return node;
},
isGlyphUri: function isGlyphUri(uriStr) {
if (uriStr && uriStr.indexOf("bingappex://") === 0) {
return true;
}
return false;
},
getGlyphFromUri: function getGlyphFromUri(uriStr) {
if (uriStr && uriStr.indexOf("bingappex://") === 0) {
return uriStr.replace("bingappex://", "");
}
return "";
},
/// <summary>
/// returns true if the 2 game dates are equal, false otherwise
/// </summary>
PreviewRecapTryIsGameTimeEqual: function PreviewRecapTryIsGameTimeEqual(league, time1, time2) {
var response = {
success: false,
value: null,
};
if (league === $SpMgr.getLeagueString(Microsoft.AppEx.Sports.SportsEnums.League.nfl)) {
if (isNaN(time1)
|| isNaN(time2)) {
return response;
}
response.success = true;
if (time1 === time2) {
response.value = true;
}
else {
response.value = false;
}
return response;
}
else {
if (!SportsJS.DateTimeHelpers.isValidDate(time1)
|| !SportsJS.DateTimeHelpers.isValidDate(time2)) {
return response;
}
response.success = true;
if (time1.getDate() === time2.getDate()
&& time1.getMonth() === time2.getMonth()
&& time1.getFullYear() === time2.getFullYear()) {
response.value = true;
}
else {
response.value = false;
}
return response;
}
}
});
WinJS.Namespace.define("SportsJS.Convertors", {
display: WinJS.Binding.converter(function (flag) {
if (flag === true) {
return "block";
}
else if (flag === false) {
return "none";
}
// other case do not modify the property
})
});
WinJS.Namespace.define("SportsJS.DateTimeHelpers", {
millisecondsInMinute: 60 * 1000,
millisecondsInHour: 60 * 60 * 1000,
etTimeZoneOffset: -5, //// UTC - 5
getCurrentDateinET: function getCurrentDateinET(league, noAdjustment) {
var that = this;
var adjustmentBuffer = -2; //// We dont want to update till 2:00 am ET
var localDate = new Date();
var localTimeZoneOffset = localDate.getTimezoneOffset();
var utc = localDate.getTime() + localTimeZoneOffset * that.millisecondsInMinute;
var ETDate;
if (noAdjustment) {
ETDate = new Date(utc + that.etTimeZoneOffset * that.millisecondsInHour);
}
else {
ETDate = new Date(utc + that.etTimeZoneOffset * that.millisecondsInHour + adjustmentBuffer * that.millisecondsInHour);
}
return ETDate;
},
// This function returns a string date in format expected by backend which is yyyy-m-d
formatDateAsPerBackend: function formatDateAsPerBackend(date) {
var that = this;
var formattedDate = null;
if (!that.isValidDate(date)) {
return formattedDate;
}
var year = date.getFullYear();
var month = date.getMonth() + 1; // javascript returns month from 0-11
var dateVal = date.getDate();
formattedDate = year + "-" + month + "-" + dateVal;
return formattedDate;
},
//// bdiTime is UTC Time in 100 nanosecond intervals since midnight of 1601/1/1
convertBdiTimeToETDate: function convertBdiTimeToETDate(bdiTime) {
var that = this;
if (!bdiTime) {
return null;
}
var bdiTimeEpoch = (bdiTime / 10000) + CommonJS.Utils._bdiTimeOriginEpoch;
var localDate = new Date();
var localOffset = localDate.getTimezoneOffset() * that.millisecondsInMinute;
var ETOffset = that.etTimeZoneOffset * that.millisecondsInHour;
var ETDate = new Date(bdiTimeEpoch + localOffset + ETOffset);
localDate = that.convertETDateToLocalDate(ETDate);
return ETDate;
},
convertETDateToLocalDate: function convertETDateToLocalDate(ETDate) {
var that = this;
if (!that.isValidDate(ETDate)) {
return null;
}
var utcTime = ETDate.getTime() - that.etTimeZoneOffset * that.millisecondsInHour;
var localDate = new Date();
//// Timezone offset is positive if the place is behind UTC
var localTimeZoneOffset = localDate.getTimezoneOffset();
var localTime = utcTime - localTimeZoneOffset * that.millisecondsInMinute;
return new Date(localTime);
},
isValidDate: function isValidDate(date) {
return date && Object.prototype.toString.call(date) === "[object Date]" && !isNaN(date.getTime());
},
});
WinJS.Namespace.define("SportsJS.Instrumentation", {
//This namespace is depricated. Use SportsJS.Telemetry
incrementDataPointId: function incrementDataPointId(dataPointId, incrementBy) {
incrementBy = incrementBy || 1;
var datasetId = PlatformJS.Services.appConfig.getDictionary("Instrumentation").getInt32("DataSetID");
if (datasetId !== 0 && dataPointId) {
PlatformJS.Services.instrumentation.incrementInt32(datasetId, dataPointId, incrementBy);
}
else {
SportsJS.Utilities.trace("Either the datasetId is not added in the appconfigurtion or invalid datapoint: " + dataPointId);
}
},
incrementInt32: function incrementInt32(datapoint, incrementBy) {
incrementBy = incrementBy || 1;
var datasetId = PlatformJS.Services.appConfig.getDictionary("Instrumentation").getInt32("DataSetID");
var dataPointId = PlatformJS.Services.appConfig.getDictionary("Instrumentation").getDictionary("DataPoints").getInt32(datapoint);
if (datasetId !== 0 && dataPointId !== 0) {
PlatformJS.Services.instrumentation.incrementInt32(datasetId, dataPointId, incrementBy);
}
else {
SportsJS.Utilities.trace("Either the datasetId is not added in the appconfigurtion or invalid datapoint: " + datapoint);
}
}
});
// TODO: chthakur -> v-krpr
// Ideally we should not have ECV utilities here. But the kind of dependency these configs have with clusterconfigs is making it impossible to load ECV utilities in ECV fragments only
WinJS.Namespace.define("SportsJS.Utilities.ECV",
{
//// adds the given css class to the loaded fragment's div element
addLeagueClass: function addLeagueClass(leagueClassName) {
var leagueNode = document.querySelector(".fragment");
leagueNode.className += " " + leagueClassName;
},
//// returns the class needs to be applied on the ECV fragment's root to set the background
getLeagueClass: function getLeagueClass(leagueName) {
return SportsJS.Utilities.isValidLeagueTypeStrict(leagueName) ? leagueName : $SpMgr.getLeagueString(Microsoft.AppEx.Sports.SportsEnums.League.nfl);
},
handleTileSelection: function handleTileSelection() {
var that = this;
if ((that.entityType === SportsJS.UI.EntityType.Team) ||
(that.item.data.status === SportsJS.UI.DataStatusType.NoData)) {
return;
}
var eventObject = that.eventObject;
var item = that.item;
var league = "";
//// preparing state object and config required by ECV controller to navigate to Leading Teams ECV                 
if (item && item.data && item.data.entityType === "Team") {
if (!PlatformJS.Services.appConfig.getDictionary("ECVConfig").getBool("IsLeadingTeamsECVEnabled")) {
return;
}
}
else if (item && item.data && item.data.entityType === "Player") {
if (!PlatformJS.Services.appConfig.getDictionary("ECVConfig").getBool("IsLeadingPlayersECVEnabled")) {
return;
}
}
var ecvData = {
isECV: true,
statType: item.data.statType,
type: item.data.entityType,
league: this.league,
conference: this._options.conference
};
var pageInfo = SportsJS.Utilities.ECV.getEcvInvokeInfo(league, ecvData);
if (ecvData.type === SportsJS.UI.ecvType.TeamRoster) {
SportsJS.Shared.Promises.Team.teamBio(league, ecvData.teamId).then(function (teamInfo) {
pageInfo.pageArgs.title = teamInfo && teamInfo.fullteamname ? SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("TeamRosterTitle"), teamInfo.fullteamname) : league;
PlatformJS.Navigation.navigateToChannel(pageInfo.channelId, pageInfo.state);
});
} else {
PlatformJS.Navigation.navigateToChannel(pageInfo.channelId, pageInfo.state);
}
},
//// handles header selection for leading player & Leading Team for all leagues.
getEcvNavigationInfo: function getEcvNavigationInfo(league, params) {
var that = this;
if (!league || !params || (!params.type && !params.ecvtype)) {
SportsJS.Utilities.interfaceException("getEcvNavigationInfo", "mandatory fields missing from configuration");
return;
}
params.type = params.type ? params.type : params.ecvtype;
params.statType = "default_1";
return SportsJS.Utilities.ECV.getEcvInvokeInfo(league, params);
},
getEcvInvokeInfo: function getEcvInvokeInfo(league, ecvData) {
var title, state;
var channelId = "";
var pageArgs;
var leagueClass = SportsJS.Utilities.ECV.getLeagueClass(ecvData.league);
if (ecvData.type === "Team" || ecvData.type === SportsJS.UI.ecvType.LeagueTeams) {
title = SportsJS.Utilities.getClusterTitle("LeagueLeadingTeamFormat", ecvData.league, ecvData.conference, true);
state = SportsJS.Utilities.ECV.getState(ecvData);
channelId = 'LeagueTeamsECV';
pageArgs = {
title: title,
class: "SportsJS.Common.ECV.LeagueTeamsCollection",
key: { league: ecvData.league, leagueClass: leagueClass, label: PlatformJS.Services.resourceLoader.getString("LeagueTeamsECVLabel") },
state: state
};
}
else if (ecvData.type === SportsJS.UI.ecvType.LeagueSchedule) {
title = PlatformJS.Services.resourceLoader.getString("LeagueScheduleECVLabel");
state = SportsJS.Utilities.ECV.getState(ecvData);
channelId = 'LeagueSchedulesECV';
pageArgs = {
title: title,
class: "SportsJS.Common.ECV.SchedulesECVCollection",
key: { league: ecvData.league, leagueClass: leagueClass, label: PlatformJS.Services.resourceLoader.getString("LeagueScheduleECVLabel") },
state: state
};
} if (ecvData.type === "StandingsECV" || ecvData.type === SportsJS.UI.ecvType.LeagueStandings) {
title = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("ECVTitle_LeagueStanding"), SportsJS.Utilities.getLocLeagueDisplayText(ecvData.league));
state = SportsJS.Utilities.ECV.getState(ecvData);
channelId = 'StandingsECV';
pageArgs = {
title: title,
class: "SportsJS.Common.ECV.StandingsECVCollection",
key: { league: ecvData.league, label: title, leagueClass: leagueClass },
state: state
};
} else if (ecvData.type === "Player" || ecvData.type === SportsJS.UI.ecvType.LeaguePlayers) {
title = SportsJS.Utilities.getClusterTitle("TitleLeadingPlayers", ecvData.league, ecvData.conference, true);
state = SportsJS.Utilities.ECV.getState(ecvData);
channelId = 'LeaguePlayersECV';
pageArgs = {
title: title,
class: "SportsJS.Common.ECV.LeaguePlayersCollection",
key: { league: ecvData.league, leagueClass: leagueClass, label: PlatformJS.Services.resourceLoader.getString("LeaguePlayers") },
state: state
};
} else if (ecvData.type === "TeamRosterECV" || ecvData.type === SportsJS.UI.ecvType.TeamRoster) {
var teamId = ecvData.teamid;
if (!teamId) {
return;
}
state = SportsJS.Utilities.ECV.getState(ecvData);
channelId = 'TeamRosterECV';
pageArgs = {
title: league,
class: "SportsJS.Common.ECV.TeamRosterCollection",
key: { league: league, leagueClass: leagueClass, label: PlatformJS.Services.resourceLoader.getString("TeamRosterECVLabel") },
state: state
};
}
return { channelId: channelId, state: pageArgs};
},
getState: function getState(ecvData) {
if (!ecvData) {
return {};
}
var state = {
statType: ecvData.statType,
league: ecvData.league,
leagueType: ecvData.league,
conference: ecvData.conference
};
var type = ecvData.type;
if (type === "Team" || type === SportsJS.UI.ecvType.LeagueTeams) {
state.label = PlatformJS.Services.resourceLoader.getString("LeagueTeamsECVLabel");
}
else if (type === SportsJS.UI.ecvType.LeagueSchedule) {
state.label = PlatformJS.Services.resourceLoader.getString("LeagueScheduleECVLabel");
} else if (type === "Player" || type === SportsJS.UI.ecvType.LeaguePlayers) {
state.label = PlatformJS.Services.resourceLoader.getString("LeaguePlayers");
} else if (type === "StandingsECV" || type === SportsJS.UI.ecvType.LeagueStandings) {
state.label = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("ECVTitle_LeagueStanding"), SportsJS.Utilities.getLocLeagueDisplayText(ecvData.league));
} else if (type === SportsJS.UI.ecvType.TeamRoster) {
state.label = PlatformJS.Services.resourceLoader.getString("TeamRosterECVLabel");
state.teamid = ecvData.teamid;
} else {
state.label = "";
}
return state;
},
//// Handles the adding bottom edgy Glossary button in all ECVs.
//// TODO: V-krpr: same function used in Sportsbasepage.js. Need to make it common.
addButtonInBottomEdgy: function addButtonInBottomEdgy(buttonData) {
if (!buttonData.title || !buttonData.onclick || !buttonData.className) {
return;
}
var buttonControl = new WinJS.UI.AppBarCommand(null, {
label: buttonData.title,
onclick: buttonData.onclick,
icon: buttonData.icon ? buttonData.icon : null,
extraClass: "appexSymbol",
});
if (!buttonControl) {
return;
}
WinJS.Utilities.addClass(buttonControl.element, buttonData.className);
var appBar = document.querySelector('.entityappbar');
if (!appBar) {
return;
}
appBar.appendChild(buttonControl.element);
},
//// Handles the adding bottom edgy Glossary button in all ECVs.
//// TODO: V-krpr: same function used in Sportsbasepage.js. Need to make it common.
addLegendButtonToBottomEdgy: function addLegendButtonToBottomEdgy(config) {
if (SportsJS.Utilities.isLegendBlocked()) {
return;
}
var legendButtonData = {
title: PlatformJS.Services.resourceLoader.getString("LegendButtonLabel"),
icon: SportsJS.UI.IconType.glossary,
onclick: SportsJS.Utilities.ECV._showLegend.bind(config),
className: "glossaryBtn",
// TODO: arengak->v-krpr  same function used in Sportsbasepage.js. Need to make it common.
buttonId: "ECVLegendButton",
};
SportsJS.Utilities.ECV.addButtonInBottomEdgy(legendButtonData);
},
/// <summary>
/// This function is invoked by the UX Framework when the Glossary button is pressed in bottom edgy
/// </summary>
/// <param name="event">
/// The event information to invoke the Glossary legend
/// </param>
/// <returns>
/// None
/// </returns>
/// TODO: V-krpr: same function used in Sportsbasepage.js. Need to make it common.
_showLegend: function _showLegend(event) {
var that = this;
that.leagueType = this.league;
if (!event || !event.srcElement || !that.leagueType) {
return;
}
WinJS.UI.Fragments.cache("/sportsLegend/sportsLegend.html").then(function () {
var legendFlyout = new SportsJS.UI.LegendFlyout(null, { leagueType: that.leagueType });
legendFlyout.show(event.srcElement, "top");
}, function () {
// do nothing
});
},
addHelpButtonToBottomEdgy: function addHelpButtonToBottomEdgy(config) {
var uri = PlatformJS.Services.appConfig.getString("HelpURL");
if (!uri) {
// do not add button if URI is not configured
return;
}
var helpButtonData = {
title: PlatformJS.Services.resourceLoader.getString("AppHelp"),
icon: SportsJS.UI.IconType.help,
onclick: SportsJS.Utilities.ECV._showHelp.bind(config),
className: "helpBtn",
//TODO: arengak->v-krpr  same function used in Sportsbasepage.js. Need to make it common.
buttonId: "HelpButton"
};
SportsJS.Utilities.ECV.addButtonInBottomEdgy(helpButtonData);
},
// navigates user to help url
_showHelp: function _showHelp(event) {
if (!event || !event.srcElement) {
return;
}
try {
var uri = PlatformJS.Services.appConfig.getString("HelpURL");
PlatformJS.Navigation.navigateTo(uri);
} catch (e) {
//eat up
}
}
});
WinJS.Namespace.define("SportsJS.Controls",
{
/// <summary>
/// BottomEdgyButton base class. Encapsulates some buttomEdgy specific functionalities
/// </summary>
BottomEdgyButton: WinJS.Class.derive(WinJS.UI.AppBarCommand, function (element, options) {
var buttonData = options;
if (!buttonData || !buttonData.title) {
SportsJS.Utilities.interfaceException("SportsJS.Controls.BottomEdgyButton", "buttonData is missing mandatory properties");
return;
}
WinJS.UI.AppBarCommand.call(this, element, {
label: buttonData.title,
onclick: buttonData.onclick ? buttonData.onclick : null,
icon: buttonData.icon ? buttonData.icon : null,
extraClass: "appexSymbol",
});
if (buttonData.className) {
WinJS.Utilities.addClass(this.element, buttonData.className);
}
this.position = buttonData.position;
this.beforeShow = buttonData.beforeShow;
this.placement = buttonData.placement;
this.refreshCallBack = buttonData.refreshCallBack;
var automationId = options && options.buttonId;
SportsJS.Utilities.setAutomationId(this.element, SportsJS.UI.AutomationComponentType.BottomEdgyButton, automationId);
}, {
// specifies the position where the button should go in bottom Edgy
position: null,
// gets called when the button is before the button is visible
beforeShow: null,
// specifies the placement option for buttom in the bottom edgy, Left/Right
placement: null,
// gets called when the edgy is refreshed
refreshCallBack: null,
// Cleanup.
cleanUp: function cleanUp() {
// do nothing.
}
}),
});
WinJS.Namespace.define("SportsJS.Controls",
{
/// <summary>
/// EntityCollectionModuleBottomEdgyButton class. Discovers Entity collection Module Control in the current page
/// </summary>
ECMBottomEdgyButton: WinJS.Class.derive(SportsJS.Controls.BottomEdgyButton, function (element, options, entityActionBar) {
options.refreshCallBack = this.refreshButton.bind(this);
SportsJS.Controls.BottomEdgyButton.call(this, element, options);
this.entityActionBar = entityActionBar;
}, {
_entityActionBar: null,
entityActionBar: {
get: function get() {
return this._entityActionBar;
},
set: function set(value) {
var that = this;
if (that._entityActionBar || !value) {
return;
}
that._entityActionBar = value;
}
},
_entityCollectionModule: null,
_isHidden: false,
entityCollectionModule: {
get: function get() {
var that = this;
//TODO : we can have league/player entitycollectionmodules also and they have to be handled in future. Then this func should return a list of ecms or one as the case may be.
if (!that._entityCollectionModule) {
if (typeof SportsJS.Common.Clusters !== "undefined" &&
typeof SportsJS.Common.Modules !== "undefined" &&
typeof SportsJS.Common.Clusters.MyTeamsClusterControl !== "undefined" &&
typeof SportsJS.Common.Modules.MyTeamsModuleControl !== "undefined") {
that._entityCollectionModule = SportsJS.Utilities.getClusterModuleInsidePagePano(SportsJS.Common.Clusters.MyTeamsClusterControl, SportsJS.Common.Modules.MyTeamsModuleControl);
}
}
return that._entityCollectionModule;
}
},
//TODO - do general stuff here
updateButton: function updateButton() {
},
//TODO - do general stuff here
refreshButton: function refreshButton() {
this._entityCollectionModule = null;
},
getNumSelectedListViewItems: function getNumSelectedListViewItems() {
var that = this;
// use this to get the overall number of selectedviewitems
// for now, only returning for one
if (!that.entityCollectionModule) {
return 0;
}
else {
return that.entityCollectionModule.numSelectedListViewItems;
}
},
showHideButton: function showHideButton(show) {
if (!this.element) {
return;
}
if (show) {
this.element.style.display = "inline-block";
this._isHidden = false;
}
else {
this.element.style.display = "none";
this._isHidden = true;
}
},
isHidden: {
get: function get() {
return this._isHidden;
}
},
})
});
WinJS.Namespace.define("SportsJS.Controls",
{
/// <summary>
/// AddECMBottomEdgyButton class. Provides add button for bottomEdgy for pages with an entity collection Module Control
/// </summary>
AddECMBottomEdgyButton: WinJS.Class.derive(SportsJS.Controls.ECMBottomEdgyButton, function (entityActionBar) {
var addButtonData = {
title: PlatformJS.Services.resourceLoader.getString("AddButtonTitle"),
icon: SportsJS.UI.IconType.add,
onclick: this._addButtonClickHandler.bind(this),
beforeShow: this.updateButton.bind(this),
className: "addButton",
placement: "left"
};
SportsJS.Controls.ECMBottomEdgyButton.call(this, null, addButtonData, entityActionBar);
this.showHideButton(true);
}, {
updateButton: function updateButton() {
if (this.getNumSelectedListViewItems() === 0) {
this.showHideButton(true);
}
else {
this.showHideButton(false);
}
},
_addButtonClickHandler: function _addButtonClickHandler(event) {
var that = this;
if (that.entityCollectionModule) {
that.entityCollectionModule.showEntitySearchUI();
}
}
}),
/// <summary>
/// ClearECMBottomEdgyButton class. Provides clear button for bottomEdgy for pages with an entity collection Module Control
/// </summary>
ClearECMBottomEdgyButton: WinJS.Class.derive(SportsJS.Controls.ECMBottomEdgyButton, function (entityActionBar) {
var clearButtonData = {
title: PlatformJS.Services.resourceLoader.getString("ClearButtonTitle"),
icon: SportsJS.UI.IconType.clear,
onclick: this._clearButtonClickHandler.bind(this),
beforeShow: this.updateButton.bind(this),
className: "clearButton",
placement: "left"
};
SportsJS.Controls.ECMBottomEdgyButton.call(this, null, clearButtonData, entityActionBar);
this.showHideButton(false);
}, {
updateButton: function updateButton() {
if (this.getNumSelectedListViewItems() > 1) {
this.showHideButton(true);
}
else {
this.showHideButton(false);
}
},
_clearButtonClickHandler: function _clearButtonClickHandler(event) {
var that = this;
// TODO: get list of all entityCollectionModules and clear all selections in the page
if (that.entityCollectionModule) {
that.entityCollectionModule.clearEntitiesSelection(event);
}
}
}),
/// <summary>
/// RemoveBottomEdgyButton class. Provides remove button for bottomEdgy for pages with an entity collection Module Control
/// </summary>
RemoveECMBottomEdgyButton: WinJS.Class.derive(SportsJS.Controls.ECMBottomEdgyButton, function (entityActionBar) {
var removeButtonData = {
title: PlatformJS.Services.resourceLoader.getString("RemoveButtonTitle"),
icon: SportsJS.UI.IconType.remove,
onclick: this._removeButtonClickHandler.bind(this),
beforeShow: this.updateButton.bind(this),
className: "removeButton",
placement: "left"
};
SportsJS.Controls.ECMBottomEdgyButton.call(this, null, removeButtonData, entityActionBar);
this.showHideButton(false);
}, {
updateButton: function updateButton() {
if (this.getNumSelectedListViewItems() > 0) {
this.showHideButton(true);
}
else {
if (this.entityActionBar && !this.entityActionBar.hidden) {
this.entityActionBar.sticky = false;
this.entityActionBar.hide();
}
else {
this.showHideButton(false);
}
}
},
_removeButtonClickHandler: function _removeButtonClickHandler(event) {
var that = this;
if (that.entityCollectionModule) {
that.entityCollectionModule.removeEntitiesFromCollection(event);
}
}
}),
/// <summary>
/// LegendBottomEdgyButton class. Provides Lengend button for bottomEdgy
/// </summary>
LegendBottomEdgyButton: WinJS.Class.derive(SportsJS.Controls.BottomEdgyButton, function (element, options) {
var that = this;
if (!options || !options.sportsType) {
SportsJS.Utilities.interfaceException("SportsJS.Controls.LegendBottomEdgyButton", "constructor options is missing one or more mandatory properties");
return;
}
that._sportsType = options.sportsType;
var legendButtonData = {
title: PlatformJS.Services.resourceLoader.getString("LegendButtonLabel"),
icon: SportsJS.UI.IconType.glossary,
onclick: that._showLegend.bind(this),
className: "glossaryBtn",
buttonId: that._sportsType + "LegendButton"
};
SportsJS.Controls.BottomEdgyButton.call(this, element, legendButtonData);
}, {
_sportsType: null,
_showLegendPromise: null,
/// <summary>
/// ShowLegend flyout
/// </summary>
_showLegend: function _showLegend(event) {
var that = this;
SportsJS.Telemetry.logAppBarClick(SportsJS.Telemetry.ElementType.Glossary);
var sportsType = that._sportsType;
if (!event || !event.srcElement) {
return;
}
that._showLegendPromise = WinJS.UI.Fragments.cache("/sportsLegend/sportsLegend.html").then(function () {
var legendFlyout = new SportsJS.UI.LegendFlyout(null, { leagueType: sportsType });
return legendFlyout.show(event.srcElement, "top");
}, function () {
// do nothing
});
},
cleanUp: function cleanUp() {
var that = this;
SportsJS.Utilities.cancelPromise(this._showLegendPromise);
}
}),
/// <summary>
/// RefreshBottomEdgyButton class. Provides refresh button for bottomEdgy
/// </summary>
RefreshBottomEdgyButton: WinJS.Class.derive(SportsJS.Controls.BottomEdgyButton, function (element, options) {
var that = this;
if (!options || !options.refreshCallBack || typeof options.refreshCallBack !== "function") {
SportsJS.Utilities.interfaceException("SportsJS.Controls.RefreshBottomEdgyButton", "constructor options is missing one or more mandatory properties");
return;
}
that._refreshCallBack = options.refreshCallBack;
var refreshButtonData = {
title: PlatformJS.Services.resourceLoader.getString("RefreshButtonTitle"),
onclick: that._onRefreshButtonClick.bind(that),
icon: SportsJS.UI.IconType.refresh,
className: "refreshBtn",
buttonId: "RefreshButton"
};
SportsJS.Controls.BottomEdgyButton.call(this, element, refreshButtonData);
}, {
_refreshCallBack: null,
_onRefreshButtonClick: function _onRefreshButtonClick(event) {
var that = this;
SportsJS.Utilities.hideTopEdgy();
SportsJS.Utilities.hideBottomEdgy();
if (that._refreshCallBack && typeof that._refreshCallBack === "function") {
that._refreshCallBack();
}
},
}),
/// <summary>
/// EntityCollectionBottomEdgyButton class. Provides entitycollection button for bottomEdgy
/// EntityCollection button is valid for league/team/player pages. This is button supports App wide Add/remove for the respective entity in entity page
/// DataAsync call returns data required for entity button.
/// </summary>
EntityCollectionBottomEdgyButton: WinJS.Class.derive(SportsJS.Controls.BottomEdgyButton, function (element, options) {
if (!options || !options.entityCollectionType || !options.leagueName || !options.entityId || typeof options.dataAsync !== "function") {
SportsJS.Utilities.interfaceException("SportsJS.Controls.EntityCollectionBottomEdgyButton", "constructor options is missing one or more mandatory properties");
return;
}
this._entityCollectionType = options.entityCollectionType;
this._leagueName = options.leagueName;
this._entityId = options.entityId;
this._dataAsync = options.dataAsync;
var sportsEntityManager = AppEx.Sports.Services.SportsEntityManager;
var buttonData;
var output = sportsEntityManager.tryCheckEntityExistsInCollection(this._entityCollectionType, this._leagueName, this._entityId);
var isAddButton = output.value && output.doesEntityExist;
var buttonId = this._entityId + this._entityCollectionType + "EntityCollectionButton";
if (isAddButton) {
buttonData = {
icon: SportsJS.UI.IconType.remove,
title: PlatformJS.Services.resourceLoader.getString("RemoveButtonTitle"),
onclick: this._removeButtonClickHandler,
placement: "left",
className: "teamManageBtn",
buttonId: buttonId
};
} else {
buttonData = {
icon: SportsJS.UI.IconType.add,
title: PlatformJS.Services.resourceLoader.getString("AddButtonTitle"),
onclick: this._addButtonClickHandler,
placement: "left",
className: "teamManageBtn",
buttonId: buttonId
};
}
SportsJS.Controls.BottomEdgyButton.call(this, element, buttonData);
}, {
_entityCollectionType: null,
_leagueName: null,
_entityId: null,
_dataAsync: null,
_removeFromCollection: function _removeFromCollection() {
var that = this;
var sportsEntityManager = AppEx.Sports.Services.SportsEntityManager;
var success = sportsEntityManager.tryRemoveFromCollection(this._entityCollectionType, this._leagueName, this._entityId);
success = success ? success.value : false;
if (success && this._entityCollectionType === SportsJS.UI.SportsEntityCollectionType.MyLeagues.name) {
SportsJS.mainProcessManager.channelManager.reset();
}
return success;
},
_addToCollection: function _addToCollection() {
var that = this;
var sportsEntityManager = AppEx.Sports.Services.SportsEntityManager;
var success = sportsEntityManager.tryAddToCollection(this._entityCollectionType, this._leagueName, this._entityId);
success = success ? success.value : false;
// this is not the best place for this code. Significant change required in Top Edgy code. chthakur -> ashokkul
if (success && this._entityCollectionType === SportsJS.UI.SportsEntityCollectionType.MyLeagues.name) {
SportsJS.mainProcessManager.channelManager.reset();
SportsJS.Telemetry.logFavLeagueAction(this._leagueName, SportsJS.Telemetry.ActionType.add, SportsJS.Telemetry.ElementType.AppBar);
}
if (success && this._entityCollectionType === SportsJS.UI.SportsEntityCollectionType.MyTeams.name) {
var teamUnivId = SportsJS.Utilities.stringFormat(
"{0}/{1}",
this._leagueName,
this._entityId);
SportsJS.Telemetry.logFavTeamAction(teamUnivId, SportsJS.Telemetry.ActionType.add, SportsJS.Telemetry.ElementType.AppBar);
}
return success;
},
_addButtonClickHandler: function _addButtonClickHandler() {
var that = this;
if (this._entityCollectionType === SportsJS.UI.SportsEntityCollectionType.MyLeagues.name && !SportsJS.Networking.isInternetAvailable) {
var messageBar = new CommonJS.MessageBar(PlatformJS.Services.resourceLoader.getString("AddLeaguesFailedOnOffline"), { level: CommonJS.MessageBarLevelWarning, autoHide: true });
messageBar.show();
return;
}
var entityButton = that;
var success = that._addToCollection();
that._dataAsync().then(function (msgData) {
var msg;
if (!msgData || !msgData.entityDisplayName || !msgData.entityDisplayType) {
SportsJS.Utilities.interfaceException("SportsJS.Controls.BottomEdgy._addButtonClickHandler", "msgData is not an valid object");
return;
}
var entityDisplayName = msgData.entityDisplayName;
var entityDisplayType = msgData.entityDisplayType;
if (success) {
msg = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("EntityAddedToCollection"), entityDisplayName, entityDisplayType);
entityButton.label = PlatformJS.Services.resourceLoader.getString("RemoveButtonTitle");
entityButton.icon = SportsJS.UI.IconType.remove;
entityButton.onclick = that._removeButtonClickHandler;
}
else {
msg = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("EntityCouldNotBeAddedToCollection"), entityDisplayName, entityDisplayType);
}
SportsJS.Utilities.showPlatformMsgBar(msg);
});
},
_removeButtonClickHandler: function _removeButtonClickHandler() {
var that = this;
if (this._entityCollectionType === SportsJS.UI.SportsEntityCollectionType.MyLeagues.name && !SportsJS.Networking.isInternetAvailable) {
var messageBar = new CommonJS.MessageBar(PlatformJS.Services.resourceLoader.getString("RemoveLeaguesFailedOnOffline"), { level: CommonJS.MessageBarLevelWarning, autoHide: true });
messageBar.show();
return;
}
var entityButton = that;
var success = that._removeFromCollection();
if (success && this._entityCollectionType === SportsJS.UI.SportsEntityCollectionType.MyLeagues.name) {
SportsJS.Telemetry.logFavLeagueAction(this._leagueName, SportsJS.Telemetry.ActionType.remove, SportsJS.Telemetry.ElementType.AppBar);
}
if (success && this._entityCollectionType === SportsJS.UI.SportsEntityCollectionType.MyTeams.name) {
var teamUnivId = SportsJS.Utilities.stringFormat(
"{0}/{1}",
this._leagueName,
this._entityId);
SportsJS.Telemetry.logFavTeamAction(teamUnivId, SportsJS.Telemetry.ActionType.remove, SportsJS.Telemetry.ElementType.AppBar);
}
this._dataAsync().then(function (msgData) {
var msg;
if (!msgData || !msgData.entityDisplayName || !msgData.entityDisplayType) {
// not possible
SportsJS.Utilities.interfaceException("SportsJS.Controls.BottomEdgy._removeButtonClickHandler", "msgData is not an valid object");
return;
}
var entityDisplayName = msgData.entityDisplayName;
var entityDisplayType = msgData.entityDisplayType;
if (success) {
msg = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("EntityRemovedFromCollection"), entityDisplayName, entityDisplayType);
entityButton.label = PlatformJS.Services.resourceLoader.getString("AddButtonTitle");
entityButton.icon = SportsJS.UI.IconType.add;
entityButton.onclick = that._addButtonClickHandler;
}
else {
msg = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("EntityCouldNotBeRemovedFromCollection"), entityDisplayName, entityDisplayType);
}
SportsJS.Utilities.showPlatformMsgBar(msg);
});
}
}),
/// <summary>
/// PinBottomEdgyButton class. Provides pinning button for bottomEdgy
/// tileDataAsync call returns data required for entity button.
/// </summary>
PinBottomEdgyButton: WinJS.Class.derive(SportsJS.Controls.BottomEdgyButton, function (element, options) {
if (!options || !options.tileId || !options.leagueType || typeof options.tileDataAsync !== "function") {
SportsJS.Utilities.interfaceException("SportsJS.Controls.PinBottomEdgyButton", "constructor options is missing one or more mandatory properties");
return;
}
this._tileId = options.tileId;
this._sportsType = options.leagueType;
this._tileDataAsync = options.tileDataAsync;
this._entityType = options.entityType;
var that = this;
var onBeforeShowBottomEdgy = function () {
var isAlreadyPinned = SportsJS.SecondaryTile.isAlreadyPinned(that._tileId);
if (isAlreadyPinned) {
that._switchToUnpinButton();
} else {
that._switchToPinButton();
}
};
var buttonData = {
title: PlatformJS.Services.resourceLoader.getString("/platform/pinToStart"),
className: "pinUnpinBtn",
placement: "left",
beforeShow: onBeforeShowBottomEdgy,
buttonId: this._tileId + "PinUnpinButton"
};
SportsJS.Controls.BottomEdgyButton.call(this, element, buttonData);
}, {
_tileDataAsync: null,
_tileId: null,
_sportsType: null,
_entityType: null,
_bottomEdgyInstance: null,
getInstrumentationID: function getInstrumentationID(entityType, entityName) {
if (entityName === "pinning") {
if (entityType === SportsJS.UI.EntityType.League) {
return "LeagueTilePinnedCount";
}
else if (entityType === SportsJS.UI.EntityType.Team) {
return "TeamTilePinnedCount";
}
}
else if (entityName === "unpinning") {
if (entityType === SportsJS.UI.EntityType.League) {
return "LeagueTileUnPinnedCount";
}
else if (entityType === SportsJS.UI.EntityType.Team) {
return "TeamTileUnPinnedCount";
}
}
},
_bottomEdgy: {
get: function get() {
if (!this._bottomEdgyInstance) {
var bottomEdgy = document.querySelector('.sportsBottomEdgy');
if (bottomEdgy && bottomEdgy.winControl) {
this._bottomEdgyInstance = bottomEdgy.winControl;
}
}
return this._bottomEdgyInstance;
}
},
// gets the tileData.  
//Make sure to pass the sportsType, Display Name and TeamID for the creation of pinned tiles with proper data.
//e.g: leagueType = "nhl" or "nfl", displayName = "NFL" or "NHL" , teamID should be passed when pinning the team pages.
_getTileDataAsync: function _getTileDataAsync() {
var that = this;
return that._tileDataAsync().then(function tileData_CompleteHander(result) {
if (!result || !result.newsData) {
return null;
}
var displayName = result.entityText;
var leagueType;
//TODO: Figure out why we don't get leagueType in a team page
if (!result.leagueType) {
leagueType = result.sportsType;
}
else {
leagueType = result.leagueType;
}
var newsData = result.newsData;
var tileData = {
channelId: null,
fragment: "/html/defaultPanoPage.html",
page: result.page,
displayName: displayName,
queryText: newsData.newsQuery,
newsType: newsData.newsQueryType,
newsCount: newsData.newsQueryCount.toString(),
heroSetting: result.heroSetting,
leagueType: that._sportsType,
teamId: result.teamId
};
return tileData;
});
},
_pinButtonClickHandler: function _pinButtonClickHandler() {
var that = this;
var bottomEdgy = this._bottomEdgy;
if (bottomEdgy) {
that._showBottomEdgy();
that._getTileDataAsync().then(function tileData_CompleteHander(tileData) {
if (!tileData) {
return;
}
try {
var instrumentationID = that.getInstrumentationID(that._entityType, "pinning");
SportsJS.SecondaryTile.createTile(that._tileId, tileData,
that.element,
that._onPinningComplete.bind(that), instrumentationID);
} catch (ex) {
that._hideBottomEdgy();
}
});
}              
},
_unpinButtonClickHandler: function _unpinButtonClickHandler() {
var that = this;
that._showBottomEdgy();
var instrumentationID = that.getInstrumentationID(that._entityType, "unpinning");
SportsJS.SecondaryTile.removeTile(that._tileId, that.element, that._onUnPinningComplete.bind(that), instrumentationID);
},
_switchToPinButton: function _switchToPinButton() {
this.label = PlatformJS.Services.resourceLoader.getString("/platform/pinToStart");
this.icon = SportsJS.UI.IconType.pin;
this.onclick = this._pinButtonClickHandler;
},
_switchToUnpinButton: function _switchToUnpinButton() {
this.label = PlatformJS.Services.resourceLoader.getString("/platform/unpinFromStart");
this.icon = SportsJS.UI.IconType.unpin;
this.onclick = this._unpinButtonClickHandler;
},
_onPinningComplete: function _onPinningComplete() {
var that = this;
that._hideBottomEdgy();
that._switchToUnpinButton();
},
_onUnPinningComplete: function _onUnPinningComplete() {
var that = this;
that._hideBottomEdgy();
that._switchToPinButton();
},
_hideBottomEdgy: function _hideBottomEdgy() {
var bottomEdgy = this._bottomEdgy;
if (bottomEdgy) {
bottomEdgy.sticky = false;
bottomEdgy.hide();
}
},
_showBottomEdgy: function _showBottomEdgy() {
var bottomEdgy = this._bottomEdgy;
if (bottomEdgy) {
bottomEdgy.sticky = true;
bottomEdgy.show();
}
},
}),
/// <summary>
/// BottomEdgy class. Provides bottomEdgy for entity pages
/// </summary>
BottomEdgy: WinJS.Class.derive(WinJS.UI.AppBar, function () {
WinJS.UI.AppBar.call(this, null, { placement: 'bottom', layout: 'custom' });
WinJS.Utilities.addClass(this.element, "sportsBottomEdgy");
var buttonsContainer = document.createElement("div");
WinJS.Utilities.addClass(buttonsContainer, "buttonsContainer");
var rightButtonsContainer = document.createElement("div");
WinJS.Utilities.addClass(rightButtonsContainer, "rightButtonsContainer");
buttonsContainer.appendChild(rightButtonsContainer);
var leftButtonsContainer = document.createElement("div");
WinJS.Utilities.addClass(leftButtonsContainer, "leftButtonsContainer");
buttonsContainer.appendChild(leftButtonsContainer);
this.element.appendChild(buttonsContainer);
this._refreshCallBacks = [];
this._buttons = [];
}, {
_refreshCallBacks: null,
// All the buttons currently added in this bottom edgy.
_buttons: null,
addButton: function addButton(buttonControl) {
if (!buttonControl || !buttonControl.element) {
return;
}
if (buttonControl.beforeShow) {
this.element.addEventListener("beforeshow", buttonControl.beforeShow);
}
if (buttonControl.refreshCallBack && typeof buttonControl.refreshCallBack === "function") {
this._refreshCallBacks.push(buttonControl.refreshCallBack);
}
//// By default, we will put buttons in right container
var buttonContainer = this.element.querySelector(".rightButtonsContainer");
if (buttonControl.placement && typeof buttonControl.placement === "string" && buttonControl.placement.toLowerCase() === "left") {
buttonContainer = this.element.querySelector(".leftButtonsContainer");
}
if (!buttonContainer) {
return null;
}
buttonContainer.appendChild(buttonControl.element);
this._buttons.push(buttonControl);
return buttonControl;
},
refreshEdgy: function refreshEdgy() {
for (var i = 0, len = this._refreshCallBacks.length; i < len; i++) {                  
if (this._refreshCallBacks[i]) {
this._refreshCallBacks[i]();
}
}
},
cleanUp: function cleanUp() {
for (var i = 0, len = this._buttons.length; i < len; i++) {                  
if (this._buttons[i] && typeof this._buttons[i].cleanUp === "function") {
this._buttons[i].cleanUp();
}
}
}
})
});
WinJS.Namespace.define("SportsJS",
{
/// <summary>
/// Handles network changes
/// </summary>
Networking: new (WinJS.Class.mix(
function () { },
{
isInternetAvailable: null,
initialize: function initialize() {
this.isInternetAvailable = SportsJS.Networking.getCurrentInternetAvailability();
Windows.Networking.Connectivity.NetworkInformation.addEventListener("networkstatuschanged", SportsJS.Networking.onNetworkStatusChange);
},
onNetworkStatusChange: function onNetworkStatusChange(event) {
var currentStatus = SportsJS.Networking.getCurrentInternetAvailability();
//app goes offline from online.
if (SportsJS.Networking.isInternetAvailable === true) {
if (currentStatus === false) {
SportsJS.Networking.isInternetAvailable = currentStatus;
SportsJS.Networking.dispatchEvent("networkoffline");
}
}
else {
// app comes online from offline.
if (currentStatus === true) {
SportsJS.Networking.isInternetAvailable = currentStatus;
SportsJS.Networking.dispatchEvent("networkonline");
}
}
},
updateNetworkStatus: function updateNetworkStatus() {
this.isInternetAvailable = SportsJS.Networking.getCurrentInternetAvailability();
},
getCurrentInternetAvailability: function getCurrentInternetAvailability() {
return Platform.Networking.NetworkManager.instance.isNetworkAvailable;
},
},
WinJS.Utilities.eventMixin,
WinJS.Utilities.createEventProperties(
'networkonline',
'networkoffline')
))
});
// Add all the promises that are shared across modules in this namespace
// It becomes easy to clean them later if required
WinJS.Namespace.define("SportsJS.Shared.Promises.Player",
{
/// Promise for obtaining player bio information
playerBio: function playerBio(league, playerId, bypassCache) {
var bioPromise = new WinJS.Promise(function (complete) {
var controller = AppEx.Sports.Services.SportsController();
var uiQuery = new AppEx.Sports.Services.TypeDefs.Request.PlayerBasicInfoQuery(league, playerId);
uiQuery.bypassCache = bypassCache;
controller.requestV2(uiQuery).then(function (res) {
if (res && res.dataObject && res.dataObject.isValid) {
var playerBio = SportsJS.Utilities.nativeObjectToJsObject(res.dataObject);
complete({ response: playerBio, meta: res });
}
else {
complete({ response: { isValid: false }, meta: {} });
}
});
});
return bioPromise;
},
});
// Add all the team promises that are shared across modules in this namespace
WinJS.Namespace.define("SportsJS.Shared.Promises.Team",
{
/// TODO(Extensibility)(chthakur): quickfix, this will be fixed in coming checkins
/// Promise for obtaining team bio information
/// we need a datamodel to provide us with teamBio from teamId.
teamBio: function teamBio(league, teamId) {
if (!league || !teamId) { return WinJS.Promise.wrap(null); }
var bioPromise = new WinJS.Promise(function (complete) {
var controller = new AppEx.Sports.Services.SportsController();
var uiQuery = new AppEx.Sports.Services.TypeDefs.Request.TeamBasicInfoQuery(league, teamId);
var handleQueryResult = function (res) {
if (res && res.isValid) {
complete(res.basicInfo);
}
else {
complete(null);
}
};
controller.request(uiQuery).then(handleQueryResult);
});
return bioPromise;
}
});
WinJS.Namespace.define("SportsJS.UI", {
EntityType: Object.freeze({
Team: "Team",
Player: "Player",
Sports: "Sports",
League: "League",
Today: "Today",
Match: "Match",
None: "None",
}),
DataStatusType: Object.freeze({
NoData: "NoData"
}),
// Leagacy, deprecated. EXTENSIBILITY - chthakur
LeagueType: Object.freeze({
all: "all",
today: "today",
app: "app",
None: "None"
}),
PageType: Object.freeze({
Home: "Home",
League: "League",
Team: "Team",
Player: "Player",
Slideshow: "Slideshow",
Today: "Today",
MyTeams: "MyTeams",
News: "News",
AllSports: "AllSports",
Snap: "Snap",
Frame: "Frame",
EditorialCollection: "EditorialCollection",
Match: "Match",
Generic: "Generic",
Preview: "Preview",
Recap: "Recap",
None: "None",
}),
ClusterType: Object.freeze({
Home: "Home",
Hero: "Hero",
News: "News",
Headlines: "Headlines",
Video: "Video",
LeagueSchedule: "LeagueSchedule",
LeagueStandings: "LeagueStandings",
LeagueStandingsSingleDivision: "LeagueStandingsSingleDivision",
TeamDivisionStandings: "DivisionStandings",
LeagueLeadingTeams: "LeagueLeadingTeams",
LeagueLeadingPlayers: "LeagueLeadingPlayers",
TeamCenter: "TeamCenter",
TeamSchedule: "TeamSchedule",
TeamRoster: "TeamRoster",
TableRoster: "TableRoster",
TeamLeaders: "TeamLeaders",
TeamStats: "TeamStats",
TodaySchedule: "TodaySchedule",
TodaySlideshow: "TodaySlideshow",
SportsNavigation: "SportsNavigation",
MyTeams: "MyTeams",
MyLeagues: "MyLeagues",
NoImageTeamLeaders: "NoImageTeamLeaders",
NoImageLeagueLeadingPlayers: "NoImageLeagueLeadingPlayers",
NoImageNoECVLeagueLeadingPlayers: "NoImageNoECVLeagueLeadingPlayers",
LeagueScheduleTable: "LeagueScheduleTable",
NoImageLeagueLeadingTeams: "NoImageLeagueLeadingTeams",
ScrollableStandingsListCluster: "ScrollableStandingsList",
RaceResultTable: "RaceResultTable",
DriverStandingsTable: "DriverStandingsTable",
TeamStandingsTable: "LeagueStandings",
LeaderBoardCluster: "LeaderBoardCluster",
AllSports: "AllSports",
Magazine: "Magazine",
MatchPreviewRecap: "MatchPreviewRecap",
MatchTeamStats: "MatchTeamStats",
ListCluster: "ListCluster",
MixedListCluster: "MixedListCluster",
LeagueCalendar: "LeagueCalendar",
None: "None"
}),
ClusterTypeToJsClass: Object.freeze({
CategoryNews: "SportsJS.Cluster.Configs.Common.categoryNewsCluster",
TodayVideo: "SportsJS.Cluster.Configs.Today.todayVideoCluster",
LeagueHero: "SportsJS.Cluster.Configs.Common.cmsHeroClusterHome",
LeagueNews: "SportsJS.Cluster.Configs.Common.leagueNewsCluster",
LeagueHeadlines: "SportsJS.Cluster.Configs.Common.leagueHeadlinesCluster",
LeagueSchedule: "SportsJS.Cluster.Configs.Common.leagueSchedule",
NoImageLeagueSchedule: "SportsJS.Cluster.Configs.Common.noImageLeagueSchedule",
ResultsOnlyLeagueSchedule: "SportsJS.Cluster.Configs.Common.ResultsOnlyLeagueSchedule",
FixturesOnlyLeagueSchedule: "SportsJS.Cluster.Configs.Common.FixturesOnlyLeagueSchedule",
LeagueScheduleTable: "SportsJS.Cluster.Configs.Common.LeagueScheduleTable",
LeagueVideo: "SportsJS.Cluster.Configs.Common.leagueVideoCluster",
LeagueStandings: "SportsJS.Cluster.Configs.Common.leagueStandings",
LeagueStandingsSingleDivision: "SportsJS.Cluster.Configs.Common.leagueStandingsSingleDivision",
TeamDivisionStandings: "SportsJS.Cluster.Configs.Common.teamDivisionStandings",
NoImageTeamDivisionStandings: "SportsJS.Cluster.Configs.Common.noImageTeamDivisionStandings",
GroupStandings: "SportsJS.Cluster.Configs.Common.groupStandings",
LeagueCalendar: "SportsJS.Cluster.Configs.Common.leagueCalendar",
CurrentTours: "SportsJS.Cluster.Configs.Common.currentTours",
LeagueLeadingPlayers: "SportsJS.Cluster.Configs.Common.leagueLeadingPlayers",
NoImageLeagueLeadingPlayers: "SportsJS.Cluster.Configs.Common.noImageLeagueLeadingPlayers",
NoImageNoECVLeagueLeadingPlayers: "SportsJS.Cluster.Configs.Common.noImageNoECVLeagueLeadingPlayers",
LeagueLeadingTeams: "SportsJS.Cluster.Configs.Common.leagueLeadingTeams",
NoImageLeagueLeadingTeams: "SportsJS.Cluster.Configs.Common.noImageLeagueLeadingTeams",
LeaderBoard: "SportsJS.Cluster.Configs.Common.leaderBoard",
TableRoster: "SportsJS.Cluster.Configs.Common.TableRoster",
TeamHero: "SportsJS.Cluster.Configs.Common.cmsHeroClusterTeam",
TeamNews: "SportsJS.Cluster.Configs.Common.teamNewsCluster",
TeamSchedule: "SportsJS.Cluster.Configs.Common.teamSchedule",
TeamStandingsTable: "SportsJS.Cluster.Configs.Common.TeamStandingsTable",
NoImageTeamStandingsTable: "SportsJS.Cluster.Configs.Common.noImageTeamStandingsTable",
DriverStandingsTable: "SportsJS.Cluster.Configs.Common.DriverStandingsTable",
RaceResultTable: "SportsJS.Cluster.Configs.Common.RaceResultTable",
NoImageTeamSchedule: "SportsJS.Cluster.Configs.Common.NoImageTeamSchedule",
TeamLeaders: "SportsJS.Cluster.Configs.Common.teamLeaders",
NoImageTeamLeaders: "SportsJS.Cluster.Configs.Common.noImageTeamLeadingPlayers",
TeamStats: "SportsJS.Cluster.Configs.Common.teamStats",
TeamSingleStats: "SportsJS.Cluster.Configs.Common.teamSingleStats",
TeamRoster: "SportsJS.Cluster.Configs.Common.teamRoster",
PlayerBio: "SportsJS.Cluster.Configs.Common.playerBio",
PlayerComparison: "SportsJS.Cluster.Configs.Common.playerComparison",
PlayerNews: "SportsJS.Cluster.Configs.Common.playerNewsCluster",
MatchPreviewRecap: "SportsJS.Cluster.Configs.Common.matchPreviewRecapCluster",
LeagueRankings: "SportsJS.Cluster.Configs.Common.leagueRankings",
TeamConferenceStandings: "SportsJS.Cluster.Configs.Common.teamConferenceStandings",
MatchBoxScore: "SportsJS.Cluster.Configs.Common.matchBoxScore",
CricketMatchBoxScore: "SportsJS.Cluster.Configs.Common.cricketMatchBoxScore",
MatchOverview: "SportsJS.Cluster.Configs.Common.matchOverview",
MatchOverviewPreGame: "SportsJS.Cluster.Configs.Common.matchOverviewPreGame",
MatchTeamStats: "SportsJS.Cluster.Configs.Common.matchTeamStats",
TournamentSchedule: "SportsJS.Cluster.Configs.Common.tournamentSchedule",
LeadingPlayersTable: "SportsJS.Cluster.Configs.Common.leadingPlayersTable",
LiveScoresTable: "SportsJS.Cluster.Configs.Common.liveScoresTable",
LeagueDetailedResults: "SportsJS.Cluster.Configs.Common.leagueDetailedResults",
DynamicEditorialCollectionCluster: "SportsJS.Cluster.Configs.Common.dynamicEditorialCollectionCluster",
Ads: "SportsJS.Cluster.Configs.Common.adsClusterConfig",
ListCluster: "SportsJS.Cluster.Configs.Common.listCluster",
MixedListCluster: "SportsJS.Cluster.Configs.Common.mixedListCluster"
}),
NewsType: Object.freeze({
bingquery: "bingquery",
bingcategory: "bingcategory",
rss: "rss",
disabled: "disabled",
}),
HeroType: Object.freeze({
enabled: "enabled",
disabled: "disabled",
image: "imageonly",
useenus: "useenus",
useenww: "useenww",
enwwimage: "enwwimage"
}),
NewsSource: Object.freeze({
bing: "bing",
rss: "rss",
editorial: "editorial",
}),
EditorialEntity: Object.freeze({
article: "article",
slideshow: "slideshow",
video: "video",
}),
ProfilerEntityType: Object.freeze({
Page: "Page",
Cluster: "Cluster",
Module: "Module",
/*"Function" and using "Func" instead - avoiding collision with reserved word*/
Func: "Func",
None: "None"
}),
ProfilerMarkType: Object.freeze({
Start: "s",
End: "e",
Progress: "m",
None: "None"
}),
ProfilerTagType: Object.freeze({
PerceivedLoad: "PerceivedLoad",
DataFetch: "DataFetch",
Render: "Render"
}),
GameState: Object.freeze({
final: "final",
inprogress: "in-progress",
pregame: "pre-game",
nogame: "nogame",
postponed: "postponed",
suspended: "suspended",
halftime: "half-over",
delayed: "delayed"
}),
MatchOutCome: Object.freeze({
notDetermined: -1,
won: 0,
lost: 1,
tied: 2
}),
StreakIndicator: Object.freeze({
win: "W",
loss: "L",
tie: "T"
}),
IconType: Object.freeze({
add: "\uE017",
remove: "\uE018",
pin: "\uE015",
unpin: "\uE016",
refresh: "\uE067",
glossary: 'glossaryBtn',
browser: "\uE181",
date: "\uE111",
help: "\uFF60",
clear: "\uE009"
}),
// Table size classification by number of columns
TableSize: Object.freeze({
Medium: "medium",
Large: "large"
}),
//TODO(chthakur) - add basic type, verify with test and add more accordingly
AutomationComponentType: Object.freeze({
Panorama: "Panorama",
PanoramaHeaderTitle: "PanoramaHeaderTitle",
PanoramaHeaderSubTitle: "PanoramaHeaderSubTitle",
PanoramaPanel: "PanoramaPanel",
Cluster: "Cluster",
Module: "Module",
ECVPanorama: "ECVPanorama",
BottomEdgyButton: "BottomEdgyButton",
}),
//Display type classification
ecvType: Object.freeze({
LeaguePlayers: "LeaguePlayers",
LeagueTeams: "LeagueTeams",
LeagueSchedule: "LeagueSchedule",
LeagueStandings: "LeagueStandings",
TeamRoster: "TeamRoster"
}),
//Display type classification
ecvDisplayType: Object.freeze({
Image: "Image",
Number: "Number",
Text: "Text",
Title: "Title",
SortTitle: "SortTitle",
NoDisplay: "NoDisplay"
}),
//Providers list
providers: Object.freeze({
AP: "AP",
Getty: "Getty Images"
}),
//Providers list
refreshType: Object.freeze({
Forced: "Forced",
Progress: "Progress",
None: "None"
}),
//Providers list
Channels: Object.freeze({
Video: "Video",
Preview: "Preview",
Recap: "Recap",
AllSports: "AllSports",
None: "None"
}),
//Type of panos available for navigation
PanoType: Object.freeze({
allsports: "allsports",
news: "news",
video: "video",
allnews: "allnews",
allvideo: "allvideo",
}),
});
WinJS.Namespace.define("SportsJS.Msg",
{
ClusterConfigNotFound: "Cluster config not found: dropping cluster from rendering.",
ClusterConfigIsInvalid: "Invalid argument: Cluster class expects cluster config to be the first argument",
ModuleConfigIsInvalid: "Invalid argument: Cluster class expects cluster config to be the first argument",
FragmentMissing: "Required Fragment missing",
TemplateMissingInsideFragment: "Required template selector missing inside fragment",
ObjectionConstruction: "Object constructed",
GetDataRequestReceived: "Get data request received",
PlayerPageStateNotFound: "State information required by player page is missing.",
TeamPageStateNotFound: "State information on team page(required for teamid) is missing.",
InvalidTeamPageState: "State information on team page is invalid. Teamid is missing",
InvalidPlayerPageState: "State information on player page is invalid. Playerid is missing",
DataProviderConfigurationNotFound: "Data provider configuration missing",
DataServedByParent: "Parent cluster served data",
DataNotServedByParent: "Parent cluster didn't serve data",
ListViewItemChanged: "ListView item changed",
ResponseNotValidForInlineRefresh: "Provider response is not valid for refresh",
LeagueBasicInfoNetworkFailure: "League Basic info could not retrieved",
LeagueConfigNotFound: "League Config not found",
StaleDataReceived: "Inline refresh data received is older than what we are already showing",
InvalidMsProfileMarkLength: "msWriteProfilerMark msg length is more than 32 characters",
ModuleParamsNotFound: "Required parameters to intialize the module are missing",
LeagueNotInUserLeagues: "League not valid user league, navigating to home page",
InvalidDataProviderResponse: "Data Provider response is not valid",
MandatoryOptionMissing: "Missing mandatory option {0}",
MandatoryFieldMissing: "Missing mandatory field {0}",
FunctionImplementationMissing: "{0} function implementation missing",
});
WinJS.Namespace.define("SportsJS.Consts",
{
LeaguePageLeadersPerCategory: 3,
AppTileNewsCount: 3,
LeagueTileNewsCount: 3,
TeamTileNewsCount: 2,
storageType: {
IE: "ie",
WIN_SETTING: "win_setting",
PLATFORM: "platform"
}
});   
})();
