﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.AllSports", {
HomePage: WinJS.Class.derive(SportsJS.Page,
/// <summary>
/// Constructor for your IPage class
/// </summary>
/// <param name="state">
/// The state object passed to WinJS.Navigation.navigate or the state object
/// preserved when the page has been navigated away from
/// </param>
function (state) {
var that = this;
this._initializeActionBar();
this.isFreOffline = SportsJS.Utilities.isFirstRunOfflineExperience();
that._basePageConstructor();
//// set dark theme to platform's assets.
CommonJS.setTheme(null, false);
that._initBottomEdgy();
this._onUserLeagueChangeHandler = that.onUserLeagueChanged.bind(that);
this.element.addEventListener("onUserLeagueChanged", this._onUserLeagueChangeHandler);
if (!this.isFreOffline) {
this._insertFooter();
}
},
{
_leagueName: SportsJS.UI.LeagueType.all,
_leagueType: SportsJS.UI.LeagueType.all,
_pageType: SportsJS.UI.PageType.AllSports,
_allSportsModuleControl: null,
_isFreOffline: false,
_queueForEventDeregistration: [],
_onUserLeagueChangeHandler: null,
getPageImpressionContext: function getPageImpressionContext() {
return "/" + this._pageType;
},
_logTelemetry: function _logTelemetry() {
return;
},
isFreOffline: {
get: function get() {
return this._isFreOffline;
},
set: function set(value) {
var that = this;
this._isFreOffline = value;
if (that._actionBar) {
that._actionBar.disabled = that._isFreOffline ? true : false;
}
// careful with enable, if not handled properly user might lose navigation bar altogether
// if in fre-offline
if (this._isFreOffline === true) {
SportsJS.Utilities.disableNavigationBar();
var stateChanged = function (event) {
if (!Platform.Networking.NetworkManager.instance.isNetworkAvailable) {
return;
}
Windows.Networking.Connectivity.NetworkInformation.removeEventListener("networkstatuschanged", stateChanged);
SportsJS.Utilities.enableNavigationBar();
};
// On network change we are going to refresh the whole page, this is required to ensure that we enable
// the TopNavigationBar 
Windows.Networking.Connectivity.NetworkInformation.addEventListener("networkstatuschanged", stateChanged);
}
},
},
_actionBar: null,
_initializeActionBar: function _initializeActionBar() {
var that = this;
var allSportsActionBarElement = document.querySelector(".sportsBottomEdgy");
that._actionBar = allSportsActionBarElement ? allSportsActionBarElement.winControl : null;
if (!allSportsActionBarElement || !that._actionBar) {
return;
}
that._actionBar.leagueAddButton = allSportsActionBarElement.querySelector(".addButton");
that._actionBar.leagueRemoveButton = allSportsActionBarElement.querySelector(".removeButton");
that._actionBar.leagueClearSelectionButton = allSportsActionBarElement.querySelector(".clearButton");
if (!that._actionBar.leagueAddButton || !that._actionBar.leagueRemoveButton || !that._actionBar.leagueClearSelectionButton) {
// no half measures
that._actionBar = null;
return;
}
},
pageUri: {
get: function get() {
return Platform.Utilities.AppExUriBuilder.toUriString(SportsJS.NavControllers.allsports, "", "", null);
}
},
/// <summary>
/// This function is invoked by the UX Framework when the page is being created and when
/// it is necessary to bind data to the UX.
/// </summary>
/// <returns>
/// Returns a promise that contains data to bind the UX to
/// </returns>
getPageData: function getPageData() {
var that = this;
that._data = new WinJS.Binding.List();
SportsJS.Utilities.showProgressBar();
that._trace(SportsJS.Msg.GetDataRequestReceived);
that.clusterConfigs = that.getClusterConfig();
that._pageTitle = PlatformJS.Services.resourceLoader.getString("AllSportsAppTitle");
var pageData = {
title: that._pageTitle,
listSource: that._data.dataSource
};
var promise = new WinJS.Promise(function (complete) {
var parr = [];
parr.push(SportsJS.mainProcessManager.appInitAsync());
parr.push(that._loadRequiredFragments());
WinJS.Promise.join(that._promiseStack(parr)).then(function () {
// with removal of AppInitAsync, the promise will succeed. So want to check isFreOffline here as well
that._errorMessageBar();
that._timeoutWrapper(function () { complete(pageData); }, that.pageDataTimeout);
}, function () {
//complete in both cases, we want to show this page in case of FRE offline/offline too
that._errorMessageBar();
complete(pageData);
});
});
return promise;
},
_errorMessageBar: function _errorMessageBar() {
if (!this._isFreOffline) {
return;
}
var messageBar = new CommonJS.MessageBar(PlatformJS.Services.resourceLoader.getString("AllSportsMsgOfflineFRE"), { level: CommonJS.MessageBarLevelWarning, autoHide: false });
messageBar.show();
var stateChanged = function () {
if (!Platform.Networking.NetworkManager.instance.isNetworkAvailable) {
return;
}
SportsJS.Networking.removeEventListener("networkonline", stateChanged);
messageBar.hide();
PlatformJS.Navigation.navigateToChannel(SportsJS.UI.PageType.Home);
};
SportsJS.Networking.addEventListener("networkonline", stateChanged);
this._queueForEventDeregistration.push(function () {
SportsJS.Networking.removeEventListener("networkonline", stateChanged);
});
},
// we need to reset allSportsModuleControl to null on refresh page
_refreshPage: function _refreshPage() {
this._allSportsModuleControl = null;
// of network comes online after suspend, we stay in inconsistent state. We were supposed to navigate to today page, if FreOffline was hit before suspend
var wasFreOfflineBeforeRefresh = this.isFreOffline;
if (wasFreOfflineBeforeRefresh) {
PlatformJS.Navigation.navigateToChannel(SportsJS.UI.PageType.Home);
return;
}
// TODO(chthakur): ideally this page doesn't require refresh. 
// This code has been well tested with refresh. Right now keeping the changes to minimal and setting _allSportsModuleControl to null only
SportsJS.Page.prototype._refreshPage.call(this);
},
onBindingComplete: function onBindingComplete() {
// override the base functionality
},
onNavigateAway: function onNavigateAway() {
SportsJS.Utilities.purgeEventQueue(this._queueForEventDeregistration);
// extra carefull with navigationBar, this page has potential to disable
// the navigation bar permanently
if (!SportsJS.Utilities.isNavigationBarEnabled()) {
SportsJS.Utilities.enableNavigationBar();
}
this.element.removeEventListener("onUserLeagueChanged", this._onUserLeagueChangeHandler);                
SportsJS.Page.prototype.onNavigateAway.call(this);
},
/// <summary>
/// Gets the clusterConfigs for the page
/// </summary>
getClusterConfig: function getClusterConfig() {
var that = this;
if (that._clusterConfig) {
return that._clusterConfig;
}
var clusterConfigs = that._clusterConfig = [];
var commonCfgs = SportsJS.Cluster.Configs.Common;
// do not show top leagues cluster in FRE offline
if (!that.isFreOffline) {
var topLeaguesConfig = commonCfgs.topLeagues(that._leagueName);
clusterConfigs.push(topLeaguesConfig);
}
var allSportsConfig = commonCfgs.allSportsV2(that._leagueName);
if (allSportsConfig
&& allSportsConfig.clusterContent
&& allSportsConfig.clusterContent.contentOptions
&& allSportsConfig.clusterContent.contentOptions.model
&& allSportsConfig.clusterContent.contentOptions.model.modelControlConfig
&& allSportsConfig.clusterContent.contentOptions.model.modelControlConfig.queryOptions) {
allSportsConfig.clusterContent.contentOptions.model.modelControlConfig.queryOptions.isFreOffline = that.isFreOffline;
}
clusterConfigs.push(allSportsConfig);
PlatformJS.Ads.addAdsClusterConfig(clusterConfigs);
that.injectRenderConfigInClusterConfigs();
return clusterConfigs;
},
//// Overriding the base class function. We dont need to set pano watermark on this page as there is no data
_setPanoramaWatermark: function _setPanoramaWatermark() {
},
_initBottomEdgy: function _initBottomEdgy() {
},
onUserLeagueChanged: function onUserLeagueChanged(event) {
if (this.element) {
var nodes = this.element.querySelectorAll(".controlsViewTemplate[data-league-type='" + event.srcElement.leagueType + "']");
for (var i = 0; i < nodes.length; i++) {
var node = nodes[i];
var buttonElement = node.querySelector(".sportsAddbutton");
if (buttonElement) {
WinJS.Utilities.toggleClass(buttonElement, "userLeague");
}
}
}
},
_insertFooter: function _insertFooter() {
var attributionDiv = document.createElement("div");
WinJS.Utilities.addClass(attributionDiv, "moreSportsFooter sportsSmallText");
var newlyAddedSymbol = document.createElement("div");
WinJS.Utilities.addClass(newlyAddedSymbol, "moreSportsFooterSymbol newLeagueIndicator");
newlyAddedSymbol.innerHTML = "•";
var newlyAddedText = document.createElement("div");
WinJS.Utilities.addClass(newlyAddedText, "moreSportsFooterText");
newlyAddedText.innerHTML = PlatformJS.Services.resourceLoader.getString("MoreSportsFooterText");
attributionDiv.appendChild(newlyAddedSymbol);
attributionDiv.appendChild(newlyAddedText);
this.element.appendChild(attributionDiv);
},
})
});
})();
