﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.Common.EditorialCollection", {
EditorialCollectionPage: WinJS.Class.derive(SportsJS.Page,
/// <summary>
/// Constructor for your IPage class
/// </summary>
/// <param name="state">
/// The state object passed to WinJS.Navigation.navigate or the state object
/// preserved when the page has been navigated away from
/// </param>
function (state) {
var that = this;
if (!state
|| !SportsJS.Utilities.isValidLeague(state.leagueName)
|| !AppEx.Sports.Services.Utils.isValidEditorialCollectionType(state.editorialCollectionType)
|| !SportsJS.Utilities.isValidSportsEntityType(state.entityType)) {
that._error("Invalid state object.");
}
that._leagueName = state.leagueName;
//// TODO(chthakur): Get rid of the need to set leagueType same as leagueName
that._leagueType = state.leagueName;
that._editorialCollectionType = state.editorialCollectionType;
that._entityType = state.entityType;
that._entityId = state.entityId;
that._provider = PlatformJS.Utilities.createObject(that._providerType);
if (that._provider === null) {
that._error("Failed to create provider object.");
}
that._providerInitPromise = that._provider.initializeAsync(that._leagueName, that._editorialCollectionType, that._entityType, that._entityId);
that._basePageConstructor(state);
},
{
_pageType: SportsJS.UI.PageType.EditorialCollection,
_providerType: {
get: function get() {
this._error(SportsJS.Msg.MandatoryFieldMissing, "_providerType");
},
},
_editorialCollectionType: null,
_entityType: null,
_entityId: null,
_provider: null,
_providerInitPromise: null,
_pageData: null,
_pageButtonControl: null,
_errorTag: "SportsJS.Common.EditorialCollection.EditorialCollectionPage",
_buttons: null,
getPageImpressionContext: function getPageImpressionContext() {
return "/" + this._pageType;
},
_logTelemetry: function _logTelemetry() {
//no need to log telemetry
return;
},
pageUri: {
get: function get() {
var that = this;
var uriBuilder = new Platform.Utilities.AppExUriBuilder();
// These checks are already done in constructor. Just to be safe.
if (!SportsJS.Utilities.isValidLeague(that._leagueType)
|| !AppEx.Sports.Services.Utils.isValidEditorialCollectionType(that._editorialCollectionType)
|| !SportsJS.Utilities.isValidSportsEntityType(that._entityType)){
uriBuilder.controllerId = SportsJS.NavControllers.application;
SportsJS.Utilities.interfaceException("EditorialCollectionPage:pageUri", "required fields to form pageUri not found");
return uriBuilder.controllerId;
}
var collectionName = $SpMgr.enumStrings.EditorialCollectionType[that._editorialCollectionType];
uriBuilder.controllerId = SportsJS.NavControllers.editorial;
uriBuilder.queryParameters.insert("id", collectionName);
uriBuilder.queryParameters.insert("editorialCollectionType", collectionName);
uriBuilder.queryParameters.insert("leagueName", that._leagueName);
uriBuilder.queryParameters.insert("entityType", that._entityType);
uriBuilder.queryParameters.insert("entityId", that._entityId);
var uri = uriBuilder.toString();
return uri;
}
},
/// <summary>
/// This function is invoked by the UX Framework when the page is being created and when
/// it is necessary to bind data to the UX.
/// </summary>
/// <returns>
/// Returns a promise that contains data to bind the UX to
/// </returns>
getPageData: function getPageData() {
var that = this;
if (that._pageData) {
return WinJS.Promise.wrap(that._pageData);
}
SportsJS.Utilities.showProgressBar();
that._trace(SportsJS.Msg.GetDataRequestReceived);
var isComplete = false;
var p = new WinJS.Promise(function (complete) {
that._promiseStack(that._providerInitPromise).then(function (success) {
if (!success) {
that.pageRenderErrorHandler();
//platform not handling error, wrap in complete 
return complete();
}
that._promiseStack(that._provider.queryAsync()).then(function (response) {
if (isComplete) {
//// Refresh the page if data is valid and changed.
if (that._isValidResponse(response)) {
if (response.metadata.isCachedResponse || response.metadata.serverResponseNotModified) {
that._setPanoramaWatermark(response);
}
else {
that._refreshPage(null);
}
}
return;
}
isComplete = true;
CommonJS.Progress.hideProgress(CommonJS.Progress.headerProgressType);
var pageData = that._processProviderResponse(response);
if (!pageData) {
if (response.metadata.hasNoData) {
that._showNoData();
return complete();
}
that.pageRenderErrorHandler();
//platform not handling error, wrap in complete 
return complete();
}
that._setPanoramaWatermark(response);
return complete(pageData);
}, function (error) {
if (SportsJS.Utilities.isCancellationError(error)) {
return;
}
if (isComplete) {
//// No nothing
return;
}
isComplete = true;
CommonJS.Progress.hideProgress(CommonJS.Progress.headerProgressType);
that.pageRenderErrorHandler();
//platform not handling error, wrap in complete 
return complete();
}, function (response) {
var pageData = that._processProviderResponse(response);
if (!pageData) {
return;
}
isComplete = true;
CommonJS.Progress.hideProgress(CommonJS.Progress.headerProgressType);
that._setPanoramaWatermark(response);
return complete(pageData);
});
});
});
return p;
},
//// returns null on error
_processProviderResponse: function _processProviderResponse(response) {
var that = this;
this._buttons = [];
var commonCfgs = SportsJS.Cluster.Configs.Common;
if (!that._isValidResponse(response)) {
return null;
}
if (response.metadata.hasNoData) {
return null;
}
var pages = response.data;                 
for (var i = 0, pagemax = pages.length; i < pagemax; i++) {
var page = pages[i];
var clusterConfigs = new WinJS.Binding.List();
var clusters = page.clusters;
for (var j = 0, clustermax = clusters.length; j < clustermax; j++) {
var cluster = clusters[j];
var clusterConfig = SportsJS.Cluster.Configs.Common.editorialCollectionPageCluster(cluster, j, that._editorialCollectionType, that._leagueName, that._entityType);
if (clusterConfig) {
clusterConfigs.push(clusterConfig);
}
}
var pageData = {
title: page.pageTitle,
clusters: clusterConfigs.dataSource,
semanticZoomRenderer: that.semanticZoomRenderer,
panoramaState: that._panoramaState,
};
if (i === 0) {
that._pageData = pageData;
}
if (pages.length > 1 && page.edgyButtonData) {
var pageButtonData = {
title: page.edgyButtonData.title,
icon: page.edgyButtonData.icon,
placement: "left",
};
var addButton = new SportsJS.Controls.BottomEdgyButton(null, pageButtonData);
this._buttons.push({ button: addButton, pageData: pageData });
var pageButtonControl = that.bottomEdgy.addButton(addButton);
if (pageButtonControl) {
pageButtonControl.onclick = that._pageButtonClickHandler.bind(that, pageData, pageButtonControl);
if (i === 0) {
pageButtonControl.disabled = true;
that._pageButtonControl = pageButtonControl;
}
}
}
}
//// Need to consume panoramaState only once
that._panoramaState = null;
return that._pageData;
},
_pageButtonClickHandler: function _pageButtonClickHandler(pageData, pageButtonControl, event) {
var that = this;
SportsJS.Utilities.hideTopEdgy();
SportsJS.Utilities.hideBottomEdgy();
if (that._pageButtonControl) {
that._pageButtonControl.disabled = false;
}
pageButtonControl.disabled = true;
that._pageButtonControl = pageButtonControl;
that._refreshPage(pageData);
},
_isValidResponse: function _isValidResponse(response) {
return response && response.metadata && response.metadata.isValid;
},
//// TODO(saarya) Implmentation not final. Pending PM input
_showNoData: function _showNoData() {
var that = this;
var errorText;
var editorialCollectionType = AppEx.Sports.Services.TypeDefs.EditorialCollectionType;
//Using switch case here as we may add other editorial collection page
switch (that._editorialCollectionType) {
case editorialCollectionType.preview:
errorText = "NoPreviewText";
break;
case editorialCollectionType.recap:
errorText = "NoRecapText";
break;
default:
errorText = "NoDataText";
break;
}
SportsJS.Page.showNoDataPageError(PlatformJS.Services.resourceLoader.getString(errorText));
},
_setPanoramaWatermark: function _setPanoramaWatermark(response) {
var that = this;
if (!that._isValidResponse(response)) {
return;
}
var panoControl = SportsJS.Utilities.getCurrentPagePanoControl();
if (!panoControl) {
return;
}
if (response.metadata.isStaleResponse) {
var lastUpdateTime = response.metadata.lastUpdateTime;
var shortDate;
var shortTime;
try {
shortDate = Windows.Globalization.DateTimeFormatting.DateTimeFormatter.shortDate.format(lastUpdateTime);
shortTime = Windows.Globalization.DateTimeFormatting.DateTimeFormatter.shortTime.format(lastUpdateTime);
}
catch (ex) {
return;
}
panoControl.watermark = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("PanoWatermarkCachedDataOnline"), shortDate, shortTime);
}
else {
panoControl.watermark = " ";
}
},
_refreshPage: function _refreshPage(pageData) {
var that = this;
if (pageData) {
that._pageData = pageData;
SportsJS.Page.prototype._refreshPage.call(this);
this._addEdgyButtons();
}
else {
that._pageData = null;
//// Cleanup bottom edgy page buttons
var pageButtonsContainer = this.bottomEdgy && this.bottomEdgy.element ? this.bottomEdgy.element.querySelector(".leftButtonsContainer") : null;
if (pageButtonsContainer) {
pageButtonsContainer.innerHTML = "";
}
SportsJS.Page.prototype._refreshPage.call(this);
}
},
_addEdgyButtons: function _addEdgyButtons() {
var that = this;
if (!that._buttons) {
return;
}
for (var i = 0; i < that._buttons.length; i++) {
var pageButtonControl = that.bottomEdgy.addButton(that._buttons[i].button);
if (pageButtonControl) {
pageButtonControl.onclick = that._pageButtonClickHandler.bind(that, that._buttons[i].pageData, pageButtonControl);
}
}
},
_error: function _error(msg, parameter) {
var that = this;
var tag = that._errorTag;
if (parameter) {
msg = SportsJS.Utilities.stringFormat(msg, parameter);
}
SportsJS.Utilities.error(tag, msg);
},
}, {
//// TODO(saarya): Currently, we handle only article type. Append as needed
itemClickHandler: function itemClickHandler(event) {
var that = this;
if (!event || !event.item) {
return;
}
if (event.item.type === SportsJS.UI.EditorialEntity.article) {
var articleId = (event.item.articleid && event.item.articleid.length > 0) ? event.item.articleid : null;
var contentId = (event.item.contentid && event.item.contentid.length > 0) ? event.item.contentid : null;
var editorialCollectionType = typeof event.item.editorialCollectionType !== 'undefined' ? event.item.editorialCollectionType : AppEx.Sports.Services.TypeDefs.EditorialCollectionType.unknown;
var market = AppEx.Sports.Services.Utils.getEditorialCollectionMarket(editorialCollectionType);
SportsJS.Utilities.launchArticle(articleId, contentId, Platform.Instrumentation.InstrumentationEditorialSourceId.cluster, null, event.item.clusterArticles, market);
}            
},
})
});
})();
