﻿(function () {
'use strict';
WinJS.Namespace.define('SportsJS.Common.EditorialCollection', {
EditorialCollectionPageProvider: WinJS.Class.define(function () {
},
{
_queryServiceIdentifier: {
get: function get() {
this._error("required _queryServiceIdentifier is missing");
}
},
_isUniqueEndpoint: {
get: function get() {
this._error("required _isUniqueEndpoint is missing");
}
},
_collectionId: {
get: function get() {
this._error("required _collectionId is missing");
}
},
_pageTitle: {
get: function get() {
this._error("required _pageTitle is missing");
}
},
_clusterTitle: {
get: function get() {
this._error("required _clusterTitle is missing");
}
},
_errorTag: {
get: function get() {
return "SportsJS.Common.EditorialCollection.EditorialCollectionPageProvider";
},
},
_leagueName: null,
_editorialCollectionType: null,
_entityType: null,
_entityId: null,
_cacheId: null,
_cacheKey: null,
_queryParameters: null,
initializeAsync: function initializeAsync(leagueName, editorialCollectionType, entityType, entityId) {
var that = this;
if (!SportsJS.Utilities.isValidLeague(leagueName)
|| !AppEx.Sports.Services.Utils.isValidEditorialCollectionType(editorialCollectionType)
|| !SportsJS.Utilities.isValidSportsEntityType(entityType)) {
return WinJS.Promise.wrap(false);
}
that._leagueName = leagueName;
that._editorialCollectionType = editorialCollectionType;
that._entityType = entityType;
that._entityId = entityId;
var collectionId = SportsJS.Utilities.getEditorialCollectionId(that._leagueName, that._editorialCollectionType, that._entityType, that._entityId, that._isUniqueEndpoint);
if (!collectionId) {
return WinJS.Promise.wrap(false);
}
this._queryParameters = PlatformJS.Collections.createStringDictionary();
this._queryParameters.insert("collectionId", collectionId);
var market = AppEx.Sports.Services.Utils.getEditorialCollectionMarket(that._editorialCollectionType);
this._queryParameters.insert("market", market);
return WinJS.Promise.wrap(true);
},
queryAsync: function queryAsync() {
var that = this;
var queryService = new Platform.QueryService(that._queryServiceIdentifier);
that._cacheId = queryService.getCacheID();
that._cacheKey = queryService.getUrl(that._queryParameters);
var options = new Platform.DataServices.QueryServiceOptions();
var hasValidData = false;
var promise = new WinJS.Promise(function (complete, error, progress) {
queryService.downloadDataAsync(that._queryParameters, null, null, options).then(function (response) {
var processedResponse = that._processResponse(response);
if (!processedResponse || !processedResponse.metadata || !processedResponse.metadata.isValid) {
return error();
}
return complete(processedResponse);
}, function (err) {
if (SportsJS.Utilities.isCancellationError(err)) {
return;
}
return error();
}, function (progressResponse) {
if (progressResponse.statusCode === Platform.DataServices.QueryServiceStatusCode.cachedEntryFound && progressResponse.cachedResponse) {
var processedResponse = that._processResponse(progressResponse.cachedResponse);
if (!processedResponse || !processedResponse.metadata || !processedResponse.metadata.isValid) {
return;
}
return progress(processedResponse);
}
});
});
return promise;
},
//// return response Schema to be consumed directly by EditorialCollectionPage
//// A valid respone has data and metadata. 
//// data is an array of pages
//// Each page has a pageTitle, edgyButtonData(optional) and clusters
//// Each cluster has a clusterTitle and dataSet which is consumed by newsCluster
//// metadata has an additional field hasNoData indicating no data received. (apart from what is defined in ResponseMetaData)
//// By default, the provider puts the entire entityList into one cluster with specified cluster title on one page with the specified page title. 
_processResponse: function _processResponse(response) {
var that = this;
var outResponse = {
data: [],
metadata: new AppEx.Sports.Services.Utilities.ResponseMetadata(response),
};
if (!response || !response.dataString) {
return outResponse;
}
var jsonResponse = SportsJS.Utilities.jsonParse(response.dataString);
if (!jsonResponse) {
return outResponse;
}
if (!jsonResponse.clusters || jsonResponse.clusters.length === 0) {
outResponse.metadata.isValid = true;
outResponse.metadata.hasNoData = true;
return outResponse;
}
var clusters = jsonResponse.clusters;
var responseCluster = null;
for (var i = 0, imax = clusters.length; i < imax; i++) {
var cluster = clusters[i];
if (cluster.entityList && cluster.entityList.collectionId === that._collectionId) {
responseCluster = cluster;
break;
}
}
if (!responseCluster || !responseCluster.entityList || !responseCluster.entityList.entities || responseCluster.entityList.entities.length === 0) {
outResponse.metadata.isValid = true;
outResponse.metadata.hasNoData = true;
return outResponse;
}
var responseEntities = responseCluster.entityList.entities;
var outClusters = [];
var entityItems = [];
for (var j = 0, jmax = responseEntities.length; j < jmax; j++) {
var entity = responseEntities[j];
var entityItem = SportsJS.Utilities.convertCMSArticle(entity);
if (!entityItem) {
continue;
}
entityItem.editorialCollectionType = that._editorialCollectionType;
entityItems.push(entityItem);
}
if (entityItems.length === 0) {
return outResponse;
}
SportsJS.Utilities.setClusterArticles(entityItems);
outClusters.push({
clusterTitle: that._clusterTitle,
dataSet: {
newsItems: entityItems,
cacheID: that._cacheId,
dataCacheID: that._cacheKey,
clusterID: that._editorialCollectionType + "Page",
uniqueResponseID: response.responseId,
},
});
var page = {
pageTitle: that._pageTitle,
clusters: outClusters,
};
outResponse.data.push(page);
outResponse.metadata.isValid = true;
return outResponse;
},
_error: function _error(msg, parameter) {
var that = this;
var tag = that._errorTag;
if (parameter) {
msg = SportsJS.Utilities.stringFormat(msg, parameter);
}
SportsJS.Utilities.error(tag, msg);
},
}),
});
})();