﻿(function () {
'use strict';
WinJS.Namespace.define('SportsJS.Common', {
SportsHeroControl: WinJS.Class.derive(CommonJS.Immersive.ParallaxItemsContainer, function (element, options) {
var that = this;
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.Start);
that._leagueType = options.league;
this._herotype = options.herotype;
this._herokey = options.herokey;
this._heroSetting = options.heroSetting;
this._onRenderCompleteCallBack = options.onRenderComplete;
that.marketParam = SportsJS.Utilities.getCMSHeroMarketString(that._heroSetting);
if (that._leagueType === "today") {
that._herotype = "today";
that.pageid = SportsJS.Utilities.getLeagueCmsMappings(that._herokey);
}
that._requestUrl = this._getLocalCacheKey(options);
var localCacheResponse = that.localCacheResponse;
if (that.shouldHandleProgress !== false && localCacheResponse) {
this.lastModified = localCacheResponse.lastModified;
if (localCacheResponse) {
this._hasRendered = true;
this._progressAlreadyConsumed = true; // can we think of a case where this is not true
this._cmsdata = localCacheResponse.data;
this._heroData = { data: localCacheResponse.data, response: localCacheResponse };
this._updateStalenessParameters(localCacheResponse);
}
}
CommonJS.Immersive.ParallaxItemsContainer.call(this, element, options);
WinJS.UI.setOptions(this, options);
that.imageData = that.getImageData(this._cmsdata);
that.itemDataSource = that.getItemData(this._cmsdata);
that.className = "sportsHeroClusterCmsLayout";
SportsJS.Common.SportsHeroControl.InitializeModuleParams(options.league, options.teamId, options.heroSummaryType);
that.onRenderInit = options.onClusterRenderInit;
// Startup Optimization: if we have cached data then render immediately.
if (this._progressAlreadyConsumed) {
this._heroRenderPromise = this.render();
}
},
{
_herotype: null,
_herokey: null,
_heroData: null,
_cmsdata: null,
_isValidObject: true,
_placeHolderDataSource: null,
_placeHolderImageData: null,
_maxArticles: 12,
_heroSetting: SportsJS.UI.HeroType.image,
_isLocalCacheResponse: false,
// tells if the control has atleast rendered once using valid data
_hasRendered: false,
// cache response for local cache
_localCacheResponse: null,
// data request url, used as key to save data in local cache
_requestUrl: null,
// scheduler (timeout) promise for refresh task
_refreshSchedulePromise: null,
// handle to refresh task
_fetchAndRenderPromise: null,
// indicatse if progress response has been consumed once. This means we should not report progress response any further
_progressAlreadyConsumed: false,
_heroRenderPromise: null,
_getLocalCacheKey: function _getLocalCacheKey(options) {
var that = this;
var key = null;
// Since accessing AppEx.Sports.Services.Request and SportsController takes more time (for the first time) and 
// below code is part of app startup code path, not using uiQuery to create the key for today's page. 
if (that._leagueType === "today") {
key = "todayHero" + that._leagueType + that.pageid + $SpMgr.cmsPreviewEnabled + that.marketParam;
} else {
var uiQuery = null;
if (that._herotype === "league") {
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.LeagueHeroQuery(that._leagueType, $SpMgr.cmsPreviewEnabled, that.marketParam);
}
else if (that._herotype === "team") {
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.TeamHeroQuery(that._leagueType, options.teamId, $SpMgr.cmsPreviewEnabled, that.marketParam);
}
key = AppEx.Sports.Services.SportsController.getUrl(uiQuery);
}
return key;
},
// cache response for local cache
localCacheResponse: {
get: function get() {
var response;
if (this._localCacheResponse) {
return this._localCacheResponse;
}
if (SportsJS.mainProcessManager.heroLocalCache.hasKey(this._requestUrl)) {
this._localCacheResponse = SportsJS.mainProcessManager.heroLocalCache.getItem(this._requestUrl);
this._localCacheResponse = SportsJS.Utilities.jsonParse(this._localCacheResponse);
if (this._localCacheResponse) {
this._localCacheResponse.lastUpdateTime = SportsJS.Utilities.isoDateStringToDateObject(this._localCacheResponse.lastUpdateTime);
var currTS = (new Date()).getTime();
var expiryTS = Date.parse(this._localCacheResponse.entryExpiresAt);
var tsDiff = !isNaN(expiryTS) ? currTS - expiryTS : 1; // 1, number greater than 0, to force staleness
this._localCacheResponse.isStaleResponse = (tsDiff > 0) ? true : false;
var defaultExpiry = AppEx.Sports.Services.SportsController.getCacheDefaultExpiry(this._localCacheResponse.cacheID);
this._localCacheResponse.maxAge = defaultExpiry - Math.floor(((new Date()).getTime() - this._localCacheResponse.lastUpdateTime.getTime()) / 1000);
}
}
return this._localCacheResponse;
},
set: function set(response) {
var that = this;
if (that._requestUrl && response && response.lastUpdateTime) {
var defaultExpiry = AppEx.Sports.Services.SportsController.getCacheDefaultExpiry(response.cacheID);
response.maxAge = defaultExpiry - Math.floor(((new Date()).getTime() - response.lastUpdateTime.getTime()) / 1000);
response.entryExpiresAt = new Date();
var expiry = (new Date()).getTime() + response.maxAge * 1000;
response.entryExpiresAt.setTime(expiry);
this._localCacheResponse = response;
SportsJS.mainProcessManager.heroLocalCache.addItem(that._requestUrl, SportsJS.Utilities.jsonStringify(response));
}
}
},
_updateLocalResponseExpiry: function _updateLocalResponseExpiry(res) {
var cachedResponse = this.localCacheResponse;
cachedResponse.lastUpdateTime = res.lastUpdateTime;
this.localCacheResponse = cachedResponse; // store the modified response
},
isStaleResponse: false,
lastUpdateTime: null,
onRenderInit: null,
_onRenderCompleteCallBack: null,
// get interval after whcih we should do refresh
_getRefreshInterval: function _getRefreshInterval() {
var minimumInterval = 1000;
var response = this.localCacheResponse;
// use the minimum interval if response is invalid/stale OR maxAge is undefined
if(!response || response.isStaleResponse === true || !response.maxAge) {
return minimumInterval;
}
// return interval in ms
return (response.maxAge * 1000);
},
render: function render() {
var that = this;
if (this._heroRenderPromise) {
return this._heroRenderPromise;
}
var p = new WinJS.Promise(function (c, e) {
var hasRendered = that._hasRendered;
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:Hero:render:s");
CommonJS.Immersive.ParallaxItemsContainer.prototype.render.call(that).then(function () {
var heroLoadModulePromise = that._heroLoadModulePromise ? that._heroLoadModulePromise : WinJS.Promise.wrap(true);
heroLoadModulePromise.then(function () {
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:Hero:render:e");
if (hasRendered && that._heroData && that._heroData.data) {
var currentResponse = that.localCacheResponse;
// this code rendering was done using Local Cache data
that._onRenderComplete(true);
// We can remove the first page load check and the else section... but not now as to minimize the risk
if ($SpMgr.isFirstPageLoad && currentResponse && currentResponse.isStaleResponse === true) {
// Using onRenderInit to control rendering of the next cluster in sequence.
that.onRenderInit(that, function () { });
} else {
var refreshInterval = that._getRefreshInterval();
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:Hero:refreshSchedule:s");
that._refreshSchedulePromise = WinJS.Promise.timeout(refreshInterval).then(function () {
if (!that._isValidObject) { return; }
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:Hero:refreshSchedule:e");
that.fetchAndRender();
});
}
}
c();
}, function () {
c();
});
}, function () {
c();
});
if (!that._hasRendered) {
// give control to parent for fetch & render trigger
that.onRenderInit(that, function () { });
}
});
this._heroRenderPromise = p;
return p;
},
fetchAndRender: function fetchAndRender() {
var that = this;
// this is required as renderProxy is public API, We can't assume caller to cancel this after cleanup
if (!that._isValidObject) {
return WinJS.Promise.wrap(true);
}
// cancel pending refresh schedule
SportsJS.Utilities.cancelPromise(that._refreshSchedulePromise);
that._refreshSchedulePromise = null;
that._fetchAndRenderPromise = new WinJS.Promise(function (complete, error) {
that.fetchProxy().then(function (success) {
if (!success) {
complete();
return;
}
that.renderProxy().then(function () {
complete();
}, function (errRes) {
if (SportsJS.Utilities.isCancellationError(errRes)) {
// simple return, no error if the promise has been cancelled
return;
}
error();
});
}, function (errRes) {
if (SportsJS.Utilities.isCancellationError(errRes)) {
// simple return, no error if the promise has been cancelled
return;
}
error();
});
});
return that._fetchAndRenderPromise;
},
fetchProxy: function fetchProxy() {
var that = this;
// this is required as fetchProxy is public API, We can't assume caller to cancel this after cleanup
if (!that._isValidObject) {
return WinJS.Promise.wrap(true);
}
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.Start, SportsJS.UI.ProfilerTagType.DataFetch);
if (that._herotype !== "league" && that._herotype !== "team" && that._herotype !== "today") {
return new WinJS.Promise(function (c) {
c(false);
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.Start, SportsJS.UI.ProfilerTagType.DataFetch);
});
}
var p = new WinJS.Promise(function (c, e) {
var isComplete = false;
SportsJS.Common.SportsHeroControl.CMSHeroDataSource.call(that, that.league, that.teamId, that.marketParam, that._herotype, that._maxArticles).then(function (result) {
that._heroData = result;
if (!isComplete) {
isComplete = true;
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.End, SportsJS.UI.ProfilerTagType.DataFetch);
c(true);
}
else {
//// If the promise is already completed, render has happened, we need to render again on getting fresh data
that._updateStalenessParameters(result.response);
that.renderProxy().then();
}
}, function (err) {
}, function (result) {
that._heroData = result;
if (!isComplete) {
isComplete = true;
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.End, SportsJS.UI.ProfilerTagType.DataFetch);
c(true);
}
else {
//// If the promise is already completed, render has happened, we need to render again on getting fresh data
this._updateStalenessParameters(result.response);
this.renderProxy().then();
}
});
});
return p;
},
_heroLoadModulePromise: null,
itemRenderer: function itemRenderer(item) {
var that = this;
var parentElement = document.createElement("div");
if (item && item.data && item.data.moduleInfo) {
var moduleInfo = item.data.moduleInfo;
that._heroLoadModulePromise = CommonJS.loadModule(moduleInfo, item.data, parentElement, null, null).then(function (renderedItem) {
that.handleClickOnHeroText(renderedItem, that._cmsdata);
}, function (err) { });
}
return parentElement;
},
customRenderer: {
get: function get() {
return this.itemRenderer.bind(this);
}
},
renderProxy: function renderProxy() {
var that = this;
// this is required as renderProxy is public API, We can't assume caller to cancel this after cleanup
if (!that._isValidObject) {
return WinJS.Promise.wrap(true);
}
var p = new WinJS.Promise(function (c, e) {
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.Start, SportsJS.UI.ProfilerTagType.Render);
var result = that._heroData;
if (result && result.response.isValid) {
var cmsdata = result.data;
that._cmsdata = cmsdata;
that.lastUpdateTime = result.response.lastUpdateTime;
that.isStaleResponse = result.response.isStaleResponse;
var refreshPromise = WinJS.Promise.wrap(true);
if (that._hasRendered) {
// this is a refresh scenario. Use platform refresh API for refresh
// this essentially waits for image to load and then updates the text.
// data is valid, we assume the data will be correct
var imageDataSource = that.getImageData(cmsdata);
var itemDataSource = that.getItemData(cmsdata);
that.preventPlatformAnimation = true; // disable animating the text
if (imageDataSource && imageDataSource.backgroundImage) {
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:Hero:refresh:s");
refreshPromise = that.refresh({ backgroundImage: imageDataSource.backgroundImage, itemDataSource: itemDataSource, attributionData: imageDataSource.attributionData }).then(function () {
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:Hero:refresh:e");
return WinJS.Promise.wrap(true);
});
}
}
else {
// this is an update scenario. This happens only in cold start
that._hasRendered = true;
that.updateImageData(cmsdata);
// in update scenario, the earlier registration for handleClick failed
// as we had empty dummy data then. We are here as we are trying to update 
// the dummy data with actual cms data, We need to do click registration
that.handleClickOnHeroText(that.element, cmsdata);
//update only in case this in Non ImageOnly heroCluster
if ((that._heroSetting !== SportsJS.UI.HeroType.image) && (that._heroSetting !== SportsJS.UI.HeroType.enwwimage)) {
that.updateItemData(cmsdata);
}
}
var completeRefresh = function () {
if (!that._isValidObject) { return; }
that._onRenderComplete(true);
c(true);
that._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.End, SportsJS.UI.ProfilerTagType.Render);
};
refreshPromise.then(completeRefresh, completeRefresh);
}
else {
// If we have not yet rendered, call "_handleImageError" to complete the promise
// which is otherwise completed when we request a network call to fetch image
// from a URL. Since in this case we do not have a valid URL to fetch image
// from, say because CMS is down, we still need to complete the promise. 
// Otherwise the app gets blocked and we don't render even the clusters for
// which we do have data.
if (that._hasRendered === false) {
that._handleImageError();
}
that._onRenderComplete(true);
c(true);
}
});
return p;
},
// fn -> is used when profiling a specific function. if function name is not specified, then
// this means the overall cluster loading is being traced
_traceMsProfileMarkInfo: function _traceMsProfileMarkInfo(markType, fn) {
var info = {
markType: markType ? markType : null,
entityType: SportsJS.UI.ProfilerEntityType.Cluster,
sports: this._leagueType,
page: SportsJS.UI.PageType.None,
cluster: SportsJS.UI.ClusterType.Hero,
func: fn ? fn : null
};
SportsJS.Utilities.sportsMsWriteProfilerMark(info);
},
handleClickOnHeroText: function handleClickOnHeroText(element, cmsdata) {
var that = this;
if (!element || !cmsdata) {
return;
}
var heroText;
if ((that._heroSetting === SportsJS.UI.HeroType.image) || (that._heroSetting === SportsJS.UI.HeroType.enwwimage)) {
heroText = element.querySelector('.sportsHeroClusterText');
if (heroText) {
heroText.style.display = 'none';
}
}
if (!cmsdata || !SportsJS.Common.SportsHeroControl.IsHeroClusterclickable(cmsdata)) {
return;
}
heroText = element.querySelector('.sportsHeroClusterText');
if (heroText) {
heroText.className += " clickableSportsHeroCluster";
PlatformJS.Utilities.enablePointerUpDownAnimations(heroText);
var onitemclick = function (e) {
if (cmsdata && cmsdata.clusterArticles) {
cmsdata.clusterArticles = SportsJS.Utilities.decorateEditorialInfoWithAdsInfo(cmsdata.clusterArticles);
}
SportsJS.Telemetry.logHeroClick(cmsdata.contentid);
SportsJS.Common.SportsHeroControl.LaunchHeroArticle({ item: cmsdata, marketParam: that.marketParam });
};
}
var textContainer = element.querySelector(".sportsHeroClusterText");
if (textContainer) {
PlatformJS.Utilities.registerItemClickProxy(textContainer,
function (domElement) {
return WinJS.Utilities.hasClass(domElement, "sportsHeroClusterText");
}, function (domElement) {
onitemclick(domElement);
});
}
},
getItemData: function getItemData(cmsdata) {
var heroListSource = new WinJS.Binding.List();
this._placeHolderDataSource = WinJS.Binding.as({
moduleInfo: {
isInteractive: true,
fragmentPath: "/leagues/common/Hero/heroImageOverlay.html",
//// assuming only two types for now
templateId: this._herotype === "team" ? "teamHeroImageOverlaycms" : "leagueHeroImageOverlaycms",
renderer: this.customRenderer
},
title: "",
byline: "",
snippet: "",
source: "",
sourceImageUrl: null,
});
heroListSource.push(this._placeHolderDataSource);
if (cmsdata && this._heroSetting !== SportsJS.UI.HeroType.image && this._heroSetting !== SportsJS.UI.HeroType.enwwimage) {
this.updateItemData(cmsdata);
}
return heroListSource.dataSource;
},
updateItemData: function updateItemData(cmsdata) {
var that = this;
if (!that._placeHolderDataSource) {
return;
}
that._placeHolderDataSource.title = toStaticHTML(cmsdata.headline),
that._placeHolderDataSource.byline = cmsdata.byline,
that._placeHolderDataSource.snippet = toStaticHTML(cmsdata.abstract),
that._placeHolderDataSource.source = cmsdata.source;
},
getImageData: function getImageData(cmsdata) {
var that = this;
var backgroundImage = "";
this._placeHolderImageData = WinJS.Binding.as({
fontColor: null,
attributionData: {
attributionText: "",
caption: "",
},
imageSize: {
width: 1190,
height: 768
},
anchorPoint: SportsJS.Common.SportsHeroControl.getAnchorMapping("Middle"),
backgroundImage: backgroundImage,
showGradient: true,
});
if (cmsdata) {
that.updateImageData(cmsdata);
}
return this._placeHolderImageData;
},
updateImageData: function updateImageData(cmsdata) {
var that = this;
if (!that._placeHolderImageData) {
return;
}
that._placeHolderImageData.fontColor = SportsJS.Utilities.getColorMapping(cmsdata.headerfont);
var imageAttribution = "";
if (cmsdata.imageAttribution) {
imageAttribution = cmsdata.imageAttribution;
}
var caption = "";
if (cmsdata.caption) {
caption = cmsdata.caption;
}
var attributionData = {
attributionText: imageAttribution,
caption: toStaticHTML(caption),
};
that._placeHolderImageData.attributionData = attributionData;
if (cmsdata.thumbnail) {
// we do not need low res, if response is cached.
if (cmsdata.thumbnailLowRes) {
that._placeHolderImageData.backgroundImage = {
lowResolutionUrl: cmsdata.thumbnailLowRes.url,
highResolutionUrl: cmsdata.thumbnail.url,
cacheId: "SportsHeroImageCache"
};
}
else {
that._placeHolderImageData.backgroundImage = cmsdata.thumbnail.url;
}
that._placeHolderImageData.imageSize = {
width: cmsdata.thumbnail.width,
height: cmsdata.thumbnail.height
};
} else {
that._placeHolderImageData.backgroundImage = "";
that._placeHolderImageData.imageSize = {
width: 1190,
height: 768
};
}
that._placeHolderImageData.source = cmsdata.source;
that._placeHolderImageData.showGradient = true;
that._placeHolderImageData.anchorPoint = SportsJS.Common.SportsHeroControl.getAnchorMapping(cmsdata.anchorpoint);
},
cleanUp: function cleanUp() {
var that = this;
if (that._heropromise && that._heropromise.cancel && typeof that._heropromise.cancel === 'function') {
that._heropromise.cancel();
}
if (that._heroLoadModulePromise && that._heroLoadModulePromise.cancel && typeof that._heroLoadModulePromise.cancel === 'function') {
that._heroLoadModulePromise.cancel();
that._heroLoadModulePromise = null;
}
SportsJS.Utilities.cancelPromise(that._refreshSchedulePromise);
SportsJS.Utilities.cancelPromise(that._fetchAndRenderPromise);
//// Platform is adding listeners for all properties on that._placeHolderImageData object. (bind method)
//// From MSDN, these listners are invoked asynchronously when the property may have changed.
//// Due to this, on quickly navigating through the edgy, we are observing them getting called 
//// after platform dispose has been called which sets _backgroundImage to null which is causing crashes.
//// We need to unbind the listeners for that._placeHolderImageData properties.
if (that._placeHolderImageData && that._placeHolderImageData.unbind) {
var keys = Object.keys(that._placeHolderImageData);
for (var i = 0; i < keys.length; i++) {
if (keys[i]) {
that._placeHolderImageData.unbind(keys[i]);
}
}
}
that._isValidObject = false;
},
_updateStalenessParameters: function _updateStalenessParameters(newResponse) {
var that = this;
var wasStaleResponse = that.isStaleResponse;
//// update staleness parameters
if (newResponse
&& typeof newResponse.isStaleResponse !== 'undefined'
&& typeof newResponse.lastUpdateTime !== 'undefined') {
that.isStaleResponse = newResponse.isStaleResponse;
that.lastUpdateTime = newResponse.lastUpdateTime;
}
//// fire data refresh if data became fresh
if (wasStaleResponse && !that.isStaleResponse) {
var eventObject = document.createEvent("CustomEvent");
eventObject.initCustomEvent("datarefreshed", true, true, null);
this.element.dispatchEvent(eventObject);
}
},
_onRenderComplete: function _onRenderComplete(isRenderSuccess) {
if (this._onRenderCompleteCallBack) {
this._onRenderCompleteCallBack(isRenderSuccess);
this._traceMsProfileMarkInfo(SportsJS.UI.ProfilerMarkType.End, null);
this._onRenderCompleteCallBack = null; // do not callback multiple times
}
},
},
{
ModuleParams: {
league: "",
teamId: "",
heroSummaryType: "",
},
InitializeModuleParams: function InitializeModuleParams(league, teamId, heroSummaryType) {
SportsJS.Common.SportsHeroControl.ModuleParams.league = league ? league : "";
SportsJS.Common.SportsHeroControl.ModuleParams.teamId = teamId ? teamId : "";
SportsJS.Common.SportsHeroControl.ModuleParams.heroSummaryType = heroSummaryType ? heroSummaryType : "";
},
CMSHeroDataSource: function CMSHeroDataSource(league, teamId, marketParam, heroType, maxArticles) {
var that = this;
var uiQuery;
if (that._herotype === "today") {
that.pageid = SportsJS.Utilities.getLeagueCmsMappings(league); // league is today in this case. chthakur -> Extensibility bug
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.CMSHeroQuery(that.pageid, $SpMgr.cmsPreviewEnabled, that.marketParam);
}
else if (that._herotype === "league") {
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.LeagueHeroQuery(league, $SpMgr.cmsPreviewEnabled, that.marketParam);
}
else if (that._herotype === "team") {
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.TeamHeroQuery(league, teamId, $SpMgr.cmsPreviewEnabled, that.marketParam);
}
var cacheID = AppEx.Sports.Services.SportsController.getCacheId(uiQuery);
var controller = AppEx.Sports.Services.SportsController();
var promise = new WinJS.Promise(function (complete, error, progress) {
var processResponse = function (res) {
if (!res || res.responseFailed) {
return null;
}
var cmsResult;
if (that._herotype === "today") {
cmsResult = SportsJS.Utilities.jsonParse(res.dataString);
PlatformJS.Ads.setAdConfig(cmsResult.adsData);
}
else {
// team/league has SDI response
var sdiResponse = SportsJS.Utilities.jsonParse(res.dataString);
if (sdiResponse && sdiResponse.Results && sdiResponse.Results.length > 0 && sdiResponse.Results[0] && sdiResponse.Results[0].Response) {
cmsResult = SportsJS.Utilities.jsonParse(sdiResponse.Results[0].Response.ResponseString);
}
else {
// this is not a sdi response
cmsResult = sdiResponse;
}
}
var result = null;
var newsEntityList = null;
if (cmsResult && cmsResult.clusters && cmsResult.clusters.length > 0) {
for (var i = 0 ; i < cmsResult.clusters.length; i++) {
var cluster = cmsResult.clusters[i];
if (cluster.type) {
if (cluster.type.toLowerCase() === "hero") {
result = cmsResult.clusters[i];
}
else if (cluster.type.toLowerCase() === "entitylist" && cluster.entityList && cluster.entityList.collectionId && cluster.entityList.collectionId.toLowerCase() === "rt_sports" && cluster.entityList.entities && cluster.entityList.entities.length > 0) {
newsEntityList = cluster.entityList.entities;
}
}
}
}
if (!result || !result.hero) {
return null;
}
var newsArticle = SportsJS.Utilities.convertCMSArticle(result.hero);
if (!newsArticle) {
return null;
}
var newsArticles = [newsArticle];
if (newsEntityList) {
// Push non-hero articles.
var max = newsEntityList.length;
if (typeof maxArticles !== "undefined") {
max = max > maxArticles ? maxArticles : newsEntityList.length;
}
for (var ii = 0; ii < max; ii++) {
var cmsArticle = SportsJS.Utilities.convertCMSArticle(newsEntityList[ii]);
if (!cmsArticle) {
continue;
}
newsArticles.push(cmsArticle);
}
}
newsArticle.clusterArticles = SportsJS.Utilities.getEditorialArticleInfos(newsArticles);
var response = {
isValid: true,
isStaleResponse: res.isStaleResponse,
lastUpdateTime: res.lastUpdateTime,
data: newsArticle,
responseId: res.responseId,
lastModified: result.lastModified ? result.lastModified.utctime : null,
cacheID: cacheID
};
return response;
};
var hasValidData = that._progressAlreadyConsumed;
var lastModified;
if (that._progressAlreadyConsumed) {
lastModified = that.lastModified;
}
controller.request(uiQuery).then(function (res) {
if (res
&& that._localCacheResponse && res.responseId && that._localCacheResponse.responseId && (res.responseId === that._localCacheResponse.responseId)
&& hasValidData === true) {
if (res.lastUpdateTime !== that.localCacheResponse.lastUpdateTime) {
that._updateLocalResponseExpiry(res);
}
that._updateStalenessParameters(res);
promise.cancel();
return;
}
var response = processResponse(res);
//// CMS server doesn't implement If-Modified-Since or If-None match. Hence, we compare lastModified timestamp to find if data has not changed to avoid re-rendering when data has not changed
if (lastModified && response && response.lastModified && lastModified === response.lastModified) {
if (that.localCacheResponse && res.lastUpdateTime !== that.localCacheResponse.lastUpdateTime) {
that._updateLocalResponseExpiry(res);
}
that._updateStalenessParameters(res);
promise.cancel();
return;
}
if (response) {
hasValidData = true;
that.localCacheResponse = response;
complete({ data: response.data, response: response });
}
else {
if (hasValidData) {
//// We dont want to do anything if complete didnt get valid data but we already have valid data from progress
promise.cancel();
}
else {
var newsArticle = {};
complete({ data: newsArticle, response: { isValid: false, data: newsArticle } });
}
}
}, function () { },
function (progressData) {
if (that.shouldHandleProgress === false || that._progressAlreadyConsumed) {
return;
}
if (progressData) {
var response = processResponse(progressData.modelResponse);
if (response) {
lastModified = response.lastModified;
hasValidData = true;
that.localCacheResponse = response;
progress({ data: response.data, response: response });
}
}
});
});
return promise;
},
/// <summary>
/// Loads the article identified by articleId in the article reader.
/// </summary>
LaunchHeroArticle: function LaunchHeroArticle(e) {
if (e && e.item) {
var data = e.item;
var articleUrl = data.articleurl;
//use article reader flag
var useArticleReader = PlatformJS.Services.appConfig.getBool("UseArticleReader");
// if the response from bedrock has article url then open the same in the browser
if (articleUrl && articleUrl !== "") {
var newsFramePageEnabled = PlatformJS.Services.appConfig.getBool("ShowNewsFramePage");
if (newsFramePageEnabled) {
var leagueType = SportsJS.UI.LeagueType.all;
if (PlatformJS.Navigation && PlatformJS.Navigation.currentIPage && PlatformJS.Navigation.currentIPage._leagueType) {
leagueType = PlatformJS.Navigation.currentIPage._leagueType;
}
msSetImmediate(function () {
PlatformJS.Navigation.navigateToChannel("SportsFrame", { sourceUrl: articleUrl, leagueType: leagueType });
});
} else {
var uri = new Windows.Foundation.Uri(articleUrl);
Windows.System.Launcher.launchUriAsync(uri).then();
}
}
else if (data.articleid && useArticleReader) { //if article id is specified use article reader
var receivedarticleId = data.articleid;
var articleId = "";
if (typeof (receivedarticleId) === "number") {
articleId = receivedarticleId.toString(10);
}
else if (typeof (receivedarticleId) === "string") {
articleId = receivedarticleId;
}
else {
return;
}
var contentId = (data.contentid && data.contentid.length > 0) ? data.contentid : null;
SportsJS.Utilities.launchArticle(articleId, contentId, Platform.Instrumentation.InstrumentationEditorialSourceId.heroImage, SportsJS.Common.SportsHeroControl.ModuleParams.league, e.item.clusterArticles, e.marketParam);
}
}
},
IsHeroClusterclickable: function IsHeroClusterclickable(data) {
if (data) {
var articleUrl = data.articleurl;
var useArticleReader = PlatformJS.Services.appConfig.getBool("UseArticleReader");
if ((articleUrl && articleUrl !== "") || (data.articleid && useArticleReader)) {
return true;
}
else {
return false;
}
}
},
getAnchorMapping: function getAnchorMapping(mappingText) {
var fallBackAnchor = "anchorLeft";
if (mappingText === "Top") {
return "anchorTop";
}
else if (mappingText === "Left") {
return "anchorLeft";
}
else if (mappingText === "Bottom") {
return "anchorBottom";
}
else if (mappingText === "Right") {
return "anchorRight";
}
else if (mappingText === "Middle") {
return "anchorMiddle";
}
else {
return fallBackAnchor;
}
},
}),
});
})();
