﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.News", {
NewsPano: WinJS.Class.derive(SportsJS.Page,
/// <summary>
/// Constructor for your IPage class
/// </summary>
/// <param name="state">
/// The state object passed to WinJS.Navigation.navigate or the state object
/// preserved when the page has been navigated away from
/// </param>
function (state) {
var that = this;
that._leagueName = (state && state.league && state.league !== "") ? state.league : SportsJS.UI.LeagueType.all;
that._leagueType = (state && state.league && state.league !== "") ? state.league : SportsJS.UI.LeagueType.all;
that._pageType = SportsJS.UI.PageType.News;
that._basePageConstructor(state);           
},
{            
pageUri: {
get: function get() {
var pageState = this._stateData;
var uriBuilder = new Platform.Utilities.AppExUriBuilder();
uriBuilder.controllerId = SportsJS.NavControllers.news;
if (pageState && pageState.entity && pageState.league && pageState.id) {
uriBuilder.queryParameters.insert("id", pageState.id);
uriBuilder.queryParameters.insert("entity", pageState.entity);
uriBuilder.queryParameters.insert("league", pageState.league);
}
return uriBuilder.toString();
}
},
_isDeeplinkSharable: true,
getPageImpressionContext: function getPageImpressionContext() {
return "/" + SportsJS.UI.PageType.News;
},
_logTelemetry: function _logTelemetry() {
if (this._stateData && this._stateData.entity) {
SportsJS.Telemetry.logContent(this._pageType, this._stateData.entity, "", "");
}
},
getPageData: function getPageData() {
var that = this;
that._data = new WinJS.Binding.List();
SportsJS.Utilities.showProgressBar();
that._trace(SportsJS.Msg.GetDataRequestReceived);
that.clusterConfigs = that.getClusterConfig();
that._pageTitle = PlatformJS.Services.resourceLoader.getString("CategoryNewsClusterTitle");
var pageData = {
title: that._pageTitle,
listSource: that._data.dataSource,
};
var promise = new WinJS.Promise(function (complete, error) {
var parr = [];                    
var appInitPromise = SportsJS.mainProcessManager.appInitAsync();
parr.push(appInitPromise);
parr.push(that._loadRequiredFragments());
WinJS.Promise.join(that._promiseStack(parr)).then(function () {
that._timeoutWrapper(function () { complete(pageData); }, that.pageDataTimeout);
}, function (errRes) {
if (SportsJS.Utilities.isCancellationError(errRes)) {
// simple return, no error if the promise has been cancelled
return;
}
that.pageRenderErrorHandler();
error(null);
});                    
});
return promise;
},
/// <summary>
/// Gets the clusterConfigs for the page
/// </summary>
getClusterConfig: function getClusterConfig() {
var that = this;
if (that._clusterConfig) {
return that._clusterConfig;
}
that._clusterConfig = [];
var commonCfgs = SportsJS.Cluster.Configs.Common;
var newsItemcount = PlatformJS.Services.appConfig.getInt32("MaxColumnsInNewsPano");
if (!newsItemcount) {
newsItemcount = 15;
}
if (that._stateData && that._stateData.type) {
if ((that._stateData.type !== SportsJS.UI.NewsType.disabled) && that._stateData.entity) {
// only required for league/team/player. Today doesn't uses these params
var configParams = {
configOptions: {
NewsQuery: that._stateData.query,
NewsQueryType: SportsJS.UI.NewsType.bingquery
}
};
switch (that._stateData.entity) {
case SportsJS.UI.EntityType.Today:
that._clusterConfig.push(commonCfgs.categoryNewsCluster("", "", "", newsItemcount, true));
break;
case SportsJS.UI.EntityType.League:
that._clusterConfig.push(commonCfgs.leagueNewsCluster(that._stateData.league, "", configParams, newsItemcount, true));
break;
case SportsJS.UI.EntityType.Team:
that._clusterConfig.push(commonCfgs.teamNewsCluster(that._stateData.league, "", configParams, newsItemcount, true));
break;
case SportsJS.UI.EntityType.Player:
that._clusterConfig.push(commonCfgs.playerNewsCluster(that._stateData.league, "", configParams, newsItemcount, true));
break;
}
}                    
}
else {
var todayNewsType = SportsJS.Utilities.getNewsTypeForPage(SportsJS.UI.PageType.Today);
if (todayNewsType && (todayNewsType.value === SportsJS.UI.NewsType.bingcategory || todayNewsType.value === SportsJS.UI.NewsType.rss)) {                       
that._clusterConfig.push(commonCfgs.categoryNewsCluster("", "", newsItemcount, true));
}
else {                     
}                    
}
if (that._clusterConfig.length > 0 && that._clusterConfig[0]) {
that._clusterConfig[0].clusterContent.contentOptions.adsConfig = { adClusterId: "" };
}
that.injectRenderConfigInClusterConfigs();
return that._clusterConfig;               
},
})
});
})();
