﻿(function () {
'use strict';
WinJS.Namespace.define('SportsJS.Common.PreviewRecap', {
PreviewRecapProvider: WinJS.Class.derive(SportsJS.Common.EditorialCollection.EditorialCollectionPageProvider, function () {
SportsJS.Common.EditorialCollection.EditorialCollectionPageProvider.call(this);
},
{
_queryServiceIdentifier: {
get: function get() {
return "PreviewRecapDataSource";
}
},
_isUniqueEndpoint: {
get: function get() {
return true;
}
},
_errorTag: {
get: function get() {
return "SportsJS.Common.PreviewRecap.PreviewRecapProvider";
}
},
_processResponse: function _processResponse(response) {
var that = this;
var outResponse = {
data: [],
metadata: new AppEx.Sports.Services.Utilities.ResponseMetadata(response),
};
if (!response || !response.dataString) {
return outResponse;
}
var jsonResponse = SportsJS.Utilities.jsonParse(response.dataString);
if (!jsonResponse) {
return outResponse;
}
if (!jsonResponse.clusters || jsonResponse.clusters.length === 0) {
outResponse.metadata.isValid = true;
outResponse.metadata.hasNoData = true;
return outResponse;
}
var responseCluster = jsonResponse.clusters[0];
if (!responseCluster.entityList || !responseCluster.entityList.entities || responseCluster.entityList.entities.length === 0) {
outResponse.metadata.isValid = true;
outResponse.metadata.hasNoData = true;
return outResponse;
}
var responseEntities = responseCluster.entityList.entities;
//// 2 entities map to a single cluster
//// This code would be modified as and when schema gets finalized
var clusters = [];
var gameTimes = [];
var output;
for (var responseEntityNum = 0, responseEntityMax = responseEntities.length; responseEntityNum < responseEntityMax; responseEntityNum += 2) {
var dummyEntity = responseEntities[responseEntityNum];
var actualEntity = responseEntities[responseEntityNum + 1];
if (!dummyEntity || !dummyEntity.content || !actualEntity) {
continue;
}
var content = dummyEntity.content;
var gameTime;
if (that._leagueName === $SpMgr.getLeagueString(Microsoft.AppEx.Sports.SportsEnums.League.nfl)) {
gameTime = parseInt(dummyEntity.template);
}
else {
var bdiTime = content.publicationDate && content.publicationDate.published && content.publicationDate.published.utctime ? content.publicationDate.published.utctime : null;
gameTime = SportsJS.DateTimeHelpers.convertBdiTimeToETDate(bdiTime);
}
if (!gameTime) {
continue;
}
//// Push the time if not already present
var gameTimeIndex = -1;
for (var ii = 0, iimax = gameTimes.length; ii < iimax; ii++) {
output = SportsJS.Utilities.PreviewRecapTryIsGameTimeEqual(that._leagueName, gameTimes[ii], gameTime);
if (output.success && output.value === true) {
gameTimeIndex = ii;
break;
}
}
if (gameTimeIndex === -1) {
gameTimes.push(gameTime);
}
else {
if (gameTime < gameTimes[gameTimeIndex]) {
gameTimes[gameTimeIndex] = gameTime;
}
}
var clusterTitle = that._getClusterTitle(content.headline);
if (!clusterTitle) {
continue;
}
var newsItem = SportsJS.Utilities.convertCMSArticle(actualEntity);
if (!newsItem) {
continue;
}
//// Need to hardcode templateClass to A
newsItem.templateClass = "A";
newsItem.editorialCollectionType = that._editorialCollectionType;
clusters.push({
gameTime: gameTime,
clusterTitle: clusterTitle,
dataSet: {
newsItems: [newsItem],
cacheID: this._cacheId,
dataCacheID: this._cacheKey,
clusterID: gameTime.toString() + clusterTitle,
uniqueResponseID: response.responseId,
},
});
}
if (clusters.length === 0) {
return outResponse;
}
var preferredTimes = that._getPreferredGameTimes(gameTimes);
var timeClusters = [];
for (var clusterNum = 0, clusterMax = clusters.length; clusterNum < clusterMax; clusterNum++) {
var cluster = clusters[clusterNum];
var clusterTimeIndex = -1;
//// Find if cluster is preffered
for (var preferredTimeNum = 0, preferredTimeMax = preferredTimes.length; preferredTimeNum < preferredTimeMax; preferredTimeNum++) {
output = SportsJS.Utilities.PreviewRecapTryIsGameTimeEqual(that._leagueName, cluster.gameTime, preferredTimes[preferredTimeNum]);
if (output.success && output.value === true) {
clusterTimeIndex = preferredTimeNum;
break;
}
}
if (clusterTimeIndex !== -1) {
if (!timeClusters[clusterTimeIndex]) {
timeClusters[clusterTimeIndex] = [];
}
timeClusters[clusterTimeIndex].push(cluster);
}
}
for (var i = 0; i < timeClusters.length; i++) {
var currentTimeClusters = timeClusters[i];
//// For a date, clusters are sorted by most recent first
currentTimeClusters.sort(function (cluster1, cluster2) {
return cluster2.dataSet.newsItems[0].publishUTCTime - cluster1.dataSet.newsItems[0].publishUTCTime;
});
var currentTimeArticles = [];
currentTimeClusters.forEach(function (value, index, array) {
currentTimeArticles.push(value.dataSet.newsItems[0]);
});
SportsJS.Utilities.setClusterArticles(currentTimeArticles);
var currentTime = currentTimeClusters[0].gameTime;
var formattedTime;
if (that._leagueName === $SpMgr.getLeagueString(Microsoft.AppEx.Sports.SportsEnums.League.nfl)) {
formattedTime = SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("/Common/WeekNum"), currentTime.toString());
}
else {
var dateResponse = AppEx.Sports.Services.Utilities.DateTimeStringConstructor.tryGetDateTimeString(currentTime.getFullYear(), currentTime.getMonth() + 1, currentTime.getDate(), "M");
if (!dateResponse.value) {
continue;
}
formattedTime = dateResponse.dateTimeString;
}
var page = {
pageTitle: that._getPageTitle(formattedTime),
edgyButtonData: {
title: formattedTime,
icon: SportsJS.UI.IconType.date,
},
//// Sort the articles by most recent first
clusters: currentTimeClusters
};
outResponse.data.push(page);
}
if (outResponse.data.length > 0) {
outResponse.metadata.isValid = true;
}
return outResponse;
},
//// Returns 2 dates in chronological order (most recent first, exception being today. If today present, it is the first)
//// For NFL, this will return the most recent weeks
_getPreferredGameTimes: function _getPreferredGameTimes(gameTimes) {
var that = this;
if (!gameTimes || gameTimes.length < 2) {
return gameTimes;
}
gameTimes.sort(function (time1, time2) {
return time2 - time1;
});
var preferredGameTimes = gameTimes.splice(0, 2);
if (that._leagueName === $SpMgr.getLeagueString(Microsoft.AppEx.Sports.SportsEnums.League.nfl)) {
return preferredGameTimes;
}
var ETToday = SportsJS.DateTimeHelpers.getCurrentDateinET(null, true);
var output = SportsJS.Utilities.PreviewRecapTryIsGameTimeEqual(that._leagueName, ETToday, preferredGameTimes[1]);
if (output.success && output.value === true) {
preferredGameTimes.reverse();
}
return preferredGameTimes;
},
_getPageTitle: function _getPageTitle(localDate) {
if (!localDate) {
return null;
}
var that = this;
var formatStringKey;
var editorialCollectionType = AppEx.Sports.Services.TypeDefs.EditorialCollectionType;
if (that._editorialCollectionType === editorialCollectionType.recap) {
formatStringKey = "RecapsPageTitle";
}
else {
formatStringKey = "PreviewsPageTitle";
}
return SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString(formatStringKey), localDate);
},
_getClusterTitle: function _getClusterTitle(headline) {
var clusterTitle;
if (headline) {
try {
var parser = new DOMParser();
var headDom = parser.parseFromString(headline, "text/html");
clusterTitle = SportsJS.Utilities.ParseTextNodes(headDom);
}
catch (e) { clusterTitle = headline; }
}
//// TODO(saarya): This is a hack to get around dummy new lines in cluster title.
//// Ideally should not be needed
return clusterTitle ? clusterTitle.replace("\n", "") : clusterTitle;
},
},
{
}),
});
})();