﻿(function () {
'use strict';
//requires utilities and modulesconfig, TODO: provide overriding for properties
WinJS.Namespace.define("SportsJS.Common.Clusters", {
StandingsClusterControl: WinJS.Class.derive(SportsJS.UI.SportsCluster, function (element, options) {
var _options = options ? options : {};
_options.dataProvider = this.dataProvider;
SportsJS.UI.SportsCluster.call(this, element, _options);
}, {
standingsDataDescription: null,
legendMarker1: null,
legendMarker2: null,
legendMarker3: null,
legendMarker4: null,
constructUiQuery: function constructUiQuery() {
var that = this;
var league = that.league ? that.league : "";
var uiQuery = new AppEx.Sports.Services.TypeDefs.Request.LeagueStandingsClusterQuery(league);
if (!uiQuery || !uiQuery.isValid){
return null;
}
return uiQuery;
},
// sort module configs in zig-zag order when we show conferences horizontally
_sortModuleConfigs: function _sortModuleConfigs(configs) {
// zig-zag ordering is not needed when we conferences veritically
// we show modules in vertical order when the screen size more than 1160px.
var clientHeight = document.body.clientHeight;
var isVerticallyOrdered = clientHeight >= 1160;
if (isVerticallyOrdered) {
return configs;
}
// ASSUME: we always have two conferences and input configs are already ordered by conference names
var sortedConfigs = [];
if (configs && configs.length > 1) {
var totalConfigs = configs.length;
var conf1Index = 0;
var conf2Index = Math.floor(totalConfigs / 2);
while (conf2Index < totalConfigs) {
sortedConfigs.push(configs[conf1Index]);
sortedConfigs.push(configs[conf2Index]);
conf1Index++;
conf2Index++;
}
}
return sortedConfigs;
},
getModuleConfigs: function getModuleConfigs(clusterResponse) {
var that = this;
if (!clusterResponse || !clusterResponse.isValid) {
return WinJS.Promise.wrapError();
}
var moduleConfigs = [];
var league = this.league ? this.league : "";
this.standingsDataDescription = clusterResponse.standingsLegendResponse[0] ? clusterResponse.standingsLegendResponse[0].value : "";
this.legendMarker1 = clusterResponse.standingsLegendResponse[1] ? clusterResponse.standingsLegendResponse[1].value : "";
this.legendMarker2 = clusterResponse.standingsLegendResponse[2] ? clusterResponse.standingsLegendResponse[2].value : "";
this.legendMarker3 = clusterResponse.standingsLegendResponse[3] ? clusterResponse.standingsLegendResponse[3].value : "";
this.legendMarker4 = clusterResponse.standingsLegendResponse[4] ? clusterResponse.standingsLegendResponse[4].value : "";
var basicInfoPromise = new WinJS.Promise(function (complete, error) {
if (clusterResponse && clusterResponse.data) {
var divisionResponse = clusterResponse.data;
var confDivisionCount = {};/* division count for each conference*/
var divisionArray = Object.keys(divisionResponse);
// set config params for different division modules
for (var kk = 0; kk < divisionArray.length; kk++) {
// we need any one division object in an array
var division0 = divisionResponse[divisionArray[kk]][0]; 
if (!division0) { continue; }
confDivisionCount[division0.confDivision] = confDivisionCount[division0.confDivision] ? confDivisionCount[division0.confDivision] : 1;
var divisionCount = confDivisionCount[division0.confDivision];
var configParams = {
dataId: division0.dataId,
divisionTitle: division0.divisionTitle,
division: division0.division,
className: division0.confDivision + divisionCount,
league: league,
telemetryId: that._clusterType,
};
var config = SportsJS.Modules.Configs.Common.divisionStandings(configParams);
moduleConfigs.push(config);
confDivisionCount[division0.confDivision] = confDivisionCount[division0.confDivision] + 1;
}
var orderedConfigs = that._sortModuleConfigs(moduleConfigs);
complete(orderedConfigs);
}
else {
error(false);
}
});
return basicInfoPromise;
},
processResponse: function processResponse(res) {
if (!res || !res.isValid) {
return null;
}
//// single response contains arrays. Need to be converted into direct properties of the object
var convertArrayElementsToProperties = true;
var jsResponse = SportsJS.Utilities.copyCsResponseMeta(res, {});
jsResponse.data = {};
var keys = Object.keys(res.standingsDivisionResponse);
for (var kk = 0; kk < keys.length; kk++) {
var key = keys[kk];
var keyData = res.standingsDivisionResponse[key];
jsResponse.data[key] = SportsJS.Utilities.nativeArrayToJsArray(keyData, convertArrayElementsToProperties);
}
jsResponse.standingsLegendResponse = SportsJS.Utilities.nativeObjectToJsObject(res.standingsLegendResponse);
var response = jsResponse;
if (response && response.data && response.standingsLegendResponse) {
return response;
}
return null;
}
})
});
})();
