﻿(function () {
"use strict";
WinJS.Namespace.define("SportsJS.Common.Modules", {
EntityCollectionModuleControl: WinJS.Class.derive(SportsJS.UI.SportsModule, function (element, options) {
var that = this;
if (!options || !options.leagueType || typeof options.pageType === 'undefined' || !options.entityCollectionType) {
throw new Error("EntityCollectionModuleControl: one of mandatory options missing from config.");
}
that._entityCollectionType = options.entityCollectionType;
options.innerListViewOptions = that._getInnerListOptions();
that._entitySearchUI = new SportsJS.SportsEntitySearchUI(that._entityCollectionType.entityType, this);
options.eventHandler = SportsJS.Common.Modules.EntityCollectionModuleControl.tileClickEventHandler.bind(that),
SportsJS.UI.SportsModule.call(this, element, options);
},
{
_currentSuggestions: null,
_entityCollectionType: null,
_entitySearchUI: null,
_entitySearchSuggestionsPromise: null,
_addTileKeyPromise: null,
_numSelectedListViewItems: 0,
onlineEventHandler: null,
offlineEventHandler: null,
_onRenderComplete: function _onRenderComplete() {
var that = this;
if (!that.listControl) {
return;
}
SportsJS.Networking.addEventListener('networkonline', that._networkOnlineEventHandlerInstance, false);
SportsJS.Networking.addEventListener('networkoffline', that._networkOfflineEventHandlerInstance, false);
if (SportsJS.Networking.isInternetAvailable) {
that._networkOnlineEventHandlerInstance();
}
else {
that._networkOfflineEventHandlerInstance();
}
},
_networkOnlineEventHandlerInstance: {
get: function get() {
if (!this.onlineEventHandler) {
this.onlineEventHandler = this.networkOnlineEventHandler.bind(this);
}
return this.onlineEventHandler;
}
},
_networkOfflineEventHandlerInstance: {
get: function get() {
if (!this.offlineEventHandler) {
this.offlineEventHandler = this.networkOfflineEventHandler.bind(this);
}
return this.offlineEventHandler;
}
},
networkOnlineEventHandler: function networkOnlineEventHandler() {
var that = this;
if (that.listControl) {
that.listControl.enabledFeatures = CommonJS.UI.ListView2.FEATURES.ALL;
}
},
networkOfflineEventHandler: function networkOfflineEventHandler() {
var that = this;
if (that.listControl) {
that.listControl.enabledFeatures = CommonJS.UI.ListView2.FEATURES.ALL - CommonJS.UI.ListView2.FEATURES.ADD - CommonJS.UI.ListView2.FEATURES.REMOVE;
}
},
cleanUp: function cleanUp() {
var that = this;
SportsJS.Networking.removeEventListener('networkonline', that._networkOnlineEventHandlerInstance);
SportsJS.Networking.removeEventListener('networkoffline', that._networkOfflineEventHandlerInstance);
},
numSelectedListViewItems : {
get: function get() {
return this._numSelectedListViewItems;
}
},
_getAddTileKeyPromise: function _getAddTileKeyPromise() {
var that = this;
if (!that._addTileKeyPromise) {
that._addTileKeyPromise = that.getListViewLastItemKey();
}
return that._addTileKeyPromise;
},
getEntityData: function getEntityData(entityInfo) {
throw new Error("getEntityData should be defined in derived class.");
},
entityTileClickEventHandler: function entityTileClickEventHandler() {
throw new Error("entityTileClickEventHandler should be defined in derived class.");
},
showEntitySearchUI: function showEntitySearchUI() {
var that = this;
if (!SportsJS.Networking.isInternetAvailable) {
var msg = PlatformJS.Services.resourceLoader.getString("AddFavoritesFailedOnOffline");
SportsJS.Utilities.showPlatformMsgBar(msg);
return;
}
this._entitySearchUI.showQuickSearch();
},
_getDisambiguatedName: function _getDisambiguatedName(entityname, suggestion)
{
return (entityname + ":" + suggestion);
},
showEntitySearchSuggestions: function showEntitySearchSuggestions(event, src) {
var that = this;
//// Presence of entitySearchUI is mandatory
if (!that._entitySearchUI) {
return;
}
//// Hide whatever message was shown for last request
that._entitySearchUI.hideMessage();
//// Cancel the last auto suggest promise as we have a new request now
if (that._entitySearchSuggestionsPromise !== null) {
that._entitySearchSuggestionsPromise.cancel();
}
if (!event || !event.queryText || !event.request) {
src.searchSuggestions = { event: event, suggestions: [] };
}
else {
var deferral = event.request.getDeferral();
that._entitySearchSuggestionsPromise = SportsJS.mainProcessManager.search.entitySuggestions(event.queryText, that._entityCollectionType.entityFlavor);
that._entitySearchSuggestionsPromise.then(function (searchSuggestions) {
var suggestions = [];
var suggestionCountDict = {};
var sameEntityNameDict = {};
var disambiguatedName;
var i = 0;
for (i = 0; i < searchSuggestions.length; i++) {
if (searchSuggestions[i].matchingEntity && searchSuggestions[i].matchingEntity.name) {
if (suggestionCountDict[searchSuggestions[i].matchingEntity.name]) {
suggestionCountDict[searchSuggestions[i].matchingEntity.name]++;
}
else {
suggestionCountDict[searchSuggestions[i].matchingEntity.name] = 1;
}
disambiguatedName = that._getDisambiguatedName(searchSuggestions[i].matchingEntity.name, searchSuggestions[i].matchingEntity.suggestionDescription);
if (sameEntityNameDict[disambiguatedName]) {
sameEntityNameDict[disambiguatedName]++;
}
else {
sameEntityNameDict[disambiguatedName] = 1;
}
suggestions.push({
Title: searchSuggestions[i].matchingEntity.name,
value: searchSuggestions[i].matchingEntity.name,
description: searchSuggestions[i].matchingEntity.suggestionDescription,
league: searchSuggestions[i].matchingEntity.attributes.sports
});
}
}
for (i = 0; i < suggestions.length; i++) {
var suggestionTitle = suggestions[i].Title;
var suggestionVal = suggestions[i].value;
var suggestionDescr = suggestions[i].description;
var leagueName = "";
if (suggestions[i].league) {
leagueName = suggestions[i].league;
}
disambiguatedName = that._getDisambiguatedName(suggestionTitle, suggestionDescr);
if (sameEntityNameDict[disambiguatedName] > 1) {
suggestionTitle += " " + SportsJS.Utilities.getLocLeagueDisplayText(leagueName);
suggestionVal = SportsJS.Utilities.getLocLeagueDisplayText(leagueName) + " " + suggestionVal;
}
else if (suggestionCountDict[suggestionTitle] > 1 && suggestionDescr) {
suggestionTitle += " " + suggestionDescr;
suggestionVal = SportsJS.Utilities.getLocLeagueDisplayText(leagueName) + " " + suggestionVal;
}
suggestions[i].Title = suggestionTitle;
suggestions[i].value = suggestionVal;
}
that._currentSuggestions = suggestions;
src.searchSuggestions = { event: event, suggestions: suggestions };
});
deferral.complete();
}
},
addEntityToCollection: function addEntityToCollection(event) {
var that = this;
//// Presence of entitySearchUI is mandatory
if (!that._entitySearchUI) {
return;
}
if (!event || !event.queryText) {
return;
}
var actualQueryText = event.queryText;
if (that._currentSuggestions && 
event.index < that._currentSuggestions.length && 
that._currentSuggestions[event.index] && 
that._currentSuggestions[event.index].value) {
actualQueryText = that._currentSuggestions[event.index].value;
}
var resourceLoader = PlatformJS.Services.resourceLoader;
var stringFormat = SportsJS.Utilities.stringFormat;
var success = false;
//// queryText has extra spaces at end which are messing display strings. Stripping them off
event.queryText = event.queryText.trim();
actualQueryText = actualQueryText.trim();
that._entitySearchUI.showProgress();
that._promiseStack(SportsJS.mainProcessManager.search.query(actualQueryText)).then(function (searchResponse) {
if (!searchResponse) {
that._entitySearchUI.showMessage(success, SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("EntityNotFound"), event.queryText));
return;
}
var searchResponseObject = SportsJS.Search.getNavConfig(searchResponse);
if (!searchResponseObject || !searchResponseObject.entityId || !searchResponseObject.navConfig || !searchResponseObject.navConfig.sports) {
that._entitySearchUI.showMessage(success, stringFormat(resourceLoader.getString("EntityNotFound"), event.queryText));
return;
}
var entityId = searchResponseObject.entityId;
var entityLeague = searchResponseObject.navConfig.sports;
var entityType = that._entityCollectionType.entityType;
var entityCollectionName = that._entityCollectionType.name;
var entityInfo = new AppEx.Sports.Services.TypeDefs.SportsEntityInfo(entityId, entityLeague, entityType);
//// Check if entity already exists.
var checkOutput = SportsJS.Services.Roaming.RoamingDataManager.tryCheckEntityExistsInCollection(entityCollectionName, entityInfo);
if (!checkOutput.value) {
that._entitySearchUI.showMessage(success, stringFormat(resourceLoader.getString("EntityCouldNotBeAddedToCollection"), event.queryText, resourceLoader.getString(entityCollectionName)));
return;
}
if (checkOutput.doesEntityExist) {
that._entitySearchUI.showMessage(success, stringFormat(resourceLoader.getString("EntityAlreadyInCollection"), event.queryText, resourceLoader.getString(entityCollectionName)));
return;
}
//// Try to get data.
that._promiseStack(that.getEntityData(entityInfo)).then(function (entityData) {
if (!entityData) {
that._entitySearchUI.showMessage(success, stringFormat(resourceLoader.getString("EntityCouldNotBeAddedToCollection"), event.queryText, resourceLoader.getString(entityCollectionName)));
return;
}
//// Try to add entity to collection
if (!SportsJS.Services.Roaming.RoamingDataManager.tryAddToCollection(entityCollectionName, entityInfo)) {
that._entitySearchUI.showMessage(success, stringFormat(resourceLoader.getString("EntityCouldNotBeAddedToCollection"), event.queryText, resourceLoader.getString(entityCollectionName)));
return;
}
//// Both getData and add entity to roaming collection succeeded. 
//// Try to show Tile
if (!that.listControl || !that.listControl.itemDataSource) {
that._entitySearchUI.showMessage(success, stringFormat(resourceLoader.getString("EntityCouldNotBeAddedToCollection"), event.queryText, resourceLoader.getString(entityCollectionName)));
return;
}
var dataSource = that.listControl.itemDataSource;
that._promiseStack(that._getAddTileKeyPromise()).then(function (addTileKey) {
//// Get add tile key promise
if (!addTileKey) {
var msg = stringFormat(resourceLoader.getString("EntityCouldNotBeAddedToCollection"), event.queryText, resourceLoader.getString(entityCollectionName));
that._entitySearchUI.showMessage(success, msg);
return;
}
//// Insert entity tile before add tile. itemKey is needed by ListView2 functionality
entityData.itemKey = entityData.entityInfo.entityId;
that._promiseStack(dataSource.insertAtEnd(null, entityData)).then(function () {
var message = stringFormat(resourceLoader.getString("EntityAddedToCollection"), event.queryText, resourceLoader.getString(entityCollectionName));
that._logTelemetryAdd(entityData.entityInfo);
success = true;
that._entitySearchUI.hideQuickSearch();
}, function () {
var message = stringFormat(resourceLoader.getString("EntityCouldNotBeAddedToCollection"), event.queryText, resourceLoader.getString(entityCollectionName));
that._entitySearchUI.showMessage(success, message);
});
});                                                                   
});
});
},
removeEntityFromCollection: function removeEntityFromCollection(event) {
var that = this;
if (event && event.detail && event.detail.entityInfo && event.detail.entityInfo.entityId) {
var entityId = event.detail.entityInfo.entityId;
var entityLeague = SportsJS.Utilities.mapCStoJSLeagueType(event.detail.entityInfo.entityLeague);
var entityType = event.detail.entityInfo.entityType;
var entityInfo = new AppEx.Sports.Services.TypeDefs.SportsEntityInfo(entityId, entityLeague, entityType);
var success = SportsJS.Services.Roaming.RoamingDataManager.tryRemoveFromCollection(this._entityCollectionType.name, entityInfo);
that._logTelemetryRemove(entityInfo);
if (!success) {
that._trace(that._entityCollectionType.name + ":Failed to remove one of the entities from collection.");
}
}
},
_logTelemetryAdd: function _logTelemetryAdd(entity) {
throw new Error("Telemetry implementation missing");
},
_logTelemetryRemove: function _logTelemetryRemove(entity) {
throw new Error("Telemetry implementation missing");
},
},
{
tileClickEventHandler: function tileClickEventHandler(event, itemData) {
var that = this;                
if (itemData && itemData.isCommonJSAddTile) {
return;
}
that.entityTileClickEventHandler(event, itemData);
},           
}),
});
})();