﻿(function () {
"use strict";
WinJS.Namespace.define("SportsJS.Common.Modules", {
HeadlinesModuleControl: WinJS.Class.derive(SportsJS.UI.SportsModule, function (element, options) {
this._leagueName = options.leagueName;
this._entityType = options.entityType;
var _options = this._initializeOptions(options);
SportsJS.UI.SportsModule.call(this, element, _options);
},
{
_leagueName: null,
_entityType: null,
_initializeOptions: function _initializeOptions(options) {
var _options = options ? options : {};
_options.templateId = "moduleFragment";
_options.fragmentPath = "/leagues/common/modules/HeadlinesModule/HeadlinesModule.html";
_options.dataProvider = this.dataProvider;
_options.eventHandler = this.onItemClick;
_options.usesItemsContainer = true;
_options._isModuleScrollable = true;
_options.hasChrome = true;
return _options;
},
constructUiQuery: function constructUiQuery() {
var that = this;
// ideally collection id should be generated in c#, chthakur -> ankurg
var collectionId = SportsJS.Utilities.getEditorialCollectionId(that._leagueName, AppEx.Sports.Services.TypeDefs.EditorialCollectionType.headlines, that._entityType, null, false);
var uiQuery = new AppEx.Sports.Services.TypeDefs.Request.HeadlineQuery(collectionId);
if (!uiQuery.isValid) {
return null;
}
return uiQuery;
},
processResponse: function processResponse(res) {
var that = this;
var processedResponse = { data: null, isValid: false };
if (!res || !res.dataString){
return processedResponse;
}
processedResponse = SportsJS.Utilities.copyCsSportsResponseMeta(res, processedResponse);
var parsedResponse = that._parseResponse(res.dataString);
if (parsedResponse && parsedResponse.headlines) {
processedResponse.data = parsedResponse.headlines;
processedResponse.chromeData = parsedResponse.chromeData;
// chthakur - parsed response time is utc milliseconds. We deliberately want to store
// cache update time, which is already present in processedResponse. 
//processedResponse.lastUpdateTime = parsedResponse.lastUpdateTime;
processedResponse.isValid = true;
}
return processedResponse;
},
//For today
headlinesClusterGroupId: "headlines",
_parseResponse: function _parseResponse(jsonString) {
var that = this;
if (!jsonString) {
return null;
}
var jsonResponse;
try {
jsonResponse = SportsJS.Utilities.jsonParse(jsonString);
} catch (ex) {
return null;
}
if (!jsonResponse.clusters) {
return;
}
var clusters = jsonResponse.clusters;
var entities;
// get the headline entity
for (var i = 0; i < clusters.length; i++) {
var cluster = clusters[i];
if (cluster.entityList && cluster.entityList.collectionId.toLowerCase() === that.headlinesClusterGroupId) {
entities = cluster.entityList.entities;
break;
}
}
if (!entities || !entities.length || entities.length === 0) {
return null;
}
var result = {};
result.headlines = [];
for (var j = 0; j < entities.length; j++) {
var entity = entities[j];
var headline = that.constructHeadlineObject(entity);
var appUri = AppEx.Sports.Services.Utilities.SportsAppExUriManager.instance.createAppUri(headline.articleUrl);
headline.articleid = appUri.pageId ? appUri.pageId : "";
headline.contentid = appUri.contentId ? appUri.contentId : "";
headline.type = appUri.entitytype ? appUri.entitytype : "";
result.headlines.push(headline);
}
var editorialArticleInfos = SportsJS.Utilities.getEditorialArticleInfos(result.headlines);
for (var ii = 0, iimax = result.headlines.length; ii < iimax; ii++) {
result.headlines[ii].clusterArticles = editorialArticleInfos;
}
result.lastUpdateTime = jsonResponse.lastModified ? jsonResponse.lastModified.utctime : "";
result.chromeData = { provider: SportsJS.Utilities.stringFormat(PlatformJS.Services.resourceLoader.getString("HeadlinesProviderText"), "Associated Press") };
return result;
},
constructHeadlineObject: function constructHeadlineObject(result) {
if (!result) {
return null;
}
var headlineObject = {};
if (result.content) {
var content = result.content;
}
//remove html tags and extra stuff from text
headlineObject.title = content.headline ? toStaticHTML(content.headline.replace(/<(?:.|\n)*?>/gm, '')) : "";
// only 40 chars and ellipsis if length > 40 chars
if (headlineObject.title.length > 40) {
var croppedTitle = headlineObject.title.substr(0, 40);
//TODO: (angupt) localize this for other markets
croppedTitle = croppedTitle.concat("...");
headlineObject.title = croppedTitle;
}
if (content.publicationDate && content.publicationDate.published) {
var utcTime = result.content.publicationDate.published.utctime;
var time = CommonJS.Utils.convertBDITimeToFriendlyTime(utcTime);
headlineObject.publishTime = time;
}
else {
headlineObject.publishTime = "";
}
headlineObject.articleUrl = result.destination;
return headlineObject;
},
onItemClick: function onItemClick(eventObject, item) {
SportsJS.Telemetry.logHeadlinesClick(this._leagueName, item.data);
if (item && item.data && item.data.articleid && item.data.contentid) {
item.data.clusterArticles = SportsJS.Utilities.decorateEditorialInfoWithAdsInfo(item.data.clusterArticles);
var market = AppEx.Sports.Services.Utils.getEditorialCollectionMarket(AppEx.Sports.Services.TypeDefs.EditorialCollectionType.headlines);
SportsJS.Utilities.launchArticle(item.data.articleid, item.data.contentid, Platform.Instrumentation.InstrumentationEditorialSourceId.cluster, null, item.data.clusterArticles, market);
}
},
})
});
})();