﻿(function () {
'use strict';
WinJS.Namespace.define("SportsJS.Common.Modules", {
SportsTableModuleControl: WinJS.Class.derive(SportsJS.UI.SportsModule, function (element, options) {
var _options = options ? options : {};
_options.dataProvider = this.dataProvider;
_options.usesItemsContainer = (_options.usesItemsContainer && _options.usesItemsContainer === true) ? _options.usesItemsContainer : false;
_options.rendererInfo = this.rendererInfo;
_options.useOrderedRendering = true;
_options.fragmentPath = "/leagues/common/modules/SportsTableModule/SportsTableModule.html";
if (_options.usesItemsContainer) {
_options.templateId = "ContainerModuleFragment";
_options.eventHandler = _options.isItemClickEnabled ? this.onItemClick : null;
} else {
_options.templateId = "ListModuleFragment";
_options.innerListViewOptions = this._getInnerListOptions();
_options.eventHandler = this.onItemClick;
}
// TODO: arengak: We can derive these two options from data.
_options.tableSize = _options.tableSize ? _options.tableSize : SportsJS.UI.TableSize.Large;
_options.hasImage = _options.hasImage ? _options.hasImage : false;
// following flag marks the module as vertically scroallable, so baseclass will handle scroll etc. events on module
_options._isModuleScrollable = true;
_options._isModuleResizeable = true;
SportsJS.UI.SportsModule.call(this, element, _options);
var uniqueMarker = "SportsTable:" + (this.clusterId ? this.clusterId : "none");
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:" + uniqueMarker + ":Init:s");
// We are also including the height of immersive header, pano bottom margin and table header while measuring the table height. 
// This would increase the minimum row count by ~3 but it is fine as it helps to improve the smoothness of scroll
// when user does scroll down faster.
var approximateHeight = document.body.clientHeight;
// dividing screen height by table row height (50px), to get the no of rows to be loaded.
this._minimumRows = Math.round(approximateHeight / 50);
this._initialViewState = Windows.UI.ViewManagement.ApplicationView.value;
this._lastViewState = this._initialViewState;
// initially we will ask base class to render _minimumRows entries for quick rendering
this._maxEntriesToRender = this._minimumRows;
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:" + uniqueMarker + ":Init:e");
},
{
_initialViewState: null,
_lastViewState: null,
_minimumRows: null,
_completeResponse: null,
// override module scroll event
handleModuleScroll: function handleModuleScroll(controlElement) {
var that = this;
if (controlElement) {
that._moduleScrollEventHandler = function (event) {
if (event && event.currentTarget === controlElement) {
controlElement.removeEventListener("scroll", that._moduleScrollEventHandler, false);
that._moduleScrollEventHandler = null;
// this code can be removed once we have virtualization implemented in ItemsContainer control or in our App.
if (that._maxEntriesToRender && that._maxEntriesToRender !== -1 && that.usesItemsContainer) {
// if we don't have _completeResponse we can check jsCache for the response
if (that._completeResponse === null && that.dataProviderKey && SportsJS.mainProcessManager.jsCache.getItem(that.dataProviderKey)) {
var resString = SportsJS.mainProcessManager.jsCache.getItem(that.dataProviderKey);
var res = JSON.parse(resString);
that._completeResponse = res;
}
if (that._completeResponse !== null) {
var response = { response: that._completeResponse };
// set _maxEntriesToRender to -1, so that we will render all the entries now onwards
that._maxEntriesToRender = -1;
// modify the hashcode to not match the already stored response, as we must update
response.response.hashCode += 1;
$SpMgr.uiThreadTimer.reset();
that._consumeData(response, true);
}
}                            
}
};
controlElement.addEventListener("scroll", that._moduleScrollEventHandler, false);
controlElement.addEventListener("mousewheel", CommonJS.Immersive.PanoramaPanel.verticalScrollHandler, false);
}
},
// override module resize event
// we can remove this function once we have virtualization implemented in ItemsContainer control or in our App.
handleModuleResize: function handleModuleResize() {
var that = this;
that._moduleResizeEventHandler = function (event) {
var viewState = Windows.UI.ViewManagement.ApplicationView.value;
if (that._maxEntriesToRender && that._maxEntriesToRender !== -1 && that.usesItemsContainer) {
var lastViewState = that._lastViewState;
var initialState = that._initialViewState;
var updateTable = false;
var portraitMode = Windows.UI.ViewManagement.ApplicationViewState.fullScreenPortrait;
if (viewState !== lastViewState && viewState === portraitMode && initialState !== portraitMode) {
updateTable = true;
} else {
var approximateHeight = document.body.clientHeight;
// don't update if new height > ~50px
var rowsCount = Math.round(approximateHeight / 50) - 1;
if (rowsCount > that._minimumRows) {
updateTable = true;
}
}
if (updateTable) {
if (that._completeResponse === null && that.dataProviderKey && SportsJS.mainProcessManager.jsCache.getItem(that.dataProviderKey)) {
var resString = SportsJS.mainProcessManager.jsCache.getItem(that.dataProviderKey);
var res = JSON.parse(resString);
that._completeResponse = res;
}
if (that._completeResponse !== null) {
var response = { response: that._completeResponse };
// set _maxEntriesToRender to -1, so that we will render all the entries now onwards
that._maxEntriesToRender = -1;
// modify the hashcode to not match the already stored response, as we must update
response.response.hashCode += 1;
$SpMgr.uiThreadTimer.reset();
that._consumeData(response, true);
}
}
}
that._lastViewState = viewState;
};
window.addEventListener("resize", that._moduleResizeEventHandler);
},
constructUiQuery: function constructUiQuery() {
var that = this;
var moduleType = "table";
var league = that.league ? that.league : "";
var teamId = that.teamId ? that.teamId : "";
var tournamentId = that.tournamentId ? that.tournamentId : "";
var uiQuery = null;
if (that.clusterId === league + SportsJS.UI.ClusterType.DriverStandingsTable) {
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.DriverStandingsTableQuery(league);
}
else if (that.clusterId === league + SportsJS.UI.ClusterType.RaceResultTable) {
// TODO: arengak: the dummy gamecodes can be removed once we move game code dependency to middle tier.
var finalGameCode = "20120729012";
var liveGameCode = "20120729012";
// uiQuery = new AppEx.Sports.Services.TypeDefs.Request.RaceResultTableQuery(league, finalGameCode, liveGameCode);
// not supported for RaceResultTable
uiQuery = null;
}
else if (that.clusterId === league + SportsJS.UI.ClusterType.TeamStandingsTable) {
var division = that.division ? that.division : null;
if (division) {
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.TeamStandingsTableQuery(league, division);
}
else {
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.TeamStandingsTableQuery(league);
}
}
else if (that.clusterId === league + SportsJS.UI.ClusterType.LeaderBoardCluster
&& tournamentId !== "") {
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.LeadersTableQuery(league, tournamentId, moduleType);
}
else if (that.clusterId === league + SportsJS.UI.ClusterType.TableRoster) {
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.GenericRosterQuery(league, teamId);
}
else {
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.LeagueScheduleTableQuery(league);
}
if (!uiQuery || !uiQuery.isValid) {
return null;
}
return uiQuery;
},
_getInnerListOptions: function _getInnerListOptions() {
var innerListViewOptions = {
layout: { type: WinJS.UI.ListLayout },
itemRendererSelector: "InnerListItemTemplate",
};
return innerListViewOptions;
},
onItemClick: function onItemClick(eventObject, item) {
// TODO: chabh: we need a better way to handle onItemClick
if (this.league && item) {
var league = this.league;
if (this.usesItemsContainer) {
if (AppEx.Sports.Services.Utils.isSoccerLeague(league) && item && item.data && item.data.id !== null) {
msSetImmediate(function () {
SportsJS.Telemetry.logClusterClick(this.clusterId);
PlatformJS.Navigation.navigateToChannel(SportsJS.UI.PageType.Team, { leagueType: league, teamId: item.data.id });
});
}
} else {
if (AppEx.Sports.Services.Utils.isSoccerLeague(league) && item.id !== null) {
msSetImmediate(function () {
SportsJS.Telemetry.logClusterClick(this.clusterId);
PlatformJS.Navigation.navigateToChannel(SportsJS.UI.PageType.Team, { leagueType: league, teamId: item.id });
});
}
}
}
},
moduleBasicInfo: null,
dataProvider: function dataProvider(bypassCache, bypassProgress) {
var that = this;
var moduleType = "table";
var league = that.league ? that.league : "";
var teamId = that.teamId ? that.teamId : "";
var tournamentId = that.tournamentId ? that.tournamentId : "";
var requireListViewIncrementalFetching = that.requireListViewIncrementalFetching ? that.requireListViewIncrementalFetching : false;
var hasImage = that.hasImage ? that.hasImage : false;
if (requireListViewIncrementalFetching) {
that.innerListViewOptions.loadingBehavior = "incremental";
}
var promise = new WinJS.Promise(function (complete, error, progress) {
var isModuleBasicInfoRequired = false;
var moduleBasicInfoProvider = null;
var moduleBasicInfoFetchPromise = null;
var processModuleBasicInfo = null;
var controller = new AppEx.Sports.Services.SportsController();
var uiQuery = null;
var uniqueMarker = "SportsTable:" + (that.clusterId ? that.clusterId : "none");
if (that.clusterId === league + SportsJS.UI.ClusterType.RaceResultTable) {
isModuleBasicInfoRequired = true;
moduleBasicInfoProvider = SportsJS.SportsTable.Utilities.fetchFormulaOneGameCodes;
processModuleBasicInfo = function (moduleBasicInfo) {
var finalGameCode = "";
var liveGameCode = "";
if (moduleBasicInfo) {
finalGameCode = moduleBasicInfo.finalGameCode;
liveGameCode = moduleBasicInfo.liveGameCode;
}
// Check we have final game code. It is a mandatory option
if (finalGameCode) {
uiQuery = new AppEx.Sports.Services.TypeDefs.Request.RaceResultTableQuery(league, finalGameCode, liveGameCode);
}
else {
return false;
}
that.moduleBasicInfo = moduleBasicInfo;
return true;
};
} else {
uiQuery = that.constructUiQuery();
}
var processSportsTableResponse = function (res) {
return new WinJS.Promise(function (completeFn, errorFn) {
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:" + uniqueMarker + ":processResponse:s");
if (res && res.dataObject && res.dataObject.isValid) {
// Note: We want to have our memory consumption is as minimal as possible. 
// At Module control/XYZ place, we might clone the data for various purposes (Ex: JS side caching).
// The data is also converted as observable object before we bind it with a template. It is unnecessary to have all the fileds as observable.
// So if We find any unused entries in the response, remove them.
var etag = res.etag;
var maxAge = res.maxAge;
res = res.dataObject;
var previousResponseTimeStamp = that.providerResponse ? that.providerResponse.timeStamp : 0;
if (res.timeStamp && previousResponseTimeStamp && (res.timeStamp < that.providerResponse.timeStamp)) {
completeFn(null);
return;
}
// TODO: arengak: we can spilt the response into chunks then convert and merge them.
var response = SportsJS.Utilities.nativeObjectToJsObject(res);
response.etag = etag;
response.maxAge = maxAge;
if (!response.banner) {
response.banner = {};
response.banner.showBanner = false;
response.banner.supplementaryData = {};
for (var i = 0; i < 4; i++) {
response.banner.supplementaryData[i] = { name: "", value: "" };
}
}
var displayEntries = true;
if (response.rowList.length <= 0) {
// TODO: arengak: Actually this can be be handled in module control... just retaining the existing code in LST module
displayEntries = false;
response.data = [{ status: "NoData" }];
response.chromeData = { bindableHeader: response.bindableHeader, banner: response.banner, displayEntries: displayEntries };
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:" + uniqueMarker + ":processResponse:e");
completeFn(response);
return;
}
var refWidths = SportsJS.SportsTable.Utilities.getStringsWidthInPixels("sportsColumnTitle", response.referenceTexts);
var header = {};
var responseHeader = response.header.entryList;
var colCount = responseHeader.length;
for (var j = 0; j < colCount; j++) {
header["col" + j] = { text: responseHeader[j], type: response.columnType[j], width: refWidths[j] };
}
// For header we dont have separate template to choose based on table size. so pad the header to the max no of columns. 
for (var k = colCount; k < 12; k++) {
header["col" + k] = { text: "", type: "", width: "0px" };
}
var supplementaryDataBindable = {};
for (var index in response.banner.supplementaryData) {
supplementaryDataBindable["key" + index] = { name: response.banner.supplementaryData[index].name, value: response.banner.supplementaryData[index].value };
}
response.banner.supplementaryData = null;
response.chromeData = { banner: response.banner, bindableHeader: header, displayEntries: displayEntries };
response.chromeData.banner.supplementaryDataBindable = supplementaryDataBindable;
response.chromeData.hasImage = hasImage;
response.header = null;
response.banner = null;
var totalRows = response.rowList.length;
for (var x = 0; x < totalRows; x++) {
var row = response.rowList[x];
var rowEntries = row.entryList;
var rowImages = row.imageList;
var entryListLength = rowEntries.length;
row.entry = {};
for (var y = 0; y < entryListLength; y++) {
if (that.hasImage && rowImages && rowImages[y]) {
var image = "url(\"" + rowImages[y] + "\")";
row.entry["col" + y] = { text: rowEntries[y], width: refWidths[y], type: response.columnType[y], image: image };
} else {
row.entry["col" + y] = { text: rowEntries[y], width: refWidths[y], type: response.columnType[y] };
}
}
row.entryList = null;
}
response.data = response.rowList;
response.rowList = null;
response.referenceTexts = null;
response.uiQuery = null;
response.columnType = null;
// save the complete response to update later on scroll down
that._completeResponse = {};
SportsJS.Utilities.observableObjectAwareDeepCopy(response, that._completeResponse);
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:" + uniqueMarker + ":processResponse:e");
completeFn(response);
}
else {
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:" + uniqueMarker + ":processResponse:e");
errorFn(null);
}
});
};
if (isModuleBasicInfoRequired) {
if (moduleBasicInfoProvider && processModuleBasicInfo) {
moduleBasicInfoFetchPromise = that.moduleBasicInfo ? WinJS.Promise.wrap(that.moduleBasicInfo) : moduleBasicInfoProvider();
}
else {
SportsJS.Utilities.dataFetchErrorCallBack(complete);
return;
}
} else {
moduleBasicInfoFetchPromise = WinJS.Promise.wrap({ isValid: true });
processModuleBasicInfo = function (response) { return response.isValid && uiQuery; };
}
that._promiseStack(moduleBasicInfoFetchPromise).then(function (moduleBasicInfo) {
if (!moduleBasicInfo || !moduleBasicInfo.isValid) {
SportsJS.Utilities.dataFetchErrorCallBack(complete);
return;
}
if (!processModuleBasicInfo(moduleBasicInfo)) {
SportsJS.Utilities.dataFetchErrorCallBack(complete);
return;
}
uiQuery.bypassCache = bypassCache;
controller.requestV2(uiQuery).then(
function (res) {
if (that._canRejectCompleteResponse(res)) {
that._updateStalenessParameters(res);
promise.cancel();
return;
}
that._promiseStack(processSportsTableResponse(res)).then(function (response) {
if (response) {
complete({ response: response });
}
else {
SportsJS.Utilities.dataFetchErrorCallBack(complete);
}
}, function (errRes) {
// process response promise error handler.
if (SportsJS.Utilities.isCancellationError(errRes)) {
return;
}
SportsJS.Utilities.dataFetchErrorCallBack(complete);
});
}, function () { },
function (progressData) {
if (that.shouldHandleProgress === false || bypassCache || bypassProgress) {
return;
}
if (progressData) {
that._promiseStack(processSportsTableResponse(progressData.modelResponse)).then(function (response) {
if (response) {
progress({ response: response });
}
}, function (errRes) {
// can be ignored.. the error will be handled in the complete handler.
});
}
});
});
});
return promise;
},
rendererInfo: function rendererInfo(item) {
var that = this;
var fragmentPath = "/leagues/common/modules/SportsTableModule/SportsTableModule.html";
var templateId = "InnerListItemTemplateMedium";
if (item.data.status === "NoData") {
templateId = "sportsNoDataTemplate";
fragmentPath = "/html/templates.html";
} else if (that.hasImage) {
templateId = that.tableSize && that.tableSize === SportsJS.UI.TableSize.Medium ? "InnerListItemWithImageTemplateMedium" : "InnerListItemWithImageTemplate";
} else {
templateId = that.tableSize && that.tableSize === SportsJS.UI.TableSize.Medium ? "InnerListItemTemplateMedium" : "InnerListItemTemplate";
}
var moduleInfo = {
fragmentPath: fragmentPath,
templateId: templateId
};
var customRendererInfo = { data: item.data, moduleInfo: moduleInfo };
return customRendererInfo;
},
},
{
setBannerDisplay: WinJS.Binding.converter(function (bannerDisplay) {
if (bannerDisplay === false) {
return "none";
}
}),
setInteractive: WinJS.Binding.converter(function (isInteractive) {
if (isInteractive === true) {
return "InnerListTemplateLayout";
}
else {
return "InnerListTemplateLayout win-interactive";
}
}),
setTournamentInfoDisplay: WinJS.Binding.converter(function (value) {
if (!value) {
return "none";
}
return "";
}),
getEntityClass: function getEntityClass(type) {
var entityClass = "";
if (type) {
type = type.toLowerCase();
switch (type) {
case "number":
entityClass = "EntityNumber";
break;
case "position":
entityClass = "EntityPosition";
break;
case "playername":
entityClass = "EntityPlayerName";
break;
case "teamname":
entityClass = "EntityTeamName";
break;
case "date":
entityClass = "EntityDate";
break;
case "place":
entityClass = "EntityPlace";
break;
case "golftournamentname":
entityClass = "EntityGolfTournamentName";
break;
case "tournamentname":
entityClass = "EntityTournamentName";
break;
case "playersteam":
entityClass = "EntityPlayersTeam";
break;
case "timetaken":
entityClass = "EntityTimeTaken";
break;
case "defendingchampion":
entityClass = "EntityDefendingChampion";
break;
case "numberwithimage":
entityClass = "EntityNumberWithImage";
break;
case "entitywithimage":
entityClass = "EntityWithImage";
break;
case "playerrole":
entityClass = "EntityPlayerRole";
break;
default:
entityClass = "unknown";
break;
}
}
return entityClass;
},
_setEntityStyle: function _setEntityStyle(source, sourceProperty, dest, destProperty) {
var type = source[sourceProperty[0]][sourceProperty[1]][sourceProperty[2]];
dest[destProperty[0]] += " " + SportsJS.Common.Modules.SportsTableModuleControl.getEntityClass(type);
return dest[destProperty[0]];
},
setEntityStyle: {
get: function get() {
this._setEntityStyle.supportedForProcessing = true;
return SportsJS.Common.Modules.SportsTableModuleControl._setEntityStyle;
}
},
_setEntityHeaderStyle: function _setEntityHeaderStyle(source, sourceProperty, dest, destProperty) {
var type = source[sourceProperty[0]][sourceProperty[1]][sourceProperty[2]][sourceProperty[3]];
dest[destProperty[0]] += " " + SportsJS.Common.Modules.SportsTableModuleControl.getEntityClass(type);
return dest[destProperty[0]];
},
setEntityHeaderStyle: {
get: function get() {
this._setEntityHeaderStyle.supportedForProcessing = true;
return SportsJS.Common.Modules.SportsTableModuleControl._setEntityHeaderStyle;
}
},
_setImageDisplay: function _setImageDisplay(source, sourceProperty, dest, destProperty) {                
if (source[sourceProperty[0]] === true) {
dest[destProperty[0]] += " SportsTableWithImage";
}                
return dest[destProperty[0]];
},
setImageDisplay: {
get: function get() {
this._setImageDisplay.supportedForProcessing = true;
return SportsJS.Common.Modules.SportsTableModuleControl._setImageDisplay;
}
}
})
});
WinJS.Namespace.define("SportsJS.SportsTable.Utilities",
{
getStringsWidthInPixels: function getStringsWidthInPixels(stringClassName, referenceStrings) {
var stringWidthArray = [];
var dummyRefSpan = document.createElement("span");
dummyRefSpan.style.visibility = 'hidden';
dummyRefSpan.style.padding = '0px';
dummyRefSpan.style.margin = '0px';
dummyRefSpan.className = stringClassName;
document.body.appendChild(dummyRefSpan);
var count = referenceStrings.length;
for (var index = 0; index < count; index++) {
var stringWidth = 0;
var text = referenceStrings[index];
if (text) {
dummyRefSpan.innerText = text;
var dummySpanOffsetWidth = dummyRefSpan.offsetWidth;
if (dummySpanOffsetWidth) {
// if width is < 50px, then mostly it could be a number. Use 10px tolerence for number and 30px for rest (text)
stringWidth = dummySpanOffsetWidth + (dummySpanOffsetWidth < 50 ? 10 : 20);
}
}
stringWidthArray[index] = stringWidth + "px";
}
document.body.removeChild(dummyRefSpan);
return stringWidthArray;
},
fetchFormulaOneGameCodes: function fetchFormulaOneGameCodes() {
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:fetchF1GameCodes:s");
var promise = new WinJS.Promise(function (complete) {
var controller = AppEx.Sports.Services.SportsController();
var uiQuery = new AppEx.Sports.Services.TypeDefs.Request.GameCodesQuery($SpMgr.getLeagueString(Microsoft.AppEx.Sports.SportsEnums.League.formulaone));
controller.request(uiQuery).then(function (res) {
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:fetchF1GameCodes:e");
var basicResponse = res ? SportsJS.Utilities.nativeObjectToJsObject(res) : null;
if (basicResponse && basicResponse.isValid) {
complete(basicResponse);
}
else {
complete(null);
}
}, function (errRes) {
if (SportsJS.Utilities.isCancellationError(errRes)) {
return;
}
SportsJS.Utilities.sportsMsWriteProfilerMark("Sports:fetchF1GameCodes:e");
complete(null);
});
});
return promise;
}
});
})();