﻿(function () {
'use strict';
// Cluster specific functionality
WinJS.Namespace.define("SportsJS.Today.Clusters", {
TodayScheduleClusterControl: WinJS.Class.derive(SportsJS.UI.SportsCluster, function (element, options) {
var _options = options ? options : {};
_options.dataProvider = this.dataProvider;
SportsJS.UI.SportsCluster.call(this, element, _options);
}, {
constructUiQuery: function constructUiQuery() {
var that = this;
var maxGamesPerLeague = 50;
var leagueType = that.leagueType ? that.leagueType : "";
var currentDate = that.currentDate ? that.currentDate : "";
var leaguesList = SportsJS.Utilities.getUserLeagues();
var uiQuery = new AppEx.Sports.Services.TypeDefs.Request.TodayScheduleQuery(leagueType, currentDate, leaguesList, maxGamesPerLeague);
if (!uiQuery || !uiQuery.isValid) {
return null;
}
return uiQuery;
},
getModuleConfigs: function getModuleConfigs(clusterResponse) {
var configs = [];
var basicInfoPromise = new WinJS.Promise(function (complete) {
if (!clusterResponse || !clusterResponse.moduleList) {
// TODO: chthakur -> ashokjul
// Not sure why we need TodaySchedule module in this case. We should have an empty module specifically for this purpose
// chthakur -> provider support in vnext
var moduleConfig = SportsJS.Modules.Configs.Today.TodaySchedule({ league: "NoGame" });
configs.push(moduleConfig);
} else {
for (var i = 0; i < clusterResponse.moduleList.length; i++) {
var league = clusterResponse.moduleList[i];
var leagueScheduleModuleConfig = SportsJS.Modules.Configs.Today.TodaySchedule({ league: league });
configs.push(leagueScheduleModuleConfig);
}
}
configs = WinJS.Promise.wrap(configs);
complete(configs);
});
return basicInfoPromise;
},
dataProvider: function dataProvider(bypassCache, bypassProgress) {
var that = this;
var maxGamesPerLeague = 50;
var promise = new WinJS.Promise(function (complete, error, progress) {
var leagueType = that.leagueType ? that.leagueType : "";
var currentDate = that.currentDate ? that.currentDate : "";
if (that.leagueType === "" || that.currentDate === "") {
return SportsJS.Utilities.fallbackResponsePromise();
}
var leaguesList = [];
leaguesList = SportsJS.Utilities.getUserLeagues();
var controller = SportsJS.mainProcessManager.scheduleController;
var uiQuery = that.constructUiQuery();
if (!uiQuery) {
return SportsJS.Utilities.fallbackResponsePromise();
}
var cacheID = AppEx.Sports.Services.SportsController.getCacheId(uiQuery);
var processResponse = function (responseData) {
if (!responseData || !responseData.dataObject || !responseData.dataObject.isValid) {
return null;
}
var response = SportsJS.Utilities.nativeObjectToJsObject(responseData.dataObject);
response.cacheID = cacheID;
response.etag = responseData.etag;
if (response.noGameToday) {
response.data = {};
response.data["NoGame"] = [{ status: "NoGame", fragmentPath: that.fragmentPath, league: SportsJS.UI.LeagueType.today, leagueLogo: "", leagueDisplayText: PlatformJS.Services.resourceLoader.getString(SportsJS.UI.LeagueType.today) }];
}
else if (response.todaySchedule && response.todaySchedule.length > 0) {
var todaySchedule = response.todaySchedule;
for (var k = 0; k < todaySchedule.length; k++) {
todaySchedule[k].fragmentPath = that.fragmentPath;
}
response.data = {};
response.moduleList = [];
for (var i = 0; i < todaySchedule.length; i++) {
if (todaySchedule[i].league) {
if (!response.data[todaySchedule[i].league]) {
response.data[todaySchedule[i].league] = [];
response.moduleList.push(todaySchedule[i].league);
}
response.data[todaySchedule[i].league].push(todaySchedule[i]);
}
}
if (!SportsJS.Utilities.checkScheduleDataRefreshValidity(response, that.providerResponse, response.data, that.dataSource)) {
return null;
}
}
if (!response.data) {
return null;
}
response.todaySchedule = null;
return response;
};
uiQuery.bypassCache = bypassCache;
//// Create a request for LKG schedule Date Response
var lkgScheduleDateResponsePromise = null;
var lkgScheduleDate = SportsJS.Utilities.getLKGScheduleDate(leagueType);
if (lkgScheduleDate && lkgScheduleDate !== currentDate) {
lkgScheduleDateResponsePromise = new WinJS.Promise(function (completeFn) {
var lkgScheduleUiQuery = new AppEx.Sports.Services.TypeDefs.Request.TodayScheduleQuery(leagueType, lkgScheduleDate, leaguesList, maxGamesPerLeague);
controller.request(lkgScheduleUiQuery).then(function (res) {
//// Dont want to do anything here as we would get data in progress handler
}, function () {
}, function (progressRes) {
var etag = progressRes && progressRes.cachedResponse ? progressRes.cachedResponse.responseId : null;
var response = processResponse({ dataObject: progressRes.modelResponse, etag: etag });
if (response) {
//// We should not inline refresh using lkgScheduleDateResponse
response.nextRefreshInterval = -1;
completeFn(response);
}
});
});
}
controller.request(uiQuery).then(function (responseData) {
// can't support requestV2 in today schedule as it uses different controller. Alternatively made changes here to adhere to correct interfaces for 
// canRejectCompleteResponse, Staleness parameters etc. chthakur -> migrate to requestV2 for December
if (responseData && responseData.dataObject && that._canRejectCompleteResponse({ etag: responseData.responseId, lastUpdateTime: responseData.lastUpdateTime, cacheID: cacheID, isValid: responseData.dataObject.isValid })) {
that._updateStalenessParameters(responseData.dataObject);
promise.cancel();
return;
}
var response = processResponse({ dataObject: responseData.dataObject, etag: responseData.responseId });
if (response) {
SportsJS.Utilities.setLKGScheduleDate(currentDate, leagueType);
complete({ response: response });
}
else {
//// Before showing error, we want to see if we have lkgScheduleDateResponse.
//// We will have lkgScheduleDateResponse only when the lkgScheduleDate is not same as currentDate.
//// If they are same, the responses woould be same, so no use
//// This would never take us back in time since the lkgScheduleDate is set as soon as schedule for a particular date is rendered
if (lkgScheduleDateResponsePromise) {
lkgScheduleDateResponsePromise.then(function (resp) {
complete({ response: resp });
});
}
else {
SportsJS.Utilities.dataFetchErrorCallBack(complete);
}
}
}, function () { },
function (progressData) {
if (that.shouldHandleProgress === false || bypassCache || bypassProgress || !progressData) {
return;
}
var etag = progressData && progressData.cachedResponse ? progressData.cachedResponse.responseId : null;
var response = processResponse({ dataObject: progressData.modelResponse, etag: etag });
if (response) {
SportsJS.Utilities.setLKGScheduleDate(currentDate, leagueType);
progress({ response: response });
}
});
});
return promise;
}
})
});
})();