﻿(function () {
'use strict';
/// <summary>
/// Sports App Settings namespace.
/// </summary>
WinJS.Namespace.define("SportsJS.Settings", {
/// <summary>
/// Initializes the application server setting
/// </summary>
_initApplicationServerSetting: function _initApplicationServerSetting() {
var envName = SportsJS.Settings.applicationServerEnvironment;
var environmentElem = document.getElementById('applicationServerList');
if (!this._environments || !environmentElem || !environmentElem.children || environmentElem.children.length !== this._environments.length) {
return;
}
var envIndex = this._environments.indexOf(envName);
if (envIndex && envIndex.index !== -1 && environmentElem.children[envIndex.index]) {
environmentElem.children[envIndex.index].selected = true;
}
},
/// <summary>
/// Initializes the auto refresh setting
/// </summary>
_initAutoRefereshSetting: function _initAutoRefereshSetting() {
var isAutoRefreshEnabled = SportsJS.Settings.autoRefreshEnabled;
var autoRefreshElem = document.getElementById('autoRefreshSwitch');
if (!autoRefreshElem || !autoRefreshElem.winControl) {
return;
}
autoRefreshElem.winControl.checked = isAutoRefreshEnabled;
var refreshIntervalIndex = SportsJS.Settings.autoRefreshIntervalIndex;
var intervalElem = document.getElementById('intervalList');
if (intervalElem && intervalElem.children && intervalElem.children.length > 0 && intervalElem.children[refreshIntervalIndex]) {
intervalElem.children[refreshIntervalIndex].selected = true;
intervalElem.disabled = !isAutoRefreshEnabled;
}
},
/// <summary>
/// Initializes the auto update setting
/// </summary>
_initAutoUpdateSetting: function _initAutoUpdateSetting() {
var autoUpdateElem = document.getElementById('autoUpdateSwitch');
if (autoUpdateElem && autoUpdateElem.winControl) {
autoUpdateElem.winControl.checked = SportsJS.Settings.autoUpdateEnabled;
}
},
/// <summary>
/// Initializes the auto update setting
/// </summary>
_initSearchHistorySetting: function _initSearchHistorySetting() {
var searchHistoryElem = document.getElementById('searchHistorySwitch');
if (searchHistoryElem && searchHistoryElem.winControl) {
searchHistoryElem.winControl.checked = SportsJS.Settings.searchHistoryEnabled;
}
},
/// <summary>
/// Property that stores the app version
/// </summary>
_appVersion: "",
/// <summary>
/// list of intervals to be shown in the interval list box.
/// TODO: finalize the list of intervals
/// </summary>
_refreshIntervals: [],
/// <summary>
/// list of environments which can be used to get an answer
/// </summary>
_environments: [],
/// <summary>
/// stores listners that need to be invoked for registered setting change
/// </summary>
_settingChangeListeners: {},
addSettingChangeEventListener: function addSettingChangeEventListener(settingType, listener) {
if (this._isValidSettingType(settingType)) {
if (!this._settingChangeListeners[settingType]) {
this._settingChangeListeners[settingType] = [];
}
this._settingChangeListeners[settingType].push(listener);
}
},
removeSettingChangeEventListener: function removeSettingChangeEventListener(settingType, listener) {
if (this._isValidSettingType(settingType) && this._settingChangeListeners[settingType]) {
var listeners = this._settingChangeListeners[settingType];
for (var i = 0, listLength = listeners.length; i < listLength; i++) {
if (listeners[i] === listener) {
listeners.splice(i, 1);
break;
}
}
}
},
_triggerSettingChangeEvent: function _triggerSettingChangeEvent(settingType) {
if (this._settingChangeListeners[settingType]) {
var listeners = this._settingChangeListeners[settingType];
for (var i = 0, listLength = listeners.length; i < listLength; i++) {
var event = {
settingType: settingType,
value: this.readSetting(settingType)
};
listeners[i].call(this, event);
}
}
},
/// <summary>
/// Function to validate a setting type
/// </summary>
_isValidSettingType: function _isValidSettingType(type) {
if (type && typeof type === "number") {
return SportsJS.SettingsManager.isValidSettingType(type);
}
return false;
},
/// <summary>
/// Function 1) to validate a setting value once the value is read
///          2) to validate a setting value before the value is written
/// </summary>
_isValidSettingValue: function _isValidSettingValue(type, value) {
switch (type) {
case SportsJS.SettingsType.autoRefresh:
case SportsJS.SettingsType.autoUpdate:
case SportsJS.SettingsType.searchHistory:
if (typeof value === "boolean") {
return true;
}
break;
case SportsJS.SettingsType.autoRefreshInterval:
if (typeof value === "number" && value >= 0 && value < this._refreshIntervals.length) {
return true;
}
break;
case SportsJS.SettingsType.applicationServerEnvironment:
if (typeof value !== "string") {
return false;
}
for (var kk = 0; kk < this._environments.length; kk++) {
var envName = this._environments[kk];
if (envName === value) {
return true;
}
}
break;
}
return false;
},
/// <summary>
/// Brings up the app settings flyout
/// </summary>
onSettingsCmd: function onSettingsCmd(ev) {
SportsJS.Settings._initAutoRefereshSetting();
//SportsJS.Settings._initAutoUpdateSetting();
//SportsJS.Settings._initSearchHistorySetting();
if (!!$SpMgr.enableEnvDropDown) {
SportsJS.Settings._initApplicationServerSetting();
}
var settingsdiv = document.querySelector('#SportsSettingsPage');
WinJS.UI.processAll(settingsdiv).then(function () {
WinJS.Resources.processAll(settingsdiv).then(function () {
if (settingsdiv.winControl) {
settingsdiv.winControl.show();
}
});
});
},
/// <summary>
/// Brings up the about flyout
/// </summary>
onAboutCmd: function onAboutCmd(event) {
var aboutdiv = document.querySelector('#SportsAboutPage');
WinJS.UI.processAll(aboutdiv).then(function () {
WinJS.Resources.processAll(aboutdiv).then(function () {
if (aboutdiv.winControl) {
aboutdiv.winControl.show();
}
});
});
},
/// <summary>
/// Enable/Disable the the league
/// </summary>
onLeagueSettingChange: function onLeagueSettingChange(event) {
var toggleControl = PlatformJS.Utilities.getControl(event.currentTarget);
if (toggleControl && (toggleControl.checked === true || toggleControl.checked === false)) {
var leagueType = toggleControl.leagueType;
if (SportsJS.Utilities.isValidLeagueType(leagueType)) {
//TODO(chthakur) - no error behavior, check with PM
if (toggleControl.checked === false) {
SportsJS.Services.Roaming.RoamingDataManager.tryRemoveFromCollection(SportsJS.UI.SportsEntityCollectionType.MyLeagues.name, leagueType);
SportsJS.Telemetry.leagueChange(leagueType, SportsJS.Telemetry.ActionType.remove);
}
else if (toggleControl.checked === true) {
SportsJS.Services.Roaming.RoamingDataManager.tryAddToCollection(SportsJS.UI.SportsEntityCollectionType.MyLeagues.name, leagueType);
SportsJS.Telemetry.leagueChange(leagueType, SportsJS.Telemetry.ActionType.add);
}
}
} else {
event.preventDefault();
}
},
/// <summary>
/// Pushes the setting commands specific to app into the application commands vector.
/// </summary>
onCommandsRequested: function onCommandsRequested(event) {
SportsJS.Settings.initializeSettingsUI();
var appSettings = Windows.UI.ApplicationSettings;
var vector = event.request.applicationCommands;
// Add app settings command to the settings charm
var settingsCmd = new appSettings.SettingsCommand("SettingsPage", PlatformJS.Services.resourceLoader.getString("/platform/optionsTitle"), SportsJS.Settings.onSettingsCmd);
vector.append(settingsCmd);
// Add app About command to the settings charm
var aboutCmd = new appSettings.SettingsCommand("AboutPage", PlatformJS.Services.resourceLoader.getString("AboutPageTitle"), SportsJS.Settings.onAboutCmd);
vector.append(aboutCmd);
//Add the default buttons for all apps
CommonJS.Settings.addCommonButtons(vector);
},
/// <summary>
/// Enable/Disable the auto refresh setting
/// </summary>
_onAutoRefereshSettingChange: function _onAutoRefereshSettingChange(event) {
var toggleControl = PlatformJS.Utilities.getControl(event.currentTarget);
if (toggleControl && (toggleControl.checked === true || toggleControl.checked === false)) {
SportsJS.Settings.autoRefreshEnabled = toggleControl.checked;
var intervalElem = document.getElementById('intervalList');
intervalElem.disabled = !toggleControl.checked;
} else {
event.preventDefault();
}
},
onAutoRefereshSettingChange: {
get: function get() {
this._onAutoRefereshSettingChange.supportedForProcessing = true;
return this._onAutoRefereshSettingChange;
}
},
/// <summary>
/// Enable/Disable the auto refresh setting
/// </summary>
_onAutoRefereshIntervalChange: function _onAutoRefereshIntervalChange(value) {
var interval = parseInt(value, 10);
SportsJS.Settings.autoRefreshIntervalIndex = interval;
},
onAutoRefereshIntervalChange: {
get: function get() {
this._onAutoRefereshIntervalChange.supportedForProcessing = true;
return this._onAutoRefereshIntervalChange;
}
},
/// <summary>
/// Enable/Disable the auto update
/// </summary>
onAutoUpdateSettingChange: function onAutoUpdateSettingChange(event) {
var toggleControl = PlatformJS.Utilities.getControl(event.currentTarget);
if (toggleControl && (toggleControl.checked === true || toggleControl.checked === false)) {
SportsJS.Settings.autoUpdateEnabled = toggleControl.checked;
} else {
event.preventDefault();
}
},
/// <summary>
/// Enable/Disable the cms preview setting
/// </summary>
_onCmsPreviewSettingChange: function _onCmsPreviewSettingChange(event) {
var toggleControl = PlatformJS.Utilities.getControl(event.currentTarget);
if (toggleControl && (toggleControl.checked === true || toggleControl.checked === false)) {
SportsJS.Settings._cmsPreviewEnabled = toggleControl.checked;
} else {
event.preventDefault();
}
},
/// <summary>
/// Enable/Disable the cms preview setting
/// </summary>
onCmsPreviewSettingChange: {
get: function get() {
SportsJS.Settings._onCmsPreviewSettingChange.supportedForProcessing = true;
return SportsJS.Settings._onCmsPreviewSettingChange;
}
},
/// <summary>
/// Enable/Disable recent searches to be shown in the search pane
/// </summary>
onSearchHistorySettingChange: function onSearchHistorySettingChange(event) {
var toggleControl = PlatformJS.Utilities.getControl(event.currentTarget);
if (toggleControl && (toggleControl.checked === true || toggleControl.checked === false)) {
SportsJS.Settings.searchHistoryEnabled = toggleControl.checked;
} else {
event.preventDefault();
}
},
/// <summary>
/// Change environment to use to get data from backend
/// </summary>
_onApplicationServerEnvironmentChange: function _onApplicationServerEnvironmentChange(value) {
var envValue = parseInt(value);
SportsJS.Settings.applicationServerEnvironment = envValue;
},
onApplicationServerEnvironmentChange: {
get: function get() {
this._onApplicationServerEnvironmentChange.supportedForProcessing = true;
return this._onApplicationServerEnvironmentChange;
}
},
/// <summary>
/// onClick event handler of back button
/// </summary>
onBackButtonClick: function onBackButtonClick(event) {
WinJS.UI.SettingsFlyout.show();
},
appVersion: {
get: function get(value) {
if (!SportsJS.Settings._appVersion) {
var version = Windows.ApplicationModel.Package.current.id.version;
var versionString = PlatformJS.Services.resourceLoader.getString("/platform/appVersion").format(version.major + "." + version.minor + "." + version.build + "." + version.revision);
SportsJS.Settings._appVersion = versionString;
}
return SportsJS.Settings._appVersion;
}
},
autoRefreshEnabled: {
set: function set(value) {
this.updateSetting(SportsJS.SettingsType.autoRefresh, value);
},
get: function get(value) {
return this.readSetting(SportsJS.SettingsType.autoRefresh);
}
},
autoRefreshIntervalIndex: {
set: function set(value) {
this.updateSetting(SportsJS.SettingsType.autoRefreshInterval, value);
},
get: function get(value) {
return this.readSetting(SportsJS.SettingsType.autoRefreshInterval);
}
},
autoUpdateEnabled: {
set: function set(value) {
this.updateSetting(SportsJS.SettingsType.autoUpdate, value);
},
get: function get(value) {
return this.readSetting(SportsJS.SettingsType.autoUpdate);
}
},
_cmsPreviewEnabled: {
set: function set(value) {
SportsJS.mainProcessManager.cmsPreviewEnabled = value;
},
get: function get(value) {
return SportsJS.mainProcessManager.cmsPreviewEnabled;
}
},
searchHistoryEnabled: {
set: function set(value) {
this.updateSetting(SportsJS.SettingsType.searchHistory, value);
},
get: function get(value) {
return this.readSetting(SportsJS.SettingsType.searchHistory);
}
},
applicationServerEnvironment: {
set: function set(value) {
if (this._environments) {
var serverEnv = this._environments[value];
this.updateSetting(SportsJS.SettingsType.applicationServerEnvironment, serverEnv);
}
},
get: function get(value) {
return this.readSetting(SportsJS.SettingsType.applicationServerEnvironment);
}
},
updateSetting: function updateSetting(type, value) {
var that = this;
if (that._isValidSettingValue(type, value)) {
if (!SportsJS.SettingsManager.tryWriteSetting(type, value)) {
var failMessage = "Failed to set settingType-" + type + " setting";
SportsJS.Utilities.trace(this, "SportsJS.Settings.updateSetting:", failMessage);
//TODO: throw setting change failed exception
} else {
that._triggerSettingChangeEvent(type);
}
} else {
var invalidMessage = "Invalid Value: settingType-" + type + " change is ignored";
SportsJS.Utilities.trace(this, "SportsJS.Settings.updateSetting:", invalidMessage);
// TODO: throw invalid setting value exception
}
},
readSetting: function readSetting(type) {
var res = SportsJS.SettingsManager.tryReadSetting(type);
return res.settingValue;
},
_isInitialized: false,
initializeSettingsUI: function initializeSettingsUI() {
if (this._isInitialized) {
return;
}
var that = this;
var settingRootElem = document.getElementById("SportsSettingsUI");
var currentDate = new Date();
var stringFormat = SportsJS.Utilities.stringFormat;
var resourceLoader = PlatformJS.Services.resourceLoader;
var statsCopyrightInfo = stringFormat(resourceLoader.getString("StatsAttributionCopyright"), currentDate.getFullYear());
var playerHeadShotFormatString = resourceLoader.getString("PlayerHeadShotAttribution");
var leagueType = Microsoft.AppEx.Sports.SportsEnums.League;
var providerAP = SportsJS.UI.providers.AP;
var providerGetty = SportsJS.UI.providers.Getty;
var providersList = stringFormat(resourceLoader.getString("TwoCommaSeperatedEntities"), providerAP, providerGetty);
var nfl = SportsJS.Utilities.getLocLeagueDisplayText($SpMgr.enumStrings.LeagueType[leagueType.nfl]);
var nba = SportsJS.Utilities.getLocLeagueDisplayText($SpMgr.enumStrings.LeagueType[leagueType.nba]);
var mlb = SportsJS.Utilities.getLocLeagueDisplayText($SpMgr.enumStrings.LeagueType[leagueType.mlb]);
var nhl = SportsJS.Utilities.getLocLeagueDisplayText($SpMgr.enumStrings.LeagueType[leagueType.nhl]);
var attribution0 = stringFormat(playerHeadShotFormatString, nfl, providerAP);
var attribution1 = stringFormat(playerHeadShotFormatString, mlb, providersList);
var attribution2 = stringFormat(playerHeadShotFormatString, nhl, providerGetty);
var attribution3 = stringFormat(playerHeadShotFormatString, nba, providerGetty);
var pageData = {
statsCopyRightInfo: statsCopyrightInfo,
appVersion: SportsJS.Settings.appVersion,
navigationHandler: SportsJS.Settings.onBackButtonClick,
//TODO: Extensibility(chthakur)
attribution0: attribution0,
attribution1: attribution1,
attribution2: attribution2,
attribution3: attribution3,
};
CommonJS.loadModule({ fragmentPath: "/settings/SportsSettingsTemplates.html", templateId: "settingPage" }, pageData, null, null, null).then(function (settingPage) {
settingRootElem.appendChild(settingPage);
var intervalElem = document.getElementById('intervalList');
var res = SportsJS.SettingsManager.tryGetIntervalList();
if (res.value && res.interval && intervalElem) {
that._refreshIntervals = res.interval;
var refreshLength = that._refreshIntervals.length;
for (var i = 0; i < refreshLength; i++) {
var refreshOptionElem = document.createElement("option");
refreshOptionElem.value = i;
refreshOptionElem.innerText = that._refreshIntervals[i] + " " + PlatformJS.Services.resourceLoader.getString("SettingsIntervalUnit");
intervalElem.appendChild(refreshOptionElem);
}
} else {
var refreshMessage = "CRITICAL: Failed to get list of refresh intervals";
SportsJS.Utilities.trace(this, "SportsJS.Settings.initializeSettingsUI:", refreshMessage);
}
var applicationServerListElem = document.getElementById('applicationServerList');
that._environments = SportsJS.SettingsManager.tryGetEnvironmentsList();
if (applicationServerListElem && that._environments && that._environments.length > 0) {
var envLength = that._environments.length;
for (var j = 0; j < envLength; j++) {
var envOptionElem = document.createElement("option");
envOptionElem.value = j;
envOptionElem.innerText = that._environments[j];
applicationServerListElem.appendChild(envOptionElem);
}
} else {
var envMessage = "CRITICAL: Failed to get list of environments";
SportsJS.Utilities.trace(this, "SportsJS.Settings.initializeSettingsUI:", envMessage);
}
if (!$SpMgr.enableEnvDropDown) {
var applicationSectionDivs = WinJS.Utilities.query(".applicationServerSection", settingPage);
if (applicationSectionDivs && applicationSectionDivs.length > 0) {
var applicationSectionDiv = applicationSectionDivs[0];
applicationSectionDiv.style.visibility = "hidden";
}
}
if (!PlatformJS.isDebug) {
var cmspreviewSettingsContent = WinJS.Utilities.query(".cmspreviewSettingsContent", settingPage);
if (cmspreviewSettingsContent && cmspreviewSettingsContent.length > 0) {
var cmspreviewSettingsContentDiv = cmspreviewSettingsContent[0];
cmspreviewSettingsContentDiv.style.display = "none";
}
}
}, function (error) {
var message = "Failed to load settingPage fragment from /settings/SportsSettingsTemplates.html";
SportsJS.Utilities.trace(this, "SportsJS.Settings.initializeSettingsUI:", message);
});
CommonJS.loadModule({ fragmentPath: "/settings/SportsSettingsTemplates.html", templateId: "aboutPage" }, pageData, null, null, null).then(function (aboutPage) {
settingRootElem.appendChild(aboutPage);
}, function (error) {
var message = "Failed to load aboutPage fragment from /settings/SportsSettingsTemplates.html";
SportsJS.Utilities.trace(this, "SportsJS.Settings.initializeSettingsUI:", message);
});
this._isInitialized = true;
},
reInitializeSettingsUI: function reInitializeSettingsUI() {
var that = this;
var settingRootElem = document.getElementById("SportsSettingsUI");
if (!settingRootElem) {
return;
}
settingRootElem.innerHTML = "";
that._isInitialized = false;
that.initializeSettingsUI();
}
});
})();
